!******************************************************************************!
!                                                                              !
!    class_vertices.f90                                                        !
!    is part of RECOLA2 (REcursive Computation of One Loop Amplitudes)2        !
!                                                                              !
!    Copyright (C) 2016-2018 Ansgar Denner, Jean-Nicolas Lang and              !
!                            Sandro Uccirati                                   !
!                                                                              !
!    RECOLA2 is licenced under the GNU GPL version 3,                          !
!    see COPYING for details.                                                  !
!                                                                              !
!******************************************************************************!
!                                                           .---.              !
!                                                          /  .  \             !
!                                                         |\_/|   |            !
!                                                         |   |  /|            !
!          .----------------------------------------------------' |            !
!         /  .-.   class_vertices.f90                             |            !
!        |  /   \  This code was generated with REPT1L.           |            !
!        | |\_.  | Change this file and you get what you deserve. |            !
!        |\|  | /| Author: J.N. Lang                              |            !
!        | `---' | UFO date: 07/2017                              |            !
!        |       | UFO version: 1.0                               |            !
!        |       | Generation date: 2018-10-11 10:57             /             !
!        |       |----------------------------------------------'              !
!        \       |                                                             !
!         \     /                                                              !
!          `---'                                                               !
!******************************************************************************!
module class_vertices
  use fill_couplings
  use class_particles
  use class_ctparameters
  use fill_ctparameters, only: init_CTparameters_mdl
  use particle_keys, only: createParticleConfig
  use dictionary, only: dict,dict_get_value,dict_init
  use constants_mdl, only: Nc
  implicit none
  save

  interface get_vertex_mdl
    module procedure get_vertex3_mdl, get_vertex4_mdl, get_vertexN_mdl
  end interface

  type Branch
    integer :: lorentz_id
    integer :: perm
    integer, allocatable :: couplings(:)
    integer, dimension(n_orders) :: coupling_order
    integer :: color_id
    integer :: colorfac_id
    ! Propagator extension (only supported for massive vectors)
    ! 0: Usual propagator
    ! 1: Rxi-propagator part with pole @ M_V^2
    ! 2: Rxi-propagator part with pole @ \xi*M_V^2
    integer :: pext
  end type

  type Vertex
    type(Branch), allocatable :: branch(:)
    type(Branch), allocatable :: branchCT(:)
    type(Branch), allocatable :: branchR2(:)
  end type

  logical :: vertices_init = .false.
  logical :: vertices_filled = .false.
    interface createCurrent
      module procedure createCurrent2, createCurrent3, createCurrent4,         &
      createCurrent5, createCurrent6, createCurrent7, createCurrent8
    end interface 
  integer, parameter :: n_vertices = 3880
  type(Vertex) :: vertices(0:n_vertices-1)

  ! Defines the maximum allowed number of legs participating at a vertex
  integer, parameter :: max_leg_multiplicity = 4

  integer, parameter :: FFaS0 = 1
  integer, parameter :: FFaS1 = 2
  integer, parameter :: FFaS2 = 3
  integer, parameter :: VFaF0 = 4
  integer, parameter :: VFaF1 = 5
  integer, parameter :: SVVS0 = 6
  integer, parameter :: VVVV0 = 7
  integer, parameter :: UUaS0 = 8
  integer, parameter :: UUaV0 = 9
  integer, parameter :: SUUa0 = 10
  integer, parameter :: VVSS0 = 11
  integer, parameter :: FaF0 = 12
  integer, parameter :: FaF1 = 13
  integer, parameter :: FaF2 = 14
  integer, parameter :: FFaV0 = 15
  integer, parameter :: FFaV1 = 16
  integer, parameter :: VVV0 = 17
  integer, parameter :: FSFa0 = 18
  integer, parameter :: FSFa1 = 19
  integer, parameter :: FSFa2 = 20
  integer, parameter :: VVS0 = 21
  integer, parameter :: VUaU0 = 22
  integer, parameter :: FaVF0 = 23
  integer, parameter :: FaVF1 = 24
  integer, parameter :: UaVU0 = 25
  integer, parameter :: VSVS0 = 26
  integer, parameter :: FVFa0 = 27
  integer, parameter :: FVFa1 = 28
  integer, parameter :: UaSU0 = 29
  integer, parameter :: USUa0 = 30
  integer, parameter :: VV0 = 31
  integer, parameter :: VV1 = 32
  integer, parameter :: VV2 = 33
  integer, parameter :: VV3 = 34
  integer, parameter :: SVSV0 = 35
  integer, parameter :: FaFS0 = 36
  integer, parameter :: FaFS1 = 37
  integer, parameter :: FaFS2 = 38
  integer, parameter :: FaFV0 = 39
  integer, parameter :: FaFV1 = 40
  integer, parameter :: SSSS0 = 41
  integer, parameter :: VS0 = 42
  integer, parameter :: VS1 = 43
  integer, parameter :: SFFa0 = 44
  integer, parameter :: SFFa1 = 45
  integer, parameter :: SFFa2 = 46
  integer, parameter :: VUUa0 = 47
  integer, parameter :: SFaF0 = 48
  integer, parameter :: SFaF1 = 49
  integer, parameter :: SFaF2 = 50
  integer, parameter :: SVV0 = 51
  integer, parameter :: FaSF0 = 52
  integer, parameter :: FaSF1 = 53
  integer, parameter :: FaSF2 = 54
  integer, parameter :: SVS0 = 55
  integer, parameter :: FFa0 = 56
  integer, parameter :: FFa1 = 57
  integer, parameter :: FFa2 = 58
  integer, parameter :: VSS0 = 59
  integer, parameter :: VSV0 = 60
  integer, parameter :: SS0 = 61
  integer, parameter :: SS1 = 62
  integer, parameter :: SS2 = 63
  integer, parameter :: SS3 = 64
  integer, parameter :: SS4 = 65
  integer, parameter :: SS5 = 66
  integer, parameter :: SSVV0 = 67
  integer, parameter :: SSV0 = 68
  integer, parameter :: SV0 = 69
  integer, parameter :: SV1 = 70
  integer, parameter :: SSS0 = 71
  integer, parameter :: UVUa0 = 72
  integer, parameter :: VSSV0 = 73
  integer, parameter :: UaUS0 = 74
  integer, parameter :: VFFa0 = 75
  integer, parameter :: VFFa1 = 76
  integer, parameter :: SUaU0 = 77
  integer, parameter :: UaUV0 = 78
  complex(dp), parameter :: c1 = cmplx(1d0, 0d0, kind=dp)
  character(len=20), parameter :: c1f = "1"
  complex(dp), parameter :: c2 = cmplx(sq2/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c2f = "sq2/2"
  complex(dp), parameter :: c3 = cmplx(-sq2/(2d0*Nc), 0d0, kind=dp)
  character(len=20), parameter :: c3f = "-sq2/(2*Nc)"
  complex(dp), parameter :: c4 = cmplx(-1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c4f = "-1/2"
  complex(dp), parameter :: c5 = cmplx(1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c5f = "1/2"
  complex(dp), parameter :: c6 = cmplx(0d0, sq2/2d0, kind=dp)
  character(len=20), parameter :: c6f = "i_*sq2/2"
  complex(dp), parameter :: c7 = cmplx(0d0, -sq2/2d0, kind=dp)
  character(len=20), parameter :: c7f = "-i_*sq2/2"
  complex(dp), parameter :: c8 = cmplx(-1d0/Nc, 0d0, kind=dp)
  character(len=20), parameter :: c8f = "-1/Nc"
  complex(dp), dimension(1:8) :: colorcoeffs = (/c1, c2, c3, c4, c5, c6, c7, c8&
                                               /)
  character(len=20), dimension(1:8) :: colorcoeffs_form = (/c1f, c2f, c3f, c4f &
                 , c5f, c6f, c7f, c8f/)
  integer, dimension(1:78) :: lorentz_rank = (/0, 0, 0, 1, 1, 0, 0, 0, 1, 0, 0 &
                                             , -1, -1, -1, 0, 0, 1, 1, 1, 1, 0 &
                                             , 1, 1, 1, 1, 0, 1, 1, 0, 0, -1, -&
                                             1, -1, -1, 0, 0, 0, 0, 0, 0, 0, -1&
                                             , -1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1&
                                             , 1, 1, -1, -1, -1, 1, 0, -1, -1  &
                                             , -1, -1, -1, -1, 0, 1, -1, -1, 0 &
                                             , 1, 0, 0, 1, 1, 0, 1/)
  integer, dimension(1:78) :: recola_base = (/5, 7, 9, 58, 53, -2, -11, 1, 161 &
                                            , 1, -4, 0, 0, 0, 15, 17, 12, 21,  &
                                            27, 25, 2, 162, 51, 57, 166, -3, 31&
                                            , 35, 1, 1, 0, 0, 0, 0, -14, 6, 10 &
                                            , 8, 18, 16, -1, 0, 0, 23, 28, 26, &
                                            163, 43, 48, 46, 13, 41, 45, 47, 3 &
                                            , 0, 0, 0, 4, 14, 0, 0, 0, 0, 0, 0 &
                                            , -12, 11, 0, 0, 1, 165, -13, 1, 36&
                                            , 33, 1, 164/)
  integer, dimension(1:78) :: propagator_extension = (/0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0/)
  character(len=*), parameter :: model_timestamp = "Thu Oct 11 10:42:55 2018"

  contains
    function get_timestamp_mdl() result(ret_timestamp)
      character(len=len(model_timestamp)) :: ret_timestamp
      ret_timestamp = model_timestamp
    end function get_timestamp_mdl

    function get_lorentz_rank_mdl(l_id) result(ret_lorentz_rank)
      integer, intent(in) :: l_id
      integer :: ret_lorentz_rank
      ret_lorentz_rank = lorentz_rank(l_id)
    end function get_lorentz_rank_mdl

    function get_propagator_extension_mdl(l_id) result(ret_pext)
      integer, intent(in) :: l_id
      integer :: ret_pext
      ret_pext = propagator_extension(l_id)
    end function get_propagator_extension_mdl

    function get_max_leg_multiplicity_mdl() result(ret_max_leg_multiplicity)
      integer :: ret_max_leg_multiplicity
      ret_max_leg_multiplicity = max_leg_multiplicity
    end function get_max_leg_multiplicity_mdl

    function is_model_init_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_init
    end function is_model_init_mdl

    function is_model_filled_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_filled
    end function is_model_filled_mdl

    subroutine get_vertex3_mdl(p1, p2, p3, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertex3_mdl

    subroutine get_vertex4_mdl(p1, p2, p3, p4, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3, p4
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, p4, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if
    end subroutine get_vertex4_mdl

    subroutine get_vertexN_mdl(particles, particleOut, vertex_ret)
      integer, intent(out)              :: vertex_ret
      integer, dimension(:), intent(in) :: particles
      integer, intent(in)               :: particleOut
      integer(kind=8)                   :: config
      integer                           :: address
      logical                           :: found_vertex

      call createParticleConfig(particles, particleOut, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertexN_mdl

    subroutine av(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branch(bid)%color_id = cid
      vertices(vid)%branch(bid)%colorfac_id = cfid
      vertices(vid)%branch(bid)%pext = pext
      vertices(vid)%branch(bid)%lorentz_id = lid
      vertices(vid)%branch(bid)%perm = perm
      vertices(vid)%branch(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branch(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branch(bid)%couplings(i) = cop(i)
      end do
    end subroutine av

    subroutine avCT(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchCT(bid)%color_id = cid
      vertices(vid)%branchCT(bid)%colorfac_id = cfid
      vertices(vid)%branchCT(bid)%pext = pext
      vertices(vid)%branchCT(bid)%lorentz_id = lid
      vertices(vid)%branchCT(bid)%perm = perm
      vertices(vid)%branchCT(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchCT(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchCT(bid)%couplings(i) = cop(i)
      end do
    end subroutine avCT

    subroutine avR2(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchR2(bid)%color_id = cid
      vertices(vid)%branchR2(bid)%colorfac_id = cfid
      vertices(vid)%branchR2(bid)%pext = pext
      vertices(vid)%branchR2(bid)%lorentz_id = lid
      vertices(vid)%branchR2(bid)%perm = perm
      vertices(vid)%branchR2(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchR2(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchR2(bid)%couplings(i) = cop(i)
      end do
    end subroutine avR2

    function get_colourfac_mdl(cfid)
      integer, intent(in) :: cfid
      complex(dp) :: get_colourfac_mdl
      get_colourfac_mdl = colorcoeffs(cfid)
    end function get_colourfac_mdl

    function get_colourfac_form_mdl(cfid)
      integer, intent(in) :: cfid
      character(len=20) :: get_colourfac_form_mdl
      get_colourfac_form_mdl = colorcoeffs_form(cfid)
    end function get_colourfac_form_mdl

  function get_recola_base_mdl(l_id) result(ret_rb)
      integer, intent(in) :: l_id
      integer :: ret_rb
      ret_rb = recola_base(l_id)
    end function get_recola_base_mdl

  subroutine get_vertex_branch_status_mdl(vx,xlp,branch_exists)
    integer, intent(in)  :: vx,xlp
    logical, intent(out) ::branch_exists
    select case (xlp)
    case(TreeBranch:LoopBranch)
      branch_exists = allocated(vertices(vx)%branch)
    case(CTBranch)
      branch_exists = allocated(vertices(vx)%branchCT)
    case(R2Branch)
      branch_exists = allocated(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_branch_status_mdl

  subroutine get_vertex_colour_branches_mdl(vx,xlp,cfids,nbranches)
    integer, allocatable, intent(out) :: cfids(:)
    integer, intent(out) :: nbranches
    integer, intent(in)  :: vx,xlp
    select case (xlp)
    case (TreeBranch:LoopBranch)
      allocate(cfids(size(vertices(vx)%branch)))
      cfids(:) = vertices(vx)%branch(0:)%color_id
      nbranches = size(vertices(vx)%branch)
    case(CTBranch)
      allocate(cfids(size(vertices(vx)%branchCT)))
      cfids(:) = vertices(vx)%branchCT(0:)%color_id
      nbranches = size(vertices(vx)%branchCT)
    case(R2Branch)
      allocate(cfids(size(vertices(vx)%branchR2)))
      cfids(:) = vertices(vx)%branchR2(0:)%color_id
      nbranches = size(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_colour_branches_mdl

  subroutine get_vertex_pext_mdl(vx,xlp,br,pext)
    integer, intent(in) :: vx,xlp,br
    integer, intent(out) :: pext
    select case (xlp)
    case (TreeBranch:LoopBranch)
      pext = vertices(vx)%branch(br)%pext
    case(CTBranch)
      pext = vertices(vx)%branchCT(br)%pext
    case(R2Branch)
      pext = vertices(vx)%branchR2(br)%pext
    end select
  end subroutine get_vertex_pext_mdl

  subroutine get_vertex_order_increase_mdl(vx,xlp,br,orderInc)
    integer, intent(in) :: vx,xlp,br
    integer, dimension(:), intent(out) :: orderInc
    select case (xlp)
    case (TreeBranch:LoopBranch)
      orderInc = vertices(vx)%branch(br)%coupling_order
    case(CTBranch)
      orderInc = vertices(vx)%branchCT(br)%coupling_order
    case(R2Branch)
      orderInc = vertices(vx)%branchR2(br)%coupling_order
    end select
  end subroutine get_vertex_order_increase_mdl

  subroutine get_vertex_lorentz_type_mdl(vx,xlp,br,lid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: lid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      lid = vertices(vx)%branch(br)%lorentz_id
    case(CTBranch)
      lid = vertices(vx)%branchCT(br)%lorentz_id
    case(R2Branch)
      lid = vertices(vx)%branchR2(br)%lorentz_id
    end select
  end subroutine get_vertex_lorentz_type_mdl

  subroutine get_vertex_perm_mdl(vx,xlp,br,perm)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: perm
    select case (xlp)
    case (TreeBranch:LoopBranch)
      perm = vertices(vx)%branch(br)%perm
    case(CTBranch)
      perm = vertices(vx)%branchCT(br)%perm
    case(R2Branch)
      perm = vertices(vx)%branchR2(br)%perm
    end select
  end subroutine get_vertex_perm_mdl

  subroutine get_vertex_colour_id_mdl(vx,xlp,br,cid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      cid = vertices(vx)%branch(br)%colorfac_id
    case(CTBranch)
      cid = vertices(vx)%branchCT(br)%colorfac_id
    case(R2Branch)
      cid = vertices(vx)%branchR2(br)%colorfac_id
    end select
  end subroutine get_vertex_colour_id_mdl

  function is_zero_coupling_vertex_mdl(vx,xlp,br) result(zero)
    use class_couplings, only: get_coupling_value_mdl
    use input_mdl, only: zerocut
    integer, intent(in)  :: vx,xlp,br
    logical              :: zero
    real(dp)             :: maxvalue
    integer              :: i

    zero = .false.
    select case (xlp)
    case (TreeBranch:LoopBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branch(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branch(br)%couplings(i-&
                1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(CTBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchCT(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchCT(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(R2Branch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchR2(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchR2(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    end select
  end function is_zero_coupling_vertex_mdl

  subroutine get_vertex_ncouplings_mdl(vx,xlp,br,ncouplings)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: ncouplings
    select case(xlp)
    case(TreeBranch, LoopBranch)
      ncouplings = size(vertices(vx)%branch(br)%couplings)
    case (CTBranch)
      ncouplings = size(vertices(vx)%branchCT(br)%couplings)
    case (R2Branch)
      ncouplings = size(vertices(vx)%branchR2(br)%couplings)
    end select
  end subroutine get_vertex_ncouplings_mdl

  subroutine get_vertex_coupling_ids_mdl(vx,xlp,br,cids)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cids(:)
    select case(xlp)
    case(TreeBranch, LoopBranch)
      cids(:) = vertices(vx)%branch(br)%couplings(:)
    case (CTBranch)
      cids(:) = vertices(vx)%branchCT(br)%couplings(:)
    case (R2Branch)
      cids(:) = vertices(vx)%branchR2(br)%couplings(:)
    end select
  end subroutine get_vertex_coupling_ids_mdl

    subroutine createCurrent2(P1, P2, id)
      integer, intent(in) :: P1, P2, id
      integer(kind=8) :: key
      integer :: address
      logical :: found
      call createParticleConfig(P1, P2, key)
      call dict(key, 2, address, found, id)
    end subroutine createCurrent2

    subroutine createCurrent3(P1, P2, P3, id)
      integer, intent(in) :: P1, P2, P3, id
      integer(kind=8) :: key
      integer :: address
      logical :: found
      call createParticleConfig(P1, P2, P3, key)
      call dict(key, 2, address, found, id)
    end subroutine createCurrent3

    subroutine createCurrent4(P1, P2, P3, P4, id)
      integer, intent(in) :: P1, P2, P3, P4, id
      integer(kind=8) :: key
      integer :: address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, key)
      call dict(key, 2, address, found, id)
    end subroutine createCurrent4

    subroutine createCurrent5(P1, P2, P3, P4, P5, id)
      integer, intent(in) :: P1, P2, P3, P4, P5, id
      integer(kind=8) :: key
      integer :: address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, key)
      call dict(key, 2, address, found, id)
    end subroutine createCurrent5

    subroutine createCurrent6(P1, P2, P3, P4, P5, P6, id)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, id
      integer(kind=8) :: key
      integer :: address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, key)
      call dict(key, 2, address, found, id)
    end subroutine createCurrent6

    subroutine createCurrent7(P1, P2, P3, P4, P5, P6, P7, id)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, id
      integer(kind=8) :: key
      integer :: address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, key)
      call dict(key, 2, address, found, id)
    end subroutine createCurrent7

    subroutine createCurrent8(P1, P2, P3, P4, P5, P6, P7, P8, id)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, P8, id
      integer(kind=8) :: key
      integer :: address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, P8, key)
      call dict(key, 2, address, found, id)
    end subroutine createCurrent8

    subroutine init_vertices_mdl()
      use constants_mdl
      use input_mdl, only: nx, error_mdl
      integer :: address
      integer :: key
      logical :: found

      ! check if modelfile is compatible to drivers
      if (model_timestamp .ne. driver_timestamp) then
        call error_mdl("Model corrupted. Driver timestamp mismatch.", &
                      where='init_vertices')
      end if

      vertices_init = .true.
      call fill_couplings_mdl
      call init_CTparameters_mdl(.true.)
      call fill_CTcouplings_mdl
      call dict_init(7759)

      call createCurrent(P_Hh, P_GMinus, P_HPlus, 646)
      call createCurrent(P_Ha, P_WPlus, P_HMinus, P_A, 418)
      call createCurrent(P_GMinus, P_G0, P_A, P_WPlus, 458)
      call createCurrent(P_WPlus, P_GPlus, P_GMinus, P_WMinus, 987)
      call createCurrent(P_GPlus, P_b, P_tAnti, 714)
      call createCurrent(P_HPlus, P_A, P_G0, P_WMinus, 2949)
      call createCurrent(P_GPlus, P_A, P_HMinus, P_Z, 2955)
      call createCurrent(P_WMinus, P_Z, P_Hl, P_HPlus, 216)
      call createCurrent(P_Hh, P_HPlus, P_Hh, P_GMinus, 704)
      call createCurrent(P_GPlus, P_A, P_Z, P_GMinus, 1567)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, P_Ha, 1038)
      call createCurrent(P_Z, P_HPlus, P_A, P_GMinus, 3403)
      call createCurrent(P_Z, P_WMinus, P_G0, P_HPlus, 3015)
      call createCurrent(P_Z, P_Hl, P_GPlus, P_WMinus, 1042)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, 1480)
      call createCurrent(P_GPlus, P_Hh, P_Hh, P_HMinus, 1089)
      call createCurrent(P_A, P_A, P_WPlus, P_WMinus, 2559)
      call createCurrent(P_Hl, P_WMinus, P_A, P_GPlus, 1886)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, 2505)
      call createCurrent(P_G0, P_HMinus, P_Ha, P_GPlus, 739)
      call createCurrent(P_GMinus, P_G0, P_G0, P_HPlus, 252)
      call createCurrent(P_g, P_g, P_Hl, P_Hl, 3683)
      call createCurrent(P_Z, P_Z, P_GPlus, P_HMinus, 2823)
      call createCurrent(P_A, P_HMinus, P_Z, P_GPlus, 3333)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, 1730)
      call createCurrent(P_G0, P_HPlus, P_GMinus, P_Hl, 1532)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, 2605)
      call createCurrent(P_Hh, P_G0, P_Ha, 1177)
      call createCurrent(P_b, P_bAnti, P_Ha, 1548)
      call createCurrent(P_HMinus, P_GPlus, P_G0, P_G0, 572)
      call createCurrent(P_Hh, P_Hl, P_Hh, P_Hh, 757)
      call createCurrent(P_WPlus, P_Hh, P_HMinus, P_Z, 1214)
      call createCurrent(P_G0, P_uAnti, P_u, 851)
      call createCurrent(P_HPlus, P_G0, P_Ha, P_GMinus, 1080)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, P_Z, 1023)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, P_G0, 571)
      call createCurrent(P_WMinus, P_GMinus, P_HPlus, P_WPlus, 3358)
      call createCurrent(P_HPlus, P_GMinus, P_GPlus, P_HMinus, 698)
      call createCurrent(P_G0, P_GMinus, P_HPlus, P_Hl, 518)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_Hl, 2196)
      call createCurrent(P_g, P_cAnti, P_c, 1654)
      call createCurrent(P_g, P_g, P_g, P_A, 3661)
      call createCurrent(P_WMinus, P_G0, P_G0, P_WPlus, 1033)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, P_A, 849)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, P_Hh, 1476)
      call createCurrent(P_Hh, P_ghWm, P_ghWmAnti, 1937)
      call createCurrent(P_Z, P_WMinus, P_WPlus, 2242)
      call createCurrent(P_Z, P_Ha, P_Z, P_G0, 3106)
      call createCurrent(P_Hl, P_G0, P_G0, P_Hh, 1484)
      call createCurrent(P_HPlus, P_HPlus, P_HMinus, P_HMinus, 2701)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_A, 1380)
      call createCurrent(P_Hl, P_HPlus, P_Ha, P_GMinus, 2569)
      call createCurrent(P_HMinus, P_Hh, P_Hh, P_HPlus, 1441)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, 584)
      call createCurrent(P_Z, P_Hh, P_A, P_Hh, 3011)
      call createCurrent(P_GMinus, P_Hh, P_Hl, P_HPlus, 1153)
      call createCurrent(P_Z, P_A, P_Z, P_Z, 3708)
      call createCurrent(P_A, P_ePlus, P_eMinus, 1425)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, P_Hh, 2348)
      call createCurrent(P_HMinus, P_G0, P_Ha, P_GPlus, 417)
      call createCurrent(P_A, P_GPlus, P_HMinus, P_Z, 3073)
      call createCurrent(P_WMinus, P_Ha, P_WPlus, P_Ha, 2113)
      call createCurrent(P_WPlus, P_HMinus, P_Hl, 2168)
      call createCurrent(P_A, P_Ha, P_WPlus, P_HMinus, 2232)
      call createCurrent(P_A, P_GMinus, P_A, P_HPlus, 3375)
      call createCurrent(P_Hh, P_HMinus, P_A, P_WPlus, 1950)
      call createCurrent(P_G0, P_GMinus, P_G0, P_HPlus, 2640)
      call createCurrent(P_WPlus, P_Z, P_Hl, P_HMinus, 1981)
      call createCurrent(P_Ha, P_Z, P_WPlus, P_GMinus, 3081)
      call createCurrent(P_GMinus, P_GMinus, P_HPlus, P_HPlus, 782)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, 3126)
      call createCurrent(P_A, P_Ha, P_G0, P_A, 3751)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_Ha, 3534)
      call createCurrent(P_Hl, P_Hh, P_Z, P_Z, 2917)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_Hh, 2371)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_A, 918)
      call createCurrent(P_tauMinus, P_tauPlus, 2744)
      call createCurrent(P_GPlus, P_HMinus, P_HMinus, P_HPlus, 327)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GPlus, 1277)
      call createCurrent(P_GPlus, P_Hl, P_Z, P_WMinus, 820)
      call createCurrent(P_Z, P_tauPlus, P_tauMinus, 131)
      call createCurrent(P_A, P_Hh, P_HPlus, P_WMinus, 2423)
      call createCurrent(P_G0, P_Hl, P_HMinus, P_HPlus, 3114)
      call createCurrent(P_WMinus, P_dAnti, P_u, 1900)
      call createCurrent(P_WMinus, P_G0, P_Ha, P_WPlus, 3345)
      call createCurrent(P_G0, P_HPlus, P_HMinus, 2752)
      call createCurrent(P_muPlus, P_muMinus, P_Hh, 2021)
      call createCurrent(P_G0, P_g, P_G0, P_g, 3850)
      call createCurrent(P_WPlus, P_G0, P_G0, P_WMinus, 2704)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, 1336)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, P_Hh, 2461)
      call createCurrent(P_Z, P_WPlus, P_A, P_WMinus, 693)
      call createCurrent(P_WMinus, P_Z, P_Ha, P_GPlus, 3101)
      call createCurrent(P_HMinus, P_Hh, P_G0, P_HPlus, 3449)
      call createCurrent(P_HMinus, P_Z, P_HPlus, P_Z, 2479)
      call createCurrent(P_GMinus, P_GPlus, 3236)
      call createCurrent(P_Hh, P_HMinus, P_Hh, P_GPlus, 121)
      call createCurrent(P_Z, P_GMinus, P_HPlus, P_A, 3550)
      call createCurrent(P_Z, P_Hh, P_WPlus, P_GMinus, 676)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GPlus, 2026)
      call createCurrent(P_HMinus, P_WPlus, P_Z, 461)
      call createCurrent(P_G0, P_Hh, P_GMinus, P_GPlus, 3218)
      call createCurrent(P_HMinus, P_A, P_GPlus, P_A, 3059)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, 200)
      call createCurrent(P_A, P_WMinus, P_Z, P_WPlus, 2258)
      call createCurrent(P_WMinus, P_A, P_HPlus, 630)
      call createCurrent(P_Hl, P_HPlus, P_Hl, P_GMinus, 1059)
      call createCurrent(P_G0, P_G0, P_GMinus, P_HPlus, 1141)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_Hl, 2591)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_Ha, 3231)
      call createCurrent(P_GPlus, P_Z, P_Hh, P_WMinus, 90)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, 1140)
      call createCurrent(P_A, P_Hl, P_A, P_Hl, 3719)
      call createCurrent(P_Z, P_WPlus, P_Z, P_WMinus, 2108)
      call createCurrent(P_Hh, P_G0, P_Hl, P_Ha, 62)
      call createCurrent(P_HMinus, P_muPlus, P_nu_mu, 941)
      call createCurrent(P_G0, P_HPlus, P_GMinus, 1168)
      call createCurrent(P_A, P_Hl, P_Hh, P_Z, 3617)
      call createCurrent(P_s, P_cAnti, P_HPlus, 1761)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_Hl, 803)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, P_G0, 2807)
      call createCurrent(P_Hl, P_HMinus, P_Ha, P_HPlus, 2924)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, 1609)
      call createCurrent(P_dAnti, P_d, P_Hl, 1222)
      call createCurrent(P_Hh, P_HPlus, P_Hl, P_HMinus, 372)
      call createCurrent(P_HPlus, P_G0, P_GMinus, P_G0, 1892)
      call createCurrent(P_WMinus, P_HPlus, P_A, P_Ha, 650)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_Hh, 2009)
      call createCurrent(P_G0, P_G0, P_HPlus, P_GMinus, 2181)
      call createCurrent(P_WMinus, P_HPlus, P_Z, 1873)
      call createCurrent(P_bAnti, P_b, P_g, 2582)
      call createCurrent(P_cAnti, P_Z, P_c, 2199)
      call createCurrent(P_A, P_WPlus, P_G0, P_HMinus, 3030)
      call createCurrent(P_A, P_Ha, P_WMinus, P_HPlus, 780)
      call createCurrent(P_eMinus, P_WPlus, P_nu_eAnti, 835)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, P_Hh, 2736)
      call createCurrent(P_Ha, P_G0, P_Hh, 1717)
      call createCurrent(P_G0, P_Hl, P_Hh, P_Ha, 2534)
      call createCurrent(P_GPlus, P_Ha, P_Ha, P_GMinus, 1596)
      call createCurrent(P_uAnti, P_u, P_Hl, 1645)
      call createCurrent(P_A, P_HMinus, P_WPlus, P_Hl, 2065)
      call createCurrent(P_GPlus, P_GMinus, P_WPlus, P_WMinus, 828)
      call createCurrent(P_Z, P_ePlus, P_eMinus, 1746)
      call createCurrent(P_ghWm, P_HPlus, P_ghZAnti, 3367)
      call createCurrent(P_G0, P_Hl, P_Ha, P_Hh, 1760)
      call createCurrent(P_A, P_tauPlus, P_tauMinus, 925)
      call createCurrent(P_Ha, P_Z, P_Z, P_Ha, 1676)
      call createCurrent(P_Hl, P_GMinus, P_G0, P_GPlus, 2981)
      call createCurrent(P_A, P_Hh, P_A, 3787)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_Z, 993)
      call createCurrent(P_Z, P_Ha, P_GMinus, P_WPlus, 3104)
      call createCurrent(P_HPlus, P_Hh, P_Ha, P_HMinus, 2725)
      call createCurrent(P_HMinus, P_A, P_Ha, P_WPlus, 311)
      call createCurrent(P_t, P_Z, P_tAnti, 1295)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghA, 3282)
      call createCurrent(P_G0, P_dAnti, P_d, 496)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, 1451)
      call createCurrent(P_GPlus, P_Hl, P_A, P_WMinus, 1396)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, 2769)
      call createCurrent(P_Hl, P_Ha, P_Ha, P_Hl, 1398)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_Hh, 2921)
      call createCurrent(P_s, P_Z, P_sAnti, 575)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_Z, 214)
      call createCurrent(P_Hl, P_muMinus, P_muPlus, 1155)
      call createCurrent(P_HMinus, P_HPlus, P_GPlus, P_GMinus, 1275)
      call createCurrent(P_nu_e, P_WMinus, P_ePlus, 1289)
      call createCurrent(P_A, P_Ha, P_Ha, P_A, 3618)
      call createCurrent(P_Hl, P_GMinus, P_Hl, P_GPlus, 971)
      call createCurrent(P_eMinus, P_Hh, P_ePlus, 1065)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, 2678)
      call createCurrent(P_Hl, P_Ha, P_GPlus, P_HMinus, 1124)
      call createCurrent(P_GPlus, P_HPlus, P_GMinus, P_HMinus, 766)
      call createCurrent(P_WMinus, P_HPlus, P_G0, P_Z, 3522)
      call createCurrent(P_GPlus, P_Hh, P_G0, P_HMinus, 846)
      call createCurrent(P_A, P_Ha, P_HPlus, P_WMinus, 325)
      call createCurrent(P_G0, P_G0, P_G0, P_G0, 2310)
      call createCurrent(P_Ha, P_Hh, P_G0, P_Hl, 114)
      call createCurrent(P_t, P_Hl, P_tAnti, 701)
      call createCurrent(P_A, P_Z, P_Z, P_A, 3841)
      call createCurrent(P_g, P_g, P_Hh, P_Hh, 3811)
      call createCurrent(P_G0, P_HPlus, P_GMinus, P_G0, 1107)
      call createCurrent(P_A, P_WMinus, P_HPlus, P_G0, 2961)
      call createCurrent(P_A, P_muPlus, P_muMinus, 720)
      call createCurrent(P_WMinus, P_GMinus, P_GPlus, P_WPlus, 1531)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, 2631)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, 409)
      call createCurrent(P_Hh, P_Hh, P_Hl, 39)
      call createCurrent(P_G0, P_GPlus, P_HMinus, P_Ha, 1093)
      call createCurrent(P_G0, P_c, P_cAnti, 211)
      call createCurrent(P_Ha, P_Hl, P_HPlus, P_HMinus, 2966)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, P_A, 636)
      call createCurrent(P_HPlus, P_Hh, P_Hl, P_GMinus, 1306)
      call createCurrent(P_HMinus, P_A, P_G0, P_WPlus, 2749)
      call createCurrent(P_A, P_Hl, P_WMinus, P_HPlus, 874)
      call createCurrent(P_A, P_g, P_g, P_Z, 3752)
      call createCurrent(P_GMinus, P_WPlus, P_G0, 2164)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_Z, 187)
      call createCurrent(P_Z, P_HPlus, P_WMinus, P_G0, 3216)
      call createCurrent(P_Ha, P_b, P_bAnti, 1318)
      call createCurrent(P_Ha, P_Ha, P_Ha, P_G0, 1348)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_G0, 590)
      call createCurrent(P_Hh, P_Hl, P_Hl, P_Hl, 970)
      call createCurrent(P_GPlus, P_Hh, P_A, P_WMinus, 1714)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_A, 3087)
      call createCurrent(P_HMinus, P_Z, P_WPlus, 591)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, 2111)
      call createCurrent(P_Hh, P_Hl, P_Hl, 1486)
      call createCurrent(P_Hh, P_Hh, P_Hl, P_Hh, 205)
      call createCurrent(P_A, P_A, P_Hh, 3797)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, P_Ha, 2482)
      call createCurrent(P_HMinus, P_WPlus, P_Hh, 1043)
      call createCurrent(P_WMinus, P_g, P_WPlus, P_g, 3653)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_Hh, 2517)
      call createCurrent(P_Hl, P_G0, P_Z, 1561)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_Hh, 2566)
      call createCurrent(P_A, P_G0, P_Hh, 2747)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WPlus, 2686)
      call createCurrent(P_g, P_A, P_g, P_Z, 3778)
      call createCurrent(P_u, P_uAnti, P_Hh, 2349)
      call createCurrent(P_Hl, P_G0, P_Ha, P_Hh, 1257)
      call createCurrent(P_Hh, P_ghWp, P_ghWpAnti, 1706)
      call createCurrent(P_Hh, P_cAnti, P_c, 2039)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_A, 2825)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_G0, 2486)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_Hl, 2755)
      call createCurrent(P_tauPlus, P_tauMinus, P_Ha, 1220)
      call createCurrent(P_GPlus, P_GMinus, P_WMinus, P_WPlus, 2147)
      call createCurrent(P_dAnti, P_d, P_A, 1270)
      call createCurrent(P_Z, P_HMinus, P_Z, P_GPlus, 2867)
      call createCurrent(P_Ha, P_WPlus, P_HMinus, 1130)
      call createCurrent(P_d, P_A, P_dAnti, 1463)
      call createCurrent(P_WMinus, P_HPlus, P_Ha, P_Z, 2183)
      call createCurrent(P_Z, P_uAnti, P_u, 2579)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_Z, 73)
      call createCurrent(P_tauMinus, P_tauPlus, P_Hh, 1849)
      call createCurrent(P_WMinus, P_HPlus, P_WPlus, P_HMinus, 1013)
      call createCurrent(P_GPlus, P_nu_muAnti, P_muMinus, 136)
      call createCurrent(P_G0, P_A, P_Ha, P_Z, 3793)
      call createCurrent(P_HMinus, P_HPlus, P_A, 1574)
      call createCurrent(P_HPlus, P_A, P_WMinus, P_G0, 2829)
      call createCurrent(P_HPlus, P_Hh, P_Ha, P_GMinus, 12)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, 3017)
      call createCurrent(P_G0, P_HMinus, P_HPlus, P_Hh, 3532)
      call createCurrent(P_Hl, P_A, P_WPlus, P_GMinus, 132)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, 267)
      call createCurrent(P_dAnti, P_g, P_d, 343)
      call createCurrent(P_G0, P_Ha, P_WMinus, P_WPlus, 2775)
      call createCurrent(P_Hh, P_Hl, P_GPlus, P_GMinus, 1017)
      call createCurrent(P_Z, P_HMinus, P_HPlus, P_A, 485)
      call createCurrent(P_HMinus, P_Ha, P_Hh, P_GPlus, 1500)
      call createCurrent(P_HPlus, P_nu_tauAnti, P_tauMinus, 2568)
      call createCurrent(P_nu_e, P_A, P_nu_eAnti, 3319)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, P_A, 423)
      call createCurrent(P_WMinus, P_HPlus, P_Ha, P_A, 1780)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, P_Hh, 1817)
      call createCurrent(P_WMinus, P_HPlus, P_HMinus, P_WPlus, 873)
      call createCurrent(P_Hl, P_HPlus, P_Z, P_WMinus, 2625)
      call createCurrent(P_G0, P_A, P_Hh, 3343)
      call createCurrent(P_WPlus, P_Hl, P_Hl, P_WMinus, 250)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, P_Ha, 3089)
      call createCurrent(P_Hl, P_Hl, P_G0, P_Ha, 2037)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, P_Ha, 779)
      call createCurrent(P_nu_e, P_HMinus, P_ePlus, 1947)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, 1525)
      call createCurrent(P_GMinus, P_HMinus, P_GPlus, P_GPlus, 2687)
      call createCurrent(P_Ha, P_sAnti, P_s, 651)
      call createCurrent(P_A, P_eMinus, P_ePlus, 1790)
      call createCurrent(P_nu_mu, P_HMinus, P_muPlus, 549)
      call createCurrent(P_Z, P_HPlus, P_Ha, P_WMinus, 1472)
      call createCurrent(P_Z, P_Ha, P_GPlus, P_WMinus, 2753)
      call createCurrent(P_Hh, P_Ha, P_G0, P_G0, 3662)
      call createCurrent(P_tAnti, P_t, P_A, 778)
      call createCurrent(P_Hl, P_Z, P_A, P_Hl, 2988)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, 1053)
      call createCurrent(P_HMinus, P_G0, P_GPlus, P_Ha, 142)
      call createCurrent(P_nu_tau, P_A, P_nu_tauAnti, 2803)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, 2153)
      call createCurrent(P_HPlus, P_HMinus, P_GMinus, P_HPlus, 334)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, P_G0, 2412)
      call createCurrent(P_Z, P_WMinus, P_Ha, P_GPlus, 3186)
      call createCurrent(P_HMinus, P_dAnti, P_u, 229)
      call createCurrent(P_Z, P_WMinus, P_HPlus, P_Hl, 266)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, P_Hl, 2005)
      call createCurrent(P_c, P_sAnti, P_WMinus, 1667)
      call createCurrent(P_Hh, P_A, P_WMinus, P_GPlus, 609)
      call createCurrent(P_A, P_d, P_dAnti, 601)
      call createCurrent(P_Ha, P_WMinus, P_Ha, P_WPlus, 837)
      call createCurrent(P_GPlus, P_HMinus, P_G0, 729)
      call createCurrent(P_GPlus, P_tauMinus, P_nu_tauAnti, 2103)
      call createCurrent(P_ghZ, P_ghWpAnti, P_HPlus, 3580)
      call createCurrent(P_ePlus, P_Hh, P_eMinus, 2492)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, P_Hh, 1922)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, 2095)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, 1285)
      call createCurrent(P_sAnti, P_s, 3476)
      call createCurrent(P_muPlus, P_nu_mu, P_WMinus, 1409)
      call createCurrent(P_Z, P_A, 3413)
      call createCurrent(P_GPlus, P_HMinus, P_HPlus, P_HMinus, 2141)
      call createCurrent(P_HPlus, P_A, P_HMinus, P_A, 592)
      call createCurrent(P_HMinus, P_WMinus, P_GPlus, P_WPlus, 3495)
      call createCurrent(P_A, P_Hl, P_Z, P_Hh, 3749)
      call createCurrent(P_Hl, P_Z, P_G0, 2481)
      call createCurrent(P_HMinus, P_Hl, P_G0, P_HPlus, 3183)
      call createCurrent(P_Z, P_A, P_Hl, P_Hh, 3695)
      call createCurrent(P_HPlus, P_Ha, P_Hl, P_HMinus, 3485)
      call createCurrent(P_Z, P_GPlus, P_HMinus, 2743)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, P_Z, 354)
      call createCurrent(P_G0, P_Hl, P_HPlus, P_HMinus, 3382)
      call createCurrent(P_HMinus, P_A, P_HPlus, P_A, 1581)
      call createCurrent(P_ePlus, P_eMinus, P_Ha, 1152)
      call createCurrent(P_Z, P_G0, P_WMinus, P_GPlus, 1103)
      call createCurrent(P_Hh, P_Hh, P_GMinus, P_HPlus, 1181)
      call createCurrent(P_G0, P_Ha, P_GMinus, P_HPlus, 2503)
      call createCurrent(P_sAnti, P_A, P_s, 1049)
      call createCurrent(P_HPlus, P_GPlus, P_HMinus, P_GMinus, 186)
      call createCurrent(P_HPlus, P_G0, P_GMinus, P_Hl, 858)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, 465)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_GMinus, 169)
      call createCurrent(P_A, P_Hl, P_Z, P_Hl, 3383)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, 2834)
      call createCurrent(P_Hh, P_Hl, P_WPlus, P_WMinus, 3042)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, P_G0, 2943)
      call createCurrent(P_WPlus, P_Hh, P_A, P_GMinus, 1293)
      call createCurrent(P_Ha, P_Ha, P_G0, P_Ha, 275)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, 611)
      call createCurrent(P_Z, P_A, P_HPlus, P_HMinus, 1752)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_Ha, 2861)
      call createCurrent(P_HPlus, P_HMinus, P_GPlus, P_HMinus, 2369)
      call createCurrent(P_Hh, P_Ha, P_Hl, P_Ha, 1386)
      call createCurrent(P_HMinus, P_WPlus, P_GPlus, P_WMinus, 3067)
      call createCurrent(P_Hh, P_Hl, 3456)
      call createCurrent(P_Ha, P_G0, P_Hl, P_G0, 3601)
      call createCurrent(P_Hl, P_Z, P_HPlus, P_WMinus, 2256)
      call createCurrent(P_Z, P_Hh, P_Z, P_Hl, 3364)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_Hh, 889)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, 2598)
      call createCurrent(P_A, P_G0, P_HPlus, P_WMinus, 3347)
      call createCurrent(P_G0, P_A, P_A, P_G0, 3636)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_Ha, 3033)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_Ha, 2879)
      call createCurrent(P_A, P_A, P_Ha, P_G0, 3633)
      call createCurrent(P_GPlus, P_A, P_A, P_HMinus, 3123)
      call createCurrent(P_Hh, P_Z, P_WPlus, P_HMinus, 1322)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, P_Hh, 3530)
      call createCurrent(P_Ha, P_HPlus, P_WMinus, P_A, 1898)
      call createCurrent(P_Z, P_WPlus, P_HMinus, P_Ha, 1358)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, 907)
      call createCurrent(P_Hl, P_G0, P_HPlus, P_HMinus, 2836)
      call createCurrent(P_Ha, P_Hh, P_Hl, P_Ha, 1169)
      call createCurrent(P_HMinus, P_GPlus, P_HPlus, P_HMinus, 684)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_G0, 1037)
      call createCurrent(P_G0, P_GPlus, P_HMinus, P_Hh, 2464)
      call createCurrent(P_uAnti, P_u, P_g, 1595)
      call createCurrent(P_WMinus, P_Hh, P_HPlus, P_A, 1866)
      call createCurrent(P_Z, P_A, P_Hl, 2806)
      call createCurrent(P_WMinus, P_HPlus, P_Hl, P_Z, 2500)
      call createCurrent(P_G0, P_G0, P_Ha, P_Hl, 3869)
      call createCurrent(P_Hh, P_Ha, P_GMinus, P_HPlus, 2124)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, 2282)
      call createCurrent(P_Hh, P_Hh, P_GPlus, P_HMinus, 1879)
      call createCurrent(P_HMinus, P_WPlus, P_Ha, 1778)
      call createCurrent(P_Hh, P_A, P_Z, P_Hh, 3172)
      call createCurrent(P_g, P_HPlus, P_HMinus, P_g, 3739)
      call createCurrent(P_g, P_Ha, P_g, P_Ha, 3840)
      call createCurrent(P_u, P_uAnti, 3249)
      call createCurrent(P_u, P_uAnti, P_Ha, 1980)
      call createCurrent(P_G0, P_G0, P_HMinus, P_GPlus, 911)
      call createCurrent(P_HMinus, P_Hl, P_Z, P_WPlus, 517)
      call createCurrent(P_A, P_A, P_GPlus, P_HMinus, 2903)
      call createCurrent(P_Z, P_HMinus, P_A, P_GPlus, 2842)
      call createCurrent(P_Z, P_Hh, P_GPlus, P_WMinus, 669)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, 1615)
      call createCurrent(P_Ha, P_GMinus, P_Z, P_WPlus, 3124)
      call createCurrent(P_A, P_Z, P_G0, P_Ha, 3753)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, P_Ha, 1899)
      call createCurrent(P_GMinus, P_Hl, P_G0, P_GPlus, 2768)
      call createCurrent(P_GPlus, P_HMinus, P_GPlus, P_HMinus, 462)
      call createCurrent(P_tauPlus, P_tauMinus, P_Hh, 1266)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_Ha, 3214)
      call createCurrent(P_ghZ, P_Hl, P_ghZAnti, 2060)
      call createCurrent(P_GPlus, P_Hl, P_Hl, P_GMinus, 505)
      call createCurrent(P_HPlus, P_G0, P_HMinus, P_Hl, 2857)
      call createCurrent(P_A, P_Hh, P_WMinus, P_HPlus, 2405)
      call createCurrent(P_tauPlus, P_HMinus, P_nu_tau, 2279)
      call createCurrent(P_WMinus, P_Z, P_HPlus, P_Hl, 1539)
      call createCurrent(P_Hh, P_muPlus, P_muMinus, 643)
      call createCurrent(P_tAnti, P_t, P_Z, 1339)
      call createCurrent(P_A, P_HPlus, P_A, P_GMinus, 2782)
      call createCurrent(P_A, P_HMinus, P_A, P_HPlus, 2134)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_GPlus, 1907)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, P_Ha, 3160)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, 1783)
      call createCurrent(P_GMinus, P_A, P_Hl, P_WPlus, 2551)
      call createCurrent(P_Hl, P_A, P_Hh, P_Z, 3831)
      call createCurrent(P_GPlus, P_WPlus, P_HMinus, P_WMinus, 3351)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_Hl, 898)
      call createCurrent(P_WMinus, P_G0, P_Z, P_GPlus, 1496)
      call createCurrent(P_Hl, P_Ha, P_Ha, 1651)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, P_Ha, 1815)
      call createCurrent(P_HMinus, P_WPlus, P_A, P_Hl, 818)
      call createCurrent(P_sAnti, P_s, P_Z, 602)
      call createCurrent(P_Hl, P_Ha, P_GMinus, P_HPlus, 2062)
      call createCurrent(P_Ha, P_HPlus, P_Hh, P_HMinus, 3316)
      call createCurrent(P_Z, P_Hl, P_Z, P_Hh, 3457)
      call createCurrent(P_Hl, P_Hl, P_GPlus, P_GMinus, 2685)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, P_G0, 1868)
      call createCurrent(P_HPlus, P_Hl, P_Ha, P_HMinus, 3400)
      call createCurrent(P_WMinus, P_A, P_HPlus, P_Ha, 813)
      call createCurrent(P_Z, P_Ha, P_Z, P_Ha, 1986)
      call createCurrent(P_A, P_WPlus, P_HMinus, 742)
      call createCurrent(P_HPlus, P_G0, P_Hh, P_GMinus, 291)
      call createCurrent(P_HPlus, P_WMinus, P_Hh, 436)
      call createCurrent(P_HMinus, P_ghZ, P_ghWmAnti, 3427)
      call createCurrent(P_Hl, P_HPlus, P_WMinus, P_Z, 2418)
      call createCurrent(P_Hh, P_ghZAnti, P_ghZ, 2334)
      call createCurrent(P_WPlus, P_Z, P_HMinus, P_Hh, 1723)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, P_Hh, 1955)
      call createCurrent(P_HPlus, P_GMinus, P_G0, P_G0, 1816)
      call createCurrent(P_Hh, P_Hh, P_WPlus, P_WMinus, 1540)
      call createCurrent(P_G0, P_Z, P_WPlus, P_GMinus, 2296)
      call createCurrent(P_GMinus, P_G0, P_HPlus, P_Hl, 1242)
      call createCurrent(P_WPlus, P_A, P_HMinus, P_Hh, 733)
      call createCurrent(P_Z, P_Z, P_GMinus, P_GPlus, 92)
      call createCurrent(P_Hh, P_Ha, P_GPlus, P_HMinus, 248)
      call createCurrent(P_Ha, P_Hl, P_Hl, P_Ha, 1416)
      call createCurrent(P_d, P_uAnti, P_HPlus, 1074)
      call createCurrent(P_GPlus, P_eMinus, P_nu_eAnti, 508)
      call createCurrent(P_G0, P_Z, P_Hh, 2702)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, P_Hl, 3148)
      call createCurrent(P_Hh, P_GMinus, P_Ha, P_HPlus, 1002)
      call createCurrent(P_Hh, P_Ha, P_A, 2754)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, 170)
      call createCurrent(P_G0, P_tAnti, P_t, 280)
      call createCurrent(P_HPlus, P_Z, P_Z, P_HMinus, 2446)
      call createCurrent(P_Z, P_G0, P_Z, P_G0, 1757)
      call createCurrent(P_Ha, P_Ha, P_HPlus, P_GMinus, 1119)
      call createCurrent(P_ePlus, P_nu_e, P_GMinus, 1920)
      call createCurrent(P_s, P_GPlus, P_cAnti, 1184)
      call createCurrent(P_GPlus, P_HMinus, P_GMinus, P_HPlus, 901)
      call createCurrent(P_Hl, P_Z, P_GMinus, P_WPlus, 800)
      call createCurrent(P_HMinus, P_Z, P_GPlus, P_A, 3167)
      call createCurrent(P_dAnti, P_d, P_g, 2173)
      call createCurrent(P_WMinus, P_HPlus, P_G0, P_A, 2767)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, P_Hl, 2027)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_Ha, 1912)
      call createCurrent(P_WMinus, P_G0, P_A, P_GPlus, 1965)
      call createCurrent(P_Z, P_Hl, P_Z, 26)
      call createCurrent(P_G0, P_Ha, P_Hl, P_Hh, 516)
      call createCurrent(P_c, P_cAnti, 3235)
      call createCurrent(P_Hl, P_A, P_A, P_Hh, 3745)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, P_Hh, 1374)
      call createCurrent(P_Hh, P_HMinus, P_Hh, P_HPlus, 551)
      call createCurrent(P_ePlus, P_eMinus, P_Hh, 133)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, P_A, 1550)
      call createCurrent(P_HPlus, P_Z, P_WMinus, P_G0, 3322)
      call createCurrent(P_Z, P_GPlus, P_Hl, P_WMinus, 553)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_Hh, 2408)
      call createCurrent(P_GPlus, P_s, P_cAnti, 2025)
      call createCurrent(P_GPlus, P_HMinus, P_A, P_Z, 3521)
      call createCurrent(P_HPlus, P_Z, P_Z, P_GMinus, 3502)
      call createCurrent(P_WMinus, P_HMinus, P_HPlus, P_WPlus, 1740)
      call createCurrent(P_A, P_HPlus, P_WMinus, P_G0, 3031)
      call createCurrent(P_uAnti, P_GPlus, P_d, 1122)
      call createCurrent(P_A, P_WMinus, P_Hl, P_GPlus, 2433)
      call createCurrent(P_A, P_HMinus, P_HPlus, P_Z, 992)
      call createCurrent(P_s, P_sAnti, P_g, 2216)
      call createCurrent(P_uAnti, P_Z, P_u, 1582)
      call createCurrent(P_Ha, P_GPlus, P_Hh, P_HMinus, 2368)
      call createCurrent(P_GMinus, P_Hl, P_Z, P_WPlus, 484)
      call createCurrent(P_Hh, P_GMinus, P_HPlus, P_Ha, 680)
      call createCurrent(P_Ha, P_Ha, P_GPlus, P_HMinus, 522)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, 1054)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, P_Ha, 390)
      call createCurrent(P_Ha, P_Z, P_GPlus, P_WMinus, 3045)
      call createCurrent(P_A, P_Hl, P_HMinus, P_WPlus, 2163)
      call createCurrent(P_Ha, P_WPlus, P_GMinus, P_Z, 3008)
      call createCurrent(P_GPlus, P_Hh, P_Hl, P_HMinus, 935)
      call createCurrent(P_d, P_dAnti, 2821)
      call createCurrent(P_HMinus, P_HPlus, P_Z, P_Z, 1936)
      call createCurrent(P_G0, P_GPlus, P_Ha, P_HMinus, 45)
      call createCurrent(P_nu_e, P_ePlus, P_WMinus, 1820)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, P_Hh, 1011)
      call createCurrent(P_GPlus, P_Z, P_Ha, P_WMinus, 3237)
      call createCurrent(P_nu_eAnti, P_nu_e, P_A, 3355)
      call createCurrent(P_G0, P_Hh, P_Ha, P_Hl, 64)
      call createCurrent(P_A, P_Ha, P_GPlus, P_WMinus, 2896)
      call createCurrent(P_Hh, P_Ha, P_Hh, P_Ha, 2426)
      call createCurrent(P_WPlus, P_Hh, P_HMinus, P_A, 1970)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_Z, 1686)
      call createCurrent(P_sAnti, P_s, P_Hl, 2333)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, P_Hl, 902)
      call createCurrent(P_Hl, P_HPlus, P_Ha, P_HMinus, 3195)
      call createCurrent(P_GPlus, P_HMinus, P_GMinus, P_GPlus, 1342)
      call createCurrent(P_WMinus, P_A, P_Hh, P_HPlus, 816)
      call createCurrent(P_Hl, P_Hl, P_Ha, P_G0, 824)
      call createCurrent(P_GPlus, P_g, P_HMinus, P_g, 3646)
      call createCurrent(P_Ha, P_Z, P_G0, P_Z, 3491)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_Ha, 3349)
      call createCurrent(P_Hl, P_HMinus, P_Hh, P_HPlus, 1999)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_Ha, 3384)
      call createCurrent(P_Ha, P_HPlus, P_G0, P_GMinus, 370)
      call createCurrent(P_Z, P_Z, P_HMinus, P_HPlus, 2603)
      call createCurrent(P_Z, P_WPlus, P_HMinus, P_Hh, 1314)
      call createCurrent(P_Ha, P_HMinus, P_Hh, P_HPlus, 3266)
      call createCurrent(P_GPlus, P_Hl, P_Ha, P_HMinus, 1261)
      call createCurrent(P_Hl, P_HMinus, P_A, P_WPlus, 1051)
      call createCurrent(P_HMinus, P_GPlus, P_G0, P_Hh, 1203)
      call createCurrent(P_A, P_A, P_Hh, P_Hl, 3663)
      call createCurrent(P_WMinus, P_HPlus, P_Hh, P_Z, 2058)
      call createCurrent(P_G0, P_d, P_dAnti, 1690)
      call createCurrent(P_bAnti, P_G0, P_b, 1915)
      call createCurrent(P_GPlus, P_Hl, P_Hh, P_GMinus, 2000)
      call createCurrent(P_Hh, P_Hl, P_Ha, P_G0, 1236)
      call createCurrent(P_GMinus, P_Z, P_HPlus, 3052)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_Hl, 2873)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_G0, 2299)
      call createCurrent(P_G0, P_HPlus, P_Z, P_WMinus, 3270)
      call createCurrent(P_A, P_HPlus, P_HMinus, P_Z, 1901)
      call createCurrent(P_G0, P_G0, P_Hh, P_Hh, 1422)
      call createCurrent(P_u, P_uAnti, P_A, 616)
      call createCurrent(P_A, P_G0, P_Ha, P_Z, 3770)
      call createCurrent(P_G0, P_Ha, P_GPlus, P_HMinus, 453)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, 2364)
      call createCurrent(P_HMinus, P_WPlus, P_HPlus, P_WMinus, 1552)
      call createCurrent(P_GMinus, P_A, P_Hh, P_WPlus, 634)
      call createCurrent(P_A, P_Hh, P_G0, 2940)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, P_Hl, 2063)
      call createCurrent(P_Z, P_HMinus, P_HPlus, 1629)
      call createCurrent(P_HPlus, P_WMinus, P_Ha, P_Z, 459)
      call createCurrent(P_bAnti, P_Z, P_b, 324)
      call createCurrent(P_A, P_Z, P_Hl, P_Hl, 2787)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, 2132)
      call createCurrent(P_Z, P_GMinus, P_Hh, P_WPlus, 2059)
      call createCurrent(P_Hh, P_Hh, P_G0, P_G0, 749)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, 1774)
      call createCurrent(P_G0, P_tauPlus, P_tauMinus, 1767)
      call createCurrent(P_Ha, P_G0, P_HPlus, P_HMinus, 2390)
      call createCurrent(P_Hh, P_Ha, P_Ha, P_Hl, 2546)
      call createCurrent(P_d, P_dAnti, P_A, 966)
      call createCurrent(P_Z, P_GPlus, P_Z, P_GMinus, 1894)
      call createCurrent(P_WMinus, P_Z, P_Hl, P_GPlus, 644)
      call createCurrent(P_tAnti, P_Ha, P_t, 1050)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_Ha, 2916)
      call createCurrent(P_HMinus, P_WPlus, 3170)
      call createCurrent(P_g, P_g, P_A, P_g, 3762)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, P_Hh, 105)
      call createCurrent(P_HPlus, P_G0, P_Hl, P_GMinus, 2188)
      call createCurrent(P_Hl, P_A, P_G0, 3514)
      call createCurrent(P_g, P_G0, P_g, P_Ha, 3802)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, P_Ha, 1844)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, P_Ha, 534)
      call createCurrent(P_g, P_GPlus, P_g, P_HMinus, 3609)
      call createCurrent(P_HPlus, P_WMinus, P_Ha, 875)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_Z, 2693)
      call createCurrent(P_G0, P_Hl, P_GPlus, P_GMinus, 3109)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, P_Ha, 1424)
      call createCurrent(P_WPlus, P_WMinus, 3335)
      call createCurrent(P_G0, P_Z, P_WMinus, P_GPlus, 130)
      call createCurrent(P_Hh, P_GPlus, P_Hh, P_HMinus, 2179)
      call createCurrent(P_HMinus, P_Z, P_Ha, P_WPlus, 709)
      call createCurrent(P_eMinus, P_Hl, P_ePlus, 2508)
      call createCurrent(P_Hl, P_G0, P_HMinus, P_HPlus, 2865)
      call createCurrent(P_Z, P_nu_tauAnti, P_nu_tau, 2091)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, P_Hl, 274)
      call createCurrent(P_WPlus, P_Ha, P_A, P_GMinus, 3299)
      call createCurrent(P_GMinus, P_HPlus, P_WPlus, P_WMinus, 3090)
      call createCurrent(P_Z, P_HPlus, P_HMinus, P_A, 1954)
      call createCurrent(P_HMinus, P_HPlus, P_G0, P_Hh, 2851)
      call createCurrent(P_A, P_Ha, P_HMinus, P_WPlus, 1521)
      call createCurrent(P_Hl, P_t, P_tAnti, 1036)
      call createCurrent(P_A, P_A, P_GMinus, P_GPlus, 1634)
      call createCurrent(P_HPlus, P_G0, P_WMinus, 3210)
      call createCurrent(P_ghWmAnti, P_ghA, P_HMinus, 2719)
      call createCurrent(P_G0, P_Z, P_Ha, P_Z, 2905)
      call createCurrent(P_HMinus, P_Hl, P_WPlus, P_Z, 1732)
      call createCurrent(P_GMinus, P_Hl, P_Ha, P_HPlus, 2120)
      call createCurrent(P_HPlus, P_Hl, P_Z, P_WMinus, 2590)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, 513)
      call createCurrent(P_muPlus, P_A, P_muMinus, 2165)
      call createCurrent(P_WMinus, P_A, P_G0, P_GPlus, 1797)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_A, 433)
      call createCurrent(P_GPlus, P_A, P_A, P_GMinus, 888)
      call createCurrent(P_eMinus, P_GPlus, P_nu_eAnti, 1349)
      call createCurrent(P_A, P_G0, P_WPlus, P_HMinus, 3002)
      call createCurrent(P_G0, P_GPlus, P_Hh, P_HMinus, 2434)
      call createCurrent(P_HPlus, P_nu_muAnti, P_muMinus, 2007)
      call createCurrent(P_Ha, P_tAnti, P_t, 85)
      call createCurrent(P_Ha, P_WPlus, P_Ha, P_WMinus, 1924)
      call createCurrent(P_WPlus, P_HMinus, P_A, 1897)
      call createCurrent(P_Hh, P_A, P_Z, P_Hl, 3743)
      call createCurrent(P_A, P_Z, P_A, P_Z, 3877)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, 968)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, P_Hh, 188)
      call createCurrent(P_Hl, P_Hl, P_Hh, P_Hl, 653)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_Ha, 3564)
      call createCurrent(P_s, P_WPlus, P_cAnti, 1235)
      call createCurrent(P_HPlus, P_Hh, P_Hh, P_HMinus, 595)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_Hl, 1765)
      call createCurrent(P_dAnti, P_WMinus, P_u, 412)
      call createCurrent(P_Hh, P_g, P_g, P_Hh, 3758)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, P_Z, 1264)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, P_Hl, 2711)
      call createCurrent(P_uAnti, P_d, P_HPlus, 451)
      call createCurrent(P_Z, P_HPlus, P_Hh, P_WMinus, 1394)
      call createCurrent(P_Ha, P_G0, P_HMinus, P_HPlus, 1799)
      call createCurrent(P_HMinus, P_A, P_WPlus, P_Hl, 2407)
      call createCurrent(P_HMinus, P_GMinus, P_HPlus, P_GPlus, 498)
      call createCurrent(P_A, P_Ha, P_Hl, 3145)
      call createCurrent(P_Ha, P_Ha, P_Hl, P_Hh, 896)
      call createCurrent(P_Ha, P_G0, P_Hl, P_Hh, 1252)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Ha, 2758)
      call createCurrent(P_dAnti, P_d, P_Hh, 884)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_G0, 1885)
      call createCurrent(P_Z, P_HPlus, P_Z, P_GMinus, 3112)
      call createCurrent(P_Z, P_Hh, P_Z, 593)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, P_Ha, 1335)
      call createCurrent(P_Z, P_Z, P_Z, P_A, 3801)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, P_Hl, 806)
      call createCurrent(P_Ha, P_GMinus, P_Hh, P_GPlus, 2785)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_HMinus, 528)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, 1982)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, 1824)
      call createCurrent(P_Ha, P_WMinus, P_GPlus, 3201)
      call createCurrent(P_HPlus, P_nu_eAnti, P_eMinus, 434)
      call createCurrent(P_G0, P_GMinus, P_Z, P_WPlus, 2332)
      call createCurrent(P_uAnti, P_u, P_Hh, 1311)
      call createCurrent(P_HPlus, P_HPlus, P_GMinus, P_GMinus, 991)
      call createCurrent(P_Hh, P_Z, P_GPlus, P_WMinus, 58)
      call createCurrent(P_GMinus, P_HPlus, P_G0, P_Hl, 1125)
      call createCurrent(P_g, P_Hl, P_Hl, P_g, 3776)
      call createCurrent(P_WMinus, P_HPlus, P_G0, 2846)
      call createCurrent(P_A, P_Ha, P_A, P_Ha, 3660)
      call createCurrent(P_G0, P_GMinus, P_Ha, P_GPlus, 2538)
      call createCurrent(P_nu_muAnti, P_nu_mu, 3531)
      call createCurrent(P_GPlus, P_g, P_GMinus, P_g, 3625)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, 1298)
      call createCurrent(P_Hh, P_G0, P_Hh, P_G0, 1943)
      call createCurrent(P_Hh, P_A, P_G0, 2882)
      call createCurrent(P_A, P_Z, P_WMinus, P_WPlus, 1385)
      call createCurrent(P_Hl, P_Ha, P_Hh, P_Ha, 2177)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, 854)
      call createCurrent(P_G0, P_Hl, P_G0, P_Hl, 7)
      call createCurrent(P_A, P_s, P_sAnti, 476)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_Z, 1672)
      call createCurrent(P_Ha, P_Hl, P_Hh, P_G0, 332)
      call createCurrent(P_HMinus, P_HPlus, P_A, P_A, 1407)
      call createCurrent(P_Hl, P_G0, P_GPlus, P_HMinus, 687)
      call createCurrent(P_Ha, P_WPlus, P_GMinus, 3254)
      call createCurrent(P_c, P_Hl, P_cAnti, 726)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_Ha, 3000)
      call createCurrent(P_Hl, P_A, P_WPlus, P_HMinus, 1762)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_Hh, 2102)
      call createCurrent(P_G0, P_HMinus, P_WPlus, P_Z, 2878)
      call createCurrent(P_WPlus, P_Ha, P_Z, P_GMinus, 3245)
      call createCurrent(P_d, P_g, P_dAnti, 357)
      call createCurrent(P_g, P_t, P_tAnti, 986)
      call createCurrent(P_G0, P_Z, P_G0, P_Z, 890)
      call createCurrent(P_t, P_tAnti, 3016)
      call createCurrent(P_G0, P_HPlus, P_HMinus, P_Ha, 1321)
      call createCurrent(P_GMinus, P_HPlus, P_A, P_A, 3398)
      call createCurrent(P_HPlus, P_Ha, P_WMinus, P_A, 1139)
      call createCurrent(P_HMinus, P_ghWp, P_ghZAnti, 3454)
      call createCurrent(P_Z, P_WPlus, P_Hh, P_HMinus, 708)
      call createCurrent(P_A, P_GPlus, P_A, P_HMinus, 3512)
      call createCurrent(P_WMinus, P_A, P_Hl, P_HPlus, 1941)
      call createCurrent(P_g, P_sAnti, P_s, 2204)
      call createCurrent(P_Hh, P_Hl, P_Hh, P_Hl, 346)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, 456)
      call createCurrent(P_GMinus, P_Hh, P_Hh, P_GPlus, 149)
      call createCurrent(P_Ha, P_g, P_G0, P_g, 3632)
      call createCurrent(P_nu_mu, P_nu_muAnti, 3137)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_GPlus, 860)
      call createCurrent(P_GMinus, P_A, P_WPlus, 1623)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_HPlus, 3088)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, P_Z, 661)
      call createCurrent(P_c, P_cAnti, P_g, 1960)
      call createCurrent(P_Ha, P_HMinus, P_Ha, P_GPlus, 965)
      call createCurrent(P_Z, P_Z, P_G0, P_Ha, 3499)
      call createCurrent(P_s, P_Ha, P_sAnti, 2705)
      call createCurrent(P_tAnti, P_b, P_HPlus, 2654)
      call createCurrent(P_u, P_uAnti, P_Z, 1024)
      call createCurrent(P_G0, P_GMinus, P_HPlus, P_Hh, 1399)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_G0, 2985)
      call createCurrent(P_HPlus, P_A, P_WMinus, P_Hl, 2604)
      call createCurrent(P_HPlus, P_WMinus, P_A, 1104)
      call createCurrent(P_WMinus, P_Hh, P_A, P_GPlus, 694)
      call createCurrent(P_G0, P_HPlus, P_A, P_WMinus, 2975)
      call createCurrent(P_nu_eAnti, P_nu_e, P_Z, 2584)
      call createCurrent(P_t, P_bAnti, P_WMinus, 2628)
      call createCurrent(P_A, P_Z, P_HPlus, P_GMinus, 2741)
      call createCurrent(P_Hh, P_c, P_cAnti, 2448)
      call createCurrent(P_Hl, P_G0, P_G0, P_Hl, 1499)
      call createCurrent(P_HMinus, P_bAnti, P_t, 2245)
      call createCurrent(P_G0, P_HPlus, P_Ha, P_HMinus, 2565)
      call createCurrent(P_g, P_b, P_bAnti, 2572)
      call createCurrent(P_A, P_b, P_bAnti, 663)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, P_Hl, 1693)
      call createCurrent(P_ePlus, P_eMinus, P_G0, 1088)
      call createCurrent(P_Hh, P_Hl, P_Hh, 1154)
      call createCurrent(P_G0, P_G0, P_Z, P_A, 2973)
      call createCurrent(P_WPlus, P_WMinus, P_Z, 2454)
      call createCurrent(P_HMinus, P_ghA, P_ghWmAnti, 3274)
      call createCurrent(P_HMinus, P_WPlus, P_Hl, 1597)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, P_Hl, 1262)
      call createCurrent(P_A, P_WPlus, P_HMinus, P_Hh, 2209)
      call createCurrent(P_G0, P_HPlus, P_WMinus, P_A, 3204)
      call createCurrent(P_g, P_Z, P_Z, P_g, 3675)
      call createCurrent(P_Hh, P_GPlus, P_Ha, P_HMinus, 504)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_G0, 838)
      call createCurrent(P_GMinus, P_nu_tau, P_tauPlus, 1160)
      call createCurrent(P_Ha, P_Ha, P_Z, P_Z, 1039)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, P_Hl, 3230)
      call createCurrent(P_HPlus, P_HMinus, P_A, 1715)
      call createCurrent(P_HPlus, P_Ha, P_G0, P_HMinus, 2635)
      call createCurrent(P_Z, P_HPlus, P_G0, P_WMinus, 3096)
      call createCurrent(P_g, P_Hh, P_g, P_Hh, 3862)
      call createCurrent(P_A, P_Hh, P_Z, P_Hl, 3692)
      call createCurrent(P_b, P_HPlus, P_tAnti, 2641)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_Ha, 3584)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, P_G0, 1411)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_Ha, 3132)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, 2351)
      call createCurrent(P_A, P_WPlus, P_G0, P_GMinus, 1558)
      call createCurrent(P_Z, P_Hh, P_Ha, 1741)
      call createCurrent(P_Hl, P_GPlus, P_G0, P_GMinus, 3166)
      call createCurrent(P_tauMinus, P_tauPlus, P_Hl, 326)
      call createCurrent(P_A, P_GMinus, P_Hh, P_WPlus, 2152)
      call createCurrent(P_G0, P_G0, P_Ha, 3795)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Ha, 3154)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_Hl, 2801)
      call createCurrent(P_WPlus, P_WMinus, P_WMinus, P_WPlus, 1916)
      call createCurrent(P_Hl, P_GPlus, P_Hh, P_GMinus, 831)
      call createCurrent(P_G0, P_WPlus, P_Z, P_HMinus, 3441)
      call createCurrent(P_g, P_GPlus, P_GMinus, P_g, 3781)
      call createCurrent(P_Hl, P_Ha, P_A, 2886)
      call createCurrent(P_A, P_HMinus, P_Ha, P_WPlus, 1115)
      call createCurrent(P_HPlus, P_A, P_GMinus, P_Z, 2864)
      call createCurrent(P_Ha, P_Hh, P_HMinus, P_HPlus, 3569)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_GMinus, 1075)
      call createCurrent(P_G0, P_A, P_G0, P_Z, 3093)
      call createCurrent(P_HPlus, P_WMinus, P_Z, P_Hh, 1728)
      call createCurrent(P_HPlus, P_HMinus, P_HPlus, P_HMinus, 717)
      call createCurrent(P_ghZ, P_HPlus, P_ghWpAnti, 2737)
      call createCurrent(P_WPlus, P_muMinus, P_nu_muAnti, 2638)
      call createCurrent(P_HMinus, P_A, P_Hh, P_WPlus, 1512)
      call createCurrent(P_Hl, P_G0, P_Ha, 2656)
      call createCurrent(P_sAnti, P_s, P_G0, 637)
      call createCurrent(P_HPlus, P_WMinus, P_Hl, P_A, 1192)
      call createCurrent(P_Hl, P_Hh, P_HPlus, P_HMinus, 1003)
      call createCurrent(P_Z, P_Z, P_HPlus, P_HMinus, 931)
      call createCurrent(P_HMinus, P_HMinus, P_HPlus, P_HPlus, 927)
      call createCurrent(P_WPlus, P_A, P_Ha, P_HMinus, 1021)
      call createCurrent(P_A, P_HPlus, P_WMinus, 1096)
      call createCurrent(P_b, P_Hl, P_bAnti, 1144)
      call createCurrent(P_A, P_Hl, P_A, P_Hh, 3800)
      call createCurrent(P_u, P_G0, P_uAnti, 1343)
      call createCurrent(P_Ha, P_GPlus, P_Hh, P_GMinus, 2764)
      call createCurrent(P_Z, P_Hh, P_Hh, P_A, 3251)
      call createCurrent(P_g, P_HPlus, P_GMinus, P_g, 3724)
      call createCurrent(P_G0, P_HMinus, P_Hl, P_HPlus, 3125)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_A, 2449)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_Hh, 1244)
      call createCurrent(P_HMinus, P_HPlus, P_G0, P_Hl, 2835)
      call createCurrent(P_HMinus, P_A, P_WPlus, P_Ha, 2430)
      call createCurrent(P_Hl, P_Ha, P_GPlus, P_GMinus, 3341)
      call createCurrent(P_A, P_G0, P_G0, P_Z, 3287)
      call createCurrent(P_Hh, P_WMinus, P_HPlus, P_A, 1471)
      call createCurrent(P_Hh, P_Ha, P_Hl, P_G0, 1808)
      call createCurrent(P_G0, P_sAnti, P_s, 2389)
      call createCurrent(P_Ha, P_HPlus, P_Ha, P_GMinus, 2043)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_G0, 3408)
      call createCurrent(P_Z, P_g, P_g, P_g, 3680)
      call createCurrent(P_GPlus, P_Hl, P_G0, P_HMinus, 801)
      call createCurrent(P_Hl, P_A, P_HPlus, P_WMinus, 886)
      call createCurrent(P_WPlus, P_A, P_Hh, P_GMinus, 464)
      call createCurrent(P_Z, P_Hl, P_WPlus, P_GMinus, 789)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, 2014)
      call createCurrent(P_GPlus, P_Hh, P_Ha, P_GMinus, 3529)
      call createCurrent(P_WPlus, P_A, P_WMinus, 1956)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, P_Ha, 2244)
      call createCurrent(P_GMinus, P_G0, P_Hl, P_GPlus, 2723)
      call createCurrent(P_eMinus, P_ePlus, P_A, 203)
      call createCurrent(P_A, P_HMinus, P_WPlus, P_Hh, 2557)
      call createCurrent(P_HMinus, P_Hh, P_WPlus, 34)
      call createCurrent(P_Hh, P_WMinus, P_HPlus, P_Z, 138)
      call createCurrent(P_g, P_g, P_GMinus, P_HPlus, 3871)
      call createCurrent(P_G0, P_Hl, P_Ha, P_Hl, 1749)
      call createCurrent(P_A, P_tauMinus, P_tauPlus, 2618)
      call createCurrent(P_G0, P_Ha, P_Hl, P_G0, 3706)
      call createCurrent(P_HMinus, P_nu_e, P_ePlus, 164)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_G0, 1756)
      call createCurrent(P_g, P_g, P_Ha, P_Ha, 3867)
      call createCurrent(P_G0, P_WPlus, P_Ha, P_WMinus, 3258)
      call createCurrent(P_GMinus, P_Hh, P_G0, P_HPlus, 2499)
      call createCurrent(P_GPlus, P_Hl, P_Hl, P_HMinus, 19)
      call createCurrent(P_HMinus, P_u, P_dAnti, 906)
      call createCurrent(P_G0, P_GPlus, P_Hl, P_HMinus, 719)
      call createCurrent(P_G0, P_Hh, P_Hl, P_Ha, 544)
      call createCurrent(P_HPlus, P_G0, P_GMinus, P_Ha, 2683)
      call createCurrent(P_A, P_Hl, P_Hh, P_A, 3755)
      call createCurrent(P_d, P_GPlus, P_uAnti, 245)
      call createCurrent(P_GMinus, P_Ha, P_Ha, P_HPlus, 916)
      call createCurrent(P_Ha, P_Hl, P_GMinus, P_GPlus, 2839)
      call createCurrent(P_Z, P_GMinus, P_Z, P_GPlus, 168)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_HPlus, 3213)
      call createCurrent(P_Hl, P_WMinus, P_Z, P_HPlus, 622)
      call createCurrent(P_GMinus, P_GPlus, P_Z, 441)
      call createCurrent(P_WPlus, P_Z, P_Ha, P_HMinus, 741)
      call createCurrent(P_WPlus, P_Ha, P_WMinus, P_Ha, 548)
      call createCurrent(P_HMinus, P_WPlus, P_Ha, P_A, 526)
      call createCurrent(P_Hh, P_A, P_Hh, P_A, 3668)
      call createCurrent(P_A, P_c, P_cAnti, 2606)
      call createCurrent(P_WMinus, P_WPlus, P_WMinus, P_WPlus, 542)
      call createCurrent(P_Hl, P_HMinus, P_G0, P_HPlus, 3533)
      call createCurrent(P_Hh, P_Hh, P_GPlus, P_GMinus, 557)
      call createCurrent(P_Ha, P_HPlus, P_WMinus, P_Z, 1185)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, P_Z, 443)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_Z, 1150)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_Hh, 1589)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, 657)
      call createCurrent(P_Z, P_HMinus, P_Hl, P_WPlus, 2271)
      call createCurrent(P_HPlus, P_Hh, P_WMinus, P_A, 2076)
      call createCurrent(P_Ha, P_Hh, P_G0, P_Hh, 2338)
      call createCurrent(P_GMinus, P_HPlus, P_WMinus, P_WPlus, 3581)
      call createCurrent(P_G0, P_HPlus, P_Ha, P_GMinus, 306)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, 1526)
      call createCurrent(P_HPlus, P_HMinus, P_G0, 2810)
      call createCurrent(P_Ha, P_WMinus, P_Z, P_GPlus, 3196)
      call createCurrent(P_Hh, P_uAnti, P_u, 2213)
      call createCurrent(P_Hl, P_Hh, P_g, P_g, 3596)
      call createCurrent(P_Z, P_A, P_GPlus, P_HMinus, 3202)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, P_Ha, 3118)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, P_Z, 1490)
      call createCurrent(P_uAnti, P_u, P_Ha, 2352)
      call createCurrent(P_Z, P_eMinus, P_ePlus, 750)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, P_Ha, 1685)
      call createCurrent(P_Hh, P_A, P_Hh, P_Z, 3180)
      call createCurrent(P_g, P_g, P_g, P_Z, 3818)
      call createCurrent(P_A, P_HMinus, P_HPlus, 165)
      call createCurrent(P_Ha, P_Ha, P_WPlus, P_WMinus, 1665)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, P_Hh, 1497)
      call createCurrent(P_WMinus, P_Z, P_Ha, P_HPlus, 885)
      call createCurrent(P_Hh, P_Ha, P_HMinus, P_GPlus, 20)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_Z, 1312)
      call createCurrent(P_WMinus, P_Hh, P_Hh, P_WPlus, 748)
      call createCurrent(P_Z, P_WPlus, P_G0, P_GMinus, 1329)
      call createCurrent(P_muPlus, P_GMinus, P_nu_mu, 1283)
      call createCurrent(P_HMinus, P_G0, P_Ha, P_HPlus, 309)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, 2487)
      call createCurrent(P_G0, P_HMinus, P_Hl, P_GPlus, 1527)
      call createCurrent(P_Hh, P_GPlus, P_G0, P_HMinus, 276)
      call createCurrent(P_Hh, P_Hl, P_Hl, P_Hh, 1679)
      call createCurrent(P_A, P_HMinus, P_Hl, P_WPlus, 1393)
      call createCurrent(P_HPlus, P_GMinus, P_A, P_Z, 3372)
      call createCurrent(P_Hh, P_Ha, P_G0, P_Hh, 1519)
      call createCurrent(P_tauMinus, P_tauPlus, P_G0, 1195)
      call createCurrent(P_Hh, P_Hh, P_Hl, P_Hl, 645)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_Hl, 1605)
      call createCurrent(P_Ha, P_d, P_dAnti, 2342)
      call createCurrent(P_GMinus, P_WPlus, P_A, 1577)
      call createCurrent(P_GMinus, P_A, P_G0, P_WPlus, 2257)
      call createCurrent(P_Ha, P_c, P_cAnti, 1641)
      call createCurrent(P_GPlus, P_Z, P_WMinus, 1841)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, 1945)
      call createCurrent(P_G0, P_Z, P_Hl, 1568)
      call createCurrent(P_c, P_Z, P_cAnti, 917)
      call createCurrent(P_WMinus, P_Z, P_HPlus, P_Ha, 297)
      call createCurrent(P_Z, P_HPlus, P_WMinus, 1308)
      call createCurrent(P_Z, P_dAnti, P_d, 2255)
      call createCurrent(P_Ha, P_G0, P_Ha, P_Ha, 1695)
      call createCurrent(P_Ha, P_WPlus, P_WMinus, P_Ha, 160)
      call createCurrent(P_WPlus, P_Z, P_Hh, P_HMinus, 1224)
      call createCurrent(P_G0, P_Z, P_Z, P_Ha, 3504)
      call createCurrent(P_Z, P_HPlus, P_WMinus, P_Hh, 2237)
      call createCurrent(P_HPlus, P_Hl, P_WMinus, P_A, 977)
      call createCurrent(P_tauPlus, P_tauMinus, P_Hl, 545)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_Ha, 3284)
      call createCurrent(P_HPlus, P_G0, P_Ha, P_HMinus, 2450)
      call createCurrent(P_Hh, P_Z, P_Z, P_Hl, 2957)
      call createCurrent(P_g, P_g, 2993)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, 808)
      call createCurrent(P_Hl, P_GPlus, P_Hl, P_GMinus, 1136)
      call createCurrent(P_G0, P_WPlus, P_HMinus, 3194)
      call createCurrent(P_A, P_HMinus, P_Z, P_HPlus, 2070)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, 3054)
      call createCurrent(P_Ha, P_GPlus, P_Hl, P_HMinus, 281)
      call createCurrent(P_WPlus, P_nu_eAnti, P_eMinus, 2589)
      call createCurrent(P_WPlus, P_A, P_G0, P_GMinus, 1366)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_Z, 289)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_Hh, 672)
      call createCurrent(P_Z, P_Ha, P_A, P_Ha, 3538)
      call createCurrent(P_Ha, P_G0, P_Hh, P_Hl, 1620)
      call createCurrent(P_WPlus, P_Ha, P_GMinus, P_A, 2910)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, 2436)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, 353)
      call createCurrent(P_G0, P_Ha, P_G0, P_Hl, 3804)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_A, 929)
      call createCurrent(P_c, P_cAnti, P_Hh, 2151)
      call createCurrent(P_GPlus, P_GMinus, P_g, P_g, 3874)
      call createCurrent(P_G0, P_G0, P_Hl, P_Hl, 1813)
      call createCurrent(P_u, P_uAnti, P_g, 10)
      call createCurrent(P_A, P_Hl, P_GMinus, P_WPlus, 1542)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, 2083)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, 2381)
      call createCurrent(P_Hl, P_GPlus, P_Hl, P_HMinus, 1534)
      call createCurrent(P_HMinus, P_HPlus, 3185)
      call createCurrent(P_Hl, P_Hh, P_A, P_A, 3595)
      call createCurrent(P_HPlus, P_A, P_WMinus, P_Ha, 792)
      call createCurrent(P_WPlus, P_Hh, P_HMinus, 2509)
      call createCurrent(P_WMinus, P_Hh, P_Z, P_HPlus, 1990)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, 959)
      call createCurrent(P_HPlus, P_A, P_HMinus, 819)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, P_G0, 2746)
      call createCurrent(P_Hh, P_HPlus, P_Ha, P_HMinus, 2953)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_HPlus, 2197)
      call createCurrent(P_Ha, P_Hl, P_GMinus, P_HPlus, 2265)
      call createCurrent(P_Hl, P_Z, P_A, P_Hh, 3701)
      call createCurrent(P_Hh, P_GMinus, P_HPlus, P_G0, 1114)
      call createCurrent(P_A, P_G0, P_WMinus, P_GPlus, 2537)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_HPlus, 1504)
      call createCurrent(P_WPlus, P_GMinus, 2862)
      call createCurrent(P_A, P_WMinus, P_Ha, P_GPlus, 3436)
      call createCurrent(P_Hl, P_GPlus, P_A, P_WMinus, 2545)
      call createCurrent(P_G0, P_GPlus, P_Hl, P_GMinus, 3001)
      call createCurrent(P_G0, P_HMinus, P_WPlus, P_A, 3071)
      call createCurrent(P_u, P_g, P_uAnti, 1453)
      call createCurrent(P_GPlus, P_G0, P_Z, P_WMinus, 535)
      call createCurrent(P_cAnti, P_HPlus, P_s, 1180)
      call createCurrent(P_GMinus, P_WPlus, P_Ha, P_Z, 3439)
      call createCurrent(P_A, P_WPlus, P_Hh, P_GMinus, 1085)
      call createCurrent(P_Hh, P_g, P_g, 3647)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, 2528)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, P_Hh, 3370)
      call createCurrent(P_Hl, P_GPlus, P_Ha, P_GMinus, 2781)
      call createCurrent(P_HMinus, P_G0, P_GPlus, P_G0, 978)
      call createCurrent(P_nu_tauAnti, P_GPlus, P_tauMinus, 1818)
      call createCurrent(P_A, P_WPlus, P_Z, P_WMinus, 2207)
      call createCurrent(P_A, P_Ha, P_Hh, 3021)
      call createCurrent(P_G0, P_Hl, P_Ha, P_G0, 3851)
      call createCurrent(P_Hl, P_G0, P_G0, 2089)
      call createCurrent(P_GPlus, P_G0, P_Hl, P_GMinus, 3070)
      call createCurrent(P_ePlus, P_eMinus, P_A, 2341)
      call createCurrent(P_Z, P_Hl, P_A, 3116)
      call createCurrent(P_g, P_g, P_HMinus, P_HPlus, 3691)
      call createCurrent(P_Hl, P_WMinus, P_Hl, P_WPlus, 2053)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_Hl, 2928)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, P_Ha, 804)
      call createCurrent(P_cAnti, P_c, 2963)
      call createCurrent(P_Z, P_WMinus, P_Hh, P_HPlus, 210)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_Hl, 339)
      call createCurrent(P_ePlus, P_eMinus, P_Hl, 466)
      call createCurrent(P_Hh, P_GMinus, P_HPlus, P_Hl, 652)
      call createCurrent(P_Z, P_HPlus, P_GMinus, P_Z, 3402)
      call createCurrent(P_HMinus, P_G0, P_G0, P_GPlus, 1190)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_Hh, 3294)
      call createCurrent(P_Ha, P_WMinus, P_WPlus, P_Ha, 1186)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, 78)
      call createCurrent(P_dAnti, P_HMinus, P_u, 1143)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GPlus, 1081)
      call createCurrent(P_ghWmAnti, P_ghZ, P_HMinus, 3405)
      call createCurrent(P_Ha, P_Hh, P_HPlus, P_HMinus, 3431)
      call createCurrent(P_HPlus, P_G0, P_GMinus, P_Hh, 2553)
      call createCurrent(P_WPlus, P_G0, P_GMinus, 2649)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_Z, 2004)
      call createCurrent(P_ghWm, P_ghZAnti, P_HPlus, 3401)
      call createCurrent(P_Hl, P_Hh, P_Z, P_A, 3847)
      call createCurrent(P_ghWp, P_ghZAnti, P_HMinus, 3219)
      call createCurrent(P_t, P_tAnti, P_A, 1782)
      call createCurrent(P_HMinus, P_HPlus, P_WPlus, P_WMinus, 937)
      call createCurrent(P_GPlus, P_A, P_Hl, P_WMinus, 1660)
      call createCurrent(P_Ha, P_muPlus, P_muMinus, 1604)
      call createCurrent(P_G0, P_Hh, P_Hh, P_G0, 1952)
      call createCurrent(P_WPlus, P_Hl, P_A, P_HMinus, 883)
      call createCurrent(P_A, P_Ha, P_GMinus, P_WPlus, 2998)
      call createCurrent(P_HPlus, P_Ha, P_A, P_WMinus, 65)
      call createCurrent(P_Hh, P_WMinus, P_A, P_GPlus, 1268)
      call createCurrent(P_A, P_nu_mu, P_nu_muAnti, 3472)
      call createCurrent(P_Ha, P_A, P_G0, P_Z, 3879)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_Hl, 1338)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_Hh, 2427)
      call createCurrent(P_HPlus, P_HMinus, P_HMinus, P_HPlus, 878)
      call createCurrent(P_Z, P_G0, P_G0, P_A, 3315)
      call createCurrent(P_Hh, P_Z, P_HPlus, P_WMinus, 1406)
      call createCurrent(P_G0, P_Ha, P_GPlus, P_GMinus, 18)
      call createCurrent(P_Hl, P_HPlus, P_G0, P_GMinus, 995)
      call createCurrent(P_Ha, P_Z, P_HPlus, P_WMinus, 506)
      call createCurrent(P_Ha, P_HMinus, P_Ha, P_HPlus, 2397)
      call createCurrent(P_sAnti, P_s, P_Hh, 1286)
      call createCurrent(P_g, P_HMinus, P_g, P_HPlus, 3664)
      call createCurrent(P_Z, P_A, P_Hl, P_Hl, 2895)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, P_Hh, 253)
      call createCurrent(P_g, P_Z, P_g, P_Z, 3744)
      call createCurrent(P_GPlus, P_Z, P_Z, P_GMinus, 1594)
      call createCurrent(P_HPlus, P_GMinus, P_g, P_g, 3835)
      call createCurrent(P_Ha, P_Ha, P_GMinus, P_GPlus, 621)
      call createCurrent(P_t, P_tAnti, P_G0, 825)
      call createCurrent(P_Hl, P_Hl, P_Z, P_Z, 2118)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_Hl, 3578)
      call createCurrent(P_WMinus, P_WPlus, P_Z, 1993)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, P_G0, 35)
      call createCurrent(P_G0, P_G0, P_Ha, P_Hh, 3606)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, P_Hl, 796)
      call createCurrent(P_dAnti, P_u, P_GMinus, 2034)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, P_G0, 1516)
      call createCurrent(P_Z, P_GPlus, P_Ha, P_WMinus, 3477)
      call createCurrent(P_HMinus, P_GPlus, P_GMinus, P_GPlus, 880)
      call createCurrent(P_A, P_Hh, P_Z, 3393)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, 3428)
      call createCurrent(P_Hh, P_Hh, P_Ha, P_Ha, 1207)
      call createCurrent(P_Hh, P_WPlus, P_Z, P_GMinus, 100)
      call createCurrent(P_GPlus, P_A, P_HMinus, 3005)
      call createCurrent(P_Hl, P_cAnti, P_c, 1619)
      call createCurrent(P_HPlus, P_HMinus, P_Z, P_A, 1825)
      call createCurrent(P_muMinus, P_Hh, P_muPlus, 1551)
      call createCurrent(P_g, P_GMinus, P_HPlus, P_g, 3757)
      call createCurrent(P_Hl, P_A, P_HMinus, P_WPlus, 1781)
      call createCurrent(P_GPlus, P_Hl, P_G0, P_GMinus, 3448)
      call createCurrent(P_Z, P_Ha, P_G0, P_A, 3771)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, P_Hh, 1383)
      call createCurrent(P_HMinus, P_Z, P_GPlus, P_Z, 3007)
      call createCurrent(P_Z, P_Hl, P_WMinus, P_GPlus, 946)
      call createCurrent(P_GMinus, P_dAnti, P_u, 473)
      call createCurrent(P_tauMinus, P_HPlus, P_nu_tauAnti, 2692)
      call createCurrent(P_Z, P_HPlus, P_Hl, P_WMinus, 2490)
      call createCurrent(P_G0, P_WPlus, P_HMinus, P_Z, 3474)
      call createCurrent(P_GPlus, P_G0, P_A, P_WMinus, 1646)
      call createCurrent(P_G0, P_WMinus, P_G0, P_WPlus, 179)
      call createCurrent(P_A, P_HMinus, P_WPlus, 1648)
      call createCurrent(P_HPlus, P_G0, P_HMinus, P_Hh, 2735)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, 2122)
      call createCurrent(P_WMinus, P_nu_mu, P_muPlus, 558)
      call createCurrent(P_HMinus, P_nu_tau, P_tauPlus, 2554)
      call createCurrent(P_WMinus, P_Z, P_HPlus, P_Hh, 922)
      call createCurrent(P_WPlus, P_Z, P_G0, P_GMinus, 1483)
      call createCurrent(P_WMinus, P_G0, P_GPlus, 2308)
      call createCurrent(P_G0, P_eMinus, P_ePlus, 5)
      call createCurrent(P_Hl, P_A, P_Z, P_Hh, 3723)
      call createCurrent(P_Z, P_GMinus, P_Z, P_HPlus, 3497)
      call createCurrent(P_Ha, P_Hl, P_GPlus, P_HMinus, 617)
      call createCurrent(P_HMinus, P_ePlus, P_nu_e, 537)
      call createCurrent(P_u, P_dAnti, P_HMinus, 2676)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_Hh, 455)
      call createCurrent(P_WPlus, P_GMinus, P_A, 1935)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_Z, 722)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_Ha, 1705)
      call createCurrent(P_HPlus, P_GMinus, P_HPlus, P_HMinus, 1731)
      call createCurrent(P_WPlus, P_HMinus, P_Hl, P_A, 909)
      call createCurrent(P_HPlus, P_muMinus, P_nu_muAnti, 2228)
      call createCurrent(P_Ha, P_Ha, P_Ha, P_Ha, 1992)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, P_Hl, 2863)
      call createCurrent(P_G0, P_A, P_G0, P_A, 3639)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_G0, 2913)
      call createCurrent(P_u, P_dAnti, P_WMinus, 2616)
      call createCurrent(P_tAnti, P_GPlus, P_b, 1559)
      call createCurrent(P_HMinus, P_WPlus, P_A, P_Hh, 1258)
      call createCurrent(P_A, P_HMinus, P_WPlus, P_G0, 3557)
      call createCurrent(P_WMinus, P_Hl, P_Hh, P_WPlus, 3470)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, P_Hl, 394)
      call createCurrent(P_G0, P_Hl, P_G0, 42)
      call createCurrent(P_Z, P_A, P_GMinus, P_HPlus, 3458)
      call createCurrent(P_HMinus, P_GPlus, P_WPlus, P_WMinus, 3177)
      call createCurrent(P_G0, P_HPlus, P_WMinus, 3061)
      call createCurrent(P_g, P_g, P_G0, P_Ha, 3748)
      call createCurrent(P_Hh, P_u, P_uAnti, 1129)
      call createCurrent(P_Z, P_Z, P_g, P_g, 3779)
      call createCurrent(P_s, P_A, P_sAnti, 2330)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_Hl, 2406)
      call createCurrent(P_GMinus, P_G0, P_HPlus, P_G0, 2374)
      call createCurrent(P_Z, P_A, P_A, P_A, 3650)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, P_Hl, 287)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, P_Hl, 2087)
      call createCurrent(P_G0, P_WMinus, P_Z, P_GPlus, 1035)
      call createCurrent(P_Hl, P_A, P_Z, 2784)
      call createCurrent(P_muPlus, P_muMinus, P_G0, 157)
      call createCurrent(P_Z, P_Z, P_Ha, P_G0, 3540)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, P_Ha, 2833)
      call createCurrent(P_A, P_WPlus, P_Hl, P_GMinus, 550)
      call createCurrent(P_GPlus, P_HMinus, P_G0, P_Ha, 1668)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_Hl, 359)
      call createCurrent(P_G0, P_A, P_WPlus, P_HMinus, 3360)
      call createCurrent(P_HMinus, P_WPlus, P_G0, 3018)
      call createCurrent(P_Hh, P_HMinus, P_Ha, P_GPlus, 2452)
      call createCurrent(P_sAnti, P_c, P_HMinus, 660)
      call createCurrent(P_GMinus, P_HPlus, P_g, P_g, 3727)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_HMinus, 68)
      call createCurrent(P_tauPlus, P_tauMinus, P_A, 2266)
      call createCurrent(P_WPlus, P_d, P_uAnti, 1635)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, P_Hl, 67)
      call createCurrent(P_Z, P_A, P_G0, P_G0, 3582)
      call createCurrent(P_GMinus, P_bAnti, P_t, 833)
      call createCurrent(P_WMinus, P_GPlus, P_Ha, P_A, 2950)
      call createCurrent(P_g, P_g, P_Z, P_Z, 3590)
      call createCurrent(P_GMinus, P_HPlus, P_A, P_Z, 2935)
      call createCurrent(P_tauPlus, P_Hl, P_tauMinus, 1330)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, P_Z, 746)
      call createCurrent(P_Ha, P_Hh, P_G0, P_G0, 3821)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, P_Hl, 2248)
      call createCurrent(P_Hh, P_Hl, P_G0, P_Ha, 1624)
      call createCurrent(P_ghWm, P_Ha, P_ghWmAnti, 3314)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, P_A, 378)
      call createCurrent(P_HPlus, P_Z, P_GMinus, P_A, 2802)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_HMinus, 3500)
      call createCurrent(P_Z, P_HMinus, P_WPlus, P_Ha, 2556)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, P_Hh, 2982)
      call createCurrent(P_cAnti, P_A, P_c, 2561)
      call createCurrent(P_WPlus, P_Ha, P_A, P_HMinus, 1838)
      call createCurrent(P_Hl, P_Ha, P_G0, 783)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_Z, 1628)
      call createCurrent(P_tauPlus, P_G0, P_tauMinus, 1932)
      call createCurrent(P_Hl, P_A, P_A, P_Hl, 3593)
      call createCurrent(P_tauMinus, P_WPlus, P_nu_tauAnti, 2516)
      call createCurrent(P_A, P_Hl, P_WPlus, P_GMinus, 525)
      call createCurrent(P_Z, P_HMinus, P_WPlus, 2432)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, P_G0, 1323)
      call createCurrent(P_Hh, P_Ha, P_HPlus, P_HMinus, 3325)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_G0, 2630)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, 147)
      call createCurrent(P_nu_e, P_nu_eAnti, P_Z, 2514)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_Z, 690)
      call createCurrent(P_Hh, P_Hh, P_A, P_A, 3737)
      call createCurrent(P_eMinus, P_ePlus, P_Hl, 809)
      call createCurrent(P_muMinus, P_muPlus, 2929)
      call createCurrent(P_Hh, P_HPlus, P_WMinus, P_A, 1803)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghA, 3324)
      call createCurrent(P_Hl, P_Hl, P_Hh, 1845)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_Hh, 2657)
      call createCurrent(P_HPlus, P_s, P_cAnti, 1684)
      call createCurrent(P_Z, P_nu_muAnti, P_nu_mu, 1479)
      call createCurrent(P_HMinus, P_HPlus, P_G0, P_G0, 374)
      call createCurrent(P_bAnti, P_b, P_G0, 1578)
      call createCurrent(P_nu_eAnti, P_nu_e, 3229)
      call createCurrent(P_HMinus, P_G0, P_HPlus, P_Hl, 2941)
      call createCurrent(P_A, P_HPlus, P_G0, P_WMinus, 2959)
      call createCurrent(P_G0, P_Hl, P_G0, P_Ha, 3679)
      call createCurrent(P_Hl, P_Ha, P_G0, P_G0, 3722)
      call createCurrent(P_g, P_GMinus, P_GPlus, P_g, 3611)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_HPlus, 1237)
      call createCurrent(P_Z, P_nu_tau, P_nu_tauAnti, 96)
      call createCurrent(P_HPlus, P_Hh, P_Z, P_WMinus, 2289)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_HPlus, 3480)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, 1428)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_Hl, 627)
      call createCurrent(P_WPlus, P_nu_muAnti, P_muMinus, 1461)
      call createCurrent(P_muMinus, P_muPlus, P_A, 61)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_G0, 2172)
      call createCurrent(P_dAnti, P_d, P_Z, 2055)
      call createCurrent(P_G0, P_Hh, P_Ha, P_Hh, 48)
      call createCurrent(P_Z, P_WMinus, P_Hl, P_GPlus, 2284)
      call createCurrent(P_Ha, P_ghWm, P_ghWmAnti, 2902)
      call createCurrent(P_G0, P_Hh, P_Hl, P_G0, 1827)
      call createCurrent(P_Hh, P_A, P_HPlus, P_WMinus, 2662)
      call createCurrent(P_sAnti, P_s, P_Ha, 335)
      call createCurrent(P_WMinus, P_c, P_sAnti, 2002)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, P_Hh, 3111)
      call createCurrent(P_GMinus, P_Hl, P_A, P_WPlus, 2038)
      call createCurrent(P_Ha, P_GPlus, P_WMinus, P_A, 2830)
      call createCurrent(P_A, P_Z, 3543)
      call createCurrent(P_WPlus, P_A, P_HMinus, P_G0, 2908)
      call createCurrent(P_Ha, P_Ha, P_WMinus, P_WPlus, 1272)
      call createCurrent(P_GMinus, P_GPlus, P_HPlus, P_GMinus, 1026)
      call createCurrent(P_A, P_Ha, P_Ha, P_Z, 2820)
      call createCurrent(P_Hl, P_WPlus, P_Hl, P_WMinus, 599)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, 1265)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_G0, 2458)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_G0, 2312)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hl, 738)
      call createCurrent(P_G0, P_A, P_WMinus, P_GPlus, 14)
      call createCurrent(P_b, P_bAnti, P_G0, 312)
      call createCurrent(P_Z, P_WPlus, P_HMinus, P_Hl, 655)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, 2624)
      call createCurrent(P_A, P_WPlus, P_WMinus, 265)
      call createCurrent(P_GPlus, P_Hh, P_Hh, P_GMinus, 610)
      call createCurrent(P_HPlus, P_Z, P_Hl, P_WMinus, 1099)
      call createCurrent(P_WMinus, P_G0, P_HPlus, P_Z, 2884)
      call createCurrent(P_Ha, P_Hh, P_Ha, 1564)
      call createCurrent(P_tauPlus, P_A, P_tauMinus, 2632)
      call createCurrent(P_tauMinus, P_tauPlus, P_A, 1012)
      call createCurrent(P_WMinus, P_Hl, P_Z, P_GPlus, 109)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, 107)
      call createCurrent(P_HMinus, P_Z, P_HPlus, 1438)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_A, 364)
      call createCurrent(P_Ha, P_Hh, P_A, 2771)
      call createCurrent(P_bAnti, P_WMinus, P_t, 1969)
      call createCurrent(P_WMinus, P_GPlus, P_A, 781)
      call createCurrent(P_Hh, P_GMinus, P_A, P_WPlus, 154)
      call createCurrent(P_HMinus, P_GMinus, P_HPlus, P_HPlus, 87)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, P_Ha, 2363)
      call createCurrent(P_Ha, P_Hl, P_GPlus, P_GMinus, 3339)
      call createCurrent(P_HMinus, P_WPlus, P_Hl, P_A, 2658)
      call createCurrent(P_G0, P_Hh, P_HMinus, P_GPlus, 422)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_A, 1544)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, P_G0, 2629)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, P_Hl, 2652)
      call createCurrent(P_A, P_GPlus, P_WMinus, 1487)
      call createCurrent(P_GMinus, P_A, P_Ha, P_WPlus, 2912)
      call createCurrent(P_Z, P_Hl, P_HMinus, P_WPlus, 1028)
      call createCurrent(P_Z, P_HMinus, P_G0, P_WPlus, 3503)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, 2109)
      call createCurrent(P_A, P_G0, P_WMinus, P_HPlus, 3250)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, P_G0, 2942)
      call createCurrent(P_ghGAnti, P_g, P_ghG, 1202)
      call createCurrent(P_Hh, P_Ha, P_Ha, P_Hh, 1805)
      call createCurrent(P_Z, P_Ha, P_WMinus, P_HPlus, 285)
      call createCurrent(P_s, P_cAnti, P_WPlus, 619)
      call createCurrent(P_Hl, P_WPlus, P_Z, P_GMinus, 2317)
      call createCurrent(P_WMinus, P_Hh, P_HPlus, P_Z, 794)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_G0, 1508)
      call createCurrent(P_G0, P_GMinus, P_Ha, P_HPlus, 1174)
      call createCurrent(P_Hl, P_Hh, P_HMinus, P_GPlus, 2210)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, P_Hh, 315)
      call createCurrent(P_A, P_WMinus, P_WPlus, 1238)
      call createCurrent(P_G0, P_HPlus, P_Hh, P_GMinus, 2203)
      call createCurrent(P_HMinus, P_Ha, P_G0, P_GPlus, 89)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_Hh, 3488)
      call createCurrent(P_Hl, P_WMinus, P_HPlus, P_A, 1621)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, 399)
      call createCurrent(P_Ha, P_Hh, P_Hh, P_G0, 1092)
      call createCurrent(P_Hh, P_G0, P_G0, P_Hl, 1008)
      call createCurrent(P_HPlus, P_A, P_GMinus, 2841)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, P_Hl, 70)
      call createCurrent(P_Hl, P_Z, P_WMinus, P_GPlus, 218)
      call createCurrent(P_Hh, P_G0, P_Ha, P_G0, 3697)
      call createCurrent(P_WPlus, P_b, P_tAnti, 1212)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_A, 95)
      call createCurrent(P_Hl, P_bAnti, P_b, 1949)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, 2623)
      call createCurrent(P_Hh, P_Z, P_Hh, P_Z, 2212)
      call createCurrent(P_Hl, P_HMinus, P_Hl, P_HPlus, 2094)
      call createCurrent(P_A, P_Hh, P_HMinus, P_WPlus, 2064)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, 1102)
      call createCurrent(P_nu_muAnti, P_Z, P_nu_mu, 296)
      call createCurrent(P_Hh, P_G0, P_GPlus, P_HMinus, 2562)
      call createCurrent(P_Z, P_A, P_G0, P_Ha, 3602)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, P_Hh, 256)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, P_Ha, 1109)
      call createCurrent(P_Z, P_WMinus, P_HPlus, 2647)
      call createCurrent(P_HPlus, P_Z, P_A, P_HMinus, 1791)
      call createCurrent(P_GMinus, P_WMinus, P_HPlus, P_WPlus, 3252)
      call createCurrent(P_nu_muAnti, P_A, P_nu_mu, 3191)
      call createCurrent(P_Ha, P_Z, P_HMinus, P_WPlus, 1084)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghWp, 2728)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_Ha, 2716)
      call createCurrent(P_ghWp, P_Ha, P_ghWpAnti, 3190)
      call createCurrent(P_GPlus, P_Ha, P_WMinus, P_A, 3048)
      call createCurrent(P_WMinus, P_Z, P_A, P_WPlus, 2567)
      call createCurrent(P_Hh, P_Hl, P_g, P_g, 3642)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, 1317)
      call createCurrent(P_G0, P_Ha, P_G0, P_Hh, 3861)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, 879)
      call createCurrent(P_WMinus, P_HPlus, P_A, 134)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, 320)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, P_Z, 471)
      call createCurrent(P_GPlus, P_HMinus, P_G0, P_Hh, 351)
      call createCurrent(P_GMinus, P_Z, P_Hl, P_WPlus, 2125)
      call createCurrent(P_Hh, P_G0, P_G0, P_Ha, 3845)
      call createCurrent(P_GMinus, P_Ha, P_Hh, P_GPlus, 3075)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_A, 1098)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, P_Hl, 1171)
      call createCurrent(P_Hl, P_Hl, P_Hh, P_Hh, 1090)
      call createCurrent(P_Ha, P_A, P_GMinus, P_WPlus, 3357)
      call createCurrent(P_HMinus, P_GPlus, P_HMinus, P_GPlus, 1229)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, 292)
      call createCurrent(P_HMinus, P_WPlus, P_Z, P_Hh, 38)
      call createCurrent(P_HMinus, P_WPlus, P_Hh, P_A, 811)
      call createCurrent(P_ghA, P_ghWmAnti, P_HMinus, 3217)
      call createCurrent(P_HPlus, P_G0, P_A, P_WMinus, 3129)
      call createCurrent(P_HMinus, P_GPlus, P_GPlus, P_GMinus, 316)
      call createCurrent(P_Hh, P_HPlus, P_Z, P_WMinus, 1565)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, P_G0, 344)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, 1031)
      call createCurrent(P_G0, P_bAnti, P_b, 1326)
      call createCurrent(P_Z, P_Z, P_HMinus, P_GPlus, 3098)
      call createCurrent(P_Z, P_Z, P_Hl, P_Hl, 225)
      call createCurrent(P_HPlus, P_GMinus, P_A, 2971)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, P_A, 1097)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_A, 538)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_Hl, 258)
      call createCurrent(P_G0, P_Ha, P_WPlus, P_WMinus, 3331)
      call createCurrent(P_HMinus, P_A, P_WPlus, P_Hh, 2600)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, P_G0, 1545)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, 1445)
      call createCurrent(P_Ha, P_G0, P_Hl, P_Hl, 2268)
      call createCurrent(P_GMinus, P_HMinus, P_HPlus, P_GPlus, 730)
      call createCurrent(P_Ha, P_WMinus, P_G0, P_WPlus, 3570)
      call createCurrent(P_GPlus, P_Hl, P_Hh, P_HMinus, 1638)
      call createCurrent(P_WPlus, P_HMinus, P_Z, P_Hl, 2215)
      call createCurrent(P_nu_muAnti, P_HPlus, P_muMinus, 949)
      call createCurrent(P_GMinus, P_tauPlus, P_nu_tau, 1120)
      call createCurrent(P_A, P_GPlus, P_Hl, P_WMinus, 938)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_Z, 1464)
      call createCurrent(P_Hl, P_Hl, P_Z, P_A, 3516)
      call createCurrent(P_muPlus, P_Ha, P_muMinus, 1354)
      call createCurrent(P_WMinus, P_Ha, P_HPlus, P_A, 2455)
      call createCurrent(P_WMinus, P_HPlus, P_Z, P_G0, 3026)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_Hh, 2665)
      call createCurrent(P_HMinus, P_GPlus, P_Z, 3451)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_G0, 2544)
      call createCurrent(P_WPlus, P_GMinus, P_HPlus, P_WMinus, 2919)
      call createCurrent(P_HMinus, P_nu_mu, P_muPlus, 212)
      call createCurrent(P_A, P_GMinus, P_G0, P_WPlus, 1162)
      call createCurrent(P_b, P_tAnti, P_HPlus, 349)
      call createCurrent(P_A, P_WPlus, P_Hh, P_HMinus, 1401)
      call createCurrent(P_G0, P_GMinus, P_Hh, P_HPlus, 1134)
      call createCurrent(P_c, P_sAnti, P_HMinus, 1939)
      call createCurrent(P_Z, P_Hl, P_G0, 1748)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, P_Ha, 2052)
      call createCurrent(P_Ha, P_Ha, P_Hl, 150)
      call createCurrent(P_WMinus, P_A, P_A, P_WPlus, 2252)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_A, 994)
      call createCurrent(P_G0, P_Hl, P_G0, P_Hh, 1745)
      call createCurrent(P_A, P_G0, P_Z, P_G0, 3295)
      call createCurrent(P_A, P_WMinus, P_HPlus, P_Hl, 361)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, 1687)
      call createCurrent(P_WPlus, P_tAnti, P_b, 1579)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_Hl, 238)
      call createCurrent(P_nu_tauAnti, P_nu_tau, 3244)
      call createCurrent(P_GPlus, P_G0, P_Hl, P_HMinus, 2035)
      call createCurrent(P_GPlus, P_Ha, P_Ha, P_HMinus, 1830)
      call createCurrent(P_Z, P_G0, P_WMinus, P_HPlus, 3508)
      call createCurrent(P_Hh, P_Z, P_G0, 172)
      call createCurrent(P_GPlus, P_Hh, P_Hl, P_GMinus, 427)
      call createCurrent(P_WPlus, P_G0, P_HMinus, P_Z, 3040)
      call createCurrent(P_GMinus, P_G0, P_Ha, P_GPlus, 192)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_Hl, 1562)
      call createCurrent(P_Z, P_Hl, P_HPlus, P_WMinus, 2247)
      call createCurrent(P_GPlus, P_HMinus, P_WPlus, P_WMinus, 3243)
      call createCurrent(P_dAnti, P_u, P_HMinus, 1015)
      call createCurrent(P_Z, P_WMinus, P_Z, P_WPlus, 2261)
      call createCurrent(P_g, P_G0, P_G0, P_g, 3607)
      call createCurrent(P_tauPlus, P_tauMinus, 3444)
      call createCurrent(P_G0, P_Hh, P_A, 3429)
      call createCurrent(P_Hh, P_Hh, P_HMinus, P_GPlus, 681)
      call createCurrent(P_GPlus, P_G0, P_HMinus, P_Hl, 1806)
      call createCurrent(P_G0, P_HPlus, P_HMinus, P_G0, 91)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, P_Hl, 1458)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, 110)
      call createCurrent(P_ghA, P_HPlus, P_ghWpAnti, 2897)
      call createCurrent(P_G0, P_HMinus, P_HPlus, P_Hl, 2789)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_Z, 460)
      call createCurrent(P_GMinus, P_Z, P_HPlus, P_Z, 3395)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_HMinus, 3072)
      call createCurrent(P_tAnti, P_t, 3463)
      call createCurrent(P_g, P_Hh, P_g, 3711)
      call createCurrent(P_WPlus, P_HMinus, P_A, P_Hl, 495)
      call createCurrent(P_Ha, P_WPlus, P_G0, P_WMinus, 2901)
      call createCurrent(P_Hl, P_Z, P_Hh, P_Z, 3047)
      call createCurrent(P_HPlus, P_A, P_Hl, P_WMinus, 249)
      call createCurrent(P_Z, P_HMinus, P_GPlus, P_A, 3479)
      call createCurrent(P_GPlus, P_A, P_GMinus, 1379)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_A, 1310)
      call createCurrent(P_Z, P_u, P_uAnti, 1071)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, P_Hh, 347)
      call createCurrent(P_Z, P_WPlus, P_WMinus, 290)
      call createCurrent(P_Z, P_nu_mu, P_nu_muAnti, 912)
      call createCurrent(P_GMinus, P_Z, P_HPlus, P_A, 3272)
      call createCurrent(P_Hh, P_A, P_Z, 3466)
      call createCurrent(P_Ha, P_ghWmAnti, P_ghWm, 2937)
      call createCurrent(P_G0, P_HPlus, P_Hl, P_GMinus, 1856)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, P_G0, 1891)
      call createCurrent(P_Ha, P_A, P_Hh, 3212)
      call createCurrent(P_HMinus, P_Ha, P_Hh, P_HPlus, 2762)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, 2359)
      call createCurrent(P_WPlus, P_uAnti, P_d, 8)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, P_Z, 2440)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, 1448)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, 2236)
      call createCurrent(P_WPlus, P_Z, P_HMinus, P_Hl, 2502)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_Z, 55)
      call createCurrent(P_u, P_Z, P_uAnti, 2651)
      call createCurrent(P_Hl, P_Z, P_Hh, P_A, 3798)
      call createCurrent(P_g, P_Ha, P_G0, P_g, 3635)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, P_Hh, 812)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, P_A, 115)
      call createCurrent(P_A, P_Hh, P_Z, P_Hh, 2811)
      call createCurrent(P_Hl, P_HPlus, P_A, P_WMinus, 2219)
      call createCurrent(P_Hl, P_G0, P_Ha, P_G0, 3819)
      call createCurrent(P_G0, P_HMinus, P_A, P_WPlus, 3376)
      call createCurrent(P_uAnti, P_A, P_u, 2169)
      call createCurrent(P_WMinus, P_Ha, P_GPlus, P_A, 3452)
      call createCurrent(P_uAnti, P_WPlus, P_d, 1057)
      call createCurrent(P_Z, P_A, P_GMinus, P_GPlus, 942)
      call createCurrent(P_HMinus, P_G0, P_Hh, P_HPlus, 3119)
      call createCurrent(P_WPlus, P_Ha, P_HMinus, P_A, 371)
      call createCurrent(P_WPlus, P_Hl, P_Z, P_GMinus, 2691)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghWm, 3417)
      call createCurrent(P_Z, P_GPlus, P_HMinus, P_A, 3215)
      call createCurrent(P_WPlus, P_A, P_Z, P_WMinus, 15)
      call createCurrent(P_Z, P_HPlus, P_HMinus, P_Z, 2456)
      call createCurrent(P_Hh, P_WPlus, P_Hl, P_WMinus, 3445)
      call createCurrent(P_Ha, P_G0, P_Hh, P_G0, 3669)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_Hh, 3551)
      call createCurrent(P_tauPlus, P_GMinus, P_nu_tau, 2302)
      call createCurrent(P_Z, P_A, P_Ha, P_Ha, 3460)
      call createCurrent(P_GMinus, P_A, P_HPlus, P_Z, 3039)
      call createCurrent(P_ghZAnti, P_Hl, P_ghZ, 337)
      call createCurrent(P_Hl, P_GMinus, P_Ha, P_HPlus, 776)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_Ha, 3085)
      call createCurrent(P_Hl, P_A, P_Ha, 2881)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_Hh, 667)
      call createCurrent(P_sAnti, P_c, P_GMinus, 1673)
      call createCurrent(P_WPlus, P_Ha, P_Ha, P_WMinus, 963)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_Z, 1432)
      call createCurrent(P_HPlus, P_WMinus, P_Z, P_Hl, 398)
      call createCurrent(P_WMinus, P_t, P_bAnti, 1362)
      call createCurrent(P_ghWp, P_HMinus, P_ghZAnti, 3224)
      call createCurrent(P_GMinus, P_GPlus, P_HMinus, P_GPlus, 303)
      call createCurrent(P_HMinus, P_c, P_sAnti, 1607)
      call createCurrent(P_WMinus, P_Z, P_GPlus, 981)
      call createCurrent(P_A, P_nu_eAnti, P_nu_e, 3094)
      call createCurrent(P_c, P_cAnti, P_Hl, 1170)
      call createCurrent(P_Hh, P_G0, P_GMinus, P_GPlus, 2826)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_Ha, 2958)
      call createCurrent(P_HPlus, P_Z, P_WMinus, P_Ha, 1911)
      call createCurrent(P_G0, P_Hl, P_Hl, P_G0, 1828)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, P_Z, 903)
      call createCurrent(P_Z, P_Hl, P_Ha, 744)
      call createCurrent(P_c, P_GMinus, P_sAnti, 1870)
      call createCurrent(P_Ha, P_A, P_Z, P_Ha, 3526)
      call createCurrent(P_nu_e, P_nu_eAnti, 2708)
      call createCurrent(P_Hl, P_Z, P_Ha, 2453)
      call createCurrent(P_HMinus, P_Z, P_Z, P_HPlus, 1663)
      call createCurrent(P_HMinus, P_Hh, P_A, P_WPlus, 1019)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, 2684)
      call createCurrent(P_nu_eAnti, P_Z, P_nu_e, 2208)
      call createCurrent(P_GPlus, P_Z, P_Z, P_HMinus, 3265)
      call createCurrent(P_HPlus, P_eMinus, P_nu_eAnti, 1632)
      call createCurrent(P_G0, P_A, P_Z, P_Ha, 3857)
      call createCurrent(P_Ha, P_WMinus, P_GPlus, P_A, 3178)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, 2395)
      call createCurrent(P_Hh, P_Z, P_A, P_Hh, 3022)
      call createCurrent(P_Hl, P_dAnti, P_d, 2205)
      call createCurrent(P_b, P_Z, P_bAnti, 1678)
      call createCurrent(P_d, P_dAnti, P_G0, 125)
      call createCurrent(P_cAnti, P_WPlus, P_s, 1121)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, 231)
      call createCurrent(P_A, P_Z, P_HMinus, P_HPlus, 871)
      call createCurrent(P_Ha, P_HPlus, P_WMinus, 207)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, 175)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_A, 1726)
      call createCurrent(P_d, P_uAnti, P_WPlus, 524)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_Ha, 3404)
      call createCurrent(P_Hl, P_Hh, P_GPlus, P_GMinus, 2466)
      call createCurrent(P_Hl, P_GMinus, P_A, P_WPlus, 2345)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_Z, 2401)
      call createCurrent(P_GPlus, P_WPlus, P_GMinus, P_WMinus, 1194)
      call createCurrent(P_tauPlus, P_WMinus, P_nu_tau, 1940)
      call createCurrent(P_GPlus, P_Ha, P_Hh, P_HMinus, 388)
      call createCurrent(P_b, P_tAnti, P_WPlus, 53)
      call createCurrent(P_g, P_g, P_WPlus, P_WMinus, 3712)
      call createCurrent(P_Ha, P_GPlus, P_G0, P_GMinus, 2535)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, P_G0, 2661)
      call createCurrent(P_u, P_HMinus, P_dAnti, 1047)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, 969)
      call createCurrent(P_Z, P_GMinus, P_A, P_HPlus, 2866)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, 2611)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, P_Z, 727)
      call createCurrent(P_WMinus, P_Z, P_Hh, P_HPlus, 1643)
      call createCurrent(P_HMinus, P_G0, P_WPlus, P_A, 3394)
      call createCurrent(P_HMinus, P_WPlus, P_Hh, P_Z, 483)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, 232)
      call createCurrent(P_Hh, P_A, P_GMinus, P_WPlus, 734)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_Hl, 2815)
      call createCurrent(P_A, P_HPlus, P_Z, P_HMinus, 2360)
      call createCurrent(P_A, P_G0, P_A, P_G0, 3780)
      call createCurrent(P_A, P_HMinus, P_GPlus, P_A, 3455)
      call createCurrent(P_GMinus, P_WPlus, P_HPlus, P_WMinus, 3588)
      call createCurrent(P_WPlus, P_HPlus, P_WMinus, P_GMinus, 3496)
      call createCurrent(P_WMinus, P_WPlus, 3459)
      call createCurrent(P_Hl, P_Z, P_WPlus, P_GMinus, 1430)
      call createCurrent(P_Z, P_HMinus, P_GPlus, P_Z, 2832)
      call createCurrent(P_G0, P_b, P_bAnti, 474)
      call createCurrent(P_Hh, P_GPlus, P_Ha, P_GMinus, 2729)
      call createCurrent(P_HPlus, P_Ha, P_Hl, P_GMinus, 1030)
      call createCurrent(P_A, P_WMinus, P_G0, P_HPlus, 3152)
      call createCurrent(P_eMinus, P_ePlus, P_Ha, 771)
      call createCurrent(P_HMinus, P_GMinus, P_GPlus, P_HPlus, 1320)
      call createCurrent(P_Hh, P_G0, P_GMinus, P_HPlus, 2698)
      call createCurrent(P_Z, P_A, P_Ha, P_G0, 3666)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, 2525)
      call createCurrent(P_WMinus, P_nu_tau, P_tauPlus, 1792)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_Hh, 1117)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, 1515)
      call createCurrent(P_Hl, P_HMinus, P_WPlus, P_Z, 707)
      call createCurrent(P_A, P_Z, P_Ha, P_G0, 3592)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghWm, 1807)
      call createCurrent(P_Hl, P_A, P_WMinus, P_GPlus, 1640)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, 368)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, 882)
      call createCurrent(P_GMinus, P_WPlus, P_Ha, 2889)
      call createCurrent(P_WPlus, P_WMinus, P_WPlus, P_WMinus, 1271)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_Hh, 3415)
      call createCurrent(P_WPlus, P_Z, P_Hl, P_GMinus, 2092)
      call createCurrent(P_uAnti, P_Ha, P_u, 59)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghWp, 2184)
      call createCurrent(P_Ha, P_dAnti, P_d, 2016)
      call createCurrent(P_nu_tau, P_Z, P_nu_tauAnti, 159)
      call createCurrent(P_WPlus, P_Hh, P_Hl, P_WMinus, 2817)
      call createCurrent(P_Ha, P_A, P_GPlus, P_WMinus, 2939)
      call createCurrent(P_Hh, P_Hl, P_HMinus, P_HPlus, 1429)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_A, 2595)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, P_G0, 1852)
      call createCurrent(P_Z, P_Hh, P_WMinus, P_HPlus, 2674)
      call createCurrent(P_Hl, P_Hh, P_HPlus, P_GMinus, 1449)
      call createCurrent(P_b, P_WPlus, P_tAnti, 2254)
      call createCurrent(P_A, P_nu_e, P_nu_eAnti, 2920)
      call createCurrent(P_cAnti, P_c, P_Hh, 1910)
      call createCurrent(P_bAnti, P_t, P_WMinus, 857)
      call createCurrent(P_Hl, P_Z, P_Hl, P_Z, 2073)
      call createCurrent(P_WMinus, P_HPlus, P_GMinus, P_WPlus, 2997)
      call createCurrent(P_Hh, P_Ha, P_G0, P_Hl, 363)
      call createCurrent(P_HMinus, P_Hh, P_Ha, P_GPlus, 2588)
      call createCurrent(P_GMinus, P_G0, P_Hh, P_HPlus, 758)
      call createCurrent(P_Ha, P_HPlus, P_Z, P_WMinus, 2442)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, P_Hl, 1819)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, P_Ha, 1689)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, P_A, 2249)
      call createCurrent(P_HMinus, P_G0, P_A, P_WPlus, 2796)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, P_Z, 1948)
      call createCurrent(P_WPlus, P_eMinus, P_nu_eAnti, 683)
      call createCurrent(P_tAnti, P_WPlus, P_b, 2230)
      call createCurrent(P_WPlus, P_Z, P_HMinus, P_G0, 3197)
      call createCurrent(P_G0, P_HMinus, P_G0, P_GPlus, 1068)
      call createCurrent(P_G0, P_Hh, P_G0, P_Ha, 3643)
      call createCurrent(P_c, P_cAnti, P_A, 469)
      call createCurrent(P_GPlus, P_HMinus, P_WMinus, P_WPlus, 3110)
      call createCurrent(P_Hl, P_ghWm, P_ghWmAnti, 1800)
      call createCurrent(P_GMinus, P_Ha, P_WPlus, P_Z, 3057)
      call createCurrent(P_Z, P_Hh, P_Z, P_Hh, 2012)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, 1636)
      call createCurrent(P_HMinus, P_G0, P_WPlus, 2713)
      call createCurrent(P_Ha, P_Hh, P_Z, 2033)
      call createCurrent(P_Z, P_HMinus, P_WPlus, P_Hh, 2519)
      call createCurrent(P_g, P_Hl, P_g, P_Hh, 3718)
      call createCurrent(P_Hh, P_WPlus, P_HMinus, 1972)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, 1877)
      call createCurrent(P_WPlus, P_G0, P_HMinus, 3025)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, P_Ha, 1878)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, P_Hl, 3290)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_Hl, 1111)
      call createCurrent(P_GMinus, P_HPlus, P_Z, P_A, 3352)
      call createCurrent(P_HMinus, P_HPlus, P_Z, 1848)
      call createCurrent(P_Ha, P_ePlus, P_eMinus, 2327)
      call createCurrent(P_HMinus, P_sAnti, P_c, 2474)
      call createCurrent(P_G0, P_Z, P_A, P_G0, 3199)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, 2539)
      call createCurrent(P_HPlus, P_Hh, P_G0, P_GMinus, 1417)
      call createCurrent(P_A, P_WMinus, P_Hh, P_HPlus, 555)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GPlus, 2578)
      call createCurrent(P_WPlus, P_GMinus, P_Z, 895)
      call createCurrent(P_G0, P_GMinus, P_Hh, P_GPlus, 3161)
      call createCurrent(P_HMinus, P_HPlus, P_GMinus, P_GPlus, 486)
      call createCurrent(P_GMinus, P_g, P_HPlus, P_g, 3698)
      call createCurrent(P_HPlus, P_ghZ, P_ghWpAnti, 2740)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, 1240)
      call createCurrent(P_G0, P_G0, P_Hl, P_Hh, 1611)
      call createCurrent(P_ghZAnti, P_Hh, P_ghZ, 143)
      call createCurrent(P_HMinus, P_Z, P_Hh, P_WPlus, 1988)
      call createCurrent(P_tauMinus, P_tauPlus, P_Ha, 2501)
      call createCurrent(P_Hh, P_Hl, P_HPlus, P_HMinus, 1979)
      call createCurrent(P_Z, P_Z, P_Ha, P_Ha, 1198)
      call createCurrent(P_g, P_Z, P_A, P_g, 3689)
      call createCurrent(P_ePlus, P_nu_e, P_HMinus, 162)
      call createCurrent(P_Hh, P_Hh, P_HPlus, P_GMinus, 868)
      call createCurrent(P_eMinus, P_ePlus, 3055)
      call createCurrent(P_GMinus, P_Z, P_WPlus, 1575)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, P_Hh, 1269)
      call createCurrent(P_HPlus, P_GMinus, P_G0, P_Ha, 1576)
      call createCurrent(P_Z, P_HMinus, P_Ha, P_WPlus, 119)
      call createCurrent(P_Hh, P_GPlus, P_G0, P_GMinus, 3233)
      call createCurrent(P_G0, P_Hl, P_Hh, P_G0, 2396)
      call createCurrent(P_G0, P_HMinus, P_GPlus, P_Hl, 491)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, P_Ha, 2738)
      call createCurrent(P_Hh, P_A, P_HMinus, P_WPlus, 1927)
      call createCurrent(P_HMinus, P_WPlus, P_Z, P_G0, 2858)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, 1415)
      call createCurrent(P_HPlus, P_WMinus, P_A, P_G0, 3206)
      call createCurrent(P_Ha, P_A, P_Ha, P_Z, 3434)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_Z, 2506)
      call createCurrent(P_HMinus, P_g, P_HPlus, P_g, 3738)
      call createCurrent(P_Z, P_A, P_WMinus, P_WPlus, 1909)
      call createCurrent(P_Ha, P_A, P_G0, P_A, 3729)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, P_Ha, 102)
      call createCurrent(P_WPlus, P_G0, P_Z, P_HMinus, 3279)
      call createCurrent(P_GPlus, P_WMinus, P_Ha, P_A, 3399)
      call createCurrent(P_tauMinus, P_Ha, P_tauPlus, 638)
      call createCurrent(P_Z, P_HPlus, P_GMinus, 3442)
      call createCurrent(P_G0, P_Ha, P_G0, P_G0, 1460)
      call createCurrent(P_WPlus, P_G0, P_A, P_HMinus, 3518)
      call createCurrent(P_G0, P_HMinus, P_Hh, P_GPlus, 1204)
      call createCurrent(P_A, P_A, P_GPlus, P_GMinus, 2324)
      call createCurrent(P_Hh, P_HPlus, P_A, P_WMinus, 1446)
      call createCurrent(P_Ha, P_Hl, P_HMinus, P_HPlus, 2970)
      call createCurrent(P_G0, P_Hh, P_HPlus, P_GMinus, 2574)
      call createCurrent(P_A, P_tAnti, P_t, 2543)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, 1657)
      call createCurrent(P_G0, P_GPlus, P_WMinus, 2234)
      call createCurrent(P_Ha, P_Z, P_WMinus, P_HPlus, 2286)
      call createCurrent(P_Hl, P_G0, P_GPlus, P_GMinus, 2898)
      call createCurrent(P_eMinus, P_Ha, P_ePlus, 2180)
      call createCurrent(P_Hl, P_Hh, P_Ha, P_Ha, 728)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_Ha, 1007)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_A, 1884)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, 221)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_Hh, 790)
      call createCurrent(P_Z, P_d, P_dAnti, 1861)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_G0, 1793)
      call createCurrent(P_HMinus, P_Z, P_A, P_HPlus, 1378)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, P_Hl, 3338)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_Ha, 2727)
      call createCurrent(P_HPlus, P_WMinus, P_A, P_Hl, 1056)
      call createCurrent(P_HPlus, P_WMinus, P_Hl, 1546)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_Ha, 3027)
      call createCurrent(P_HPlus, P_d, P_uAnti, 445)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, P_Hh, 3136)
      call createCurrent(P_G0, P_Ha, P_Z, P_Z, 3184)
      call createCurrent(P_eMinus, P_ePlus, P_Hh, 1110)
      call createCurrent(P_HMinus, P_WPlus, P_WMinus, P_HPlus, 1755)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, 1764)
      call createCurrent(P_Z, P_A, P_GPlus, P_GMinus, 1159)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_G0, 3565)
      call createCurrent(P_G0, P_WPlus, P_G0, P_WMinus, 449)
      call createCurrent(P_GMinus, P_c, P_sAnti, 945)
      call createCurrent(P_g, P_c, P_cAnti, 870)
      call createCurrent(P_HPlus, P_Z, P_HMinus, P_A, 1622)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, 3169)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, 414)
      call createCurrent(P_Ha, P_HMinus, P_Hl, P_HPlus, 3388)
      call createCurrent(P_HMinus, P_Hh, P_WPlus, P_Z, 2472)
      call createCurrent(P_HPlus, P_GMinus, P_Z, P_Z, 2933)
      call createCurrent(P_Hh, P_Z, P_A, 3208)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, 976)
      call createCurrent(P_G0, P_Hh, P_Ha, P_G0, 3775)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_GMinus, 196)
      call createCurrent(P_WMinus, P_GPlus, 3377)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_Hl, 1223)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, P_G0, 523)
      call createCurrent(P_HMinus, P_Z, P_WPlus, P_Ha, 1201)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, P_G0, 3009)
      call createCurrent(P_G0, P_Z, P_GPlus, P_WMinus, 2529)
      call createCurrent(P_Hh, P_G0, P_GPlus, P_GMinus, 3056)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_A, 2393)
      call createCurrent(P_GPlus, P_d, P_uAnti, 2293)
      call createCurrent(P_GPlus, P_Ha, P_G0, P_HMinus, 1296)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, P_Hl, 472)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, 1495)
      call createCurrent(P_Ha, P_Hh, P_GPlus, P_HMinus, 1163)
      call createCurrent(P_s, P_Hh, P_sAnti, 1888)
      call createCurrent(P_G0, P_GPlus, P_G0, P_GMinus, 2253)
      call createCurrent(P_A, P_nu_tauAnti, P_nu_tau, 3037)
      call createCurrent(P_GMinus, P_G0, P_Z, P_WPlus, 2235)
      call createCurrent(P_ghZAnti, P_ghWp, P_HMinus, 2890)
      call createCurrent(P_A, P_nu_tau, P_nu_tauAnti, 2850)
      call createCurrent(P_Z, P_GMinus, P_HPlus, P_Z, 3281)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_Z, 1747)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, P_Hh, 2307)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_Ha, 3044)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hh, 397)
      call createCurrent(P_Hh, P_Z, P_WMinus, P_HPlus, 2601)
      call createCurrent(P_HPlus, P_Z, P_HMinus, 1249)
      call createCurrent(P_A, P_A, P_Hh, P_Hh, 3747)
      call createCurrent(P_ePlus, P_nu_e, P_WMinus, 1106)
      call createCurrent(P_GMinus, P_Ha, P_Hl, P_HPlus, 240)
      call createCurrent(P_Ha, P_G0, P_GMinus, P_HPlus, 1243)
      call createCurrent(P_WMinus, P_A, P_GPlus, 1644)
      call createCurrent(P_A, P_G0, P_Z, P_Ha, 3644)
      call createCurrent(P_Z, P_Ha, P_HMinus, P_WPlus, 1917)
      call createCurrent(P_A, P_t, P_tAnti, 1708)
      call createCurrent(P_HPlus, P_WMinus, P_Hh, P_A, 419)
      call createCurrent(P_HMinus, P_Ha, P_WPlus, P_Z, 876)
      call createCurrent(P_b, P_G0, P_bAnti, 2373)
      call createCurrent(P_nu_tau, P_GMinus, P_tauPlus, 381)
      call createCurrent(P_Z, P_Hl, P_Hl, P_Z, 1963)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, P_A, 1241)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, P_Z, 2201)
      call createCurrent(P_WPlus, P_A, P_Hl, P_GMinus, 2602)
      call createCurrent(P_Hh, P_Z, P_GMinus, P_WPlus, 6)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, 1288)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, 2610)
      call createCurrent(P_GPlus, P_Ha, P_Hh, P_GMinus, 3576)
      call createCurrent(P_Z, P_s, P_sAnti, 1835)
      call createCurrent(P_nu_tau, P_WMinus, P_tauPlus, 209)
      call createCurrent(P_tauPlus, P_Z, P_tauMinus, 775)
      call createCurrent(P_bAnti, P_HMinus, P_t, 821)
      call createCurrent(P_Hl, P_Hh, P_GPlus, P_HMinus, 2633)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, 480)
      call createCurrent(P_GPlus, P_HPlus, P_GMinus, P_GMinus, 1206)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_GMinus, 623)
      call createCurrent(P_HMinus, P_HPlus, P_g, P_g, 3678)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_A, 1375)
      call createCurrent(P_G0, P_A, P_HMinus, P_WPlus, 3157)
      call createCurrent(P_sAnti, P_s, P_g, 936)
      call createCurrent(P_G0, P_Hh, P_G0, P_Hh, 1210)
      call createCurrent(P_Z, P_A, P_A, P_Z, 3788)
      call createCurrent(P_GPlus, P_Ha, P_Hl, P_GMinus, 3303)
      call createCurrent(P_HPlus, P_Hh, P_A, P_WMinus, 2085)
      call createCurrent(P_A, P_g, P_Z, P_g, 3827)
      call createCurrent(P_HMinus, P_Ha, P_Hl, P_GPlus, 13)
      call createCurrent(P_WPlus, P_WPlus, P_WMinus, P_WMinus, 406)
      call createCurrent(P_GPlus, P_WMinus, P_A, 1333)
      call createCurrent(P_HPlus, P_A, P_Z, P_HMinus, 640)
      call createCurrent(P_Ha, P_uAnti, P_u, 2161)
      call createCurrent(P_ePlus, P_Hl, P_eMinus, 814)
      call createCurrent(P_HPlus, P_Hl, P_G0, P_GMinus, 2061)
      call createCurrent(P_WMinus, P_Hl, P_HPlus, P_Z, 2105)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, P_Hh, 2653)
      call createCurrent(P_tAnti, P_t, P_g, 1669)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, P_Hh, 1217)
      call createCurrent(P_GMinus, P_HPlus, P_A, 3078)
      call createCurrent(P_Ha, P_G0, P_A, P_A, 3741)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_Hl, 1586)
      call createCurrent(P_HMinus, P_A, P_WPlus, 1055)
      call createCurrent(P_Ha, P_GPlus, P_Hl, P_GMinus, 3200)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_Hh, 2225)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, 2044)
      call createCurrent(P_Ha, P_G0, P_G0, P_G0, 220)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, 1675)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, P_G0, 770)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, P_Hh, 736)
      call createCurrent(P_Ha, P_Hh, P_GMinus, P_HPlus, 331)
      call createCurrent(P_HPlus, P_GMinus, P_WPlus, P_WMinus, 3365)
      call createCurrent(P_t, P_tAnti, P_Hl, 2243)
      call createCurrent(P_HMinus, P_Ha, P_Ha, P_HPlus, 532)
      call createCurrent(P_A, P_Hl, P_Hl, P_A, 3603)
      call createCurrent(P_t, P_Ha, P_tAnti, 2459)
      call createCurrent(P_HMinus, P_G0, P_Hl, P_GPlus, 1420)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, 271)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, P_G0, 470)
      call createCurrent(P_eMinus, P_ePlus, P_G0, 116)
      call createCurrent(P_bAnti, P_b, 3234)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_G0, 272)
      call createCurrent(P_g, P_g, P_g, 2518)
      call createCurrent(P_GPlus, P_WMinus, P_G0, 489)
      call createCurrent(P_Ha, P_Hl, P_G0, 2144)
      call createCurrent(P_WPlus, P_HPlus, P_HMinus, P_WMinus, 2392)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, P_G0, 2421)
      call createCurrent(P_A, P_Hl, P_WPlus, P_HMinus, 961)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_Ha, 3487)
      call createCurrent(P_Hl, P_tauPlus, P_tauMinus, 16)
      call createCurrent(P_Hl, P_Ha, P_HMinus, P_GPlus, 201)
      call createCurrent(P_uAnti, P_u, P_Z, 1260)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, P_Hh, 79)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, 541)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, P_Ha, 607)
      call createCurrent(P_Ha, P_Hl, P_HMinus, P_GPlus, 984)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, P_Hh, 30)
      call createCurrent(P_Ha, P_Ha, P_GPlus, P_GMinus, 957)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, 2154)
      call createCurrent(P_GMinus, P_G0, P_Hh, P_GPlus, 3397)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_Z, 126)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, 1457)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, 1775)
      call createCurrent(P_WPlus, P_HMinus, 3203)
      call createCurrent(P_g, P_Hl, P_Hh, P_g, 3630)
      call createCurrent(P_nu_mu, P_Z, P_nu_muAnti, 556)
      call createCurrent(P_Ha, P_Hl, P_G0, P_Hh, 1661)
      call createCurrent(P_WPlus, P_HMinus, P_GPlus, P_WMinus, 2880)
      call createCurrent(P_Hl, P_A, P_Hl, P_A, 3759)
      call createCurrent(P_Z, P_g, P_g, P_A, 3645)
      call createCurrent(P_Ha, P_WMinus, P_HPlus, P_A, 2354)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_GMinus, 1392)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_Ha, 3541)
      call createCurrent(P_HPlus, P_WPlus, P_GMinus, P_WMinus, 3385)
      call createCurrent(P_G0, P_u, P_uAnti, 2178)
      call createCurrent(P_u, P_WMinus, P_dAnti, 988)
      call createCurrent(P_GPlus, P_A, P_Z, P_HMinus, 2778)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, 3293)
      call createCurrent(P_Ha, P_GPlus, P_Ha, P_HMinus, 713)
      call createCurrent(P_Z, P_WMinus, P_GPlus, 283)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_Ha, 540)
      call createCurrent(P_ghG, P_g, P_ghGAnti, 1823)
      call createCurrent(P_HMinus, P_WPlus, P_A, P_G0, 3107)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_Hl, 863)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_HPlus, 1569)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, 2663)
      call createCurrent(P_HMinus, P_A, P_Z, P_GPlus, 3179)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, P_Hh, 120)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, P_G0, 1853)
      call createCurrent(P_sAnti, P_HMinus, P_c, 243)
      call createCurrent(P_tauMinus, P_Z, P_tauPlus, 158)
      call createCurrent(P_A, P_g, P_g, P_A, 3610)
      call createCurrent(P_HMinus, P_G0, P_HPlus, P_Hh, 2819)
      call createCurrent(P_GMinus, P_nu_mu, P_muPlus, 2429)
      call createCurrent(P_HPlus, P_HMinus, P_Z, P_Z, 330)
      call createCurrent(P_G0, P_GMinus, P_Hl, P_HPlus, 502)
      call createCurrent(P_A, P_bAnti, P_b, 1215)
      call createCurrent(P_g, P_HMinus, P_HPlus, P_g, 3814)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, 2489)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_Hh, 184)
      call createCurrent(P_G0, P_G0, P_A, P_Z, 3464)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, P_Ha, 269)
      call createCurrent(P_ePlus, P_eMinus, 2790)
      call createCurrent(P_HMinus, P_A, P_A, P_GPlus, 3381)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_Z, 1680)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, 2138)
      call createCurrent(P_G0, P_Hl, P_Hl, P_Ha, 2323)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, P_Z, 745)
      call createCurrent(P_HMinus, P_HPlus, P_GMinus, P_HPlus, 1809)
      call createCurrent(P_Hl, P_tauMinus, P_tauPlus, 797)
      call createCurrent(P_Ha, P_GPlus, P_Z, P_WMinus, 3359)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Ha, 3425)
      call createCurrent(P_A, P_Z, P_Hh, 3142)
      call createCurrent(P_HMinus, P_HMinus, P_GPlus, P_HPlus, 2422)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, 560)
      call createCurrent(P_g, P_Ha, P_Ha, P_g, 3634)
      call createCurrent(P_GPlus, P_G0, P_HMinus, P_Ha, 924)
      call createCurrent(P_GPlus, P_G0, P_HMinus, 2319)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, 463)
      call createCurrent(P_g, P_Z, P_g, P_g, 3702)
      call createCurrent(P_Z, P_tauMinus, P_tauPlus, 1245)
      call createCurrent(P_HMinus, P_Z, P_GPlus, 3525)
      call createCurrent(P_GMinus, P_HMinus, P_HPlus, P_HPlus, 122)
      call createCurrent(P_GPlus, P_HPlus, P_HMinus, P_GMinus, 104)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, 565)
      call createCurrent(P_Ha, P_A, P_WPlus, P_HMinus, 1367)
      call createCurrent(P_Z, P_A, P_WPlus, P_WMinus, 2648)
      call createCurrent(P_Hl, P_Hl, P_Hl, P_Hh, 546)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, P_G0, 2709)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_G0, 1610)
      call createCurrent(P_HPlus, P_Hl, P_A, P_WMinus, 129)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, 1431)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, P_Hh, 1794)
      call createCurrent(P_Ha, P_eMinus, P_ePlus, 360)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, 2532)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, P_Hh, 3329)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, P_Hl, 2576)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, P_A, 1554)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, P_G0, 3555)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, P_Hl, 2239)
      call createCurrent(P_sAnti, P_g, P_s, 1846)
      call createCurrent(P_G0, P_tauMinus, P_tauPlus, 2409)
      call createCurrent(P_A, P_A, P_Hl, P_Hl, 3681)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, P_Hh, 2669)
      call createCurrent(P_G0, P_s, P_sAnti, 1906)
      call createCurrent(P_g, P_ghG, P_ghGAnti, 1072)
      call createCurrent(P_WMinus, P_HPlus, P_Hl, 1566)
      call createCurrent(P_GPlus, P_HMinus, P_g, P_g, 3842)
      call createCurrent(P_Ha, P_Ha, P_GMinus, P_HPlus, 1933)
      call createCurrent(P_A, P_HMinus, P_WPlus, P_Ha, 302)
      call createCurrent(P_Hl, P_G0, P_HMinus, P_GPlus, 1412)
      call createCurrent(P_bAnti, P_b, P_Hl, 1871)
      call createCurrent(P_Hl, P_WPlus, P_A, P_GMinus, 1699)
      call createCurrent(P_Ha, P_Hl, P_Ha, 1739)
      call createCurrent(P_G0, P_WMinus, P_A, P_HPlus, 3138)
      call createCurrent(P_Hh, P_Hl, P_GMinus, P_HPlus, 867)
      call createCurrent(P_GMinus, P_HPlus, P_G0, P_G0, 1639)
      call createCurrent(P_A, P_GMinus, P_HPlus, 3297)
      call createCurrent(P_muMinus, P_muPlus, P_Hl, 786)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, 2495)
      call createCurrent(P_nu_tau, P_nu_tauAnti, 3493)
      call createCurrent(P_Ha, P_A, P_Hl, 3003)
      call createCurrent(P_muPlus, P_HMinus, P_nu_mu, 389)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, 1151)
      call createCurrent(P_tauPlus, P_nu_tau, P_WMinus, 1176)
      call createCurrent(P_HPlus, P_GPlus, P_HMinus, P_HMinus, 628)
      call createCurrent(P_HMinus, P_GPlus, P_GMinus, P_HPlus, 444)
      call createCurrent(P_Z, P_g, P_A, P_g, 3774)
      call createCurrent(P_tAnti, P_t, P_G0, 2498)
      call createCurrent(P_muMinus, P_nu_muAnti, P_HPlus, 139)
      call createCurrent(P_Hh, P_GMinus, P_HPlus, P_Hh, 665)
      call createCurrent(P_WPlus, P_WMinus, P_HPlus, P_GMinus, 3587)
      call createCurrent(P_WPlus, P_Hl, P_A, P_GMinus, 437)
      call createCurrent(P_Hh, P_tauMinus, P_tauPlus, 2127)
      call createCurrent(P_Hh, P_G0, P_G0, P_Hh, 1452)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, P_Ha, 317)
      call createCurrent(P_b, P_bAnti, P_Hh, 840)
      call createCurrent(P_s, P_G0, P_sAnti, 1703)
      call createCurrent(P_Hl, P_HMinus, P_G0, P_GPlus, 1737)
      call createCurrent(P_HMinus, P_Hl, P_Hl, P_HPlus, 1363)
      call createCurrent(P_Ha, P_GPlus, P_WMinus, 3520)
      call createCurrent(P_HMinus, P_G0, P_GPlus, 2547)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, 716)
      call createCurrent(P_WPlus, P_A, P_HMinus, P_Ha, 1796)
      call createCurrent(P_Hh, P_GMinus, P_Hh, P_HPlus, 1533)
      call createCurrent(P_A, P_GPlus, P_Ha, P_WMinus, 2918)
      call createCurrent(P_Hh, P_G0, P_G0, 1560)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_Ha, 3369)
      call createCurrent(P_A, P_HPlus, P_WMinus, P_Hl, 383)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WPlus, 805)
      call createCurrent(P_nu_e, P_nu_eAnti, P_A, 3264)
      call createCurrent(P_Hh, P_G0, P_Hl, P_G0, 933)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, P_Hl, 2870)
      call createCurrent(P_A, P_Z, P_GPlus, P_GMinus, 50)
      call createCurrent(P_t, P_bAnti, P_GMinus, 1281)
      call createCurrent(P_HPlus, P_WMinus, P_WPlus, P_HMinus, 2340)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, P_Ha, 2047)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, P_Z, 841)
      call createCurrent(P_Z, P_G0, P_Ha, P_Z, 3302)
      call createCurrent(P_Hh, P_G0, P_Hh, P_Ha, 596)
      call createCurrent(P_WPlus, P_Z, P_HMinus, 41)
      call createCurrent(P_G0, P_GPlus, P_G0, P_HMinus, 2170)
      call createCurrent(P_HMinus, P_Hh, P_WPlus, P_A, 1494)
      call createCurrent(P_Ha, P_Z, 3013)
      call createCurrent(P_G0, P_Ha, P_Hh, P_G0, 3816)
      call createCurrent(P_GPlus, P_G0, P_WMinus, 2468)
      call createCurrent(P_Hh, P_Ha, P_GMinus, P_GPlus, 3256)
      call createCurrent(P_HMinus, P_HPlus, P_G0, 2794)
      call createCurrent(P_Z, P_G0, P_Z, P_Ha, 3147)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, P_Z, 1183)
      call createCurrent(P_A, P_Hh, P_GMinus, P_WPlus, 2617)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, P_G0, 939)
      call createCurrent(P_GMinus, P_Hl, P_Ha, P_GPlus, 2969)
      call createCurrent(P_HMinus, P_WPlus, P_Z, P_Hl, 282)
      call createCurrent(P_g, P_g, P_Z, P_A, 3733)
      call createCurrent(P_Hh, P_HMinus, P_Hl, P_HPlus, 23)
      call createCurrent(P_G0, P_HMinus, P_GPlus, P_G0, 2664)
      call createCurrent(P_Z, P_Z, 3285)
      call createCurrent(P_Hh, P_Hl, P_Z, P_A, 3730)
      call createCurrent(P_ghZ, P_Hh, P_ghZAnti, 1840)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, 1444)
      call createCurrent(P_Z, P_Z, P_Hl, P_Hh, 3509)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_Z, 2048)
      call createCurrent(P_A, P_A, P_GMinus, P_HPlus, 2798)
      call createCurrent(P_WPlus, P_Ha, P_WMinus, P_G0, 2925)
      call createCurrent(P_A, P_WMinus, P_Hh, P_GPlus, 982)
      call createCurrent(P_HPlus, P_WPlus, P_WMinus, P_GMinus, 3277)
      call createCurrent(P_A, P_WPlus, P_GMinus, 288)
      call createCurrent(P_GMinus, P_Ha, P_WPlus, 3409)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, 2552)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, 1903)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_Hh, 2868)
      call createCurrent(P_HPlus, P_Ha, P_Ha, P_GMinus, 1230)
      call createCurrent(P_WMinus, P_A, P_Hl, P_GPlus, 515)
      call createCurrent(P_tAnti, P_A, P_t, 2145)
      call createCurrent(P_Hh, P_G0, P_HMinus, P_GPlus, 2090)
      call createCurrent(P_Z, P_G0, P_A, P_G0, 3257)
      call createCurrent(P_HPlus, P_Z, P_Hh, P_WMinus, 362)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_HPlus, 2856)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, P_Hh, 834)
      call createCurrent(P_c, P_WMinus, P_sAnti, 1091)
      call createCurrent(P_Hh, P_Hh, P_HPlus, P_HMinus, 2193)
      call createCurrent(P_WPlus, P_HMinus, P_Hh, P_A, 2504)
      call createCurrent(P_g, P_GPlus, P_g, P_GMinus, 3709)
      call createCurrent(P_Hh, P_GMinus, P_Z, P_WPlus, 323)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, P_A, 163)
      call createCurrent(P_s, P_sAnti, P_A, 407)
      call createCurrent(P_A, P_Hl, P_HPlus, P_WMinus, 2229)
      call createCurrent(P_Ha, P_s, P_sAnti, 2470)
      call createCurrent(P_WPlus, P_Hl, P_Z, P_HMinus, 2619)
      call createCurrent(P_A, P_GPlus, P_Z, P_HMinus, 2770)
      call createCurrent(P_t, P_tAnti, P_g, 1590)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, P_Ha, 2367)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, 322)
      call createCurrent(P_Hl, P_HMinus, P_Z, P_WPlus, 387)
      call createCurrent(P_Hl, P_Hl, P_Ha, P_Ha, 1221)
      call createCurrent(P_GPlus, P_Hh, P_G0, P_GMinus, 3519)
      call createCurrent(P_Hl, P_Z, P_Z, 411)
      call createCurrent(P_A, P_HPlus, P_GMinus, 3014)
      call createCurrent(P_Z, P_Hh, P_A, 3041)
      call createCurrent(P_Hl, P_g, P_Hh, P_g, 3834)
      call createCurrent(P_Hl, P_g, P_g, 3619)
      call createCurrent(P_WMinus, P_WPlus, P_HMinus, P_GPlus, 3389)
      call createCurrent(P_Z, P_bAnti, P_b, 2074)
      call createCurrent(P_A, P_WMinus, P_HPlus, P_Hh, 1811)
      call createCurrent(P_Hh, P_Ha, P_Hh, P_G0, 2387)
      call createCurrent(P_Ha, P_A, P_HMinus, P_WPlus, 2414)
      call createCurrent(P_G0, P_GPlus, P_Z, P_WMinus, 700)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_A, 1593)
      call createCurrent(P_Ha, P_Hl, P_Z, 2564)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_Hh, 1470)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_HMinus, 1060)
      call createCurrent(P_HMinus, P_Hh, P_Ha, P_HPlus, 3066)
      call createCurrent(P_HMinus, P_GPlus, P_GPlus, P_HMinus, 2032)
      call createCurrent(P_A, P_WMinus, P_A, P_WPlus, 71)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, 226)
      call createCurrent(P_Ha, P_Ha, P_Hh, P_Hh, 128)
      call createCurrent(P_HMinus, P_Hh, P_Hl, P_GPlus, 570)
      call createCurrent(P_bAnti, P_b, P_Z, 2672)
      call createCurrent(P_sAnti, P_Hh, P_s, 1359)
      call createCurrent(P_G0, P_Ha, P_A, P_A, 3792)
      call createCurrent(P_HPlus, P_Hl, P_G0, P_HMinus, 2808)
      call createCurrent(P_G0, P_Hl, P_GMinus, P_HPlus, 543)
      call createCurrent(P_Hh, P_GMinus, P_G0, P_HPlus, 2096)
      call createCurrent(P_GPlus, P_Z, P_HMinus, 3440)
      call createCurrent(P_GPlus, P_G0, P_HMinus, P_Hh, 366)
      call createCurrent(P_WMinus, P_A, P_Ha, P_GPlus, 3092)
      call createCurrent(P_tAnti, P_t, P_Ha, 1219)
      call createCurrent(P_A, P_uAnti, P_u, 2117)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_A, 1777)
      call createCurrent(P_GPlus, P_Z, P_GMinus, 594)
      call createCurrent(P_GMinus, P_G0, P_HPlus, 182)
      call createCurrent(P_HPlus, P_G0, P_G0, P_GMinus, 2420)
      call createCurrent(P_nu_eAnti, P_HPlus, P_eMinus, 2100)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_Z, 827)
      call createCurrent(P_WPlus, P_HMinus, P_A, P_Hh, 934)
      call createCurrent(P_Hl, P_Hl, 3165)
      call createCurrent(P_Z, P_g, P_Z, P_g, 3624)
      call createCurrent(P_uAnti, P_u, 3396)
      call createCurrent(P_Ha, P_Z, P_Ha, P_Z, 98)
      call createCurrent(P_Hl, P_Ha, P_Z, 1300)
      call createCurrent(P_b, P_A, P_bAnti, 2675)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WPlus, 915)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, P_Hh, 2106)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_G0, 3289)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, P_Hl, 3435)
      call createCurrent(P_s, P_g, P_sAnti, 2627)
      call createCurrent(P_Hl, P_Ha, P_HMinus, P_HPlus, 3174)
      call createCurrent(P_G0, P_G0, P_Z, P_Z, 2365)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, P_Ha, 862)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, P_Ha, 2128)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, P_Ha, 615)
      call createCurrent(P_Z, P_GMinus, P_WPlus, 832)
      call createCurrent(P_GPlus, P_Ha, P_Z, P_WMinus, 3255)
      call createCurrent(P_Z, P_GMinus, P_Hl, P_WPlus, 1172)
      call createCurrent(P_G0, P_G0, P_G0, P_Ha, 2488)
      call createCurrent(P_HMinus, P_Z, P_HPlus, P_A, 1344)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, P_Hh, 2550)
      call createCurrent(P_A, P_g, P_g, P_g, 3690)
      call createCurrent(P_Z, P_Ha, P_WPlus, P_GMinus, 2962)
      call createCurrent(P_WMinus, P_GPlus, P_Ha, 3242)
      call createCurrent(P_nu_e, P_GMinus, P_ePlus, 1734)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_G0, 2965)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, 580)
      call createCurrent(P_b, P_Hh, P_bAnti, 1768)
      call createCurrent(P_Hh, P_A, P_A, P_Hh, 3848)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, P_Hl, 1263)
      call createCurrent(P_WMinus, P_WPlus, P_HPlus, P_GMinus, 3552)
      call createCurrent(P_HMinus, P_WPlus, P_G0, P_A, 2885)
      call createCurrent(P_HPlus, P_Z, P_G0, P_WMinus, 2717)
      call createCurrent(P_WMinus, P_Ha, P_GPlus, 3501)
      call createCurrent(P_WMinus, P_Ha, P_Z, P_HPlus, 600)
      call createCurrent(P_HMinus, P_Z, P_WPlus, P_G0, 2872)
      call createCurrent(P_Hh, P_Ha, P_G0, 1503)
      call createCurrent(P_ghZ, P_HMinus, P_ghWmAnti, 3305)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, 597)
      call createCurrent(P_HPlus, P_Ha, P_G0, P_GMinus, 1250)
      call createCurrent(P_dAnti, P_d, 3407)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_Ha, 3076)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_G0, 836)
      call createCurrent(P_Hh, P_Z, P_Hh, P_A, 3544)
      call createCurrent(P_s, P_sAnti, P_Z, 823)
      call createCurrent(P_A, P_Hl, P_Ha, 3058)
      call createCurrent(P_HPlus, P_G0, P_WMinus, P_A, 3077)
      call createCurrent(P_Hh, P_GPlus, P_Hl, P_HMinus, 1175)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, P_G0, 3559)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_Ha, 2900)
      call createCurrent(P_Hl, P_WPlus, P_HMinus, P_Z, 944)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, 2281)
      call createCurrent(P_HMinus, P_A, P_A, P_HPlus, 2540)
      call createCurrent(P_WPlus, P_HMinus, P_Hh, P_Z, 264)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_Hl, 224)
      call createCurrent(P_Z, P_G0, P_Hl, 1009)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, P_Hl, 183)
      call createCurrent(P_Z, P_Hh, P_WMinus, P_GPlus, 1282)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, 213)
      call createCurrent(P_g, P_d, P_dAnti, 373)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghZ, 2837)
      call createCurrent(P_Hl, P_HPlus, P_WMinus, P_A, 1025)
      call createCurrent(P_G0, P_G0, P_Hl, P_Ha, 3761)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, P_Ha, 1509)
      call createCurrent(P_Hl, P_Hl, P_A, P_Z, 3468)
      call createCurrent(P_ghZAnti, P_ghWm, P_HPlus, 3063)
      call createCurrent(P_cAnti, P_g, P_c, 999)
      call createCurrent(P_G0, P_Ha, P_HPlus, P_HMinus, 2238)
      call createCurrent(P_HPlus, P_G0, P_Hh, P_HMinus, 2915)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_GMinus, 2123)
      call createCurrent(P_A, P_cAnti, P_c, 2220)
      call createCurrent(P_HPlus, P_Hl, P_Ha, P_GMinus, 787)
      call createCurrent(P_GPlus, P_GPlus, P_HMinus, P_HMinus, 295)
      call createCurrent(P_GMinus, P_Z, P_A, P_GPlus, 392)
      call createCurrent(P_Ha, P_A, P_WMinus, P_HPlus, 587)
      call createCurrent(P_Ha, P_Hl, P_Ha, P_Hl, 431)
      call createCurrent(P_A, P_Hh, P_Hl, P_A, 3803)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_A, 2577)
      call createCurrent(P_A, P_nu_muAnti, P_nu_mu, 3334)
      call createCurrent(P_g, P_tAnti, P_t, 1926)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_Ha, 3278)
      call createCurrent(P_GPlus, P_g, P_g, P_HMinus, 3860)
      call createCurrent(P_WPlus, P_Hl, P_HMinus, P_Z, 2530)
      call createCurrent(P_A, P_A, P_A, P_A, 3754)
      call createCurrent(P_G0, P_Ha, P_HMinus, P_HPlus, 2269)
      call createCurrent(P_cAnti, P_Hl, P_c, 844)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_G0, 847)
      call createCurrent(P_Ha, P_Hl, P_G0, P_G0, 3866)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_G0, 2922)
      call createCurrent(P_A, P_Z, P_A, P_A, 3589)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, 2135)
      call createCurrent(P_Hh, P_WPlus, P_A, P_GMinus, 1404)
      call createCurrent(P_Z, P_Z, P_Z, P_Z, 3813)
      call createCurrent(P_Hh, P_Hl, P_A, P_Z, 3667)
      call createCurrent(P_g, P_g, P_GMinus, P_GPlus, 3876)
      call createCurrent(P_A, P_Hl, P_A, 3657)
      call createCurrent(P_cAnti, P_s, P_WPlus, 49)
      call createCurrent(P_Hh, P_WPlus, P_Hh, P_WMinus, 1259)
      call createCurrent(P_t, P_g, P_tAnti, 2139)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, P_Hl, 3373)
      call createCurrent(P_Hl, P_Z, P_HMinus, P_WPlus, 921)
      call createCurrent(P_Z, P_Hh, P_Hh, P_Z, 2378)
      call createCurrent(P_g, P_g, P_Ha, P_G0, 3836)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, 1041)
      call createCurrent(P_G0, P_HMinus, P_Z, P_WPlus, 3292)
      call createCurrent(P_G0, P_G0, P_HPlus, P_HMinus, 2116)
      call createCurrent(P_HPlus, P_GMinus, P_A, P_A, 3536)
      call createCurrent(P_ghG, P_ghGAnti, P_g, 1218)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, P_Z, 705)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_A, 1832)
      call createCurrent(P_HPlus, P_Hh, P_WMinus, P_Z, 1789)
      call createCurrent(P_Hh, P_Z, P_Hl, P_A, 3791)
      call createCurrent(P_Hh, P_G0, P_HPlus, P_GMinus, 1538)
      call createCurrent(P_HMinus, P_Hl, P_Ha, P_GPlus, 2190)
      call createCurrent(P_G0, P_WPlus, P_Z, P_GMinus, 1666)
      call createCurrent(P_A, P_HMinus, P_A, P_GPlus, 2765)
      call createCurrent(P_WPlus, P_A, P_A, P_WMinus, 1758)
      call createCurrent(P_WMinus, P_HPlus, P_Hl, P_A, 1953)
      call createCurrent(P_Hl, P_A, P_Z, P_Hl, 3527)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, 1750)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, 960)
      call createCurrent(P_Ha, P_Z, P_Ha, P_A, 3483)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, P_Hl, 228)
      call createCurrent(P_Hl, P_d, P_dAnti, 608)
      call createCurrent(P_HPlus, P_Ha, P_WMinus, 751)
      call createCurrent(P_Hh, P_eMinus, P_ePlus, 1864)
      call createCurrent(P_u, P_Hh, P_uAnti, 2277)
      call createCurrent(P_muPlus, P_muMinus, 2824)
      call createCurrent(P_A, P_WMinus, P_HPlus, P_Ha, 488)
      call createCurrent(P_WMinus, P_GPlus, P_Z, 1188)
      call createCurrent(P_Z, P_HPlus, P_WMinus, P_Ha, 1772)
      call createCurrent(P_Ha, P_G0, P_GMinus, P_GPlus, 815)
      call createCurrent(P_GMinus, P_Hh, P_Hl, P_GPlus, 2520)
      call createCurrent(P_G0, P_Ha, P_Hl, 377)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_Hl, 2377)
      call createCurrent(P_uAnti, P_G0, P_u, 666)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_A, 967)
      call createCurrent(P_Ha, P_Hh, P_Hl, P_G0, 2400)
      call createCurrent(P_G0, P_G0, P_Ha, P_G0, 2080)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, P_A, 2011)
      call createCurrent(P_HMinus, P_GPlus, P_G0, P_Ha, 1802)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, 1482)
      call createCurrent(P_Z, P_A, P_Hh, P_Hl, 3864)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, 1324)
      call createCurrent(P_Hh, P_dAnti, P_d, 2587)
      call createCurrent(P_WPlus, P_Hh, P_Hh, P_WMinus, 2644)
      call createCurrent(P_HPlus, P_HMinus, P_GMinus, P_GPlus, 2612)
      call createCurrent(P_Hl, P_ghZAnti, P_ghZ, 718)
      call createCurrent(P_Z, P_G0, P_Ha, P_A, 3824)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, 166)
      call createCurrent(P_Ha, P_A, P_A, P_Ha, 3812)
      call createCurrent(P_HPlus, P_WMinus, P_Z, P_G0, 2722)
      call createCurrent(P_d, P_Hl, P_dAnti, 1391)
      call createCurrent(P_Hh, P_A, P_Hl, P_A, 3849)
      call createCurrent(P_Hl, P_u, P_uAnti, 365)
      call createCurrent(P_WPlus, P_WMinus, P_g, P_g, 3815)
      call createCurrent(P_WPlus, P_Ha, P_HMinus, 2614)
      call createCurrent(P_Z, P_G0, P_GPlus, P_WMinus, 1842)
      call createCurrent(P_Hl, P_ghWp, P_ghWpAnti, 2051)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_HMinus, 3246)
      call createCurrent(P_HPlus, P_G0, P_HMinus, P_G0, 2175)
      call createCurrent(P_Z, P_b, P_bAnti, 1698)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_Z, 1697)
      call createCurrent(P_HMinus, P_G0, P_HPlus, 2721)
      call createCurrent(P_HMinus, P_Hl, P_Hl, P_GPlus, 1423)
      call createCurrent(P_muMinus, P_Hl, P_muPlus, 1279)
      call createCurrent(P_WPlus, P_G0, P_Z, P_GMinus, 1627)
      call createCurrent(P_HPlus, P_Hh, P_G0, P_HMinus, 3144)
      call createCurrent(P_G0, P_Hl, P_HPlus, P_GMinus, 2023)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, P_Hh, 1384)
      call createCurrent(P_HMinus, P_WMinus, P_HPlus, P_WPlus, 25)
      call createCurrent(P_GMinus, P_HPlus, P_HPlus, P_HMinus, 429)
      call createCurrent(P_Hh, P_Ha, P_Z, 420)
      call createCurrent(P_WMinus, P_nu_e, P_ePlus, 305)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, P_Ha, 2974)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, 1492)
      call createCurrent(P_Ha, P_Z, P_WPlus, P_HMinus, 822)
      call createCurrent(P_g, P_u, P_uAnti, 1798)
      call createCurrent(P_d, P_WPlus, P_uAnti, 1469)
      call createCurrent(P_HMinus, P_A, P_GPlus, 3523)
      call createCurrent(P_eMinus, P_A, P_ePlus, 631)
      call createCurrent(P_Ha, P_GMinus, P_Ha, P_GPlus, 1855)
      call createCurrent(P_Hh, P_Hh, P_HMinus, P_HPlus, 101)
      call createCurrent(P_HPlus, P_WMinus, P_G0, P_Z, 2859)
      call createCurrent(P_A, P_Hh, P_Hh, P_Z, 3079)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, P_G0, 479)
      call createCurrent(P_A, P_HPlus, P_HMinus, P_A, 2126)
      call createCurrent(P_nu_tauAnti, P_Z, P_nu_tau, 2315)
      call createCurrent(P_nu_muAnti, P_GPlus, P_muMinus, 2295)
      call createCurrent(P_Z, P_HMinus, P_WPlus, P_Hl, 1729)
      call createCurrent(P_Ha, P_WPlus, P_GMinus, P_A, 3386)
      call createCurrent(P_WPlus, P_g, P_WMinus, P_g, 3725)
      call createCurrent(P_A, P_WPlus, P_HMinus, P_Hl, 769)
      call createCurrent(P_WPlus, P_HMinus, P_Ha, P_A, 2110)
      call createCurrent(P_GPlus, P_GMinus, P_Z, 920)
      call createCurrent(P_Hl, P_Hh, P_WMinus, P_WPlus, 2977)
      call createCurrent(P_g, P_Hl, P_g, P_Hl, 3658)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, P_Z, 2399)
      call createCurrent(P_HPlus, P_GMinus, P_GMinus, P_HPlus, 1100)
      call createCurrent(P_HPlus, P_WMinus, P_Hh, P_Z, 1727)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_G0, 1332)
      call createCurrent(P_A, P_GMinus, P_A, P_GPlus, 731)
      call createCurrent(P_Z, P_GMinus, P_Ha, P_WPlus, 3507)
      call createCurrent(P_Ha, P_Hh, P_Ha, P_Hh, 500)
      call createCurrent(P_bAnti, P_Ha, P_b, 1063)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_Ha, 3175)
      call createCurrent(P_sAnti, P_s, P_A, 191)
      call createCurrent(P_G0, P_Hh, P_HPlus, P_HMinus, 3060)
      call createCurrent(P_g, P_HMinus, P_g, P_GPlus, 3605)
      call createCurrent(P_muMinus, P_muPlus, P_Ha, 108)
      call createCurrent(P_Hl, P_HPlus, P_WMinus, 856)
      call createCurrent(P_HMinus, P_G0, P_Hl, P_HPlus, 2987)
      call createCurrent(P_GMinus, P_G0, P_HPlus, P_Ha, 199)
      call createCurrent(P_WPlus, P_HMinus, P_Hl, P_Z, 1925)
      call createCurrent(P_WMinus, P_A, P_G0, P_HPlus, 2780)
      call createCurrent(P_eMinus, P_ePlus, P_Z, 2416)
      call createCurrent(P_A, P_HPlus, P_Hh, P_WMinus, 244)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, 304)
      call createCurrent(P_GMinus, P_Ha, P_G0, P_HPlus, 2523)
      call createCurrent(P_GMinus, P_HPlus, P_HMinus, P_HPlus, 985)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_GMinus, 1784)
      call createCurrent(P_s, P_sAnti, P_Hl, 141)
      call createCurrent(P_G0, P_G0, P_WPlus, P_WMinus, 691)
      call createCurrent(P_HMinus, P_Hh, P_Hh, P_GPlus, 2069)
      call createCurrent(P_GMinus, P_ePlus, P_nu_e, 624)
      call createCurrent(P_G0, P_A, P_GPlus, P_WMinus, 1113)
      call createCurrent(P_t, P_tAnti, P_Hh, 1883)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, P_Hl, 1712)
      call createCurrent(P_GPlus, P_G0, P_GMinus, 2707)
      call createCurrent(P_Z, P_Hl, P_Hh, P_A, 3626)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, 974)
      call createCurrent(P_Hh, P_Hh, P_GMinus, P_GPlus, 639)
      call createCurrent(P_Hh, P_HPlus, P_WMinus, P_Z, 204)
      call createCurrent(P_ePlus, P_Ha, P_eMinus, 696)
      call createCurrent(P_Hl, P_GMinus, P_Hl, P_HPlus, 547)
      call createCurrent(P_Z, P_Z, P_HPlus, P_GMinus, 2849)
      call createCurrent(P_GPlus, P_Ha, P_WMinus, 3128)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, 910)
      call createCurrent(P_Ha, P_bAnti, P_b, 531)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, 1199)
      call createCurrent(P_cAnti, P_c, P_g, 1571)
      call createCurrent(P_cAnti, P_Ha, P_c, 2366)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_A, 3130)
      call createCurrent(P_dAnti, P_Hh, P_d, 2357)
      call createCurrent(P_GMinus, P_G0, P_G0, P_GPlus, 688)
      call createCurrent(P_G0, P_G0, P_GPlus, P_HMinus, 490)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, 2570)
      call createCurrent(P_nu_e, P_ePlus, P_HMinus, 877)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, P_G0, 2748)
      call createCurrent(P_WMinus, P_WPlus, P_g, P_g, 3858)
      call createCurrent(P_Hh, P_Hl, P_HMinus, P_GPlus, 1254)
      call createCurrent(P_Z, P_Ha, 3535)
      call createCurrent(P_HPlus, P_HMinus, P_WPlus, P_WMinus, 2362)
      call createCurrent(P_HPlus, P_WMinus, 3337)
      call createCurrent(P_HPlus, P_Z, P_GMinus, P_Z, 3225)
      call createCurrent(P_A, P_g, P_A, P_g, 3594)
      call createCurrent(P_A, P_A, P_G0, P_Ha, 3853)
      call createCurrent(P_Hh, P_HPlus, P_Hh, P_HMinus, 2018)
      call createCurrent(P_Hh, P_Hl, P_GPlus, P_HMinus, 2358)
      call createCurrent(P_A, P_sAnti, P_s, 1961)
      call createCurrent(P_G0, P_GPlus, P_Hh, P_GMinus, 2788)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, P_Hl, 3412)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_Ha, 1256)
      call createCurrent(P_Ha, P_GMinus, P_G0, P_HPlus, 817)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, P_Ha, 446)
      call createCurrent(P_WPlus, P_HMinus, P_HPlus, P_WMinus, 1769)
      call createCurrent(P_HPlus, P_WMinus, P_A, P_Hh, 1501)
      call createCurrent(P_WPlus, P_Ha, P_GMinus, 2972)
      call createCurrent(P_cAnti, P_c, P_Z, 1239)
      call createCurrent(P_A, P_G0, P_WPlus, P_GMinus, 1477)
      call createCurrent(P_GMinus, P_HPlus, P_Z, P_Z, 3043)
      call createCurrent(P_d, P_dAnti, P_Z, 923)
      call createCurrent(P_WMinus, P_Ha, P_A, P_GPlus, 2714)
      call createCurrent(P_dAnti, P_Ha, P_d, 1405)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, P_Hl, 2984)
      call createCurrent(P_HMinus, P_tauPlus, P_nu_tau, 703)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, P_G0, 606)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, P_G0, 2313)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, P_Ha, 574)
      call createCurrent(P_GPlus, P_GMinus, P_HPlus, P_HMinus, 1353)
      call createCurrent(P_g, P_g, P_Hh, 3822)
      call createCurrent(P_G0, P_Hh, P_G0, 2403)
      call createCurrent(P_Hh, P_d, P_dAnti, 1709)
      call createCurrent(P_G0, P_WMinus, P_HPlus, P_Z, 3473)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, P_Hh, 3019)
      call createCurrent(P_HPlus, P_WPlus, P_WMinus, P_HMinus, 450)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, P_Hl, 3153)
      call createCurrent(P_WPlus, P_A, P_HMinus, 1688)
      call createCurrent(P_Ha, P_GMinus, P_G0, P_GPlus, 2370)
      call createCurrent(P_cAnti, P_s, P_GPlus, 514)
      call createCurrent(P_G0, P_A, P_GMinus, P_WPlus, 1149)
      call createCurrent(P_Z, P_A, P_g, P_g, 3604)
      call createCurrent(P_u, P_Hl, P_uAnti, 962)
      call createCurrent(P_A, P_HMinus, P_GPlus, 3313)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, 2191)
      call createCurrent(P_HPlus, P_Z, P_GMinus, 2774)
      call createCurrent(P_GMinus, P_G0, P_GPlus, 2706)
      call createCurrent(P_HPlus, P_g, P_HMinus, P_g, 3830)
      call createCurrent(P_Z, P_GMinus, P_A, P_GPlus, 1857)
      call createCurrent(P_GMinus, P_u, P_dAnti, 604)
      call createCurrent(P_Hh, P_HPlus, P_Ha, P_GMinus, 140)
      call createCurrent(P_Ha, P_HPlus, P_Hl, P_GMinus, 27)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_Ha, 2911)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, P_Ha, 773)
      call createCurrent(P_Hl, P_Ha, P_G0, P_Hl, 914)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, 2694)
      call createCurrent(P_Z, P_Ha, P_HPlus, P_WMinus, 2098)
      call createCurrent(P_Ha, P_A, P_WMinus, P_GPlus, 2927)
      call createCurrent(P_Z, P_WPlus, P_GMinus, 2475)
      call createCurrent(P_Ha, P_G0, P_HPlus, P_GMinus, 1029)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_G0, 1390)
      call createCurrent(P_A, P_Z, P_Hl, 3273)
      call createCurrent(P_Hh, P_Z, P_Hl, P_Z, 3150)
      call createCurrent(P_Hl, P_GMinus, P_Ha, P_GPlus, 2795)
      call createCurrent(P_Ha, P_HMinus, P_WPlus, P_Z, 1518)
      call createCurrent(P_Hl, P_Z, P_Z, P_Hh, 2827)
      call createCurrent(P_A, P_A, P_HMinus, P_GPlus, 3139)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_Z, 2231)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, P_Hh, 3462)
      call createCurrent(P_sAnti, P_G0, P_s, 454)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_A, 56)
      call createCurrent(P_ghGAnti, P_ghG, P_g, 1821)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghA, 3143)
      call createCurrent(P_Ha, P_tauMinus, P_tauPlus, 861)
      call createCurrent(P_Hh, P_G0, P_Z, 2300)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, P_Ha, 2130)
      call createCurrent(P_muMinus, P_Z, P_muPlus, 2306)
      call createCurrent(P_G0, P_G0, P_WMinus, P_WPlus, 2082)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, P_Z, 2143)
      call createCurrent(P_Ha, P_WMinus, P_HPlus, P_Z, 2336)
      call createCurrent(P_Hl, P_g, P_Hl, P_g, 3769)
      call createCurrent(P_b, P_bAnti, P_A, 955)
      call createCurrent(P_Hh, P_Hh, P_Hh, P_Hl, 1625)
      call createCurrent(P_A, P_G0, 3374)
      call createCurrent(P_GPlus, P_WMinus, P_HMinus, P_WPlus, 3489)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, 2668)
      call createCurrent(P_A, P_Z, P_Hh, P_Hh, 3571)
      call createCurrent(P_A, P_Hh, P_GPlus, P_WMinus, 2003)
      call createCurrent(P_WPlus, P_WMinus, P_HPlus, P_HMinus, 2195)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, P_Hh, 3547)
      call createCurrent(P_WMinus, P_GPlus, P_GMinus, P_WPlus, 2536)
      call createCurrent(P_GMinus, P_G0, P_Hl, P_HPlus, 2200)
      call createCurrent(P_Ha, P_WPlus, P_Z, P_HMinus, 2015)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, P_G0, 40)
      call createCurrent(P_HPlus, P_g, P_GMinus, P_g, 3638)
      call createCurrent(P_g, P_g, P_g, P_g, 94)
      call createCurrent(P_HMinus, P_Z, P_A, P_GPlus, 2730)
      call createCurrent(P_G0, P_G0, P_Hh, P_Ha, 3825)
      call createCurrent(P_tAnti, P_b, P_WPlus, 2594)
      call createCurrent(P_G0, P_Hh, P_G0, P_Hl, 194)
      call createCurrent(P_WMinus, P_HPlus, P_Hh, 1724)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, 1410)
      call createCurrent(P_GMinus, P_A, P_Z, P_HPlus, 3411)
      call createCurrent(P_HMinus, P_A, P_Z, P_HPlus, 223)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WPlus, 2054)
      call createCurrent(P_Z, P_G0, P_HMinus, P_WPlus, 3420)
      call createCurrent(P_bAnti, P_b, P_Hh, 2471)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, P_G0, 1148)
      call createCurrent(P_Hh, P_GMinus, P_Hh, P_GPlus, 1389)
      call createCurrent(P_HPlus, P_WPlus, P_HMinus, P_WMinus, 2280)
      call createCurrent(P_WMinus, P_Hl, P_HPlus, 1197)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, P_G0, 338)
      call createCurrent(P_Hl, P_Ha, P_GMinus, P_GPlus, 3276)
      call createCurrent(P_A, P_GPlus, P_Z, P_GMinus, 241)
      call createCurrent(P_muMinus, P_muPlus, P_Hh, 440)
      call createCurrent(P_G0, P_HMinus, P_GPlus, P_Ha, 2275)
      call createCurrent(P_Ha, P_G0, P_G0, P_Hl, 3760)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, 2241)
      call createCurrent(P_A, P_Z, P_HMinus, P_GPlus, 3430)
      call createCurrent(P_GPlus, P_HMinus, P_A, P_A, 3490)
      call createCurrent(P_Hh, P_WMinus, P_Hl, P_WPlus, 3307)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, P_Hl, 2097)
      call createCurrent(P_G0, P_A, P_A, P_Ha, 3676)
      call createCurrent(P_t, P_WMinus, P_bAnti, 1079)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_Hh, 251)
      call createCurrent(P_Hl, P_c, P_cAnti, 1253)
      call createCurrent(P_G0, P_G0, P_Hh, 1498)
      call createCurrent(P_HMinus, P_Hh, P_Z, P_WPlus, 747)
      call createCurrent(P_HPlus, P_HMinus, P_G0, P_G0, 1995)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_G0, 3188)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_Hl, 1137)
      call createCurrent(P_t, P_tAnti, P_Ha, 1543)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, P_G0, 2067)
      call createCurrent(P_c, P_HMinus, P_sAnti, 1522)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, 2445)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, P_A, 1996)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_G0, 1435)
      call createCurrent(P_HPlus, P_GMinus, P_Z, P_A, 3471)
      call createCurrent(P_g, P_g, P_WMinus, P_WPlus, 3872)
      call createCurrent(P_A, P_HPlus, P_Hl, P_WMinus, 352)
      call createCurrent(P_A, P_WMinus, P_Hl, P_HPlus, 1598)
      call createCurrent(P_Hl, P_Hh, P_Hh, 2413)
      call createCurrent(P_Hl, P_GPlus, P_Hh, P_HMinus, 1133)
      call createCurrent(P_A, P_GPlus, P_GMinus, 2101)
      call createCurrent(P_WPlus, P_Z, P_GMinus, 2375)
      call createCurrent(P_bAnti, P_A, P_b, 300)
      call createCurrent(P_Hh, P_Ha, P_HPlus, P_GMinus, 2356)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, P_G0, 1653)
      call createCurrent(P_HMinus, P_t, P_bAnti, 1368)
      call createCurrent(P_A, P_A, P_A, P_Z, 3687)
      call createCurrent(P_Hl, P_Ha, P_HPlus, P_GMinus, 972)
      call createCurrent(P_G0, P_t, P_tAnti, 1804)
      call createCurrent(P_Hl, P_HMinus, P_Hh, P_GPlus, 2443)
      call createCurrent(P_cAnti, P_c, P_G0, 765)
      call createCurrent(P_tAnti, P_Hl, P_t, 1766)
      call createCurrent(P_cAnti, P_c, P_Hl, 2270)
      call createCurrent(P_bAnti, P_g, P_b, 294)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, 493)
      call createCurrent(P_Z, P_WMinus, P_Hl, P_HPlus, 926)
      call createCurrent(P_HMinus, P_A, P_HPlus, P_Z, 2131)
      call createCurrent(P_Hh, P_GPlus, P_Hl, P_GMinus, 2555)
      call createCurrent(P_GMinus, P_GMinus, P_HPlus, P_GPlus, 829)
      call createCurrent(P_GMinus, P_A, P_GPlus, 2402)
      call createCurrent(P_WPlus, P_HMinus, P_A, P_G0, 3010)
      call createCurrent(P_GPlus, P_WMinus, P_Ha, P_Z, 3539)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_A, 2388)
      call createCurrent(P_GPlus, P_GMinus, P_HMinus, P_HPlus, 2424)
      call createCurrent(P_HPlus, P_A, P_HMinus, P_Z, 1930)
      call createCurrent(P_Ha, P_Hl, P_G0, P_Hl, 2593)
      call createCurrent(P_HMinus, P_Z, P_Z, P_GPlus, 3100)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_GPlus, 124)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghWp, 86)
      call createCurrent(P_Z, P_c, P_cAnti, 1373)
      call createCurrent(P_Hh, P_HMinus, P_Ha, P_HPlus, 3082)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, 1946)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, 1123)
      call createCurrent(P_Ha, P_Hh, P_G0, 702)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, 588)
      call createCurrent(P_g, P_uAnti, P_u, 400)
      call createCurrent(P_Ha, P_Z, P_GMinus, P_WPlus, 3211)
      call createCurrent(P_GMinus, P_HPlus, P_G0, P_Ha, 236)
      call createCurrent(P_Ha, P_Hl, P_A, 2828)
      call createCurrent(P_Ha, P_t, P_tAnti, 1854)
      call createCurrent(P_HMinus, P_WPlus, P_G0, P_Z, 2978)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, 2991)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, P_Hl, 561)
      call createCurrent(P_G0, P_Hl, P_A, 3560)
      call createCurrent(P_A, P_Hl, P_Z, 3558)
      call createCurrent(P_muMinus, P_G0, P_muPlus, 1682)
      call createCurrent(P_Z, P_WPlus, P_Hl, P_HMinus, 380)
      call createCurrent(P_GPlus, P_HMinus, P_G0, P_G0, 1613)
      call createCurrent(P_HMinus, P_GPlus, P_A, 2715)
      call createCurrent(P_WMinus, P_A, P_Ha, P_HPlus, 2599)
      call createCurrent(P_nu_mu, P_GMinus, P_muPlus, 1701)
      call createCurrent(P_WMinus, P_g, P_g, P_WPlus, 3685)
      call createCurrent(P_Hl, P_g, P_g, P_Hh, 3705)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, 1931)
      call createCurrent(P_G0, P_Z, P_GMinus, P_WPlus, 577)
      call createCurrent(P_HMinus, P_Hl, P_WPlus, 2511)
      call createCurrent(P_G0, P_Ha, P_A, P_Z, 3704)
      call createCurrent(P_tauMinus, P_Hl, P_tauPlus, 859)
      call createCurrent(P_Ha, P_HMinus, P_WPlus, P_A, 1062)
      call createCurrent(P_Hh, P_bAnti, P_b, 1400)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, 1022)
      call createCurrent(P_tauPlus, P_tauMinus, P_G0, 979)
      call createCurrent(P_Hh, P_Z, P_Z, P_Hh, 83)
      call createCurrent(P_Hh, P_Hh, P_Z, P_A, 3505)
      call createCurrent(P_HMinus, P_WPlus, P_Ha, P_Z, 678)
      call createCurrent(P_HPlus, P_GMinus, P_WMinus, P_WPlus, 2945)
      call createCurrent(P_WMinus, P_HPlus, P_Z, P_Hl, 1372)
      call createCurrent(P_muPlus, P_Z, P_muMinus, 31)
      call createCurrent(P_Hh, P_Ha, P_GPlus, P_GMinus, 3288)
      call createCurrent(P_Hh, P_Hh, P_G0, P_Ha, 1297)
      call createCurrent(P_Ha, P_HMinus, P_WPlus, 1006)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, 2428)
      call createCurrent(P_A, P_A, P_Z, P_A, 3740)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, P_Ha, 2923)
      call createCurrent(P_Hh, P_HMinus, P_WPlus, 899)
      call createCurrent(P_Ha, P_Ha, P_g, P_g, 3620)
      call createCurrent(P_G0, P_G0, P_Ha, P_Ha, 1073)
      call createCurrent(P_Ha, P_Z, P_A, P_G0, 3677)
      call createCurrent(P_g, P_WMinus, P_WPlus, P_g, 3717)
      call createCurrent(P_Z, P_Hh, P_HMinus, P_WPlus, 2477)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, P_Z, 1307)
      call createCurrent(P_d, P_Hh, P_dAnti, 768)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_Hh, 507)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, 2218)
      call createCurrent(P_HMinus, P_GPlus, P_A, P_Z, 3380)
      call createCurrent(P_Hh, P_Hh, P_g, P_g, 3863)
      call createCurrent(P_Hh, P_Hl, P_Ha, P_Ha, 807)
      call createCurrent(P_HPlus, P_Ha, P_Hh, P_HMinus, 3371)
      call createCurrent(P_Z, P_A, P_Z, P_A, 3659)
      call createCurrent(P_Hl, P_Hl, P_Hl, P_Hl, 983)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_Hl, 1975)
      call createCurrent(P_HPlus, P_Hl, P_WMinus, P_Z, 2107)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghZ, 3566)
      call createCurrent(P_A, P_Hl, P_Hl, P_Z, 3149)
      call createCurrent(P_Z, P_cAnti, P_c, 2615)
      call createCurrent(P_Hl, P_ghZ, P_ghZAnti, 1313)
      call createCurrent(P_muPlus, P_G0, P_muMinus, 529)
      call createCurrent(P_HPlus, P_G0, P_HMinus, P_Ha, 2301)
      call createCurrent(P_nu_eAnti, P_A, P_nu_e, 2907)
      call createCurrent(P_nu_tauAnti, P_WPlus, P_tauMinus, 430)
      call createCurrent(P_Hl, P_G0, P_G0, P_Ha, 3826)
      call createCurrent(P_HPlus, P_HPlus, P_GMinus, P_HMinus, 2329)
      call createCurrent(P_nu_tau, P_tauPlus, P_GMinus, 2079)
      call createCurrent(P_HPlus, P_WMinus, P_Hl, P_Z, 740)
      call createCurrent(P_HMinus, P_GPlus, P_HMinus, P_HPlus, 2613)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, P_Hl, 510)
      call createCurrent(P_WMinus, P_HPlus, 3301)
      call createCurrent(P_A, P_A, P_Hl, P_Hh, 3591)
      call createCurrent(P_HMinus, P_Ha, P_A, P_WPlus, 2186)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, P_Hl, 1489)
      call createCurrent(P_WMinus, P_HPlus, P_Ha, 1128)
      call createCurrent(P_Z, P_Hh, P_G0, 795)
      call createCurrent(P_g, P_A, P_g, P_A, 3764)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, 137)
      call createCurrent(P_G0, P_HPlus, P_Hl, P_HMinus, 2894)
      call createCurrent(P_Z, P_Z, P_Hh, 1491)
      call createCurrent(P_GPlus, P_Ha, P_WMinus, P_Z, 3156)
      call createCurrent(P_G0, P_GMinus, P_HPlus, P_G0, 585)
      call createCurrent(P_bAnti, P_b, P_Ha, 2156)
      call createCurrent(P_s, P_cAnti, P_GPlus, 76)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, 152)
      call createCurrent(P_cAnti, P_c, P_A, 1118)
      call createCurrent(P_WMinus, P_Hl, P_A, P_GPlus, 2321)
      call createCurrent(P_HPlus, P_Hh, P_WMinus, 1983)
      call createCurrent(P_HMinus, P_WPlus, P_A, P_Ha, 1700)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_Hh, 2121)
      call createCurrent(P_Hh, P_WMinus, P_Hh, P_WPlus, 943)
      call createCurrent(P_A, P_GMinus, P_Z, P_HPlus, 2797)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, 1872)
      call createCurrent(P_A, P_WMinus, P_GPlus, 1656)
      call createCurrent(P_Hl, P_Hl, P_A, P_A, 3868)
      call createCurrent(P_HPlus, P_HMinus, P_HMinus, P_GPlus, 2217)
      call createCurrent(P_HMinus, P_G0, P_G0, P_HPlus, 1851)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, 2383)
      call createCurrent(P_u, P_uAnti, P_G0, 1537)
      call createCurrent(P_Ha, P_WPlus, P_A, P_GMinus, 2930)
      call createCurrent(P_tauMinus, P_G0, P_tauPlus, 2425)
      call createCurrent(P_HPlus, P_WMinus, P_G0, P_A, 3317)
      call createCurrent(P_HPlus, P_Hl, P_Hl, P_GMinus, 980)
      call createCurrent(P_Hl, P_Hl, P_HMinus, P_GPlus, 11)
      call createCurrent(P_Hh, P_WPlus, P_HMinus, P_Z, 75)
      call createCurrent(P_GPlus, P_GMinus, P_HPlus, P_GMinus, 1785)
      call createCurrent(P_Z, P_Hl, P_WPlus, P_HMinus, 1882)
      call createCurrent(P_G0, P_GMinus, P_GPlus, 3342)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, 2093)
      call createCurrent(P_GMinus, P_nu_e, P_ePlus, 9)
      call createCurrent(P_G0, P_Ha, P_HMinus, P_GPlus, 33)
      call createCurrent(P_G0, P_HMinus, P_GPlus, P_Hh, 930)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_HPlus, 2029)
      call createCurrent(P_Z, P_Z, P_Hh, P_Hl, 3065)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, P_Ha, 3356)
      call createCurrent(P_Hl, P_Hh, P_Hl, P_Hh, 66)
      call createCurrent(P_WMinus, P_Ha, P_Ha, P_WPlus, 2030)
      call createCurrent(P_WMinus, P_ePlus, P_nu_e, 764)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, P_Hh, 1)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, P_Ha, 156)
      call createCurrent(P_Hh, P_HMinus, P_Hl, P_GPlus, 439)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, P_Hh, 118)
      call createCurrent(P_G0, P_Ha, P_GMinus, P_GPlus, 1511)
      call createCurrent(P_g, P_g, P_GPlus, P_HMinus, 3808)
      call createCurrent(P_G0, P_Z, P_HMinus, P_WPlus, 2852)
      call createCurrent(P_t, P_bAnti, P_HMinus, 1617)
      call createCurrent(P_GMinus, P_A, P_HPlus, P_A, 3465)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, P_Hh, 2946)
      call createCurrent(P_GMinus, P_GPlus, P_HPlus, P_HMinus, 2382)
      call createCurrent(P_Ha, P_A, P_WPlus, P_GMinus, 3062)
      call createCurrent(P_Z, P_G0, P_Hh, 675)
      call createCurrent(P_HPlus, P_HMinus, P_G0, P_Hl, 3134)
      call createCurrent(P_WPlus, P_Z, P_Ha, P_GMinus, 2906)
      call createCurrent(P_Hh, P_GPlus, P_Hh, P_GMinus, 845)
      call createCurrent(P_Hl, P_Hh, P_G0, P_Ha, 1465)
      call createCurrent(P_g, P_GMinus, P_g, P_HPlus, 3805)
      call createCurrent(P_Hl, P_WMinus, P_Hh, P_WPlus, 3573)
      call createCurrent(P_Z, P_A, P_HPlus, P_GMinus, 3029)
      call createCurrent(P_HPlus, P_GMinus, P_G0, P_Hl, 1642)
      call createCurrent(P_A, P_G0, P_A, P_Ha, 3621)
      call createCurrent(P_WMinus, P_HPlus, P_A, P_Hh, 208)
      call createCurrent(P_Hh, P_Z, P_Ha, 54)
      call createCurrent(P_uAnti, P_u, P_A, 848)
      call createCurrent(P_tAnti, P_G0, P_t, 1536)
      call createCurrent(P_WPlus, P_A, P_G0, P_HMinus, 2783)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghZ, 3023)
      call createCurrent(P_b, P_bAnti, P_Hl, 2250)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghWm, 1928)
      call createCurrent(P_s, P_sAnti, P_Ha, 2112)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, P_G0, 1052)
      call createCurrent(P_muPlus, P_nu_mu, P_GMinus, 2386)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, P_A, 181)
      call createCurrent(P_Z, P_nu_eAnti, P_nu_e, 1662)
      call createCurrent(P_WMinus, P_HPlus, P_A, P_G0, 2734)
      call createCurrent(P_Hl, P_Hh, P_Hl, P_Hl, 2287)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, P_Hh, 2206)
      call createCurrent(P_HPlus, P_A, P_WMinus, 881)
      call createCurrent(P_tAnti, P_Z, P_t, 1291)
      call createCurrent(P_Hh, P_Hh, 3461)
      call createCurrent(P_WMinus, P_u, P_dAnti, 664)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_Hh, 1637)
      call createCurrent(P_G0, P_Z, P_Z, P_G0, 413)
      call createCurrent(P_Hh, P_muMinus, P_muPlus, 1502)
      call createCurrent(P_GPlus, P_Ha, P_Hl, P_HMinus, 1387)
      call createCurrent(P_g, P_G0, P_Ha, P_g, 3772)
      call createCurrent(P_WMinus, P_Hh, P_Z, P_GPlus, 195)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, 1787)
      call createCurrent(P_Hl, P_A, P_GPlus, P_WMinus, 1274)
      call createCurrent(P_Z, P_WMinus, P_HPlus, P_Hh, 2521)
      call createCurrent(P_Z, P_Ha, P_WMinus, P_GPlus, 3102)
      call createCurrent(P_c, P_cAnti, P_G0, 2398)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, P_Hh, 3515)
      call createCurrent(P_tauMinus, P_tauPlus, P_Z, 1138)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_G0, 850)
      call createCurrent(P_Hh, P_Hl, P_GMinus, P_GPlus, 2182)
      call createCurrent(P_b, P_bAnti, P_g, 499)
      call createCurrent(P_Hl, P_HPlus, P_Hh, P_HMinus, 2541)
      call createCurrent(P_Z, P_WMinus, P_Hh, P_GPlus, 1032)
      call createCurrent(P_ghWmAnti, P_Ha, P_ghWm, 2994)
      call createCurrent(P_nu_mu, P_WMinus, P_muPlus, 2580)
      call createCurrent(P_Ha, P_G0, P_WPlus, P_WMinus, 2812)
      call createCurrent(P_GMinus, P_HPlus, P_GPlus, P_GMinus, 1397)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WPlus, 732)
      call createCurrent(P_A, P_A, P_WMinus, P_WPlus, 393)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_Z, 1505)
      call createCurrent(P_Hl, P_Ha, P_Hl, P_G0, 1232)
      call createCurrent(P_Hh, P_Hh, P_Z, P_Z, 2680)
      call createCurrent(P_Hl, P_WPlus, P_Hh, P_WMinus, 3097)
      call createCurrent(P_A, P_Z, P_Hh, P_Hl, 3746)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, 1193)
      call createCurrent(P_g, P_A, P_A, P_g, 3651)
      call createCurrent(P_Ha, P_g, P_g, P_Ha, 3623)
      call createCurrent(P_G0, P_Ha, P_G0, 3823)
      call createCurrent(P_sAnti, P_Z, P_s, 2042)
      call createCurrent(P_Hh, P_G0, P_Ha, P_Hh, 2020)
      call createCurrent(P_HPlus, P_Z, P_WMinus, 1834)
      call createCurrent(P_Hl, P_G0, P_Hh, P_G0, 699)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, P_Hl, 711)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, 1580)
      call createCurrent(P_G0, P_g, P_g, P_G0, 3688)
      call createCurrent(P_g, P_WPlus, P_WMinus, P_g, 3856)
      call createCurrent(P_G0, P_Ha, P_Hh, 286)
      call createCurrent(P_Z, P_muMinus, P_muPlus, 1456)
      call createCurrent(P_Hl, P_HMinus, P_WPlus, P_A, 2696)
      call createCurrent(P_WPlus, P_Z, P_Hh, P_GMinus, 2104)
      call createCurrent(P_Hh, P_A, P_WPlus, P_GMinus, 869)
      call createCurrent(P_WMinus, P_Z, P_HPlus, 1929)
      call createCurrent(P_b, P_tAnti, P_GPlus, 1302)
      call createCurrent(P_HMinus, P_HMinus, P_GPlus, P_GPlus, 1058)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_A, 1082)
      call createCurrent(P_A, P_WPlus, P_HMinus, P_G0, 3121)
      call createCurrent(P_WMinus, P_G0, P_A, P_HPlus, 2712)
      call createCurrent(P_dAnti, P_A, P_d, 897)
      call createCurrent(P_Hl, P_G0, P_A, 3275)
      call createCurrent(P_HMinus, P_GPlus, P_A, P_A, 3498)
      call createCurrent(P_Z, P_WPlus, P_HMinus, 1413)
      call createCurrent(P_GPlus, P_WMinus, 3286)
      call createCurrent(P_Ha, P_WMinus, P_Z, P_HPlus, 1721)
      call createCurrent(P_Z, P_tAnti, P_t, 1131)
      call createCurrent(P_Ha, P_A, P_Z, P_G0, 3694)
      call createCurrent(P_muPlus, P_muMinus, P_Hl, 2391)
      call createCurrent(P_Ha, P_GMinus, P_A, P_WPlus, 2760)
      call createCurrent(P_tauMinus, P_GPlus, P_nu_tauAnti, 1156)
      call createCurrent(P_Z, P_G0, P_WPlus, P_GMinus, 328)
      call createCurrent(P_g, P_g, P_Hl, P_Hh, 3665)
      call createCurrent(P_A, P_A, P_Z, P_Z, 3674)
      call createCurrent(P_GMinus, P_WPlus, P_Z, 2385)
      call createCurrent(P_Hl, P_GMinus, P_Z, P_WPlus, 2571)
      call createCurrent(P_A, P_Hl, P_WMinus, P_GPlus, 2198)
      call createCurrent(P_Z, P_Ha, P_G0, P_Z, 2809)
      call createCurrent(P_Hh, P_Ha, P_HMinus, P_HPlus, 3105)
      call createCurrent(P_s, P_sAnti, 3363)
      call createCurrent(P_G0, P_G0, P_Hl, 1166)
      call createCurrent(P_HMinus, P_Z, P_Hl, P_WPlus, 1213)
      call createCurrent(P_dAnti, P_d, P_Ha, 1905)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, P_Hl, 579)
      call createCurrent(P_Ha, P_HPlus, P_A, P_WMinus, 2645)
      call createCurrent(P_Z, P_Z, P_GMinus, P_HPlus, 3467)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, 1831)
      call createCurrent(P_HMinus, P_HPlus, P_HPlus, P_HMinus, 2476)
      call createCurrent(P_u, P_dAnti, P_GMinus, 99)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, P_Hl, 2637)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_A, 1233)
      call createCurrent(P_Hl, P_g, P_g, P_Hl, 3728)
      call createCurrent(P_Ha, P_Hh, P_Hh, P_Ha, 1376)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, 952)
      call createCurrent(P_WMinus, P_Z, P_G0, P_HPlus, 3336)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, P_G0, 674)
      call createCurrent(P_g, P_G0, P_g, P_G0, 3654)
      call createCurrent(P_WMinus, P_HMinus, P_GPlus, P_WPlus, 3575)
      call createCurrent(P_GMinus, P_A, P_A, P_HPlus, 3344)
      call createCurrent(P_HMinus, P_G0, P_GPlus, P_Hh, 900)
      call createCurrent(P_A, P_Z, P_Hl, P_Hh, 3742)
      call createCurrent(P_Hl, P_A, P_GMinus, P_WPlus, 1584)
      call createCurrent(P_WPlus, P_GMinus, P_G0, 2522)
      call createCurrent(P_Z, P_G0, P_A, P_Ha, 3655)
      call createCurrent(P_HMinus, P_ghZAnti, P_ghWp, 3131)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, P_G0, 1859)
      call createCurrent(P_Ha, P_Ha, P_Hl, P_Hl, 1350)
      call createCurrent(P_GPlus, P_HMinus, 3568)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_G0, 2703)
      call createCurrent(P_HPlus, P_G0, P_Hl, P_HMinus, 3556)
      call createCurrent(P_Ha, P_G0, 3310)
      call createCurrent(P_Z, P_Hl, P_Hh, P_Z, 3327)
      call createCurrent(P_HMinus, P_Hl, P_G0, P_GPlus, 1997)
      call createCurrent(P_sAnti, P_c, P_WMinus, 1711)
      call createCurrent(P_GMinus, P_HPlus, 2751)
      call createCurrent(P_WPlus, P_Hl, P_Hh, P_WMinus, 3155)
      call createCurrent(P_bAnti, P_t, P_GMinus, 2146)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, P_Hh, 435)
      call createCurrent(P_G0, P_HPlus, P_WMinus, P_Z, 3517)
      call createCurrent(P_Ha, P_WPlus, P_Z, P_GMinus, 3528)
      call createCurrent(P_GMinus, P_Ha, P_Hl, P_GPlus, 2899)
      call createCurrent(P_Z, P_HMinus, P_GPlus, 3574)
      call createCurrent(P_G0, P_Z, P_Ha, P_A, 3703)
      call createCurrent(P_A, P_WMinus, P_G0, P_GPlus, 135)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, 677)
      call createCurrent(P_WPlus, P_Hh, P_Z, P_GMinus, 785)
      call createCurrent(P_Hl, P_Hh, P_G0, P_G0, 2246)
      call createCurrent(P_G0, P_G0, 3326)
      call createCurrent(P_Z, P_GMinus, P_G0, P_WPlus, 2297)
      call createCurrent(P_A, P_Hh, P_WMinus, P_GPlus, 161)
      call createCurrent(P_HMinus, P_Ha, P_WPlus, 759)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, P_Ha, 2162)
      call createCurrent(P_WMinus, P_bAnti, P_t, 887)
      call createCurrent(P_nu_tau, P_HMinus, P_tauPlus, 2276)
      call createCurrent(P_Hh, P_WPlus, P_A, P_HMinus, 958)
      call createCurrent(P_GMinus, P_Z, P_Z, P_HPlus, 3084)
      call createCurrent(P_A, P_HPlus, P_Z, P_GMinus, 2990)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_G0, 217)
      call createCurrent(P_G0, P_Z, P_A, P_Ha, 3765)
      call createCurrent(P_GPlus, P_Ha, P_G0, P_GMinus, 1086)
      call createCurrent(P_GMinus, P_Z, P_Hh, P_WPlus, 1341)
      call createCurrent(P_Ha, P_Hl, P_Ha, P_Hh, 0)
      call createCurrent(P_G0, P_GMinus, P_WPlus, 612)
      call createCurrent(P_Hh, P_WMinus, P_Z, P_HPlus, 1468)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, P_Ha, 2531)
      call createCurrent(P_Z, P_HMinus, P_Hh, P_WPlus, 1555)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, P_G0, 1718)
      call createCurrent(P_WMinus, P_WPlus, P_A, 1440)
      call createCurrent(P_Z, P_G0, P_GMinus, P_WPlus, 1989)
      call createCurrent(P_A, P_GPlus, P_Hh, P_WMinus, 1048)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_Hl, 2240)
      call createCurrent(P_Hh, P_HPlus, P_WMinus, 2634)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, P_A, 511)
      call createCurrent(P_sAnti, P_GMinus, P_c, 2316)
      call createCurrent(P_Hl, P_sAnti, P_s, 468)
      call createCurrent(P_Ha, P_WMinus, P_WPlus, P_G0, 3226)
      call createCurrent(P_GPlus, P_cAnti, P_s, 743)
      call createCurrent(P_A, P_HPlus, P_A, P_HMinus, 1284)
      call createCurrent(P_Hl, P_Z, P_WPlus, P_HMinus, 117)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, 123)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, 1987)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, 864)
      call createCurrent(P_HMinus, P_Ha, P_Ha, P_GPlus, 533)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Ha, 2844)
      call createCurrent(P_Ha, P_GPlus, P_A, P_WMinus, 3387)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_G0, 2689)
      call createCurrent(P_Hh, P_sAnti, P_s, 355)
      call createCurrent(P_GPlus, P_Z, P_A, P_HMinus, 3135)
      call createCurrent(P_GPlus, P_Hl, P_Ha, P_GMinus, 3086)
      call createCurrent(P_HPlus, P_HPlus, P_HMinus, P_GMinus, 2695)
      call createCurrent(P_u, P_GMinus, P_dAnti, 333)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, 1978)
      call createCurrent(P_GPlus, P_g, P_g, P_GMinus, 3789)
      call createCurrent(P_Hl, P_HPlus, P_G0, P_HMinus, 3332)
      call createCurrent(P_nu_eAnti, P_GPlus, P_eMinus, 84)
      call createCurrent(P_G0, P_Hh, P_GMinus, P_HPlus, 721)
      call createCurrent(P_HMinus, P_HPlus, P_A, P_Z, 1904)
      call createCurrent(P_GMinus, P_G0, P_Ha, P_HPlus, 1514)
      call createCurrent(P_HPlus, P_HMinus, P_HPlus, P_GMinus, 554)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, 1630)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, P_Hl, 2573)
      call createCurrent(P_G0, P_HMinus, P_HPlus, P_G0, 1707)
      call createCurrent(P_Hh, P_HPlus, P_Hl, P_GMinus, 1681)
      call createCurrent(P_GPlus, P_GMinus, P_A, 802)
      call createCurrent(P_Hl, P_Hl, P_GMinus, P_GPlus, 111)
      call createCurrent(P_tauMinus, P_Hh, P_tauPlus, 1357)
      call createCurrent(P_Hl, P_Hl, P_HPlus, P_GMinus, 762)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, P_Hh, 1246)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_G0, 3549)
      call createCurrent(P_Z, P_Z, P_A, P_Z, 3809)
      call createCurrent(P_g, P_bAnti, P_b, 2211)
      call createCurrent(P_WPlus, P_HMinus, P_Z, P_G0, 2960)
      call createCurrent(P_Z, P_Hl, P_WMinus, P_HPlus, 913)
      call createCurrent(P_Hl, P_GPlus, P_G0, P_HMinus, 1507)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, 1725)
      call createCurrent(P_GMinus, P_GPlus, P_HMinus, P_HPlus, 1795)
      call createCurrent(P_HMinus, P_HPlus, P_Z, P_A, 1474)
      call createCurrent(P_WPlus, P_HMinus, P_Z, 1481)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_Ha, 3004)
      call createCurrent(P_WMinus, P_muPlus, P_nu_mu, 2361)
      call createCurrent(P_Hl, P_HPlus, P_Hl, P_HMinus, 171)
      call createCurrent(P_G0, P_Ha, P_Hl, P_Hl, 1743)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, P_Hh, 1142)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, 1304)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_Hh, 146)
      call createCurrent(P_Ha, P_G0, P_Ha, P_G0, 277)
      call createCurrent(P_A, P_GPlus, P_G0, P_WMinus, 564)
      call createCurrent(P_Ha, P_Z, P_WMinus, P_GPlus, 2724)
      call createCurrent(P_A, P_Hh, P_Hl, P_Z, 3766)
      call createCurrent(P_Hl, P_Hl, P_g, P_g, 3859)
      call createCurrent(P_HPlus, P_GMinus, P_G0, P_Hh, 2328)
      call createCurrent(P_WMinus, P_sAnti, P_c, 1958)
      call createCurrent(P_Hl, P_G0, P_Hl, P_G0, 1248)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, 2189)
      call createCurrent(P_Hh, P_HPlus, P_G0, P_GMinus, 2376)
      call createCurrent(P_A, P_Ha, P_WPlus, P_GMinus, 2964)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, P_G0, 2325)
      call createCurrent(P_bAnti, P_b, P_A, 2068)
      call createCurrent(P_WMinus, P_WPlus, P_WPlus, P_WMinus, 1225)
      call createCurrent(P_HPlus, P_HMinus, P_GPlus, P_GMinus, 1347)
      call createCurrent(P_GPlus, P_Ha, P_A, P_WMinus, 2976)
      call createCurrent(P_Hh, P_A, P_WPlus, P_HMinus, 425)
      call createCurrent(P_G0, P_G0, P_GPlus, P_GMinus, 1875)
      call createCurrent(P_WPlus, P_Ha, P_Z, P_HMinus, 2150)
      call createCurrent(P_WMinus, P_Ha, P_Z, P_GPlus, 2968)
      call createCurrent(P_GMinus, P_muPlus, P_nu_mu, 47)
      call createCurrent(P_Z, P_WPlus, P_Hh, P_GMinus, 2036)
      call createCurrent(P_WMinus, P_HMinus, P_WPlus, P_HPlus, 1328)
      call createCurrent(P_Hh, P_Hl, P_HPlus, P_GMinus, 656)
      call createCurrent(P_GMinus, P_A, P_A, P_GPlus, 2646)
      call createCurrent(P_G0, P_muPlus, P_muMinus, 239)
      call createCurrent(P_GMinus, P_HPlus, P_G0, 578)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, P_A, 799)
      call createCurrent(P_Hh, P_A, P_WMinus, P_HPlus, 1862)
      call createCurrent(P_Ha, P_Z, P_A, P_Ha, 3095)
      call createCurrent(P_Hl, P_Ha, P_HPlus, P_HMinus, 3228)
      call createCurrent(P_Ha, P_G0, P_Z, P_Z, 3583)
      call createCurrent(P_GPlus, P_A, P_WMinus, 2159)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, P_Hh, 576)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, 668)
      call createCurrent(P_HMinus, P_g, P_GPlus, P_g, 3777)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, P_G0, 1934)
      call createCurrent(P_GMinus, P_HPlus, P_GMinus, P_HPlus, 206)
      call createCurrent(P_A, P_HPlus, P_HMinus, 46)
      call createCurrent(P_b, P_GPlus, P_tAnti, 519)
      call createCurrent(P_HMinus, P_GPlus, P_Z, P_Z, 3268)
      call createCurrent(P_Ha, P_u, P_uAnti, 2347)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, P_Hh, 1968)
      call createCurrent(P_Ha, P_Hh, P_HPlus, P_GMinus, 872)
      call createCurrent(P_GMinus, P_Hh, P_Hh, P_HPlus, 1001)
      call createCurrent(P_muPlus, P_muMinus, P_A, 2444)
      call createCurrent(P_WMinus, P_HPlus, P_WPlus, P_GMinus, 3361)
      call createCurrent(P_Z, P_HPlus, P_HMinus, 1173)
      call createCurrent(P_HPlus, P_A, P_A, P_GMinus, 3446)
      call createCurrent(P_WMinus, P_Ha, P_WPlus, P_G0, 3193)
      call createCurrent(P_WMinus, P_GPlus, P_HMinus, P_WPlus, 3542)
      call createCurrent(P_g, P_GPlus, P_HMinus, P_g, 3846)
      call createCurrent(P_HMinus, P_Ha, P_WPlus, P_A, 2592)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, P_Hl, 3036)
      call createCurrent(P_G0, P_GMinus, P_A, P_WPlus, 1064)
      call createCurrent(P_GMinus, P_HPlus, P_Z, 2948)
      call createCurrent(P_WMinus, P_A, P_Z, P_WPlus, 1364)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, P_Ha, 2513)
      call createCurrent(P_HMinus, P_WPlus, P_A, 1020)
      call createCurrent(P_c, P_Ha, P_cAnti, 2017)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_Ha, 2081)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_G0, 497)
      call createCurrent(P_Hl, P_Ha, P_Hh, P_G0, 36)
      call createCurrent(P_Z, P_A, P_HMinus, P_HPlus, 1485)
      call createCurrent(P_GMinus, P_HPlus, P_GMinus, P_GPlus, 1189)
      call createCurrent(P_HMinus, P_Hl, P_Ha, P_HPlus, 2853)
      call createCurrent(P_Hh, P_Z, P_WMinus, P_GPlus, 2075)
      call createCurrent(P_Ha, P_Hh, P_Ha, P_Hl, 60)
      call createCurrent(P_WMinus, P_WPlus, P_Ha, P_Ha, 2485)
      call createCurrent(P_WMinus, P_A, P_HPlus, P_Hh, 369)
      call createCurrent(P_Z, P_HPlus, P_Z, P_HMinus, 1101)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, P_Ha, 1108)
      call createCurrent(P_WMinus, P_GPlus, P_Ha, P_Z, 3475)
      call createCurrent(P_g, P_HPlus, P_g, P_GMinus, 3736)
      call createCurrent(P_Ha, P_HMinus, P_A, P_WPlus, 567)
      call createCurrent(P_HPlus, P_WMinus, P_G0, 2761)
      call createCurrent(P_Hl, P_HPlus, P_Hh, P_GMinus, 1786)
      call createCurrent(P_WMinus, P_Hl, P_HPlus, P_A, 1962)
      call createCurrent(P_tauPlus, P_nu_tau, P_HMinus, 307)
      call createCurrent(P_Ha, P_G0, P_HMinus, P_GPlus, 234)
      call createCurrent(P_HPlus, P_Z, P_WMinus, P_Hh, 928)
      call createCurrent(P_G0, P_GPlus, P_A, P_WMinus, 2493)
      call createCurrent(P_G0, P_Hl, P_GMinus, P_GPlus, 2909)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, 1664)
      call createCurrent(P_Z, P_G0, 2914)
      call createCurrent(P_ghWpAnti, P_ghZ, P_HPlus, 3453)
      call createCurrent(P_A, P_A, P_HPlus, P_GMinus, 3546)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, P_G0, 1403)
      call createCurrent(P_Hh, P_HMinus, P_G0, P_HPlus, 2904)
      call createCurrent(P_tauMinus, P_A, P_tauPlus, 69)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_GPlus, 219)
      call createCurrent(P_GPlus, P_A, P_Ha, P_WMinus, 3561)
      call createCurrent(P_HPlus, P_Ha, P_Ha, P_HMinus, 1670)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, P_Ha, 2932)
      call createCurrent(P_Z, P_WPlus, P_G0, P_HMinus, 2710)
      call createCurrent(P_Hl, P_Hh, P_HMinus, P_HPlus, 1763)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, 1436)
      call createCurrent(P_A, P_HPlus, P_Ha, P_WMinus, 1005)
      call createCurrent(P_GPlus, P_Z, P_A, P_GMinus, 93)
      call createCurrent(P_WPlus, P_HMinus, P_G0, 3068)
      call createCurrent(P_uAnti, P_g, P_u, 1228)
      call createCurrent(P_HMinus, P_A, P_WPlus, P_G0, 3554)
      call createCurrent(P_Hh, P_Hl, P_A, P_A, 3786)
      call createCurrent(P_GPlus, P_G0, P_Hh, P_HMinus, 1132)
      call createCurrent(P_Hh, P_Z, P_Z, 376)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_G0, 145)
      call createCurrent(P_WPlus, P_G0, P_A, P_GMinus, 242)
      call createCurrent(P_HPlus, P_GMinus, P_Z, 2843)
      call createCurrent(P_G0, P_A, 2954)
      call createCurrent(P_Hl, P_uAnti, P_u, 1365)
      call createCurrent(P_GMinus, P_g, P_GPlus, P_g, 3732)
      call createCurrent(P_G0, P_Ha, P_Z, P_A, 3612)
      call createCurrent(P_ePlus, P_A, P_eMinus, 1814)
      call createCurrent(P_G0, P_HMinus, P_G0, P_HPlus, 603)
      call createCurrent(P_Z, P_HPlus, P_A, P_HMinus, 2045)
      call createCurrent(P_HPlus, P_G0, P_HMinus, 3260)
      call createCurrent(P_g, P_GMinus, P_g, P_GPlus, 3641)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, 1759)
      call createCurrent(P_Hh, P_tAnti, P_t, 2639)
      call createCurrent(P_uAnti, P_Hl, P_u, 2291)
      call createCurrent(P_HPlus, P_GMinus, P_HPlus, P_GMinus, 2575)
      call createCurrent(P_Hl, P_A, P_WMinus, P_HPlus, 2335)
      call createCurrent(P_A, P_Hh, P_A, P_Hh, 3714)
      call createCurrent(P_Z, P_muPlus, P_muMinus, 1273)
      call createCurrent(P_b, P_Ha, P_bAnti, 1510)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_Z, 293)
      call createCurrent(P_A, P_Hh, P_WPlus, P_HMinus, 2260)
      call createCurrent(P_GPlus, P_A, P_Hh, P_WMinus, 1716)
      call createCurrent(P_GPlus, P_nu_tauAnti, P_tauMinus, 2660)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_Hl, 1583)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, P_Hh, 3469)
      call createCurrent(P_A, P_HPlus, P_GMinus, P_Z, 3034)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_A, 1010)
      call createCurrent(P_GPlus, P_G0, P_G0, P_HMinus, 1066)
      call createCurrent(P_G0, P_Hh, P_Hh, P_Ha, 2431)
      call createCurrent(P_HPlus, P_cAnti, P_s, 318)
      call createCurrent(P_HMinus, P_HPlus, P_HMinus, P_HPlus, 2410)
      call createCurrent(P_dAnti, P_d, P_G0, 1951)
      call createCurrent(P_Hh, P_HMinus, P_WPlus, P_A, 1742)
      call createCurrent(P_tauPlus, P_Hh, P_tauMinus, 2283)
      call createCurrent(P_G0, P_A, P_Hl, 3239)
      call createCurrent(P_G0, P_cAnti, P_c, 2285)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_G0, 2185)
      call createCurrent(P_A, P_Hh, P_A, P_Hl, 3637)
      call createCurrent(P_c, P_G0, P_cAnti, 2262)
      call createCurrent(P_G0, P_HPlus, P_G0, P_HMinus, 2343)
      call createCurrent(P_nu_mu, P_muPlus, P_GMinus, 1370)
      call createCurrent(P_GMinus, P_Ha, P_A, P_WPlus, 3115)
      call createCurrent(P_GPlus, P_G0, P_Ha, P_HMinus, 635)
      call createCurrent(P_WMinus, P_Hh, P_HPlus, 1913)
      call createCurrent(P_Z, P_WPlus, P_HMinus, P_G0, 2979)
      call createCurrent(P_Ha, P_Ha, P_Hh, P_Hl, 2353)
      call createCurrent(P_WMinus, P_HPlus, P_Z, P_Ha, 481)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, P_Hh, 3492)
      call createCurrent(P_Hl, P_WMinus, P_Z, P_GPlus, 1944)
      call createCurrent(P_WPlus, P_Hl, P_HMinus, 1998)
      call createCurrent(P_Z, P_Ha, P_Hh, 51)
      call createCurrent(P_muMinus, P_muPlus, P_G0, 1442)
      call createCurrent(P_Ha, P_HPlus, P_Ha, P_HMinus, 777)
      call createCurrent(P_HPlus, P_Hh, P_Hh, P_GMinus, 530)
      call createCurrent(P_Z, P_HPlus, P_WMinus, P_Hl, 22)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GPlus, 586)
      call createCurrent(P_A, P_A, P_Ha, P_Ha, 3629)
      call createCurrent(P_c, P_cAnti, P_Ha, 670)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_Hh, 843)
      call createCurrent(P_Hh, P_A, P_A, 3767)
      call createCurrent(P_Hl, P_Ha, P_G0, P_Hh, 261)
      call createCurrent(P_Z, P_HPlus, P_GMinus, P_A, 3205)
      call createCurrent(P_bAnti, P_Hh, P_b, 997)
      call createCurrent(P_Ha, P_WMinus, P_GPlus, P_Z, 3006)
      call createCurrent(P_t, P_Hh, P_tAnti, 2690)
      call createCurrent(P_Ha, P_Ha, P_Hh, 487)
      call createCurrent(P_WPlus, P_GMinus, P_Ha, P_Z, 2980)
      call createCurrent(P_uAnti, P_d, P_WPlus, 1070)
      call createCurrent(P_A, P_Z, P_g, P_g, 3622)
      call createCurrent(P_A, P_GMinus, P_Z, P_GPlus, 1858)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_GPlus, 173)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, P_Hl, 2892)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_GPlus, 1919)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, P_Hl, 3198)
      call createCurrent(P_Ha, P_G0, P_g, P_g, 3710)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_Ha, 3443)
      call createCurrent(P_Hl, P_Hh, P_WPlus, P_WMinus, 2854)
      call createCurrent(P_Ha, P_g, P_Ha, P_g, 3693)
      call createCurrent(P_WMinus, P_A, P_Hh, P_GPlus, 202)
      call createCurrent(P_Ha, P_Z, P_Hh, 1553)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, P_Hl, 2677)
      call createCurrent(P_G0, P_g, P_g, P_Ha, 3615)
      call createCurrent(P_Ha, P_Hh, P_HMinus, P_GPlus, 408)
      call createCurrent(P_HPlus, P_HMinus, P_A, P_Z, 404)
      call createCurrent(P_A, P_GMinus, P_GPlus, 180)
      call createCurrent(P_A, P_dAnti, P_d, 1713)
      call createCurrent(P_HMinus, P_GPlus, P_WMinus, P_WPlus, 2887)
      call createCurrent(P_HPlus, P_Hl, P_Hl, P_HMinus, 1427)
      call createCurrent(P_A, P_Z, P_HPlus, P_HMinus, 1426)
      call createCurrent(P_Hh, P_Hh, P_Hh, P_Hh, 1722)
      call createCurrent(P_G0, P_WPlus, P_A, P_GMinus, 2463)
      call createCurrent(P_A, P_G0, P_Ha, P_A, 3817)
      call createCurrent(P_HPlus, P_ghA, P_ghWpAnti, 3300)
      call createCurrent(P_Hl, P_Z, P_WMinus, P_HPlus, 1287)
      call createCurrent(P_HPlus, P_ghZAnti, P_ghWm, 3423)
      call createCurrent(P_c, P_sAnti, P_GMinus, 2187)
      call createCurrent(P_Hl, P_Hl, P_G0, P_G0, 673)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, 613)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, 1316)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hh, 710)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, P_Ha, 647)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_GMinus, 559)
      call createCurrent(P_WMinus, P_Z, P_Hh, P_GPlus, 2057)
      call createCurrent(P_Z, P_Z, P_G0, P_G0, 1292)
      call createCurrent(P_Hh, P_G0, P_HMinus, P_HPlus, 2926)
      call createCurrent(P_G0, P_Hh, P_GPlus, P_HMinus, 1923)
      call createCurrent(P_WPlus, P_GMinus, P_Ha, P_A, 3537)
      call createCurrent(P_HMinus, P_Z, P_G0, P_WPlus, 3484)
      call createCurrent(P_Z, P_Ha, P_Ha, P_A, 3586)
      call createCurrent(P_A, P_Z, P_GMinus, P_HPlus, 3424)
      call createCurrent(P_d, P_dAnti, P_Hl, 614)
      call createCurrent(P_Z, P_Z, P_Hl, 1691)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, P_Hh, 1833)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, 3248)
      call createCurrent(P_A, P_WPlus, P_HMinus, P_Ha, 2226)
      call createCurrent(P_Hh, P_ghZ, P_ghZAnti, 2480)
      call createCurrent(P_G0, P_GMinus, P_Hl, P_GPlus, 2732)
      call createCurrent(P_WPlus, P_GMinus, P_GPlus, P_WMinus, 940)
      call createCurrent(P_G0, P_Ha, P_G0, P_Ha, 247)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, 894)
      call createCurrent(P_eMinus, P_HPlus, P_nu_eAnti, 767)
      call createCurrent(P_HPlus, P_G0, P_GMinus, 1402)
      call createCurrent(P_HPlus, P_Ha, P_Hh, P_GMinus, 697)
      call createCurrent(P_Ha, P_G0, P_G0, P_Hh, 3713)
      call createCurrent(P_HPlus, P_GPlus, P_GMinus, P_HMinus, 2318)
      call createCurrent(P_Z, P_HMinus, P_HPlus, P_Z, 582)
      call createCurrent(P_Hh, P_GMinus, P_Hl, P_GPlus, 2439)
      call createCurrent(P_HPlus, P_HMinus, P_G0, P_Hh, 2805)
      call createCurrent(P_dAnti, P_Hl, P_d, 2292)
      call createCurrent(P_t, P_G0, P_tAnti, 2078)
      call createCurrent(P_WPlus, P_A, P_Ha, P_GMinus, 3486)
      call createCurrent(P_g, P_Hl, P_g, 3734)
      call createCurrent(P_d, P_Ha, P_dAnti, 63)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, P_Z, 1847)
      call createCurrent(P_HMinus, P_Z, P_WPlus, P_Hh, 2384)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_Hh, 1541)
      call createCurrent(P_WMinus, P_Hh, P_A, P_HPlus, 260)
      call createCurrent(P_HPlus, P_HMinus, 2733)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, P_Hh, 77)
      call createCurrent(P_WMinus, P_Ha, P_GPlus, P_Z, 2967)
      call createCurrent(P_WPlus, P_Z, P_WMinus, 2171)
      call createCurrent(P_HMinus, P_G0, P_Hh, P_GPlus, 1095)
      call createCurrent(P_GMinus, P_Hl, P_Hh, P_HPlus, 1276)
      call createCurrent(P_Ha, P_Ha, P_HMinus, P_HPlus, 2119)
      call createCurrent(P_WPlus, P_tauMinus, P_nu_tauAnti, 113)
      call createCurrent(P_WPlus, P_WMinus, P_HMinus, P_GPlus, 2992)
      call createCurrent(P_HPlus, P_g, P_g, P_HMinus, 3672)
      call createCurrent(P_G0, P_Hh, P_GPlus, P_GMinus, 3271)
      call createCurrent(P_Hl, P_Hh, P_Ha, P_G0, 1974)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_HPlus, 3046)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, 2008)
      call createCurrent(P_Z, P_A, P_Hh, 3585)
      call createCurrent(P_G0, P_HPlus, P_GMinus, P_Ha, 2467)
      call createCurrent(P_uAnti, P_HPlus, P_d, 1158)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, 1388)
      call createCurrent(P_HPlus, P_G0, P_G0, P_HMinus, 190)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, P_Hl, 1683)
      call createCurrent(P_Ha, P_Z, P_Z, P_G0, 3506)
      call createCurrent(P_G0, P_HMinus, P_GPlus, 1964)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, P_A, 1044)
      call createCurrent(P_Ha, P_Hh, P_GMinus, P_GPlus, 3222)
      call createCurrent(P_ePlus, P_HMinus, P_nu_e, 695)
      call createCurrent(P_A, P_Hh, P_Ha, 3494)
      call createCurrent(P_G0, P_WPlus, P_A, P_HMinus, 3418)
      call createCurrent(P_Hh, P_HPlus, P_G0, P_HMinus, 2776)
      call createCurrent(P_GMinus, P_HPlus, P_GPlus, P_HMinus, 88)
      call createCurrent(P_GPlus, P_WMinus, P_Z, 1588)
      call createCurrent(P_Z, P_WPlus, P_Hl, P_GMinus, 1696)
      call createCurrent(P_G0, P_Ha, 3038)
      call createCurrent(P_WPlus, P_HMinus, P_Z, P_Ha, 32)
      call createCurrent(P_Z, P_Hl, P_A, P_Hl, 2951)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_Hh, 1902)
      call createCurrent(P_Hl, P_Hh, P_Hh, P_Hh, 2158)
      call createCurrent(P_Hh, P_GMinus, P_Ha, P_GPlus, 2947)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, 3437)
      call createCurrent(P_Ha, P_GMinus, P_Hl, P_GPlus, 2891)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_G0, 2840)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, P_Ha, 80)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_Z, 1655)
      call createCurrent(P_t, P_GMinus, P_bAnti, 44)
      call createCurrent(P_GPlus, P_GMinus, P_HMinus, P_GPlus, 2596)
      call createCurrent(P_GMinus, P_Z, P_Z, P_GPlus, 774)
      call createCurrent(P_Z, P_A, P_Hh, P_Hh, 3392)
      call createCurrent(P_WPlus, P_HMinus, P_G0, P_Z, 3064)
      call createCurrent(P_G0, P_HPlus, P_HMinus, P_Hl, 3354)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, 2478)
      call createCurrent(P_WPlus, P_GPlus, P_HMinus, P_WMinus, 3263)
      call createCurrent(P_Hl, P_WMinus, P_HPlus, 2671)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_Hh, 2622)
      call createCurrent(P_GMinus, P_Ha, P_Z, P_WPlus, 3032)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, 384)
      call createCurrent(P_d, P_HPlus, P_uAnti, 501)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, 752)
      call createCurrent(P_G0, P_WMinus, P_HPlus, 2888)
      call createCurrent(P_HPlus, P_g, P_g, P_GMinus, 3844)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, 405)
      call createCurrent(P_HPlus, P_GMinus, P_HMinus, P_HPlus, 2304)
      call createCurrent(P_muMinus, P_GPlus, P_nu_muAnti, 839)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, P_G0, 3247)
      call createCurrent(P_u, P_A, P_uAnti, 1027)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, 1557)
      call createCurrent(P_GMinus, P_Hh, P_Z, P_WPlus, 919)
      call createCurrent(P_Ha, P_WMinus, P_A, P_HPlus, 1165)
      call createCurrent(P_G0, P_WMinus, P_Z, P_HPlus, 3158)
      call createCurrent(P_ghA, P_HMinus, P_ghWmAnti, 2875)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_Hh, 1018)
      call createCurrent(P_Hh, P_b, P_bAnti, 1421)
      call createCurrent(P_A, P_u, P_uAnti, 1034)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, P_A, 1529)
      call createCurrent(P_WMinus, P_HPlus, P_Z, P_Hh, 308)
      call createCurrent(P_WMinus, P_Z, P_HPlus, P_G0, 2757)
      call createCurrent(P_G0, P_HPlus, P_HMinus, P_Hh, 3176)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, P_Hh, 3511)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, 1985)
      call createCurrent(P_G0, P_Ha, P_Ha, P_Ha, 947)
      call createCurrent(P_Hl, P_Z, P_Z, P_Hl, 2290)
      call createCurrent(P_s, P_sAnti, P_Hh, 2494)
      call createCurrent(P_GPlus, P_A, P_G0, P_WMinus, 367)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, P_G0, 1325)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, P_Hl, 1563)
      call createCurrent(P_HMinus, P_Hh, P_Hl, P_HPlus, 1876)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, 1247)
      call createCurrent(P_Z, P_GPlus, P_GMinus, 2441)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, P_Ha, 2609)
      call createCurrent(P_Ha, P_Ha, P_HMinus, P_GPlus, 788)
      call createCurrent(P_HMinus, P_GPlus, 3321)
      call createCurrent(P_GMinus, P_Ha, P_Hh, P_HPlus, 1674)
      call createCurrent(P_G0, P_HMinus, P_HPlus, 2786)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, P_Hl, 1918)
      call createCurrent(P_G0, P_A, P_WPlus, P_GMinus, 2114)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_Hl, 521)
      call createCurrent(P_dAnti, P_GMinus, P_u, 712)
      call createCurrent(P_bAnti, P_Hl, P_b, 1459)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, P_Hh, 1014)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_G0, 2046)
      call createCurrent(P_Hh, P_Hh, P_Ha, P_G0, 625)
      call createCurrent(P_Ha, P_GMinus, P_WPlus, P_A, 3379)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, 1942)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, P_A, 798)
      call createCurrent(P_Ha, P_muMinus, P_muPlus, 340)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_Hh, 761)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_Z, 477)
      call createCurrent(P_GMinus, P_GPlus, P_WPlus, P_WMinus, 692)
      call createCurrent(P_HPlus, P_GMinus, 3410)
      call createCurrent(P_WPlus, P_Z, P_G0, P_HMinus, 3340)
      call createCurrent(P_muMinus, P_WPlus, P_nu_muAnti, 2129)
      call createCurrent(P_g, P_Z, P_g, P_A, 3597)
      call createCurrent(P_Z, P_Hl, P_Hl, P_A, 3049)
      call createCurrent(P_HPlus, P_GPlus, P_GMinus, P_GMinus, 964)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, P_Hh, 2626)
      call createCurrent(P_WPlus, P_HMinus, P_WMinus, P_GPlus, 3308)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_Hl, 1301)
      call createCurrent(P_GMinus, P_GPlus, P_G0, 3182)
      call createCurrent(P_G0, P_GMinus, P_HPlus, P_Ha, 1843)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_A, 301)
      call createCurrent(P_G0, P_muMinus, P_muPlus, 1083)
      call createCurrent(P_A, P_A, P_HMinus, P_HPlus, 1836)
      call createCurrent(P_G0, P_GPlus, P_HMinus, P_G0, 1447)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, P_G0, 442)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_A, 3298)
      call createCurrent(P_Hh, P_ePlus, P_eMinus, 103)
      call createCurrent(P_nu_mu, P_muPlus, P_WMinus, 998)
      call createCurrent(P_Ha, P_cAnti, P_c, 29)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_Z, 268)
      call createCurrent(P_Ha, P_Ha, P_Z, P_A, 2893)
      call createCurrent(P_Hh, P_A, P_Hl, P_Z, 3763)
      call createCurrent(P_WMinus, P_Ha, P_A, P_HPlus, 148)
      call createCurrent(P_WPlus, P_GMinus, P_Ha, 2731)
      call createCurrent(P_HPlus, P_HMinus, P_g, P_g, 3699)
      call createCurrent(P_HPlus, P_ghWm, P_ghZAnti, 3563)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, P_A, 410)
      call createCurrent(P_WPlus, P_Z, P_HMinus, P_Ha, 1278)
      call createCurrent(P_WPlus, P_Ha, P_GMinus, P_Z, 3053)
      call createCurrent(P_HMinus, P_HPlus, P_HMinus, P_GPlus, 2483)
      call createCurrent(P_GPlus, P_GPlus, P_HMinus, P_GMinus, 1801)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, 2507)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_Hl, 2166)
      call createCurrent(P_GPlus, P_G0, P_G0, P_GMinus, 2417)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, P_Hh, 2777)
      call createCurrent(P_Z, P_Z, P_A, P_A, 3807)
      call createCurrent(P_Hh, P_tauPlus, P_tauMinus, 956)
      call createCurrent(P_Z, P_GPlus, P_Z, P_HMinus, 2944)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WPlus, 112)
      call createCurrent(P_Z, P_Hl, P_GMinus, P_WPlus, 230)
      call createCurrent(P_Z, P_Z, P_GPlus, P_GMinus, 2379)
      call createCurrent(P_g, P_WMinus, P_g, P_WPlus, 3649)
      call createCurrent(P_G0, P_A, P_Ha, P_A, 3715)
      call createCurrent(P_HMinus, P_A, P_Hl, P_WPlus, 2311)
      call createCurrent(P_Ha, P_G0, P_WMinus, P_WPlus, 3304)
      call createCurrent(P_GMinus, P_WPlus, P_Ha, P_A, 3416)
      call createCurrent(P_Hh, P_G0, P_A, 3168)
      call createCurrent(P_Ha, P_G0, P_G0, P_Ha, 1433)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_A, 562)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_Ha, 3438)
      call createCurrent(P_A, P_Hh, P_Hh, P_A, 3652)
      call createCurrent(P_g, P_Hh, P_g, P_Hl, 3796)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, P_Hl, 2202)
      call createCurrent(P_Hh, P_WPlus, P_Z, P_HMinus, 447)
      call createCurrent(P_HPlus, P_WMinus, P_Z, P_Ha, 2160)
      call createCurrent(P_HPlus, P_Z, P_HMinus, P_Z, 279)
      call createCurrent(P_Hl, P_GPlus, P_Ha, P_HMinus, 1369)
      call createCurrent(P_Z, P_WPlus, P_Ha, P_GMinus, 3378)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, 626)
      call createCurrent(P_GMinus, P_Z, P_GPlus, 155)
      call createCurrent(P_GPlus, P_muMinus, P_nu_muAnti, 1251)
      call createCurrent(P_g, P_g, P_Z, P_g, 3598)
      call createCurrent(P_muMinus, P_A, P_muPlus, 865)
      call createCurrent(P_muPlus, P_WMinus, P_nu_mu, 82)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, P_Hl, 2822)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, P_Ha, 438)
      call createCurrent(P_Ha, P_tauPlus, P_tauMinus, 1887)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_G0, 2814)
      call createCurrent(P_muPlus, P_nu_mu, P_HMinus, 1346)
      call createCurrent(P_Z, P_GMinus, P_HPlus, 3553)
      call createCurrent(P_G0, P_G0, P_A, P_A, 3784)
      call createCurrent(P_Hh, P_Hl, P_Z, P_Z, 3481)
      call createCurrent(P_g, P_g, P_HMinus, P_GPlus, 3696)
      call createCurrent(P_G0, P_A, P_WMinus, P_HPlus, 3103)
      call createCurrent(P_Z, P_GMinus, P_GPlus, 853)
      call createCurrent(P_bAnti, P_t, P_HMinus, 1971)
      call createCurrent(P_A, P_WPlus, P_Ha, P_HMinus, 2040)
      call createCurrent(P_A, P_A, P_HPlus, P_HMinus, 735)
      call createCurrent(P_HMinus, P_A, P_HPlus, 756)
      call createCurrent(P_HPlus, P_Z, P_A, P_GMinus, 3223)
      call createCurrent(P_HPlus, P_G0, P_Z, P_WMinus, 3320)
      call createCurrent(P_GMinus, P_HMinus, P_GPlus, P_HPlus, 1305)
      call createCurrent(P_Ha, P_G0, P_GPlus, P_HMinus, 426)
      call createCurrent(P_WPlus, P_WMinus, P_Ha, P_Ha, 2274)
      call createCurrent(P_WMinus, P_Hl, P_Hl, P_WPlus, 153)
      call createCurrent(P_ePlus, P_WMinus, P_nu_e, 1880)
      call createCurrent(P_G0, P_HMinus, P_WPlus, 3269)
      call createCurrent(P_uAnti, P_Hh, P_u, 2667)
      call createCurrent(P_g, P_HPlus, P_g, P_HMinus, 3600)
      call createCurrent(P_muMinus, P_Ha, P_muPlus, 1351)
      call createCurrent(P_A, P_GMinus, P_HPlus, P_Z, 3122)
      call createCurrent(P_Z, P_Hh, P_GMinus, P_WPlus, 2233)
      call createCurrent(P_nu_tauAnti, P_HPlus, P_tauMinus, 432)
      call createCurrent(P_g, P_A, P_g, P_g, 3726)
      call createCurrent(P_HMinus, P_Hl, P_WPlus, P_A, 2194)
      call createCurrent(P_Ha, P_g, P_g, P_G0, 3782)
      call createCurrent(P_WPlus, P_Hl, P_HMinus, P_A, 2251)
      call createCurrent(P_WPlus, P_A, P_GMinus, 1443)
      call createCurrent(P_nu_muAnti, P_muMinus, P_HPlus, 2298)
      call createCurrent(P_G0, P_Ha, P_Hh, P_Hh, 310)
      call createCurrent(P_GMinus, P_Hl, P_Hl, P_GPlus, 1585)
      call createCurrent(P_Hl, P_Hh, P_GMinus, P_HPlus, 1234)
      call createCurrent(P_d, P_uAnti, P_GPlus, 1608)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_GPlus, 246)
      call createCurrent(P_WPlus, P_Z, P_Z, P_WMinus, 1046)
      call createCurrent(P_WMinus, P_Hl, P_A, P_HPlus, 569)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_GMinus, 382)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, P_G0, 1493)
      call createCurrent(P_g, P_A, P_Z, P_g, 3682)
      call createCurrent(P_WMinus, P_Ha, P_HPlus, P_Z, 1226)
      call createCurrent(P_Hl, P_G0, P_Hl, P_Ha, 2679)
      call createCurrent(P_ePlus, P_eMinus, P_Z, 2484)
      call createCurrent(P_ghWpAnti, P_Ha, P_ghWp, 3291)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, 237)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, P_Hl, 314)
      call createCurrent(P_G0, P_HMinus, P_Ha, P_HPlus, 2355)
      call createCurrent(P_cAnti, P_Hh, P_c, 1530)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, P_Ha, 3414)
      call createCurrent(P_GPlus, P_HMinus, P_HPlus, P_GMinus, 826)
      call createCurrent(P_WMinus, P_WPlus, P_Ha, P_G0, 2983)
      call createCurrent(P_A, P_Hl, P_GPlus, P_WMinus, 1735)
      call createCurrent(P_A, P_A, P_Hl, 3838)
      call createCurrent(P_G0, P_Z, P_HPlus, P_WMinus, 3362)
      call createCurrent(P_HPlus, P_GMinus, P_G0, 1523)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, P_G0, 2320)
      call createCurrent(P_Hl, P_Hl, P_WMinus, P_WPlus, 2372)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, 2558)
      call createCurrent(P_GPlus, P_GMinus, 3311)
      call createCurrent(P_WPlus, P_Ha, P_G0, P_WMinus, 3348)
      call createCurrent(P_c, P_g, P_cAnti, 270)
      call createCurrent(P_A, P_Z, P_Z, P_Z, 3735)
      call createCurrent(P_Ha, P_WPlus, P_HMinus, P_Z, 37)
      call createCurrent(P_Hl, P_G0, P_Hh, P_Ha, 1178)
      call createCurrent(P_Ha, P_G0, P_G0, 3750)
      call createCurrent(P_HMinus, P_HPlus, P_G0, P_Ha, 467)
      call createCurrent(P_c, P_cAnti, P_Z, 329)
      call createCurrent(P_HPlus, P_Hl, P_Hh, P_HMinus, 2469)
      call createCurrent(P_Hh, P_G0, P_Ha, P_Hl, 2512)
      call createCurrent(P_WMinus, P_G0, P_Z, P_HPlus, 3579)
      call createCurrent(P_Z, P_GPlus, P_A, P_GMinus, 424)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, P_Hh, 1649)
      call createCurrent(P_Hl, P_Hh, P_Hl, 2322)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_Hh, 1677)
      call createCurrent(P_Ha, P_Ha, P_HPlus, P_HMinus, 1473)
      call createCurrent(P_Hl, P_Hl, P_Hl, 1157)
      call createCurrent(P_WPlus, P_HMinus, P_G0, P_A, 3238)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, P_Hl, 682)
      call createCurrent(P_GMinus, P_Hl, P_Hh, P_GPlus, 662)
      call createCurrent(P_GMinus, P_Ha, P_WPlus, P_A, 3187)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_Hh, 2050)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, P_Ha, 2303)
      call createCurrent(P_u, P_Ha, P_uAnti, 1692)
      call createCurrent(P_HPlus, P_WMinus, P_Z, 685)
      call createCurrent(P_dAnti, P_Z, P_d, 2465)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_A, 753)
      call createCurrent(P_muMinus, P_HPlus, P_nu_muAnti, 1419)
      call createCurrent(P_Z, P_Hh, P_A, P_Hl, 3613)
      call createCurrent(P_WMinus, P_Hh, P_Hl, P_WPlus, 2952)
      call createCurrent(P_HPlus, P_Ha, P_WMinus, P_Z, 2437)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, P_Hh, 2155)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, 2142)
      call createCurrent(P_WPlus, P_WMinus, P_Ha, P_G0, 3171)
      call createCurrent(P_A, P_GMinus, P_WPlus, 512)
      call createCurrent(P_A, P_Ha, P_Z, P_G0, 3810)
      call createCurrent(P_Z, P_A, P_HMinus, P_GPlus, 3513)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_G0, 81)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_Z, 72)
      call createCurrent(P_sAnti, P_WMinus, P_c, 1829)
      call createCurrent(P_uAnti, P_u, P_G0, 74)
      call createCurrent(P_GPlus, P_tAnti, P_b, 2077)
      call createCurrent(P_s, P_HPlus, P_cAnti, 1736)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_Hl, 891)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, 1869)
      call createCurrent(P_Hl, P_WPlus, P_HMinus, P_A, 2066)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_Hl, 385)
      call createCurrent(P_Hh, P_GPlus, P_A, P_WMinus, 1040)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, 1966)
      call createCurrent(P_WMinus, P_HMinus, P_WPlus, P_GPlus, 2742)
      call createCurrent(P_Hl, P_Z, P_Hl, P_A, 3232)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, P_A, 2013)
      call createCurrent(P_G0, P_Hh, P_Z, 4)
      call createCurrent(P_G0, P_GPlus, P_GMinus, 3478)
      call createCurrent(P_Z, P_GPlus, P_G0, P_WMinus, 2583)
      call createCurrent(P_g, P_g, P_HPlus, P_HMinus, 3640)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, P_Hh, 375)
      call createCurrent(P_Hl, P_b, P_bAnti, 1573)
      call createCurrent(P_HPlus, P_GMinus, P_GPlus, P_GMinus, 106)
      call createCurrent(P_Ha, P_GMinus, P_WPlus, P_Z, 3328)
      call createCurrent(P_G0, P_Z, P_WMinus, P_HPlus, 2871)
      call createCurrent(P_GMinus, P_HPlus, P_HPlus, P_GMinus, 1754)
      call createCurrent(P_tAnti, P_t, P_Hl, 1720)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, P_Hl, 222)
      call createCurrent(P_G0, P_G0, P_Hh, P_Hl, 973)
      call createCurrent(P_nu_tauAnti, P_A, P_nu_tau, 3099)
      call createCurrent(P_Ha, P_G0, P_A, P_Z, 3878)
      call createCurrent(P_GPlus, P_HMinus, P_Z, P_A, 3020)
      call createCurrent(P_Hl, P_GMinus, P_G0, P_HPlus, 552)
      call createCurrent(P_HMinus, P_Ha, P_Hl, P_HPlus, 2792)
      call createCurrent(P_Hl, P_A, P_Hh, P_A, 3833)
      call createCurrent(P_GPlus, P_Hh, P_Ha, P_HMinus, 262)
      call createCurrent(P_GPlus, P_Hh, P_Z, P_WMinus, 416)
      call createCurrent(P_A, P_HPlus, P_GMinus, P_A, 3173)
      call createCurrent(P_A, P_Ha, P_WMinus, P_GPlus, 2813)
      call createCurrent(P_g, P_g, P_A, P_Z, 3806)
      call createCurrent(P_tauPlus, P_tauMinus, P_Z, 2563)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghZ, 3050)
      call createCurrent(P_A, P_A, 3133)
      call createCurrent(P_Hh, P_WMinus, P_Z, P_GPlus, 144)
      call createCurrent(P_Hl, P_WMinus, P_HPlus, P_Z, 313)
      call createCurrent(P_Hl, P_GMinus, P_Hh, P_HPlus, 1355)
      call createCurrent(P_WMinus, P_Z, P_Z, P_WPlus, 1881)
      call createCurrent(P_eMinus, P_nu_eAnti, P_HPlus, 1466)
      call createCurrent(P_Hl, P_Hh, P_A, P_Z, 3832)
      call createCurrent(P_WPlus, P_g, P_g, P_WMinus, 3837)
      call createCurrent(P_Z, P_WMinus, P_HPlus, P_Ha, 2028)
      call createCurrent(P_HPlus, P_A, P_WMinus, P_Hh, 341)
      call createCurrent(P_HPlus, P_Hh, P_Hl, P_HMinus, 1967)
      call createCurrent(P_nu_mu, P_muPlus, P_HMinus, 1702)
      call createCurrent(P_GMinus, P_Z, P_Ha, P_WPlus, 2750)
      call createCurrent(P_Z, P_Ha, P_Ha, P_Z, 1719)
      call createCurrent(P_WMinus, P_WPlus, P_HMinus, P_HPlus, 1874)
      call createCurrent(P_b, P_bAnti, 3390)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, 259)
      call createCurrent(P_G0, P_Z, P_WPlus, P_HMinus, 2848)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_GPlus, 299)
      call createCurrent(P_HMinus, P_HMinus, P_HPlus, P_GPlus, 391)
      call createCurrent(P_Hh, P_A, P_GPlus, P_WMinus, 176)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, 1094)
      call createCurrent(P_HMinus, P_Hl, P_Hh, P_HPlus, 686)
      call createCurrent(P_Hh, P_GMinus, P_Hl, P_HPlus, 321)
      call createCurrent(P_A, P_A, P_g, P_g, 3843)
      call createCurrent(P_Z, P_HMinus, P_A, P_HPlus, 319)
      call createCurrent(P_Z, P_Hh, P_WPlus, P_HMinus, 1984)
      call createCurrent(P_s, P_Hl, P_sAnti, 763)
      call createCurrent(P_GMinus, P_GPlus, P_A, 177)
      call createCurrent(P_A, P_G0, P_G0, P_A, 3768)
      call createCurrent(P_Hl, P_HMinus, P_Ha, P_GPlus, 1437)
      call createCurrent(P_GPlus, P_G0, P_Ha, P_GMinus, 1418)
      call createCurrent(P_Hl, P_Hl, P_GMinus, P_HPlus, 2346)
      call createCurrent(P_Hh, P_HMinus, P_Z, P_WPlus, 1614)
      call createCurrent(P_Hl, P_tAnti, P_t, 1076)
      call createCurrent(P_HPlus, P_HMinus, P_WMinus, P_WPlus, 1547)
      call createCurrent(P_Z, P_G0, P_HPlus, P_WMinus, 2720)
      call createCurrent(P_Hl, P_Ha, P_Ha, P_Hh, 951)
      call createCurrent(P_Ha, P_G0, P_Hh, P_Hh, 2024)
      call createCurrent(P_WMinus, P_A, P_WPlus, 1395)
      call createCurrent(P_WPlus, P_A, P_Hh, P_HMinus, 189)
      call createCurrent(P_WMinus, P_WPlus, P_HPlus, P_HMinus, 1303)
      call createCurrent(P_Hl, P_G0, P_HPlus, P_GMinus, 2435)
      call createCurrent(P_ghA, P_ghWpAnti, P_HPlus, 2773)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_A, 2137)
      call createCurrent(P_Hl, P_WPlus, P_A, P_HMinus, 2524)
      call createCurrent(P_GPlus, P_HMinus, P_HMinus, P_GPlus, 43)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_Hl, 1652)
      call createCurrent(P_HMinus, P_HPlus, P_HPlus, P_GMinus, 1600)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, 1771)
      call createCurrent(P_G0, P_GPlus, P_HMinus, 478)
      call createCurrent(P_Hh, P_Z, P_WPlus, P_GMinus, 17)
      call createCurrent(P_GPlus, P_HMinus, P_Z, 3421)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, 1408)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, P_A, 1776)
      call createCurrent(P_GMinus, P_g, P_g, P_HPlus, 3608)
      call createCurrent(P_HPlus, P_WMinus, P_Ha, P_A, 2223)
      call createCurrent(P_Z, P_sAnti, P_s, 2222)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, 1371)
      call createCurrent(P_nu_tau, P_tauPlus, P_HMinus, 2457)
      call createCurrent(P_g, P_g, P_Hh, P_Hl, 3875)
      call createCurrent(P_G0, P_WMinus, P_A, P_GPlus, 97)
      call createCurrent(P_Hl, P_A, P_A, 3716)
      call createCurrent(P_GPlus, P_HMinus, P_GPlus, P_GMinus, 1773)
      call createCurrent(P_Hl, P_GMinus, P_Hh, P_GPlus, 654)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_Ha, 2800)
      call createCurrent(P_Ha, P_HMinus, P_Hl, P_GPlus, 1528)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, 2404)
      call createCurrent(P_Z, P_G0, P_G0, P_Z, 566)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_Z, 1147)
      call createCurrent(P_GMinus, P_Ha, P_G0, P_GPlus, 2548)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, 386)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, P_G0, 1439)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, P_Hh, 2288)
      call createCurrent(P_HPlus, P_tauMinus, P_nu_tauAnti, 1067)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, 2462)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_Ha, 3350)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, P_Hl, 3189)
      call createCurrent(P_HPlus, P_A, P_Ha, P_WMinus, 2272)
      call createCurrent(P_GMinus, P_Z, P_A, P_HPlus, 2799)
      call createCurrent(P_G0, P_HMinus, P_HPlus, P_Ha, 1164)
      call createCurrent(P_GMinus, P_Hh, P_Ha, P_HPlus, 475)
      call createCurrent(P_Z, P_WMinus, P_Ha, P_HPlus, 1850)
      call createCurrent(P_Hl, P_eMinus, P_ePlus, 633)
      call createCurrent(P_Hl, P_Hl, P_GPlus, P_HMinus, 2585)
      call createCurrent(P_G0, P_HPlus, P_G0, P_GMinus, 1000)
      call createCurrent(P_A, P_Ha, P_Z, P_Ha, 3309)
      call createCurrent(P_HPlus, P_tAnti, P_b, 648)
      call createCurrent(P_Z, P_Ha, P_Hl, 2380)
      call createCurrent(P_Z, P_GPlus, P_WMinus, 904)
      call createCurrent(P_WPlus, P_Hh, P_Z, P_HMinus, 2115)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_A, 2510)
      call createCurrent(P_WPlus, P_HMinus, P_A, P_Ha, 1381)
      call createCurrent(P_Z, P_Z, P_WPlus, P_WMinus, 350)
      call createCurrent(P_G0, P_G0, P_GMinus, P_GPlus, 2515)
      call createCurrent(P_g, P_g, P_HPlus, P_GMinus, 3671)
      call createCurrent(P_Hh, P_HMinus, P_G0, P_GPlus, 2001)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, P_Hh, 1361)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, P_G0, 2022)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_Hl, 1319)
      call createCurrent(P_WPlus, P_HMinus, P_Hh, 1839)
      call createCurrent(P_GPlus, P_nu_eAnti, P_eMinus, 379)
      call createCurrent(P_Hh, P_t, P_tAnti, 2688)
      call createCurrent(P_HMinus, P_G0, P_Z, P_WPlus, 3028)
      call createCurrent(P_Hl, P_G0, P_Ha, P_Hl, 1077)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, P_G0, 2099)
      call createCurrent(P_A, P_Hh, P_WPlus, P_GMinus, 1377)
      call createCurrent(P_GPlus, P_HMinus, P_G0, P_Hl, 2176)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_A, 2670)
      call createCurrent(P_HMinus, P_A, P_GPlus, P_Z, 3346)
      call createCurrent(P_A, P_Z, P_G0, P_G0, 2936)
      call createCurrent(P_HPlus, P_A, P_A, P_HMinus, 953)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, 2560)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_Z, 428)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, P_Hl, 1016)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, P_G0, 908)
      call createCurrent(P_Ha, P_Hl, P_Hl, P_G0, 954)
      call createCurrent(P_WMinus, P_Z, P_G0, P_GPlus, 1208)
      call createCurrent(P_cAnti, P_G0, P_c, 336)
      call createCurrent(P_HPlus, P_HMinus, P_Z, 1863)
      call createCurrent(P_Ha, P_Z, P_Hl, 1061)
      call createCurrent(P_G0, P_A, P_HPlus, P_WMinus, 2938)
      call createCurrent(P_HMinus, P_GPlus, P_g, P_g, 3820)
      call createCurrent(P_G0, P_g, P_Ha, P_g, 3731)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_HMinus, 3162)
      call createCurrent(P_A, P_HMinus, P_GPlus, P_Z, 3318)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, P_Hl, 1524)
      call createCurrent(P_sAnti, P_Hl, P_s, 2526)
      call createCurrent(P_Hh, P_WPlus, P_HMinus, P_A, 1414)
      call createCurrent(P_Hh, P_GPlus, P_Z, P_WMinus, 452)
      call createCurrent(P_Hh, P_Z, P_HMinus, P_WPlus, 996)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_Ha, 3433)
      call createCurrent(P_WPlus, P_s, P_cAnti, 568)
      call createCurrent(P_Hl, P_A, P_Hl, P_Z, 2745)
      call createCurrent(P_Ha, P_HPlus, P_Hl, P_HMinus, 3426)
      call createCurrent(P_HPlus, P_WMinus, P_GMinus, P_WPlus, 3261)
      call createCurrent(P_Z, P_Hh, P_HPlus, P_WMinus, 1227)
      call createCurrent(P_Ha, P_GMinus, P_WPlus, 2793)
      call createCurrent(P_HMinus, P_G0, P_WPlus, P_Z, 3259)
      call createCurrent(P_GMinus, P_G0, P_WPlus, 1890)
      call createCurrent(P_A, P_WMinus, P_Ha, P_HPlus, 2)
      call createCurrent(P_Hh, P_GMinus, P_G0, P_GPlus, 3159)
      call createCurrent(P_G0, P_Hl, P_Z, 457)
      call createCurrent(P_Z, P_HMinus, P_Z, P_HPlus, 482)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hl, 1045)
      call createCurrent(P_A, P_HPlus, P_WMinus, P_Hh, 830)
      call createCurrent(P_G0, P_GMinus, P_G0, P_GPlus, 1267)
      call createCurrent(P_HPlus, P_uAnti, P_d, 1733)
      call createCurrent(P_HMinus, P_WMinus, P_WPlus, P_GPlus, 3323)
      call createCurrent(P_WPlus, P_HPlus, P_GMinus, P_WMinus, 3192)
      call createCurrent(P_Ha, P_G0, P_GPlus, P_GMinus, 1751)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, P_Ha, 198)
      call createCurrent(P_Ha, P_A, P_Ha, P_A, 3855)
      call createCurrent(P_HPlus, P_HMinus, P_G0, P_Ha, 1994)
      call createCurrent(P_A, P_GPlus, P_HMinus, P_A, 3406)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, 2031)
      call createCurrent(P_d, P_dAnti, P_Hh, 273)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, P_A, 2278)
      call createCurrent(P_g, P_s, P_sAnti, 1078)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_G0, 2491)
      call createCurrent(P_HPlus, P_G0, P_WMinus, P_Z, 3562)
      call createCurrent(P_WMinus, P_A, P_HPlus, P_Hl, 1860)
      call createCurrent(P_Z, P_Z, P_Hh, P_Hh, 1647)
      call createCurrent(P_Ha, P_A, P_HPlus, P_WMinus, 1434)
      call createCurrent(P_eMinus, P_G0, P_ePlus, 527)
      call createCurrent(P_WPlus, P_HMinus, P_WMinus, P_HPlus, 520)
      call createCurrent(P_GPlus, P_WMinus, P_GMinus, P_WPlus, 1658)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_Ha, 3524)
      call createCurrent(P_HPlus, P_Z, P_WMinus, P_Hl, 151)
      call createCurrent(P_G0, P_WMinus, P_GPlus, 1549)
      call createCurrent(P_Z, P_Hh, P_Hl, P_Z, 3069)
      call createCurrent(P_c, P_A, P_cAnti, 2133)
      call createCurrent(P_Hl, P_Ha, P_Hl, P_Ha, 1631)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, 679)
      call createCurrent(P_GPlus, P_Z, P_G0, P_WMinus, 1069)
      call createCurrent(P_muPlus, P_Hh, P_muMinus, 2659)
      call createCurrent(P_G0, P_HPlus, P_GMinus, P_Hh, 1977)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_A, 1209)
      call createCurrent(P_G0, P_Z, 2931)
      call createCurrent(P_ghWpAnti, P_ghA, P_HPlus, 2999)
      call createCurrent(P_HPlus, P_GMinus, P_GMinus, P_GPlus, 1145)
      call createCurrent(P_WMinus, P_WMinus, P_WPlus, P_WPlus, 2650)
      call createCurrent(P_G0, P_WPlus, P_HMinus, P_A, 2759)
      call createCurrent(P_Ha, P_G0, P_Hl, 2056)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_G0, 589)
      call createCurrent(P_A, P_GMinus, P_Hl, P_WPlus, 671)
      call createCurrent(P_c, P_Hh, P_cAnti, 1895)
      call createCurrent(P_A, P_G0, P_GPlus, P_WMinus, 1602)
      call createCurrent(P_Z, P_WMinus, P_A, P_WPlus, 2221)
      call createCurrent(P_Hh, P_g, P_Hh, P_g, 3616)
      call createCurrent(P_A, P_GMinus, P_HPlus, P_A, 2883)
      call createCurrent(P_A, P_GPlus, P_A, P_GMinus, 1105)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, 905)
      call createCurrent(P_Ha, P_Hl, P_HPlus, P_GMinus, 2263)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, 197)
      call createCurrent(P_A, P_Z, P_GPlus, P_HMinus, 3117)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, P_Hl, 2394)
      call createCurrent(P_GMinus, P_g, P_g, P_GPlus, 3707)
      call createCurrent(P_Hl, P_G0, P_GMinus, P_GPlus, 3024)
      call createCurrent(P_A, P_WPlus, P_Ha, P_GMinus, 2804)
      call createCurrent(P_Hh, P_HMinus, P_WPlus, P_Z, 402)
      call createCurrent(P_Hl, P_WMinus, P_A, P_HPlus, 583)
      call createCurrent(P_HMinus, P_GPlus, P_G0, 659)
      call createCurrent(P_Hh, P_s, P_sAnti, 403)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, P_Hh, 3306)
      call createCurrent(P_G0, P_A, P_Z, P_G0, 3353)
      call createCurrent(P_A, P_G0, P_HMinus, P_WPlus, 3207)
      call createCurrent(P_t, P_tAnti, P_Z, 2681)
      call createCurrent(P_GPlus, P_uAnti, P_d, 2339)
      call createCurrent(P_nu_mu, P_A, P_nu_muAnti, 3080)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, 2643)
      call createCurrent(P_Ha, P_Z, P_G0, P_A, 3773)
      call createCurrent(P_g, P_g, P_G0, P_G0, 3686)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_Ha, 3391)
      call createCurrent(P_Ha, P_ghWp, P_ghWpAnti, 2831)
      call createCurrent(P_WPlus, P_HMinus, P_Ha, P_Z, 2473)
      call createCurrent(P_nu_tau, P_tauPlus, P_WMinus, 581)
      call createCurrent(P_Hl, P_Hl, P_HPlus, P_HMinus, 1200)
      call createCurrent(P_HMinus, P_Ha, P_Z, P_WPlus, 950)
      call createCurrent(P_Ha, P_G0, P_Z, P_A, 3648)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_G0, 1126)
      call createCurrent(P_Ha, P_WPlus, P_A, P_HMinus, 396)
      call createCurrent(P_Hl, P_G0, P_GMinus, P_HPlus, 2682)
      call createCurrent(P_HMinus, P_WPlus, P_Hl, P_Z, 2149)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_Z, 1112)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_HPlus, 2996)
      call createCurrent(P_HMinus, P_g, P_g, P_GPlus, 3854)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, P_A, 2350)
      call createCurrent(P_Z, P_nu_e, P_nu_eAnti, 2496)
      call createCurrent(P_b, P_bAnti, P_Z, 1513)
      call createCurrent(P_Hh, P_g, P_Hl, P_g, 3829)
      call createCurrent(P_WPlus, P_WMinus, P_A, 2314)
      call createCurrent(P_tAnti, P_Hh, P_t, 263)
      call createCurrent(P_GPlus, P_G0, P_HMinus, P_G0, 1280)
      call createCurrent(P_A, P_muMinus, P_muPlus, 1290)
      call createCurrent(P_g, P_Ha, P_g, P_G0, 3785)
      call createCurrent(P_WMinus, P_A, P_HPlus, P_G0, 3163)
      call createCurrent(P_Z, P_Hh, P_Hl, P_A, 3673)
      call createCurrent(P_GMinus, P_WMinus, P_GPlus, P_WPlus, 2460)
      call createCurrent(P_GMinus, P_GPlus, P_g, P_g, 3720)
      call createCurrent(P_WMinus, P_Z, P_WPlus, 1865)
      call createCurrent(P_A, P_Ha, P_A, P_G0, 3614)
      call createCurrent(P_Ha, P_Ha, P_G0, P_G0, 1599)
      call createCurrent(P_G0, P_Hh, P_HMinus, P_HPlus, 3267)
      call createCurrent(P_Hh, P_A, P_A, P_Hl, 3794)
      call createCurrent(P_G0, P_WMinus, P_HPlus, P_A, 3253)
      call createCurrent(P_Hh, P_Hh, P_Hh, 1601)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, 3366)
      call createCurrent(P_GMinus, P_Hh, P_Ha, P_GPlus, 2726)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, 2084)
      call createCurrent(P_HMinus, P_Ha, P_G0, P_HPlus, 618)
      call createCurrent(P_ePlus, P_Z, P_eMinus, 539)
      call createCurrent(P_Ha, P_GMinus, P_Hl, P_HPlus, 1957)
      call createCurrent(P_HMinus, P_HPlus, P_GPlus, P_HMinus, 642)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, 2411)
      call createCurrent(P_Hl, P_WPlus, P_Z, P_HMinus, 649)
      call createCurrent(P_G0, P_GPlus, P_HMinus, P_Hl, 1976)
      call createCurrent(P_GPlus, P_WMinus, P_Ha, 3181)
      call createCurrent(P_Ha, P_GPlus, P_G0, P_HMinus, 2167)
      call createCurrent(P_GMinus, P_WPlus, 3120)
      call createCurrent(P_A, P_Z, P_GMinus, P_GPlus, 358)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_Ha, 3422)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, 1462)
      call createCurrent(P_HMinus, P_GMinus, P_GPlus, P_GPlus, 1744)
      call createCurrent(P_A, P_Z, P_WPlus, P_WMinus, 2549)
      call createCurrent(P_nu_e, P_Z, P_nu_eAnti, 1826)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, P_G0, 2331)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_Hl, 852)
      call createCurrent(P_ghZ, P_ghWmAnti, P_HMinus, 2855)
      call createCurrent(P_dAnti, P_u, P_WMinus, 1812)
      call createCurrent(P_A, P_G0, P_Hl, 3510)
      call createCurrent(P_uAnti, P_d, P_GPlus, 948)
      call createCurrent(P_s, P_sAnti, P_G0, 1087)
      call createCurrent(P_Hl, P_Z, P_GPlus, P_WMinus, 421)
      call createCurrent(P_g, P_g, P_GPlus, P_GMinus, 3790)
      call createCurrent(P_u, P_uAnti, P_Hl, 21)
      call createCurrent(P_Ha, P_HMinus, P_Z, P_WPlus, 793)
      call createCurrent(P_HPlus, P_WMinus, P_HMinus, P_WPlus, 1587)
      call createCurrent(P_A, P_A, P_G0, P_G0, 3873)
      call createCurrent(P_HMinus, P_Hl, P_Hh, P_GPlus, 725)
      call createCurrent(P_G0, P_Hh, P_Ha, 990)
      call createCurrent(P_Hl, P_HMinus, P_Hl, P_GPlus, 1659)
      call createCurrent(P_G0, P_GPlus, P_Ha, P_GMinus, 2267)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GPlus, 1327)
      call createCurrent(P_Ha, P_WPlus, P_WMinus, P_G0, 3545)
      call createCurrent(P_Hh, P_A, P_Ha, 3577)
      call createCurrent(P_nu_muAnti, P_WPlus, P_muMinus, 2697)
      call createCurrent(P_Ha, P_Hh, P_GPlus, P_GMinus, 3419)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_Z, 2041)
      call createCurrent(P_Z, P_g, P_g, P_Z, 3783)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, P_Hh, 2174)
      call createCurrent(P_HMinus, P_Hh, P_G0, P_GPlus, 1216)
      call createCurrent(P_HMinus, P_WMinus, P_WPlus, P_HPlus, 1618)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, P_Ha, 2816)
      call createCurrent(P_Z, P_t, P_tAnti, 755)
      call createCurrent(P_nu_e, P_ePlus, P_GMinus, 629)
      call createCurrent(P_d, P_G0, P_dAnti, 1810)
      call createCurrent(P_HMinus, P_GPlus, P_Z, P_A, 3450)
      call createCurrent(P_A, P_GMinus, P_Ha, P_WPlus, 3220)
      call createCurrent(P_Z, P_GPlus, P_Hh, P_WMinus, 2527)
      call createCurrent(P_sAnti, P_Ha, P_s, 1255)
      call createCurrent(P_Hl, P_HMinus, P_WPlus, 298)
      call createCurrent(P_Hl, P_Hh, 2818)
      call createCurrent(P_Hh, P_Hl, P_WMinus, P_WPlus, 3280)
      call createCurrent(P_GMinus, P_Ha, P_Ha, P_GPlus, 1356)
      call createCurrent(P_cAnti, P_c, P_Ha, 278)
      call createCurrent(P_tAnti, P_b, P_GPlus, 492)
      call createCurrent(P_A, P_HMinus, P_Hh, P_WPlus, 620)
      call createCurrent(P_muPlus, P_Hl, P_muMinus, 1908)
      call createCurrent(P_Hh, P_g, P_g, P_Hl, 3756)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, P_G0, 3)
      call createCurrent(P_GMinus, P_Hh, P_G0, P_GPlus, 3035)
      call createCurrent(P_HPlus, P_GMinus, P_HMinus, P_GPlus, 598)
      call createCurrent(P_Ha, P_HMinus, P_G0, P_GPlus, 2533)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_G0, 1187)
      call createCurrent(P_HPlus, P_Hl, P_WMinus, 1179)
      call createCurrent(P_d, P_dAnti, P_Ha, 2636)
      call createCurrent(P_Ha, P_GPlus, P_Ha, P_GMinus, 57)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, 2419)
      call createCurrent(P_G0, P_Ha, P_HPlus, P_GMinus, 24)
      call createCurrent(P_tauPlus, P_nu_tau, P_GMinus, 1334)
      call createCurrent(P_b, P_g, P_bAnti, 1196)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_G0, 3164)
      call createCurrent(P_HPlus, P_Hl, P_Hh, P_GMinus, 227)
      call createCurrent(P_Ha, P_HMinus, P_Hh, P_GPlus, 536)
      call createCurrent(P_WPlus, P_HMinus, P_Ha, 1478)
      call createCurrent(P_A, P_HPlus, P_WMinus, P_Ha, 2148)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, 345)
      call createCurrent(P_HPlus, P_b, P_tAnti, 689)
      call createCurrent(P_ePlus, P_G0, P_eMinus, 1837)
      call createCurrent(P_HMinus, P_GPlus, P_HPlus, P_GMinus, 2006)
      call createCurrent(P_GPlus, P_HMinus, P_Z, P_Z, 2874)
      call createCurrent(P_GMinus, P_G0, P_HPlus, P_Hh, 1517)
      call createCurrent(P_WPlus, P_A, P_HMinus, P_Hl, 284)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, 723)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_Ha, 3209)
      call createCurrent(P_Hh, P_WMinus, P_HPlus, 975)
      call createCurrent(P_Ha, P_WMinus, P_A, P_GPlus, 3241)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, 842)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, P_Ha, 3113)
      call createCurrent(P_g, P_Hh, P_Hl, P_g, 3670)
      call createCurrent(P_WPlus, P_Ha, P_HMinus, P_Z, 866)
      call createCurrent(P_HMinus, P_HPlus, P_WMinus, P_WPlus, 1753)
      call createCurrent(P_WMinus, P_tauPlus, P_nu_tau, 2620)
      call createCurrent(P_GPlus, P_HPlus, P_HMinus, P_HMinus, 2309)
      call createCurrent(P_WPlus, P_nu_tauAnti, P_tauMinus, 2700)
      call createCurrent(P_Hl, P_WPlus, P_HMinus, 1294)
      call createCurrent(P_G0, P_GMinus, P_HPlus, 255)
      call createCurrent(P_WMinus, P_G0, P_HPlus, 3083)
      call createCurrent(P_ePlus, P_GMinus, P_nu_e, 2088)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, P_Hl, 2294)
      call createCurrent(P_Hl, P_Hl, P_WPlus, P_WMinus, 1345)
      call createCurrent(P_HMinus, P_G0, P_GPlus, P_Hl, 167)
      call createCurrent(P_t, P_HMinus, P_bAnti, 754)
      call createCurrent(P_GMinus, P_A, P_Z, P_GPlus, 1991)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, 1191)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, P_Hh, 1633)
      call createCurrent(P_HPlus, P_WMinus, P_WPlus, P_GMinus, 2986)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_G0, 1914)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_Hl, 1467)
      call createCurrent(P_Hh, P_Ha, P_Ha, 1896)
      call createCurrent(P_Ha, P_Hl, P_Hh, P_Ha, 2581)
      call createCurrent(P_HMinus, P_WPlus, P_Z, P_Ha, 2259)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghA, 2845)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, P_Z, 193)
      call createCurrent(P_WPlus, P_WMinus, P_HMinus, P_HPlus, 1626)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, P_Hl, 1535)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, P_Ha, 2621)
      call createCurrent(P_HMinus, P_g, P_g, P_HPlus, 3852)
      call createCurrent(P_GPlus, P_G0, P_Hh, P_GMinus, 2956)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_A, 2010)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_Z, 401)
      call createCurrent(P_Z, P_Hl, P_Z, P_Hl, 494)
      call createCurrent(P_GPlus, P_GMinus, P_G0, 3548)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_Ha, 3146)
      call createCurrent(P_Z, P_G0, P_WPlus, P_HMinus, 3221)
      call createCurrent(P_Ha, P_Ha, P_A, P_A, 3631)
      call createCurrent(P_Ha, P_A, P_A, P_G0, 3865)
      call createCurrent(P_G0, P_Hl, P_HMinus, P_GPlus, 215)
      call createCurrent(P_HPlus, P_Ha, P_Z, P_WMinus, 1788)
      call createCurrent(P_Hl, P_GPlus, P_Z, P_WMinus, 1889)
      call createCurrent(P_A, P_WMinus, P_HPlus, 892)
      call createCurrent(P_HPlus, P_WMinus, P_A, P_Ha, 1161)
      call createCurrent(P_A, P_WPlus, P_Hl, P_HMinus, 563)
      call createCurrent(P_Ha, P_HMinus, P_G0, P_HPlus, 2264)
      call createCurrent(P_HMinus, P_WPlus, P_WMinus, P_GPlus, 3051)
      call createCurrent(P_tauPlus, P_Ha, P_tauMinus, 605)
      call createCurrent(P_cAnti, P_GPlus, P_s, 348)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_Hl, 1616)
      call createCurrent(P_muPlus, P_muMinus, P_Z, 233)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, 1671)
      call createCurrent(P_Z, P_Ha, P_WPlus, P_HMinus, 448)
      call createCurrent(P_Z, P_WMinus, P_HPlus, P_G0, 3482)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, 2214)
      call createCurrent(P_Hl, P_Z, P_A, 3330)
      call createCurrent(P_WPlus, P_G0, P_HMinus, P_A, 3567)
      call createCurrent(P_g, P_dAnti, P_d, 1488)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, P_Hl, 1454)
      call createCurrent(P_GMinus, P_t, P_bAnti, 1694)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, P_G0, 1331)
      call createCurrent(P_G0, P_Ha, P_Ha, P_G0, 1299)
      call createCurrent(P_A, P_GPlus, P_HMinus, 3240)
      call createCurrent(P_d, P_Z, P_dAnti, 342)
      call createCurrent(P_Ha, P_HPlus, P_Hh, P_GMinus, 1973)
      call createCurrent(P_bAnti, P_GMinus, P_t, 724)
      call createCurrent(P_WMinus, P_HPlus, P_A, P_Hl, 2438)
      call createCurrent(P_Z, P_Z, P_WMinus, P_WPlus, 174)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, 2224)
      call createCurrent(P_t, P_A, P_tAnti, 632)
      call createCurrent(P_WMinus, P_Ha, P_HPlus, 772)
      call createCurrent(P_HPlus, P_A, P_Z, P_GMinus, 3074)
      call createCurrent(P_HPlus, P_A, P_Hh, P_WMinus, 257)
      call createCurrent(P_G0, P_Z, P_G0, P_A, 2766)
      call createCurrent(P_HMinus, P_Z, P_WPlus, P_Hl, 2019)
      call createCurrent(P_A, P_Hl, P_G0, 2995)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, 784)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_HMinus, 3127)
      call createCurrent(P_Ha, P_Ha, 2860)
      call createCurrent(P_GMinus, P_Hl, P_G0, P_HPlus, 1770)
      call createCurrent(P_GMinus, P_sAnti, P_c, 2071)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_Hl, 1004)
      call createCurrent(P_Hl, P_Hh, P_Hh, P_Hl, 2655)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, P_Hh, 127)
      call createCurrent(P_Hl, P_ePlus, P_eMinus, 509)
      call createCurrent(P_HMinus, P_GPlus, P_G0, P_Hl, 52)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_Ha, 2876)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, P_Hl, 1127)
      call createCurrent(P_WPlus, P_HMinus, P_Z, P_Hh, 2699)
      call createCurrent(P_GPlus, P_A, P_HMinus, P_A, 3151)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, P_Ha, 989)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, P_Hh, 3368)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_Hh, 855)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_G0, 1591)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, P_Hl, 2451)
      call createCurrent(P_G0, P_Ha, P_g, P_g, 3870)
      call createCurrent(P_WMinus, P_GPlus, P_G0, 235)
      call createCurrent(P_A, P_G0, P_GMinus, P_WPlus, 2140)
      call createCurrent(P_A, P_HMinus, P_G0, P_WPlus, 3312)
      call createCurrent(P_d, P_dAnti, P_g, 2608)
      call createCurrent(P_WMinus, P_Hl, P_Z, P_HPlus, 2344)
      call createCurrent(P_Ha, P_ghWpAnti, P_ghWp, 2869)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, P_Hl, 1455)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, P_Hh, 1211)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_HMinus, 3227)
      call createCurrent(P_HPlus, P_HMinus, P_A, P_A, 1704)
      call createCurrent(P_HMinus, P_Hl, P_A, P_WPlus, 2086)
      call createCurrent(P_Z, P_Hl, P_A, P_Hh, 3656)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, 1450)
      call createCurrent(P_Hl, P_Hh, P_GMinus, P_GPlus, 2607)
      call createCurrent(P_Ha, P_WMinus, P_HPlus, 1520)
      call createCurrent(P_G0, P_WPlus, P_GMinus, 573)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_Z, 1309)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, P_G0, 658)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, 1475)
      call createCurrent(P_Ha, P_GMinus, P_Hh, P_HPlus, 1921)
      call createCurrent(P_g, P_WPlus, P_g, P_WMinus, 3599)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, P_G0, 2718)
      call createCurrent(P_GMinus, P_Hh, P_A, P_WPlus, 2192)
      call createCurrent(P_A, P_HMinus, P_HPlus, P_A, 2447)
      call createCurrent(P_GPlus, P_HMinus, P_A, 2739)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_Ha, 2877)
      call createCurrent(P_Hl, P_Hl, P_HMinus, P_HPlus, 28)
      call createCurrent(P_dAnti, P_G0, P_d, 2305)
      call createCurrent(P_HMinus, P_G0, P_HPlus, P_G0, 2157)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, P_Hl, 641)
      call createCurrent(P_Z, P_WPlus, P_Ha, P_HMinus, 1603)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, 185)
      call createCurrent(P_A, P_Ha, P_G0, P_Z, 3839)
      call createCurrent(P_g, P_ghGAnti, P_ghG, 706)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, 1337)
      call createCurrent(P_muMinus, P_muPlus, P_Z, 178)
      call createCurrent(P_eMinus, P_Z, P_ePlus, 1592)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, 2642)
      call createCurrent(P_G0, P_G0, P_HMinus, P_HPlus, 1352)
      call createCurrent(P_HPlus, P_Z, P_Ha, P_WMinus, 2273)
      call createCurrent(P_G0, P_Ha, P_Hh, P_Hl, 760)
      call createCurrent(P_WPlus, P_cAnti, P_s, 932)
      call createCurrent(P_G0, P_Hl, P_Ha, 1779)
      call createCurrent(P_Z, P_HMinus, P_WPlus, P_G0, 3140)
      call createCurrent(P_Hh, P_WMinus, P_A, P_HPlus, 1340)
      call createCurrent(P_WPlus, P_Z, P_A, P_WMinus, 2673)
      call createCurrent(P_GPlus, P_Z, P_HMinus, P_A, 3091)
      call createCurrent(P_Hh, P_G0, P_HPlus, P_HMinus, 2772)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, 2542)
      call createCurrent(P_Hh, P_Hh, P_A, P_Z, 3012)
      call createCurrent(P_tAnti, P_g, P_t, 1572)
      call createCurrent(P_GMinus, P_Z, P_G0, P_WPlus, 1205)
      call createCurrent(P_GMinus, P_A, P_HPlus, 3141)
      call createCurrent(P_Z, P_GPlus, P_HMinus, P_Z, 2989)
      call createCurrent(P_HPlus, P_A, P_GMinus, P_A, 3447)
      call createCurrent(P_g, P_g, P_Hl, 3799)
      call createCurrent(P_GMinus, P_HPlus, P_HMinus, P_GPlus, 2326)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, 1650)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_A, 1959)
      call createCurrent(P_muPlus, P_muMinus, P_Ha, 395)
      call createCurrent(P_G0, P_HPlus, P_Hh, P_HMinus, 3262)
      call createCurrent(P_G0, P_WMinus, P_Ha, P_WPlus, 3296)
      call createCurrent(P_tAnti, P_t, P_Hh, 1382)
      call createCurrent(P_cAnti, P_s, P_HPlus, 893)
      call createCurrent(P_Z, P_Ha, P_A, P_G0, 3628)
      call createCurrent(P_WPlus, P_G0, P_Ha, P_WMinus, 3283)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, P_G0, 2763)
      call createCurrent(P_G0, P_HMinus, P_Hh, P_HPlus, 2934)
      call createCurrent(P_GPlus, P_Z, P_Hl, P_WMinus, 1231)
      call createCurrent(P_Z, P_WMinus, P_G0, P_GPlus, 2415)
      call createCurrent(P_A, P_Z, P_Ha, P_Ha, 2779)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_Hh, 1570)
      call createCurrent(P_Ha, P_GMinus, P_Ha, P_HPlus, 737)
      call createCurrent(P_tAnti, P_HPlus, P_b, 1822)
      call createCurrent(P_Hl, P_s, P_sAnti, 1135)
      call createCurrent(P_Ha, P_GPlus, P_WMinus, P_Z, 3572)
      call createCurrent(P_Ha, P_Ha, P_A, P_Z, 3108)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, P_Ha, 791)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_Z, 1893)
      call createCurrent(P_Hh, P_Hl, P_G0, P_G0, 2072)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_Hh, 2227)
      call createCurrent(P_Ha, P_HPlus, P_G0, P_HMinus, 503)
      call createCurrent(P_A, P_WPlus, P_A, P_WMinus, 1315)
      call createCurrent(P_G0, P_Hl, P_GPlus, P_HMinus, 2586)
      call createCurrent(P_WPlus, P_Hh, P_A, P_HMinus, 415)
      call createCurrent(P_Z, P_GPlus, P_A, P_HMinus, 2756)
      call createCurrent(P_nu_eAnti, P_eMinus, P_HPlus, 254)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, 2337)
      call createCurrent(P_GMinus, P_GPlus, P_WMinus, P_WPlus, 1506)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, P_Ha, 1146)
      call createCurrent(P_GMinus, P_Hl, P_Hl, P_HPlus, 1167)
      call createCurrent(P_g, P_Hh, P_Hh, P_g, 3721)
      call createCurrent(P_nu_eAnti, P_WPlus, P_eMinus, 2666)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, P_Z, 1738)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, 1867)
      call createCurrent(P_g, P_HMinus, P_GPlus, P_g, 3684)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, P_Hh, 356)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_Hl, 1606)
      call createCurrent(P_G0, P_ePlus, P_eMinus, 2049)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, P_Hl, 2597)
      call createCurrent(P_WMinus, P_Ha, P_G0, P_WPlus, 2791)
      call createCurrent(P_WPlus, P_A, P_Hl, P_HMinus, 2136)
      call createCurrent(P_G0, P_G0, P_g, P_g, 3700)
      call createCurrent(P_WMinus, P_G0, P_HPlus, P_A, 2847)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, P_Hl, 2838)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, P_G0, 715)
      call createCurrent(P_GPlus, P_Z, P_HMinus, P_Z, 3432)
      call createCurrent(P_GMinus, P_HPlus, P_G0, P_Hh, 1556)
      call createCurrent(P_HMinus, P_G0, P_HPlus, P_Ha, 1710)
      call createCurrent(P_WMinus, P_HPlus, P_Hh, P_A, 1182)
      call createCurrent(P_Hl, P_muPlus, P_muMinus, 1612)
      call createCurrent(P_Hh, P_Z, P_A, P_Hl, 3627)
      call createCurrent(P_Hh, P_Hh, P_WMinus, P_WPlus, 2497)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, P_Z, 810)
      call createCurrent(P_g, P_g, P_A, P_A, 3828)
      call createCurrent(P_WPlus, P_HPlus, P_WMinus, P_HMinus, 1938)
      call createCurrent(P_GMinus, P_WPlus, P_GPlus, P_WMinus, 1360)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_GPlus, 1116)
    end subroutine init_vertices_mdl

    subroutine check_vertices_mdl()
      integer(kind=8) :: config
      integer :: res, address
      logical :: found
      call createParticleConfig(P_Hh, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",646
      if ( res /= 646) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WPlus, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",418
      if ( res /= 418) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",458
      if ( res /= 458) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GPlus, P_GMinus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",987
      if ( res /= 987) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_b, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",714
      if ( res /= 714) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2949
      if ( res /= 2949) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2955
      if ( res /= 2955) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",216
      if ( res /= 216) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",704
      if ( res /= 704) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1567
      if ( res /= 1567) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1038
      if ( res /= 1038) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3403
      if ( res /= 3403) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3015
      if ( res /= 3015) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1042
      if ( res /= 1042) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1480
      if ( res /= 1480) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1089
      if ( res /= 1089) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2559
      if ( res /= 2559) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1886
      if ( res /= 1886) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2505
      if ( res /= 2505) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",739
      if ( res /= 739) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",252
      if ( res /= 252) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3683
      if ( res /= 3683) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2823
      if ( res /= 2823) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3333
      if ( res /= 3333) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1730
      if ( res /= 1730) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1532
      if ( res /= 1532) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2605
      if ( res /= 2605) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1177
      if ( res /= 1177) then
        stop
      end if
      call createParticleConfig(P_b, P_bAnti, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1548
      if ( res /= 1548) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",572
      if ( res /= 572) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",757
      if ( res /= 757) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1214
      if ( res /= 1214) then
        stop
      end if
      call createParticleConfig(P_G0, P_uAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",851
      if ( res /= 851) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1080
      if ( res /= 1080) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1023
      if ( res /= 1023) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",571
      if ( res /= 571) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GMinus, P_HPlus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3358
      if ( res /= 3358) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",698
      if ( res /= 698) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",518
      if ( res /= 518) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2196
      if ( res /= 2196) then
        stop
      end if
      call createParticleConfig(P_g, P_cAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1654
      if ( res /= 1654) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_g, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3661
      if ( res /= 3661) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1033
      if ( res /= 1033) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",849
      if ( res /= 849) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1476
      if ( res /= 1476) then
        stop
      end if
      call createParticleConfig(P_Hh, P_ghWm, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1937
      if ( res /= 1937) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2242
      if ( res /= 2242) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3106
      if ( res /= 3106) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1484
      if ( res /= 1484) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HPlus, P_HMinus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2701
      if ( res /= 2701) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1380
      if ( res /= 1380) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2569
      if ( res /= 2569) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1441
      if ( res /= 1441) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_Hh, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",584
      if ( res /= 584) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3011
      if ( res /= 3011) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1153
      if ( res /= 1153) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3708
      if ( res /= 3708) then
        stop
      end if
      call createParticleConfig(P_A, P_ePlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1425
      if ( res /= 1425) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2348
      if ( res /= 2348) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",417
      if ( res /= 417) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3073
      if ( res /= 3073) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Ha, P_WPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2113
      if ( res /= 2113) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2168
      if ( res /= 2168) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2232
      if ( res /= 2232) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3375
      if ( res /= 3375) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1950
      if ( res /= 1950) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2640
      if ( res /= 2640) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1981
      if ( res /= 1981) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3081
      if ( res /= 3081) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GMinus, P_HPlus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",782
      if ( res /= 782) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3126
      if ( res /= 3126) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3751
      if ( res /= 3751) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3534
      if ( res /= 3534) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2917
      if ( res /= 2917) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2371
      if ( res /= 2371) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",918
      if ( res /= 918) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2744
      if ( res /= 2744) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",327
      if ( res /= 327) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_eMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1277
      if ( res /= 1277) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",820
      if ( res /= 820) then
        stop
      end if
      call createParticleConfig(P_Z, P_tauPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",131
      if ( res /= 131) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2423
      if ( res /= 2423) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3114
      if ( res /= 3114) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_dAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1900
      if ( res /= 1900) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_Ha, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3345
      if ( res /= 3345) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2752
      if ( res /= 2752) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_muMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2021
      if ( res /= 2021) then
        stop
      end if
      call createParticleConfig(P_G0, P_g, P_G0, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3850
      if ( res /= 3850) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2704
      if ( res /= 2704) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghWmAnti, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1336
      if ( res /= 1336) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2461
      if ( res /= 2461) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",693
      if ( res /= 693) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3101
      if ( res /= 3101) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3449
      if ( res /= 3449) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2479
      if ( res /= 2479) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3236
      if ( res /= 3236) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",121
      if ( res /= 121) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3550
      if ( res /= 3550) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",676
      if ( res /= 676) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_nu_tauAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2026
      if ( res /= 2026) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",461
      if ( res /= 461) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3218
      if ( res /= 3218) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3059
      if ( res /= 3059) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",200
      if ( res /= 200) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2258
      if ( res /= 2258) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",630
      if ( res /= 630) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1059
      if ( res /= 1059) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1141
      if ( res /= 1141) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2591
      if ( res /= 2591) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3231
      if ( res /= 3231) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",90
      if ( res /= 90) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_Hl, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1140
      if ( res /= 1140) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3719
      if ( res /= 3719) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2108
      if ( res /= 2108) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",62
      if ( res /= 62) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_muPlus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",941
      if ( res /= 941) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1168
      if ( res /= 1168) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3617
      if ( res /= 3617) then
        stop
      end if
      call createParticleConfig(P_s, P_cAnti, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1761
      if ( res /= 1761) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",803
      if ( res /= 803) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2807
      if ( res /= 2807) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2924
      if ( res /= 2924) then
        stop
      end if
      call createParticleConfig(P_A, P_ghWm, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1609
      if ( res /= 1609) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_d, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1222
      if ( res /= 1222) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",372
      if ( res /= 372) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1892
      if ( res /= 1892) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",650
      if ( res /= 650) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2009
      if ( res /= 2009) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2181
      if ( res /= 2181) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1873
      if ( res /= 1873) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_b, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2582
      if ( res /= 2582) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_Z, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2199
      if ( res /= 2199) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3030
      if ( res /= 3030) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",780
      if ( res /= 780) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_WPlus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",835
      if ( res /= 835) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2736
      if ( res /= 2736) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1717
      if ( res /= 1717) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2534
      if ( res /= 2534) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1596
      if ( res /= 1596) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_u, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1645
      if ( res /= 1645) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2065
      if ( res /= 2065) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",828
      if ( res /= 828) then
        stop
      end if
      call createParticleConfig(P_Z, P_ePlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1746
      if ( res /= 1746) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_HPlus, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3367
      if ( res /= 3367) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1760
      if ( res /= 1760) then
        stop
      end if
      call createParticleConfig(P_A, P_tauPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",925
      if ( res /= 925) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1676
      if ( res /= 1676) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2981
      if ( res /= 2981) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3787
      if ( res /= 3787) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",993
      if ( res /= 993) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3104
      if ( res /= 3104) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2725
      if ( res /= 2725) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_Ha, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",311
      if ( res /= 311) then
        stop
      end if
      call createParticleConfig(P_t, P_Z, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1295
      if ( res /= 1295) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_HPlus, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3282
      if ( res /= 3282) then
        stop
      end if
      call createParticleConfig(P_G0, P_dAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",496
      if ( res /= 496) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_GMinus, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1451
      if ( res /= 1451) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1396
      if ( res /= 1396) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2769
      if ( res /= 2769) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1398
      if ( res /= 1398) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2921
      if ( res /= 2921) then
        stop
      end if
      call createParticleConfig(P_s, P_Z, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",575
      if ( res /= 575) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",214
      if ( res /= 214) then
        stop
      end if
      call createParticleConfig(P_Hl, P_muMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1155
      if ( res /= 1155) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1275
      if ( res /= 1275) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_WMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1289
      if ( res /= 1289) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3618
      if ( res /= 3618) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",971
      if ( res /= 971) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_Hh, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1065
      if ( res /= 1065) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2678
      if ( res /= 2678) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1124
      if ( res /= 1124) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HPlus, P_GMinus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",766
      if ( res /= 766) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3522
      if ( res /= 3522) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",846
      if ( res /= 846) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",325
      if ( res /= 325) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2310
      if ( res /= 2310) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",114
      if ( res /= 114) then
        stop
      end if
      call createParticleConfig(P_t, P_Hl, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",701
      if ( res /= 701) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3841
      if ( res /= 3841) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3811
      if ( res /= 3811) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1107
      if ( res /= 1107) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2961
      if ( res /= 2961) then
        stop
      end if
      call createParticleConfig(P_A, P_muPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",720
      if ( res /= 720) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GMinus, P_GPlus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1531
      if ( res /= 1531) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghWmAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2631
      if ( res /= 2631) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",409
      if ( res /= 409) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",39
      if ( res /= 39) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1093
      if ( res /= 1093) then
        stop
      end if
      call createParticleConfig(P_G0, P_c, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",211
      if ( res /= 211) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2966
      if ( res /= 2966) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",636
      if ( res /= 636) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1306
      if ( res /= 1306) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2749
      if ( res /= 2749) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",874
      if ( res /= 874) then
        stop
      end if
      call createParticleConfig(P_A, P_g, P_g, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3752
      if ( res /= 3752) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2164
      if ( res /= 2164) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_nu_muAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",187
      if ( res /= 187) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3216
      if ( res /= 3216) then
        stop
      end if
      call createParticleConfig(P_Ha, P_b, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1318
      if ( res /= 1318) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1348
      if ( res /= 1348) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",590
      if ( res /= 590) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",970
      if ( res /= 970) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1714
      if ( res /= 1714) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_nu_tauAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3087
      if ( res /= 3087) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",591
      if ( res /= 591) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_GPlus, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2111
      if ( res /= 2111) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1486
      if ( res /= 1486) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",205
      if ( res /= 205) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3797
      if ( res /= 3797) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2482
      if ( res /= 2482) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1043
      if ( res /= 1043) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_g, P_WPlus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3653
      if ( res /= 3653) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2517
      if ( res /= 2517) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1561
      if ( res /= 1561) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2566
      if ( res /= 2566) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2747
      if ( res /= 2747) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_nu_muAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2686
      if ( res /= 2686) then
        stop
      end if
      call createParticleConfig(P_g, P_A, P_g, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3778
      if ( res /= 3778) then
        stop
      end if
      call createParticleConfig(P_u, P_uAnti, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2349
      if ( res /= 2349) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1257
      if ( res /= 1257) then
        stop
      end if
      call createParticleConfig(P_Hh, P_ghWp, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1706
      if ( res /= 1706) then
        stop
      end if
      call createParticleConfig(P_Hh, P_cAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2039
      if ( res /= 2039) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_nu_muAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2825
      if ( res /= 2825) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2486
      if ( res /= 2486) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2755
      if ( res /= 2755) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_tauMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1220
      if ( res /= 1220) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2147
      if ( res /= 2147) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_d, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1270
      if ( res /= 1270) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2867
      if ( res /= 2867) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1130
      if ( res /= 1130) then
        stop
      end if
      call createParticleConfig(P_d, P_A, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1463
      if ( res /= 1463) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2183
      if ( res /= 2183) then
        stop
      end if
      call createParticleConfig(P_Z, P_uAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2579
      if ( res /= 2579) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",73
      if ( res /= 73) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_tauPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1849
      if ( res /= 1849) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1013
      if ( res /= 1013) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_nu_muAnti, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",136
      if ( res /= 136) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3793
      if ( res /= 3793) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1574
      if ( res /= 1574) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2829
      if ( res /= 2829) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",12
      if ( res /= 12) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3017
      if ( res /= 3017) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3532
      if ( res /= 3532) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",132
      if ( res /= 132) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",267
      if ( res /= 267) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_g, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",343
      if ( res /= 343) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2775
      if ( res /= 2775) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1017
      if ( res /= 1017) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",485
      if ( res /= 485) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1500
      if ( res /= 1500) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_nu_tauAnti, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2568
      if ( res /= 2568) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_A, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3319
      if ( res /= 3319) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",423
      if ( res /= 423) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1780
      if ( res /= 1780) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1817
      if ( res /= 1817) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",873
      if ( res /= 873) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2625
      if ( res /= 2625) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3343
      if ( res /= 3343) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",250
      if ( res /= 250) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3089
      if ( res /= 3089) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2037
      if ( res /= 2037) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",779
      if ( res /= 779) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_HMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1947
      if ( res /= 1947) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1525
      if ( res /= 1525) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HMinus, P_GPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2687
      if ( res /= 2687) then
        stop
      end if
      call createParticleConfig(P_Ha, P_sAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",651
      if ( res /= 651) then
        stop
      end if
      call createParticleConfig(P_A, P_eMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1790
      if ( res /= 1790) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_HMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",549
      if ( res /= 549) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_Ha, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1472
      if ( res /= 1472) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2753
      if ( res /= 2753) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3662
      if ( res /= 3662) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_t, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",778
      if ( res /= 778) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2988
      if ( res /= 2988) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1053
      if ( res /= 1053) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",142
      if ( res /= 142) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_A, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2803
      if ( res /= 2803) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_ghWm, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2153
      if ( res /= 2153) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",334
      if ( res /= 334) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2412
      if ( res /= 2412) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3186
      if ( res /= 3186) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_dAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",229
      if ( res /= 229) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",266
      if ( res /= 266) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2005
      if ( res /= 2005) then
        stop
      end if
      call createParticleConfig(P_c, P_sAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1667
      if ( res /= 1667) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",609
      if ( res /= 609) then
        stop
      end if
      call createParticleConfig(P_A, P_d, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",601
      if ( res /= 601) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WMinus, P_Ha, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",837
      if ( res /= 837) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",729
      if ( res /= 729) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_tauMinus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2103
      if ( res /= 2103) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_ghWpAnti, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3580
      if ( res /= 3580) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_Hh, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2492
      if ( res /= 2492) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1922
      if ( res /= 1922) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2095
      if ( res /= 2095) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghZ, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1285
      if ( res /= 1285) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3476
      if ( res /= 3476) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_nu_mu, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1409
      if ( res /= 1409) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3413
      if ( res /= 3413) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2141
      if ( res /= 2141) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",592
      if ( res /= 592) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WMinus, P_GPlus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3495
      if ( res /= 3495) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3749
      if ( res /= 3749) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2481
      if ( res /= 2481) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3183
      if ( res /= 3183) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3695
      if ( res /= 3695) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3485
      if ( res /= 3485) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2743
      if ( res /= 2743) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",354
      if ( res /= 354) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3382
      if ( res /= 3382) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1581
      if ( res /= 1581) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_eMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1152
      if ( res /= 1152) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1103
      if ( res /= 1103) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1181
      if ( res /= 1181) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2503
      if ( res /= 2503) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_A, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1049
      if ( res /= 1049) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GPlus, P_HMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",186
      if ( res /= 186) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",858
      if ( res /= 858) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",465
      if ( res /= 465) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",169
      if ( res /= 169) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3383
      if ( res /= 3383) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2834
      if ( res /= 2834) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3042
      if ( res /= 3042) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2943
      if ( res /= 2943) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1293
      if ( res /= 1293) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",275
      if ( res /= 275) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",611
      if ( res /= 611) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1752
      if ( res /= 1752) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2861
      if ( res /= 2861) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2369
      if ( res /= 2369) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1386
      if ( res /= 1386) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3067
      if ( res /= 3067) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3456
      if ( res /= 3456) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3601
      if ( res /= 3601) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2256
      if ( res /= 2256) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3364
      if ( res /= 3364) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",889
      if ( res /= 889) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2598
      if ( res /= 2598) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3347
      if ( res /= 3347) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3636
      if ( res /= 3636) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3033
      if ( res /= 3033) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_WPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2879
      if ( res /= 2879) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3633
      if ( res /= 3633) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3123
      if ( res /= 3123) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1322
      if ( res /= 1322) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3530
      if ( res /= 3530) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1898
      if ( res /= 1898) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1358
      if ( res /= 1358) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_ghZAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",907
      if ( res /= 907) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2836
      if ( res /= 2836) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1169
      if ( res /= 1169) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",684
      if ( res /= 684) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1037
      if ( res /= 1037) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2464
      if ( res /= 2464) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_u, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1595
      if ( res /= 1595) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1866
      if ( res /= 1866) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2806
      if ( res /= 2806) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2500
      if ( res /= 2500) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3869
      if ( res /= 3869) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2124
      if ( res /= 2124) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_A, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2282
      if ( res /= 2282) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1879
      if ( res /= 1879) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1778
      if ( res /= 1778) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3172
      if ( res /= 3172) then
        stop
      end if
      call createParticleConfig(P_g, P_HPlus, P_HMinus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3739
      if ( res /= 3739) then
        stop
      end if
      call createParticleConfig(P_g, P_Ha, P_g, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3840
      if ( res /= 3840) then
        stop
      end if
      call createParticleConfig(P_u, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3249
      if ( res /= 3249) then
        stop
      end if
      call createParticleConfig(P_u, P_uAnti, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1980
      if ( res /= 1980) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",911
      if ( res /= 911) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",517
      if ( res /= 517) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2903
      if ( res /= 2903) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2842
      if ( res /= 2842) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",669
      if ( res /= 669) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_Hh, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1615
      if ( res /= 1615) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3124
      if ( res /= 3124) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3753
      if ( res /= 3753) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1899
      if ( res /= 1899) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2768
      if ( res /= 2768) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",462
      if ( res /= 462) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_tauMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1266
      if ( res /= 1266) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3214
      if ( res /= 3214) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_Hl, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2060
      if ( res /= 2060) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",505
      if ( res /= 505) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2857
      if ( res /= 2857) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2405
      if ( res /= 2405) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_HMinus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2279
      if ( res /= 2279) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1539
      if ( res /= 1539) then
        stop
      end if
      call createParticleConfig(P_Hh, P_muPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",643
      if ( res /= 643) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_t, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1339
      if ( res /= 1339) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2782
      if ( res /= 2782) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2134
      if ( res /= 2134) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1907
      if ( res /= 1907) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3160
      if ( res /= 3160) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1783
      if ( res /= 1783) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2551
      if ( res /= 2551) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3831
      if ( res /= 3831) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WPlus, P_HMinus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3351
      if ( res /= 3351) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",898
      if ( res /= 898) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1496
      if ( res /= 1496) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1651
      if ( res /= 1651) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1815
      if ( res /= 1815) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",818
      if ( res /= 818) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_s, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",602
      if ( res /= 602) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2062
      if ( res /= 2062) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3316
      if ( res /= 3316) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3457
      if ( res /= 3457) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2685
      if ( res /= 2685) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1868
      if ( res /= 1868) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3400
      if ( res /= 3400) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",813
      if ( res /= 813) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1986
      if ( res /= 1986) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",742
      if ( res /= 742) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",291
      if ( res /= 291) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",436
      if ( res /= 436) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_ghZ, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3427
      if ( res /= 3427) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2418
      if ( res /= 2418) then
        stop
      end if
      call createParticleConfig(P_Hh, P_ghZAnti, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2334
      if ( res /= 2334) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1723
      if ( res /= 1723) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1955
      if ( res /= 1955) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1816
      if ( res /= 1816) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1540
      if ( res /= 1540) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2296
      if ( res /= 2296) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1242
      if ( res /= 1242) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",733
      if ( res /= 733) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",92
      if ( res /= 92) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",248
      if ( res /= 248) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1416
      if ( res /= 1416) then
        stop
      end if
      call createParticleConfig(P_d, P_uAnti, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1074
      if ( res /= 1074) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_eMinus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",508
      if ( res /= 508) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2702
      if ( res /= 2702) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3148
      if ( res /= 3148) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1002
      if ( res /= 1002) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2754
      if ( res /= 2754) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",170
      if ( res /= 170) then
        stop
      end if
      call createParticleConfig(P_G0, P_tAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",280
      if ( res /= 280) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2446
      if ( res /= 2446) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1757
      if ( res /= 1757) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1119
      if ( res /= 1119) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_nu_e, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1920
      if ( res /= 1920) then
        stop
      end if
      call createParticleConfig(P_s, P_GPlus, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1184
      if ( res /= 1184) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",901
      if ( res /= 901) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",800
      if ( res /= 800) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3167
      if ( res /= 3167) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_d, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2173
      if ( res /= 2173) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2767
      if ( res /= 2767) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2027
      if ( res /= 2027) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1912
      if ( res /= 1912) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1965
      if ( res /= 1965) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",26
      if ( res /= 26) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",516
      if ( res /= 516) then
        stop
      end if
      call createParticleConfig(P_c, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3235
      if ( res /= 3235) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3745
      if ( res /= 3745) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1374
      if ( res /= 1374) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",551
      if ( res /= 551) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_eMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",133
      if ( res /= 133) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1550
      if ( res /= 1550) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3322
      if ( res /= 3322) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",553
      if ( res /= 553) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2408
      if ( res /= 2408) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_s, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2025
      if ( res /= 2025) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3521
      if ( res /= 3521) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3502
      if ( res /= 3502) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HMinus, P_HPlus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1740
      if ( res /= 1740) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3031
      if ( res /= 3031) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_GPlus, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1122
      if ( res /= 1122) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2433
      if ( res /= 2433) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",992
      if ( res /= 992) then
        stop
      end if
      call createParticleConfig(P_s, P_sAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2216
      if ( res /= 2216) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_Z, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1582
      if ( res /= 1582) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2368
      if ( res /= 2368) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",484
      if ( res /= 484) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",680
      if ( res /= 680) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",522
      if ( res /= 522) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghA, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1054
      if ( res /= 1054) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",390
      if ( res /= 390) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3045
      if ( res /= 3045) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2163
      if ( res /= 2163) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3008
      if ( res /= 3008) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",935
      if ( res /= 935) then
        stop
      end if
      call createParticleConfig(P_d, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2821
      if ( res /= 2821) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1936
      if ( res /= 1936) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",45
      if ( res /= 45) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_ePlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1820
      if ( res /= 1820) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1011
      if ( res /= 1011) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_Ha, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3237
      if ( res /= 3237) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_nu_e, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3355
      if ( res /= 3355) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",64
      if ( res /= 64) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2896
      if ( res /= 2896) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2426
      if ( res /= 2426) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1970
      if ( res /= 1970) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1686
      if ( res /= 1686) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_s, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2333
      if ( res /= 2333) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",902
      if ( res /= 902) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3195
      if ( res /= 3195) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1342
      if ( res /= 1342) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",816
      if ( res /= 816) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",824
      if ( res /= 824) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_g, P_HMinus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3646
      if ( res /= 3646) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3491
      if ( res /= 3491) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_WMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3349
      if ( res /= 3349) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1999
      if ( res /= 1999) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_WPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3384
      if ( res /= 3384) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",370
      if ( res /= 370) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2603
      if ( res /= 2603) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1314
      if ( res /= 1314) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3266
      if ( res /= 3266) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1261
      if ( res /= 1261) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1051
      if ( res /= 1051) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1203
      if ( res /= 1203) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3663
      if ( res /= 3663) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2058
      if ( res /= 2058) then
        stop
      end if
      call createParticleConfig(P_G0, P_d, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1690
      if ( res /= 1690) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_G0, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1915
      if ( res /= 1915) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2000
      if ( res /= 2000) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1236
      if ( res /= 1236) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3052
      if ( res /= 3052) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2873
      if ( res /= 2873) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2299
      if ( res /= 2299) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3270
      if ( res /= 3270) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1901
      if ( res /= 1901) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1422
      if ( res /= 1422) then
        stop
      end if
      call createParticleConfig(P_u, P_uAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",616
      if ( res /= 616) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3770
      if ( res /= 3770) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",453
      if ( res /= 453) then
        stop
      end if
      call createParticleConfig(P_G0, P_ghWmAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2364
      if ( res /= 2364) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1552
      if ( res /= 1552) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",634
      if ( res /= 634) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2940
      if ( res /= 2940) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2063
      if ( res /= 2063) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1629
      if ( res /= 1629) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",459
      if ( res /= 459) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_Z, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",324
      if ( res /= 324) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2787
      if ( res /= 2787) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2132
      if ( res /= 2132) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2059
      if ( res /= 2059) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",749
      if ( res /= 749) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghWm, P_ghAAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1774
      if ( res /= 1774) then
        stop
      end if
      call createParticleConfig(P_G0, P_tauPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1767
      if ( res /= 1767) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2390
      if ( res /= 2390) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2546
      if ( res /= 2546) then
        stop
      end if
      call createParticleConfig(P_d, P_dAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",966
      if ( res /= 966) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1894
      if ( res /= 1894) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",644
      if ( res /= 644) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_Ha, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1050
      if ( res /= 1050) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_WMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2916
      if ( res /= 2916) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3170
      if ( res /= 3170) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_A, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3762
      if ( res /= 3762) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",105
      if ( res /= 105) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2188
      if ( res /= 2188) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3514
      if ( res /= 3514) then
        stop
      end if
      call createParticleConfig(P_g, P_G0, P_g, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3802
      if ( res /= 3802) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1844
      if ( res /= 1844) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",534
      if ( res /= 534) then
        stop
      end if
      call createParticleConfig(P_g, P_GPlus, P_g, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3609
      if ( res /= 3609) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",875
      if ( res /= 875) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2693
      if ( res /= 2693) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3109
      if ( res /= 3109) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1424
      if ( res /= 1424) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3335
      if ( res /= 3335) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",130
      if ( res /= 130) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2179
      if ( res /= 2179) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_Ha, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",709
      if ( res /= 709) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_Hl, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2508
      if ( res /= 2508) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2865
      if ( res /= 2865) then
        stop
      end if
      call createParticleConfig(P_Z, P_nu_tauAnti, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2091
      if ( res /= 2091) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",274
      if ( res /= 274) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Ha, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3299
      if ( res /= 3299) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3090
      if ( res /= 3090) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1954
      if ( res /= 1954) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2851
      if ( res /= 2851) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1521
      if ( res /= 1521) then
        stop
      end if
      call createParticleConfig(P_Hl, P_t, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1036
      if ( res /= 1036) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1634
      if ( res /= 1634) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3210
      if ( res /= 3210) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghA, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2719
      if ( res /= 2719) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2905
      if ( res /= 2905) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1732
      if ( res /= 1732) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2120
      if ( res /= 2120) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2590
      if ( res /= 2590) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",513
      if ( res /= 513) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_A, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2165
      if ( res /= 2165) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1797
      if ( res /= 1797) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",433
      if ( res /= 433) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",888
      if ( res /= 888) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_GPlus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1349
      if ( res /= 1349) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3002
      if ( res /= 3002) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2434
      if ( res /= 2434) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_nu_muAnti, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2007
      if ( res /= 2007) then
        stop
      end if
      call createParticleConfig(P_Ha, P_tAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",85
      if ( res /= 85) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WPlus, P_Ha, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1924
      if ( res /= 1924) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1897
      if ( res /= 1897) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3743
      if ( res /= 3743) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3877
      if ( res /= 3877) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_Z, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",968
      if ( res /= 968) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",188
      if ( res /= 188) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",653
      if ( res /= 653) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3564
      if ( res /= 3564) then
        stop
      end if
      call createParticleConfig(P_s, P_WPlus, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1235
      if ( res /= 1235) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",595
      if ( res /= 595) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1765
      if ( res /= 1765) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_WMinus, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",412
      if ( res /= 412) then
        stop
      end if
      call createParticleConfig(P_Hh, P_g, P_g, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3758
      if ( res /= 3758) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1264
      if ( res /= 1264) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2711
      if ( res /= 2711) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_d, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",451
      if ( res /= 451) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1394
      if ( res /= 1394) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1799
      if ( res /= 1799) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2407
      if ( res /= 2407) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GMinus, P_HPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",498
      if ( res /= 498) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3145
      if ( res /= 3145) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",896
      if ( res /= 896) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1252
      if ( res /= 1252) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghWp, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2758
      if ( res /= 2758) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_d, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",884
      if ( res /= 884) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1885
      if ( res /= 1885) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3112
      if ( res /= 3112) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",593
      if ( res /= 593) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1335
      if ( res /= 1335) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3801
      if ( res /= 3801) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",806
      if ( res /= 806) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2785
      if ( res /= 2785) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GPlus, P_GMinus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",528
      if ( res /= 528) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_A, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1982
      if ( res /= 1982) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1824
      if ( res /= 1824) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3201
      if ( res /= 3201) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_nu_eAnti, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",434
      if ( res /= 434) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2332
      if ( res /= 2332) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_u, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1311
      if ( res /= 1311) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HPlus, P_GMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",991
      if ( res /= 991) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",58
      if ( res /= 58) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1125
      if ( res /= 1125) then
        stop
      end if
      call createParticleConfig(P_g, P_Hl, P_Hl, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3776
      if ( res /= 3776) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2846
      if ( res /= 2846) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3660
      if ( res /= 3660) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2538
      if ( res /= 2538) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3531
      if ( res /= 3531) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_g, P_GMinus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3625
      if ( res /= 3625) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1298
      if ( res /= 1298) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1943
      if ( res /= 1943) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2882
      if ( res /= 2882) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1385
      if ( res /= 1385) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2177
      if ( res /= 2177) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",854
      if ( res /= 854) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",7
      if ( res /= 7) then
        stop
      end if
      call createParticleConfig(P_A, P_s, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",476
      if ( res /= 476) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1672
      if ( res /= 1672) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",332
      if ( res /= 332) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1407
      if ( res /= 1407) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",687
      if ( res /= 687) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3254
      if ( res /= 3254) then
        stop
      end if
      call createParticleConfig(P_c, P_Hl, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",726
      if ( res /= 726) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3000
      if ( res /= 3000) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1762
      if ( res /= 1762) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2102
      if ( res /= 2102) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2878
      if ( res /= 2878) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Ha, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3245
      if ( res /= 3245) then
        stop
      end if
      call createParticleConfig(P_d, P_g, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",357
      if ( res /= 357) then
        stop
      end if
      call createParticleConfig(P_g, P_t, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",986
      if ( res /= 986) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",890
      if ( res /= 890) then
        stop
      end if
      call createParticleConfig(P_t, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3016
      if ( res /= 3016) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1321
      if ( res /= 1321) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3398
      if ( res /= 3398) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1139
      if ( res /= 1139) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_ghWp, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3454
      if ( res /= 3454) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",708
      if ( res /= 708) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3512
      if ( res /= 3512) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1941
      if ( res /= 1941) then
        stop
      end if
      call createParticleConfig(P_g, P_sAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2204
      if ( res /= 2204) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",346
      if ( res /= 346) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_WPlus, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",456
      if ( res /= 456) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",149
      if ( res /= 149) then
        stop
      end if
      call createParticleConfig(P_Ha, P_g, P_G0, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3632
      if ( res /= 3632) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3137
      if ( res /= 3137) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GMinus, P_GPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",860
      if ( res /= 860) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1623
      if ( res /= 1623) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WMinus, P_WPlus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3088
      if ( res /= 3088) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",661
      if ( res /= 661) then
        stop
      end if
      call createParticleConfig(P_c, P_cAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1960
      if ( res /= 1960) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",965
      if ( res /= 965) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3499
      if ( res /= 3499) then
        stop
      end if
      call createParticleConfig(P_s, P_Ha, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2705
      if ( res /= 2705) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_b, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2654
      if ( res /= 2654) then
        stop
      end if
      call createParticleConfig(P_u, P_uAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1024
      if ( res /= 1024) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1399
      if ( res /= 1399) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2985
      if ( res /= 2985) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2604
      if ( res /= 2604) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1104
      if ( res /= 1104) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",694
      if ( res /= 694) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2975
      if ( res /= 2975) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_nu_e, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2584
      if ( res /= 2584) then
        stop
      end if
      call createParticleConfig(P_t, P_bAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2628
      if ( res /= 2628) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2741
      if ( res /= 2741) then
        stop
      end if
      call createParticleConfig(P_Hh, P_c, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2448
      if ( res /= 2448) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1499
      if ( res /= 1499) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_bAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2245
      if ( res /= 2245) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2565
      if ( res /= 2565) then
        stop
      end if
      call createParticleConfig(P_g, P_b, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2572
      if ( res /= 2572) then
        stop
      end if
      call createParticleConfig(P_A, P_b, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",663
      if ( res /= 663) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1693
      if ( res /= 1693) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_eMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1088
      if ( res /= 1088) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1154
      if ( res /= 1154) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2973
      if ( res /= 2973) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2454
      if ( res /= 2454) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_ghA, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3274
      if ( res /= 3274) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1597
      if ( res /= 1597) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1262
      if ( res /= 1262) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2209
      if ( res /= 2209) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3204
      if ( res /= 3204) then
        stop
      end if
      call createParticleConfig(P_g, P_Z, P_Z, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3675
      if ( res /= 3675) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",504
      if ( res /= 504) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",838
      if ( res /= 838) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_nu_tau, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1160
      if ( res /= 1160) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1039
      if ( res /= 1039) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3230
      if ( res /= 3230) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1715
      if ( res /= 1715) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2635
      if ( res /= 2635) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3096
      if ( res /= 3096) then
        stop
      end if
      call createParticleConfig(P_g, P_Hh, P_g, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3862
      if ( res /= 3862) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3692
      if ( res /= 3692) then
        stop
      end if
      call createParticleConfig(P_b, P_HPlus, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2641
      if ( res /= 2641) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3584
      if ( res /= 3584) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1411
      if ( res /= 1411) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3132
      if ( res /= 3132) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2351
      if ( res /= 2351) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1558
      if ( res /= 1558) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1741
      if ( res /= 1741) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3166
      if ( res /= 3166) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_tauPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",326
      if ( res /= 326) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2152
      if ( res /= 2152) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3795
      if ( res /= 3795) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghWmAnti, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3154
      if ( res /= 3154) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2801
      if ( res /= 2801) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1916
      if ( res /= 1916) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",831
      if ( res /= 831) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3441
      if ( res /= 3441) then
        stop
      end if
      call createParticleConfig(P_g, P_GPlus, P_GMinus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3781
      if ( res /= 3781) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2886
      if ( res /= 2886) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_Ha, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1115
      if ( res /= 1115) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2864
      if ( res /= 2864) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3569
      if ( res /= 3569) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1075
      if ( res /= 1075) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3093
      if ( res /= 3093) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1728
      if ( res /= 1728) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",717
      if ( res /= 717) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_HPlus, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2737
      if ( res /= 2737) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_muMinus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2638
      if ( res /= 2638) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1512
      if ( res /= 1512) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2656
      if ( res /= 2656) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_s, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",637
      if ( res /= 637) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1192
      if ( res /= 1192) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1003
      if ( res /= 1003) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",931
      if ( res /= 931) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HMinus, P_HPlus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",927
      if ( res /= 927) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1021
      if ( res /= 1021) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1096
      if ( res /= 1096) then
        stop
      end if
      call createParticleConfig(P_b, P_Hl, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1144
      if ( res /= 1144) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3800
      if ( res /= 3800) then
        stop
      end if
      call createParticleConfig(P_u, P_G0, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1343
      if ( res /= 1343) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2764
      if ( res /= 2764) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3251
      if ( res /= 3251) then
        stop
      end if
      call createParticleConfig(P_g, P_HPlus, P_GMinus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3724
      if ( res /= 3724) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3125
      if ( res /= 3125) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2449
      if ( res /= 2449) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1244
      if ( res /= 1244) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2835
      if ( res /= 2835) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_WPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2430
      if ( res /= 2430) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3341
      if ( res /= 3341) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3287
      if ( res /= 3287) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1471
      if ( res /= 1471) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1808
      if ( res /= 1808) then
        stop
      end if
      call createParticleConfig(P_G0, P_sAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2389
      if ( res /= 2389) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2043
      if ( res /= 2043) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3408
      if ( res /= 3408) then
        stop
      end if
      call createParticleConfig(P_Z, P_g, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3680
      if ( res /= 3680) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",801
      if ( res /= 801) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",886
      if ( res /= 886) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",464
      if ( res /= 464) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",789
      if ( res /= 789) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_G0, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2014
      if ( res /= 2014) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3529
      if ( res /= 3529) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1956
      if ( res /= 1956) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2244
      if ( res /= 2244) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2723
      if ( res /= 2723) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_ePlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",203
      if ( res /= 203) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2557
      if ( res /= 2557) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",34
      if ( res /= 34) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",138
      if ( res /= 138) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3871
      if ( res /= 3871) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1749
      if ( res /= 1749) then
        stop
      end if
      call createParticleConfig(P_A, P_tauMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2618
      if ( res /= 2618) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3706
      if ( res /= 3706) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_nu_e, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",164
      if ( res /= 164) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1756
      if ( res /= 1756) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3867
      if ( res /= 3867) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_Ha, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3258
      if ( res /= 3258) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2499
      if ( res /= 2499) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",19
      if ( res /= 19) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_u, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",906
      if ( res /= 906) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",719
      if ( res /= 719) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",544
      if ( res /= 544) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2683
      if ( res /= 2683) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3755
      if ( res /= 3755) then
        stop
      end if
      call createParticleConfig(P_d, P_GPlus, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",245
      if ( res /= 245) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",916
      if ( res /= 916) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2839
      if ( res /= 2839) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",168
      if ( res /= 168) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GMinus, P_WPlus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3213
      if ( res /= 3213) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",622
      if ( res /= 622) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",441
      if ( res /= 441) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",741
      if ( res /= 741) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Ha, P_WMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",548
      if ( res /= 548) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",526
      if ( res /= 526) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3668
      if ( res /= 3668) then
        stop
      end if
      call createParticleConfig(P_A, P_c, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2606
      if ( res /= 2606) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",542
      if ( res /= 542) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3533
      if ( res /= 3533) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",557
      if ( res /= 557) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1185
      if ( res /= 1185) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",443
      if ( res /= 443) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1150
      if ( res /= 1150) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1589
      if ( res /= 1589) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghZAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",657
      if ( res /= 657) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2271
      if ( res /= 2271) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2076
      if ( res /= 2076) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2338
      if ( res /= 2338) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3581
      if ( res /= 3581) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",306
      if ( res /= 306) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_ghWmAnti, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1526
      if ( res /= 1526) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2810
      if ( res /= 2810) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3196
      if ( res /= 3196) then
        stop
      end if
      call createParticleConfig(P_Hh, P_uAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2213
      if ( res /= 2213) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3596
      if ( res /= 3596) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3202
      if ( res /= 3202) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3118
      if ( res /= 3118) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1490
      if ( res /= 1490) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_u, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2352
      if ( res /= 2352) then
        stop
      end if
      call createParticleConfig(P_Z, P_eMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",750
      if ( res /= 750) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1685
      if ( res /= 1685) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3180
      if ( res /= 3180) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_g, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3818
      if ( res /= 3818) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",165
      if ( res /= 165) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1665
      if ( res /= 1665) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1497
      if ( res /= 1497) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",885
      if ( res /= 885) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",20
      if ( res /= 20) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1312
      if ( res /= 1312) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",748
      if ( res /= 748) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1329
      if ( res /= 1329) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_GMinus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1283
      if ( res /= 1283) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",309
      if ( res /= 309) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_ghWp, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2487
      if ( res /= 2487) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1527
      if ( res /= 1527) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",276
      if ( res /= 276) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1679
      if ( res /= 1679) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1393
      if ( res /= 1393) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3372
      if ( res /= 3372) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1519
      if ( res /= 1519) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_tauPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1195
      if ( res /= 1195) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",645
      if ( res /= 645) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1605
      if ( res /= 1605) then
        stop
      end if
      call createParticleConfig(P_Ha, P_d, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2342
      if ( res /= 2342) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1577
      if ( res /= 1577) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2257
      if ( res /= 2257) then
        stop
      end if
      call createParticleConfig(P_Ha, P_c, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1641
      if ( res /= 1641) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1841
      if ( res /= 1841) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1945
      if ( res /= 1945) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1568
      if ( res /= 1568) then
        stop
      end if
      call createParticleConfig(P_c, P_Z, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",917
      if ( res /= 917) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",297
      if ( res /= 297) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1308
      if ( res /= 1308) then
        stop
      end if
      call createParticleConfig(P_Z, P_dAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2255
      if ( res /= 2255) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1695
      if ( res /= 1695) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WPlus, P_WMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",160
      if ( res /= 160) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1224
      if ( res /= 1224) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3504
      if ( res /= 3504) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2237
      if ( res /= 2237) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",977
      if ( res /= 977) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_tauMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",545
      if ( res /= 545) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_WMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3284
      if ( res /= 3284) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2450
      if ( res /= 2450) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2957
      if ( res /= 2957) then
        stop
      end if
      call createParticleConfig(P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2993
      if ( res /= 2993) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghWp, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",808
      if ( res /= 808) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1136
      if ( res /= 1136) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3194
      if ( res /= 3194) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2070
      if ( res /= 2070) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3054
      if ( res /= 3054) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",281
      if ( res /= 281) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_nu_eAnti, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2589
      if ( res /= 2589) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1366
      if ( res /= 1366) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",289
      if ( res /= 289) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",672
      if ( res /= 672) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3538
      if ( res /= 3538) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1620
      if ( res /= 1620) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Ha, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2910
      if ( res /= 2910) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2436
      if ( res /= 2436) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghA, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",353
      if ( res /= 353) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3804
      if ( res /= 3804) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",929
      if ( res /= 929) then
        stop
      end if
      call createParticleConfig(P_c, P_cAnti, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2151
      if ( res /= 2151) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3874
      if ( res /= 3874) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1813
      if ( res /= 1813) then
        stop
      end if
      call createParticleConfig(P_u, P_uAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",10
      if ( res /= 10) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1542
      if ( res /= 1542) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_Hh, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2083
      if ( res /= 2083) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_ghWpAnti, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2381
      if ( res /= 2381) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1534
      if ( res /= 1534) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3185
      if ( res /= 3185) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3595
      if ( res /= 3595) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_WMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",792
      if ( res /= 792) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2509
      if ( res /= 2509) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1990
      if ( res /= 1990) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",959
      if ( res /= 959) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",819
      if ( res /= 819) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2746
      if ( res /= 2746) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2953
      if ( res /= 2953) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GMinus, P_GPlus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2197
      if ( res /= 2197) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2265
      if ( res /= 2265) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3701
      if ( res /= 3701) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1114
      if ( res /= 1114) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2537
      if ( res /= 2537) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_tauMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1504
      if ( res /= 1504) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2862
      if ( res /= 2862) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3436
      if ( res /= 3436) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2545
      if ( res /= 2545) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3001
      if ( res /= 3001) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3071
      if ( res /= 3071) then
        stop
      end if
      call createParticleConfig(P_u, P_g, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1453
      if ( res /= 1453) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",535
      if ( res /= 535) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_HPlus, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1180
      if ( res /= 1180) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3439
      if ( res /= 3439) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1085
      if ( res /= 1085) then
        stop
      end if
      call createParticleConfig(P_Hh, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3647
      if ( res /= 3647) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2528
      if ( res /= 2528) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3370
      if ( res /= 3370) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2781
      if ( res /= 2781) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",978
      if ( res /= 978) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_GPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1818
      if ( res /= 1818) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2207
      if ( res /= 2207) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3021
      if ( res /= 3021) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3851
      if ( res /= 3851) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2089
      if ( res /= 2089) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3070
      if ( res /= 3070) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_eMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2341
      if ( res /= 2341) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3116
      if ( res /= 3116) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3691
      if ( res /= 3691) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2053
      if ( res /= 2053) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2928
      if ( res /= 2928) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",804
      if ( res /= 804) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2963
      if ( res /= 2963) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",210
      if ( res /= 210) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",339
      if ( res /= 339) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_eMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",466
      if ( res /= 466) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",652
      if ( res /= 652) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3402
      if ( res /= 3402) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1190
      if ( res /= 1190) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3294
      if ( res /= 3294) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WMinus, P_WPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1186
      if ( res /= 1186) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_WMinus, P_ghAAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",78
      if ( res /= 78) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_HMinus, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1143
      if ( res /= 1143) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_nu_muAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1081
      if ( res /= 1081) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghZ, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3405
      if ( res /= 3405) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3431
      if ( res /= 3431) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2553
      if ( res /= 2553) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2649
      if ( res /= 2649) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2004
      if ( res /= 2004) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghZAnti, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3401
      if ( res /= 3401) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3847
      if ( res /= 3847) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghZAnti, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3219
      if ( res /= 3219) then
        stop
      end if
      call createParticleConfig(P_t, P_tAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1782
      if ( res /= 1782) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",937
      if ( res /= 937) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1660
      if ( res /= 1660) then
        stop
      end if
      call createParticleConfig(P_Ha, P_muPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1604
      if ( res /= 1604) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1952
      if ( res /= 1952) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",883
      if ( res /= 883) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2998
      if ( res /= 2998) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",65
      if ( res /= 65) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1268
      if ( res /= 1268) then
        stop
      end if
      call createParticleConfig(P_A, P_nu_mu, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3472
      if ( res /= 3472) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3879
      if ( res /= 3879) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1338
      if ( res /= 1338) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2427
      if ( res /= 2427) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",878
      if ( res /= 878) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3315
      if ( res /= 3315) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1406
      if ( res /= 1406) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",18
      if ( res /= 18) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",995
      if ( res /= 995) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",506
      if ( res /= 506) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2397
      if ( res /= 2397) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_s, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1286
      if ( res /= 1286) then
        stop
      end if
      call createParticleConfig(P_g, P_HMinus, P_g, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3664
      if ( res /= 3664) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2895
      if ( res /= 2895) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",253
      if ( res /= 253) then
        stop
      end if
      call createParticleConfig(P_g, P_Z, P_g, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3744
      if ( res /= 3744) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1594
      if ( res /= 1594) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3835
      if ( res /= 3835) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",621
      if ( res /= 621) then
        stop
      end if
      call createParticleConfig(P_t, P_tAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",825
      if ( res /= 825) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2118
      if ( res /= 2118) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3578
      if ( res /= 3578) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1993
      if ( res /= 1993) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",35
      if ( res /= 35) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3606
      if ( res /= 3606) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",796
      if ( res /= 796) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_u, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2034
      if ( res /= 2034) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1516
      if ( res /= 1516) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_Ha, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3477
      if ( res /= 3477) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",880
      if ( res /= 880) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3393
      if ( res /= 3393) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3428
      if ( res /= 3428) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1207
      if ( res /= 1207) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",100
      if ( res /= 100) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3005
      if ( res /= 3005) then
        stop
      end if
      call createParticleConfig(P_Hl, P_cAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1619
      if ( res /= 1619) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1825
      if ( res /= 1825) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_Hh, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1551
      if ( res /= 1551) then
        stop
      end if
      call createParticleConfig(P_g, P_GMinus, P_HPlus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3757
      if ( res /= 3757) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1781
      if ( res /= 1781) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3448
      if ( res /= 3448) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3771
      if ( res /= 3771) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1383
      if ( res /= 1383) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3007
      if ( res /= 3007) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",946
      if ( res /= 946) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_dAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",473
      if ( res /= 473) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_HPlus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2692
      if ( res /= 2692) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2490
      if ( res /= 2490) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3474
      if ( res /= 3474) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1646
      if ( res /= 1646) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",179
      if ( res /= 179) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1648
      if ( res /= 1648) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2735
      if ( res /= 2735) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2122
      if ( res /= 2122) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_nu_mu, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",558
      if ( res /= 558) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_nu_tau, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2554
      if ( res /= 2554) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",922
      if ( res /= 922) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1483
      if ( res /= 1483) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2308
      if ( res /= 2308) then
        stop
      end if
      call createParticleConfig(P_G0, P_eMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",5
      if ( res /= 5) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3723
      if ( res /= 3723) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3497
      if ( res /= 3497) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",617
      if ( res /= 617) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_ePlus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",537
      if ( res /= 537) then
        stop
      end if
      call createParticleConfig(P_u, P_dAnti, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2676
      if ( res /= 2676) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",455
      if ( res /= 455) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1935
      if ( res /= 1935) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",722
      if ( res /= 722) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1705
      if ( res /= 1705) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1731
      if ( res /= 1731) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",909
      if ( res /= 909) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_muMinus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2228
      if ( res /= 2228) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1992
      if ( res /= 1992) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2863
      if ( res /= 2863) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3639
      if ( res /= 3639) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2913
      if ( res /= 2913) then
        stop
      end if
      call createParticleConfig(P_u, P_dAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2616
      if ( res /= 2616) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_GPlus, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1559
      if ( res /= 1559) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1258
      if ( res /= 1258) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3557
      if ( res /= 3557) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3470
      if ( res /= 3470) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",394
      if ( res /= 394) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",42
      if ( res /= 42) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3458
      if ( res /= 3458) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3177
      if ( res /= 3177) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3061
      if ( res /= 3061) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3748
      if ( res /= 3748) then
        stop
      end if
      call createParticleConfig(P_Hh, P_u, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1129
      if ( res /= 1129) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3779
      if ( res /= 3779) then
        stop
      end if
      call createParticleConfig(P_s, P_A, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2330
      if ( res /= 2330) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2406
      if ( res /= 2406) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2374
      if ( res /= 2374) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3650
      if ( res /= 3650) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",287
      if ( res /= 287) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2087
      if ( res /= 2087) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1035
      if ( res /= 1035) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2784
      if ( res /= 2784) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_muMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",157
      if ( res /= 157) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3540
      if ( res /= 3540) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2833
      if ( res /= 2833) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",550
      if ( res /= 550) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1668
      if ( res /= 1668) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",359
      if ( res /= 359) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3360
      if ( res /= 3360) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3018
      if ( res /= 3018) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2452
      if ( res /= 2452) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_c, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",660
      if ( res /= 660) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3727
      if ( res /= 3727) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",68
      if ( res /= 68) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_tauMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2266
      if ( res /= 2266) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_d, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1635
      if ( res /= 1635) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",67
      if ( res /= 67) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3582
      if ( res /= 3582) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_bAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",833
      if ( res /= 833) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2950
      if ( res /= 2950) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3590
      if ( res /= 3590) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2935
      if ( res /= 2935) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_Hl, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1330
      if ( res /= 1330) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",746
      if ( res /= 746) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3821
      if ( res /= 3821) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2248
      if ( res /= 2248) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1624
      if ( res /= 1624) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_Ha, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3314
      if ( res /= 3314) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",378
      if ( res /= 378) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2802
      if ( res /= 2802) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3500
      if ( res /= 3500) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_WPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2556
      if ( res /= 2556) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2982
      if ( res /= 2982) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_A, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2561
      if ( res /= 2561) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Ha, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1838
      if ( res /= 1838) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",783
      if ( res /= 783) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1628
      if ( res /= 1628) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_G0, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1932
      if ( res /= 1932) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3593
      if ( res /= 3593) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_WPlus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2516
      if ( res /= 2516) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",525
      if ( res /= 525) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2432
      if ( res /= 2432) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1323
      if ( res /= 1323) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3325
      if ( res /= 3325) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2630
      if ( res /= 2630) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghZAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",147
      if ( res /= 147) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_nu_eAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2514
      if ( res /= 2514) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",690
      if ( res /= 690) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3737
      if ( res /= 3737) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_ePlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",809
      if ( res /= 809) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2929
      if ( res /= 2929) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1803
      if ( res /= 1803) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_ghWmAnti, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3324
      if ( res /= 3324) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1845
      if ( res /= 1845) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2657
      if ( res /= 2657) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_s, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1684
      if ( res /= 1684) then
        stop
      end if
      call createParticleConfig(P_Z, P_nu_muAnti, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1479
      if ( res /= 1479) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",374
      if ( res /= 374) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_b, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1578
      if ( res /= 1578) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3229
      if ( res /= 3229) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2941
      if ( res /= 2941) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2959
      if ( res /= 2959) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3679
      if ( res /= 3679) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3722
      if ( res /= 3722) then
        stop
      end if
      call createParticleConfig(P_g, P_GMinus, P_GPlus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3611
      if ( res /= 3611) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1237
      if ( res /= 1237) then
        stop
      end if
      call createParticleConfig(P_Z, P_nu_tau, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",96
      if ( res /= 96) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2289
      if ( res /= 2289) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3480
      if ( res /= 3480) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_GPlus, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1428
      if ( res /= 1428) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",627
      if ( res /= 627) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_nu_muAnti, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1461
      if ( res /= 1461) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_muPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",61
      if ( res /= 61) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2172
      if ( res /= 2172) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_d, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2055
      if ( res /= 2055) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",48
      if ( res /= 48) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2284
      if ( res /= 2284) then
        stop
      end if
      call createParticleConfig(P_Ha, P_ghWm, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2902
      if ( res /= 2902) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1827
      if ( res /= 1827) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2662
      if ( res /= 2662) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_s, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",335
      if ( res /= 335) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_c, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2002
      if ( res /= 2002) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3111
      if ( res /= 3111) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2038
      if ( res /= 2038) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2830
      if ( res /= 2830) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3543
      if ( res /= 3543) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2908
      if ( res /= 2908) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1272
      if ( res /= 1272) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1026
      if ( res /= 1026) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2820
      if ( res /= 2820) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",599
      if ( res /= 599) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1265
      if ( res /= 1265) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2458
      if ( res /= 2458) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2312
      if ( res /= 2312) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_ghZAnti, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",738
      if ( res /= 738) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",14
      if ( res /= 14) then
        stop
      end if
      call createParticleConfig(P_b, P_bAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",312
      if ( res /= 312) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",655
      if ( res /= 655) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2624
      if ( res /= 2624) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",265
      if ( res /= 265) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",610
      if ( res /= 610) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1099
      if ( res /= 1099) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2884
      if ( res /= 2884) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1564
      if ( res /= 1564) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_A, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2632
      if ( res /= 2632) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_tauPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1012
      if ( res /= 1012) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",109
      if ( res /= 109) then
        stop
      end if
      call createParticleConfig(P_ghA, P_ghWpAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",107
      if ( res /= 107) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1438
      if ( res /= 1438) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",364
      if ( res /= 364) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2771
      if ( res /= 2771) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_WMinus, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1969
      if ( res /= 1969) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",781
      if ( res /= 781) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",154
      if ( res /= 154) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GMinus, P_HPlus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",87
      if ( res /= 87) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2363
      if ( res /= 2363) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3339
      if ( res /= 3339) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2658
      if ( res /= 2658) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",422
      if ( res /= 422) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1544
      if ( res /= 1544) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2629
      if ( res /= 2629) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2652
      if ( res /= 2652) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1487
      if ( res /= 1487) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_Ha, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2912
      if ( res /= 2912) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1028
      if ( res /= 1028) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3503
      if ( res /= 3503) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghWm, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2109
      if ( res /= 2109) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3250
      if ( res /= 3250) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2942
      if ( res /= 2942) then
        stop
      end if
      call createParticleConfig(P_ghGAnti, P_g, P_ghG, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1202
      if ( res /= 1202) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1805
      if ( res /= 1805) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",285
      if ( res /= 285) then
        stop
      end if
      call createParticleConfig(P_s, P_cAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",619
      if ( res /= 619) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2317
      if ( res /= 2317) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",794
      if ( res /= 794) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1508
      if ( res /= 1508) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1174
      if ( res /= 1174) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2210
      if ( res /= 2210) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",315
      if ( res /= 315) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1238
      if ( res /= 1238) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2203
      if ( res /= 2203) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",89
      if ( res /= 89) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3488
      if ( res /= 3488) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1621
      if ( res /= 1621) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",399
      if ( res /= 399) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1092
      if ( res /= 1092) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1008
      if ( res /= 1008) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2841
      if ( res /= 2841) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",70
      if ( res /= 70) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",218
      if ( res /= 218) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3697
      if ( res /= 3697) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_b, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1212
      if ( res /= 1212) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",95
      if ( res /= 95) then
        stop
      end if
      call createParticleConfig(P_Hl, P_bAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1949
      if ( res /= 1949) then
        stop
      end if
      call createParticleConfig(P_ghA, P_GPlus, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2623
      if ( res /= 2623) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2212
      if ( res /= 2212) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2094
      if ( res /= 2094) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2064
      if ( res /= 2064) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghWm, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1102
      if ( res /= 1102) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_Z, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",296
      if ( res /= 296) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2562
      if ( res /= 2562) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3602
      if ( res /= 3602) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",256
      if ( res /= 256) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1109
      if ( res /= 1109) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2647
      if ( res /= 2647) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1791
      if ( res /= 1791) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WMinus, P_HPlus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3252
      if ( res /= 3252) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_A, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3191
      if ( res /= 3191) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1084
      if ( res /= 1084) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_HMinus, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2728
      if ( res /= 2728) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2716
      if ( res /= 2716) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_Ha, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3190
      if ( res /= 3190) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3048
      if ( res /= 3048) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2567
      if ( res /= 2567) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3642
      if ( res /= 3642) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_ghWmAnti, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1317
      if ( res /= 1317) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3861
      if ( res /= 3861) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",879
      if ( res /= 879) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",134
      if ( res /= 134) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",320
      if ( res /= 320) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",471
      if ( res /= 471) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",351
      if ( res /= 351) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2125
      if ( res /= 2125) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3845
      if ( res /= 3845) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3075
      if ( res /= 3075) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1098
      if ( res /= 1098) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1171
      if ( res /= 1171) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1090
      if ( res /= 1090) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3357
      if ( res /= 3357) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1229
      if ( res /= 1229) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",292
      if ( res /= 292) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",38
      if ( res /= 38) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",811
      if ( res /= 811) then
        stop
      end if
      call createParticleConfig(P_ghA, P_ghWmAnti, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3217
      if ( res /= 3217) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3129
      if ( res /= 3129) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",316
      if ( res /= 316) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1565
      if ( res /= 1565) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",344
      if ( res /= 344) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_ghA, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1031
      if ( res /= 1031) then
        stop
      end if
      call createParticleConfig(P_G0, P_bAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1326
      if ( res /= 1326) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3098
      if ( res /= 3098) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",225
      if ( res /= 225) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2971
      if ( res /= 2971) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1097
      if ( res /= 1097) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",538
      if ( res /= 538) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",258
      if ( res /= 258) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3331
      if ( res /= 3331) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2600
      if ( res /= 2600) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1545
      if ( res /= 1545) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1445
      if ( res /= 1445) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2268
      if ( res /= 2268) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HMinus, P_HPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",730
      if ( res /= 730) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WMinus, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3570
      if ( res /= 3570) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1638
      if ( res /= 1638) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2215
      if ( res /= 2215) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_HPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",949
      if ( res /= 949) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_tauPlus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1120
      if ( res /= 1120) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",938
      if ( res /= 938) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1464
      if ( res /= 1464) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3516
      if ( res /= 3516) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_Ha, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1354
      if ( res /= 1354) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Ha, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2455
      if ( res /= 2455) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3026
      if ( res /= 3026) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2665
      if ( res /= 2665) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3451
      if ( res /= 3451) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2544
      if ( res /= 2544) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2919
      if ( res /= 2919) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_nu_mu, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",212
      if ( res /= 212) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1162
      if ( res /= 1162) then
        stop
      end if
      call createParticleConfig(P_b, P_tAnti, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",349
      if ( res /= 349) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1401
      if ( res /= 1401) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1134
      if ( res /= 1134) then
        stop
      end if
      call createParticleConfig(P_c, P_sAnti, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1939
      if ( res /= 1939) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1748
      if ( res /= 1748) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2052
      if ( res /= 2052) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",150
      if ( res /= 150) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2252
      if ( res /= 2252) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",994
      if ( res /= 994) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1745
      if ( res /= 1745) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3295
      if ( res /= 3295) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",361
      if ( res /= 361) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1687
      if ( res /= 1687) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_tAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1579
      if ( res /= 1579) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",238
      if ( res /= 238) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3244
      if ( res /= 3244) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2035
      if ( res /= 2035) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1830
      if ( res /= 1830) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3508
      if ( res /= 3508) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",172
      if ( res /= 172) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",427
      if ( res /= 427) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3040
      if ( res /= 3040) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",192
      if ( res /= 192) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1562
      if ( res /= 1562) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2247
      if ( res /= 2247) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3243
      if ( res /= 3243) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_u, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1015
      if ( res /= 1015) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2261
      if ( res /= 2261) then
        stop
      end if
      call createParticleConfig(P_g, P_G0, P_G0, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3607
      if ( res /= 3607) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3444
      if ( res /= 3444) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3429
      if ( res /= 3429) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",681
      if ( res /= 681) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1806
      if ( res /= 1806) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",91
      if ( res /= 91) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1458
      if ( res /= 1458) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",110
      if ( res /= 110) then
        stop
      end if
      call createParticleConfig(P_ghA, P_HPlus, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2897
      if ( res /= 2897) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2789
      if ( res /= 2789) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_nu_tau, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",460
      if ( res /= 460) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3395
      if ( res /= 3395) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GPlus, P_WMinus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3072
      if ( res /= 3072) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3463
      if ( res /= 3463) then
        stop
      end if
      call createParticleConfig(P_g, P_Hh, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3711
      if ( res /= 3711) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",495
      if ( res /= 495) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WPlus, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2901
      if ( res /= 2901) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3047
      if ( res /= 3047) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",249
      if ( res /= 249) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3479
      if ( res /= 3479) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1379
      if ( res /= 1379) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1310
      if ( res /= 1310) then
        stop
      end if
      call createParticleConfig(P_Z, P_u, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1071
      if ( res /= 1071) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",347
      if ( res /= 347) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",290
      if ( res /= 290) then
        stop
      end if
      call createParticleConfig(P_Z, P_nu_mu, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",912
      if ( res /= 912) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3272
      if ( res /= 3272) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3466
      if ( res /= 3466) then
        stop
      end if
      call createParticleConfig(P_Ha, P_ghWmAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2937
      if ( res /= 2937) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1856
      if ( res /= 1856) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1891
      if ( res /= 1891) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3212
      if ( res /= 3212) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2762
      if ( res /= 2762) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2359
      if ( res /= 2359) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_uAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",8
      if ( res /= 8) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2440
      if ( res /= 2440) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_GMinus, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1448
      if ( res /= 1448) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghWp, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2236
      if ( res /= 2236) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2502
      if ( res /= 2502) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",55
      if ( res /= 55) then
        stop
      end if
      call createParticleConfig(P_u, P_Z, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2651
      if ( res /= 2651) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3798
      if ( res /= 3798) then
        stop
      end if
      call createParticleConfig(P_g, P_Ha, P_G0, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3635
      if ( res /= 3635) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",812
      if ( res /= 812) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",115
      if ( res /= 115) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2811
      if ( res /= 2811) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2219
      if ( res /= 2219) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3819
      if ( res /= 3819) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3376
      if ( res /= 3376) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_A, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2169
      if ( res /= 2169) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Ha, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3452
      if ( res /= 3452) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_WPlus, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1057
      if ( res /= 1057) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",942
      if ( res /= 942) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3119
      if ( res /= 3119) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Ha, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",371
      if ( res /= 371) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2691
      if ( res /= 2691) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_HPlus, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3417
      if ( res /= 3417) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3215
      if ( res /= 3215) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",15
      if ( res /= 15) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2456
      if ( res /= 2456) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3445
      if ( res /= 3445) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3669
      if ( res /= 3669) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3551
      if ( res /= 3551) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_GMinus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2302
      if ( res /= 2302) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3460
      if ( res /= 3460) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3039
      if ( res /= 3039) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_Hl, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",337
      if ( res /= 337) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",776
      if ( res /= 776) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3085
      if ( res /= 3085) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2881
      if ( res /= 2881) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",667
      if ( res /= 667) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_c, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1673
      if ( res /= 1673) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Ha, P_Ha, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",963
      if ( res /= 963) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1432
      if ( res /= 1432) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",398
      if ( res /= 398) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_t, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1362
      if ( res /= 1362) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_HMinus, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3224
      if ( res /= 3224) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",303
      if ( res /= 303) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_c, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1607
      if ( res /= 1607) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",981
      if ( res /= 981) then
        stop
      end if
      call createParticleConfig(P_A, P_nu_eAnti, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3094
      if ( res /= 3094) then
        stop
      end if
      call createParticleConfig(P_c, P_cAnti, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1170
      if ( res /= 1170) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2826
      if ( res /= 2826) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_WMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2958
      if ( res /= 2958) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_WMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1911
      if ( res /= 1911) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1828
      if ( res /= 1828) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",903
      if ( res /= 903) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",744
      if ( res /= 744) then
        stop
      end if
      call createParticleConfig(P_c, P_GMinus, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1870
      if ( res /= 1870) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3526
      if ( res /= 3526) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2708
      if ( res /= 2708) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2453
      if ( res /= 2453) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1663
      if ( res /= 1663) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1019
      if ( res /= 1019) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghWpAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2684
      if ( res /= 2684) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_Z, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2208
      if ( res /= 2208) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3265
      if ( res /= 3265) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_eMinus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1632
      if ( res /= 1632) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3857
      if ( res /= 3857) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3178
      if ( res /= 3178) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghZAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2395
      if ( res /= 2395) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3022
      if ( res /= 3022) then
        stop
      end if
      call createParticleConfig(P_Hl, P_dAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2205
      if ( res /= 2205) then
        stop
      end if
      call createParticleConfig(P_b, P_Z, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1678
      if ( res /= 1678) then
        stop
      end if
      call createParticleConfig(P_d, P_dAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",125
      if ( res /= 125) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_WPlus, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1121
      if ( res /= 1121) then
        stop
      end if
      call createParticleConfig(P_ghAAnti, P_WMinus, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",231
      if ( res /= 231) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",871
      if ( res /= 871) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",207
      if ( res /= 207) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",175
      if ( res /= 175) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1726
      if ( res /= 1726) then
        stop
      end if
      call createParticleConfig(P_d, P_uAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",524
      if ( res /= 524) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3404
      if ( res /= 3404) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2466
      if ( res /= 2466) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2345
      if ( res /= 2345) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_nu_mu, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2401
      if ( res /= 2401) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WPlus, P_GMinus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1194
      if ( res /= 1194) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_WMinus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1940
      if ( res /= 1940) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",388
      if ( res /= 388) then
        stop
      end if
      call createParticleConfig(P_b, P_tAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",53
      if ( res /= 53) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3712
      if ( res /= 3712) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2535
      if ( res /= 2535) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2661
      if ( res /= 2661) then
        stop
      end if
      call createParticleConfig(P_u, P_HMinus, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1047
      if ( res /= 1047) then
        stop
      end if
      call createParticleConfig(P_ghAAnti, P_ghWp, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",969
      if ( res /= 969) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2866
      if ( res /= 2866) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_WPlus, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2611
      if ( res /= 2611) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",727
      if ( res /= 727) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1643
      if ( res /= 1643) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3394
      if ( res /= 3394) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",483
      if ( res /= 483) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghA, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",232
      if ( res /= 232) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",734
      if ( res /= 734) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2815
      if ( res /= 2815) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2360
      if ( res /= 2360) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3780
      if ( res /= 3780) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3455
      if ( res /= 3455) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3588
      if ( res /= 3588) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HPlus, P_WMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3496
      if ( res /= 3496) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3459
      if ( res /= 3459) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1430
      if ( res /= 1430) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2832
      if ( res /= 2832) then
        stop
      end if
      call createParticleConfig(P_G0, P_b, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",474
      if ( res /= 474) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2729
      if ( res /= 2729) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1030
      if ( res /= 1030) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3152
      if ( res /= 3152) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_ePlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",771
      if ( res /= 771) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GMinus, P_GPlus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1320
      if ( res /= 1320) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2698
      if ( res /= 2698) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3666
      if ( res /= 3666) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_GPlus, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2525
      if ( res /= 2525) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_nu_tau, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1792
      if ( res /= 1792) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1117
      if ( res /= 1117) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1515
      if ( res /= 1515) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",707
      if ( res /= 707) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3592
      if ( res /= 3592) then
        stop
      end if
      call createParticleConfig(P_Hh, P_ghWmAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1807
      if ( res /= 1807) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1640
      if ( res /= 1640) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",368
      if ( res /= 368) then
        stop
      end if
      call createParticleConfig(P_ghAAnti, P_ghWm, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",882
      if ( res /= 882) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2889
      if ( res /= 2889) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1271
      if ( res /= 1271) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3415
      if ( res /= 3415) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2092
      if ( res /= 2092) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_Ha, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",59
      if ( res /= 59) then
        stop
      end if
      call createParticleConfig(P_Hl, P_ghWpAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2184
      if ( res /= 2184) then
        stop
      end if
      call createParticleConfig(P_Ha, P_dAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2016
      if ( res /= 2016) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_Z, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",159
      if ( res /= 159) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2817
      if ( res /= 2817) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2939
      if ( res /= 2939) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1429
      if ( res /= 1429) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2595
      if ( res /= 2595) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1852
      if ( res /= 1852) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2674
      if ( res /= 2674) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1449
      if ( res /= 1449) then
        stop
      end if
      call createParticleConfig(P_b, P_WPlus, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2254
      if ( res /= 2254) then
        stop
      end if
      call createParticleConfig(P_A, P_nu_e, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2920
      if ( res /= 2920) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_c, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1910
      if ( res /= 1910) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_t, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",857
      if ( res /= 857) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2073
      if ( res /= 2073) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2997
      if ( res /= 2997) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",363
      if ( res /= 363) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2588
      if ( res /= 2588) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",758
      if ( res /= 758) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2442
      if ( res /= 2442) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1819
      if ( res /= 1819) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1689
      if ( res /= 1689) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2249
      if ( res /= 2249) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2796
      if ( res /= 2796) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1948
      if ( res /= 1948) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_eMinus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",683
      if ( res /= 683) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_WPlus, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2230
      if ( res /= 2230) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3197
      if ( res /= 3197) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1068
      if ( res /= 1068) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3643
      if ( res /= 3643) then
        stop
      end if
      call createParticleConfig(P_c, P_cAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",469
      if ( res /= 469) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3110
      if ( res /= 3110) then
        stop
      end if
      call createParticleConfig(P_Hl, P_ghWm, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1800
      if ( res /= 1800) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3057
      if ( res /= 3057) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2012
      if ( res /= 2012) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1636
      if ( res /= 1636) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2713
      if ( res /= 2713) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2033
      if ( res /= 2033) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2519
      if ( res /= 2519) then
        stop
      end if
      call createParticleConfig(P_g, P_Hl, P_g, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3718
      if ( res /= 3718) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1972
      if ( res /= 1972) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1877
      if ( res /= 1877) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3025
      if ( res /= 3025) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1878
      if ( res /= 1878) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3290
      if ( res /= 3290) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1111
      if ( res /= 1111) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3352
      if ( res /= 3352) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1848
      if ( res /= 1848) then
        stop
      end if
      call createParticleConfig(P_Ha, P_ePlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2327
      if ( res /= 2327) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_sAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2474
      if ( res /= 2474) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3199
      if ( res /= 3199) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2539
      if ( res /= 2539) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1417
      if ( res /= 1417) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",555
      if ( res /= 555) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_tauMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2578
      if ( res /= 2578) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",895
      if ( res /= 895) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3161
      if ( res /= 3161) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",486
      if ( res /= 486) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_g, P_HPlus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3698
      if ( res /= 3698) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_ghZ, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2740
      if ( res /= 2740) then
        stop
      end if
      call createParticleConfig(P_A, P_ghWpAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1240
      if ( res /= 1240) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1611
      if ( res /= 1611) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_Hh, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",143
      if ( res /= 143) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1988
      if ( res /= 1988) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_tauPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2501
      if ( res /= 2501) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1979
      if ( res /= 1979) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1198
      if ( res /= 1198) then
        stop
      end if
      call createParticleConfig(P_g, P_Z, P_A, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3689
      if ( res /= 3689) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_nu_e, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",162
      if ( res /= 162) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",868
      if ( res /= 868) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3055
      if ( res /= 3055) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1575
      if ( res /= 1575) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1269
      if ( res /= 1269) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1576
      if ( res /= 1576) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_Ha, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",119
      if ( res /= 119) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3233
      if ( res /= 3233) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2396
      if ( res /= 2396) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",491
      if ( res /= 491) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2738
      if ( res /= 2738) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1927
      if ( res /= 1927) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2858
      if ( res /= 2858) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_Z, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1415
      if ( res /= 1415) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3206
      if ( res /= 3206) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3434
      if ( res /= 3434) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2506
      if ( res /= 2506) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_g, P_HPlus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3738
      if ( res /= 3738) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1909
      if ( res /= 1909) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3729
      if ( res /= 3729) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",102
      if ( res /= 102) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3279
      if ( res /= 3279) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3399
      if ( res /= 3399) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_Ha, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",638
      if ( res /= 638) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3442
      if ( res /= 3442) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1460
      if ( res /= 1460) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3518
      if ( res /= 3518) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1204
      if ( res /= 1204) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2324
      if ( res /= 2324) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1446
      if ( res /= 1446) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2970
      if ( res /= 2970) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2574
      if ( res /= 2574) then
        stop
      end if
      call createParticleConfig(P_A, P_tAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2543
      if ( res /= 2543) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1657
      if ( res /= 1657) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2234
      if ( res /= 2234) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2286
      if ( res /= 2286) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2898
      if ( res /= 2898) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_Ha, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2180
      if ( res /= 2180) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",728
      if ( res /= 728) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1007
      if ( res /= 1007) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1884
      if ( res /= 1884) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",221
      if ( res /= 221) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",790
      if ( res /= 790) then
        stop
      end if
      call createParticleConfig(P_Z, P_d, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1861
      if ( res /= 1861) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1793
      if ( res /= 1793) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1378
      if ( res /= 1378) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3338
      if ( res /= 3338) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2727
      if ( res /= 2727) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1056
      if ( res /= 1056) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1546
      if ( res /= 1546) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3027
      if ( res /= 3027) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_d, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",445
      if ( res /= 445) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3136
      if ( res /= 3136) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3184
      if ( res /= 3184) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_ePlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1110
      if ( res /= 1110) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1755
      if ( res /= 1755) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghZ, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1764
      if ( res /= 1764) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1159
      if ( res /= 1159) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3565
      if ( res /= 3565) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",449
      if ( res /= 449) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_c, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",945
      if ( res /= 945) then
        stop
      end if
      call createParticleConfig(P_g, P_c, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",870
      if ( res /= 870) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1622
      if ( res /= 1622) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3169
      if ( res /= 3169) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghWp, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",414
      if ( res /= 414) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3388
      if ( res /= 3388) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2472
      if ( res /= 2472) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2933
      if ( res /= 2933) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3208
      if ( res /= 3208) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",976
      if ( res /= 976) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3775
      if ( res /= 3775) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",196
      if ( res /= 196) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3377
      if ( res /= 3377) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1223
      if ( res /= 1223) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",523
      if ( res /= 523) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_WPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1201
      if ( res /= 1201) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3009
      if ( res /= 3009) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2529
      if ( res /= 2529) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3056
      if ( res /= 3056) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2393
      if ( res /= 2393) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_d, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2293
      if ( res /= 2293) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1296
      if ( res /= 1296) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",472
      if ( res /= 472) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghWm, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1495
      if ( res /= 1495) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1163
      if ( res /= 1163) then
        stop
      end if
      call createParticleConfig(P_s, P_Hh, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1888
      if ( res /= 1888) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2253
      if ( res /= 2253) then
        stop
      end if
      call createParticleConfig(P_A, P_nu_tauAnti, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3037
      if ( res /= 3037) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2235
      if ( res /= 2235) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_ghWp, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2890
      if ( res /= 2890) then
        stop
      end if
      call createParticleConfig(P_A, P_nu_tau, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2850
      if ( res /= 2850) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3281
      if ( res /= 3281) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1747
      if ( res /= 1747) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2307
      if ( res /= 2307) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3044
      if ( res /= 3044) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_ghZAnti, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",397
      if ( res /= 397) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2601
      if ( res /= 2601) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1249
      if ( res /= 1249) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3747
      if ( res /= 3747) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_nu_e, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1106
      if ( res /= 1106) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",240
      if ( res /= 240) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1243
      if ( res /= 1243) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1644
      if ( res /= 1644) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3644
      if ( res /= 3644) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1917
      if ( res /= 1917) then
        stop
      end if
      call createParticleConfig(P_A, P_t, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1708
      if ( res /= 1708) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",419
      if ( res /= 419) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",876
      if ( res /= 876) then
        stop
      end if
      call createParticleConfig(P_b, P_G0, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2373
      if ( res /= 2373) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_GMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",381
      if ( res /= 381) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1963
      if ( res /= 1963) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1241
      if ( res /= 1241) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2201
      if ( res /= 2201) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2602
      if ( res /= 2602) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",6
      if ( res /= 6) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_Z, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1288
      if ( res /= 1288) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2610
      if ( res /= 2610) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3576
      if ( res /= 3576) then
        stop
      end if
      call createParticleConfig(P_Z, P_s, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1835
      if ( res /= 1835) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_WMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",209
      if ( res /= 209) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_Z, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",775
      if ( res /= 775) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_HMinus, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",821
      if ( res /= 821) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2633
      if ( res /= 2633) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghZAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",480
      if ( res /= 480) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HPlus, P_GMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1206
      if ( res /= 1206) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",623
      if ( res /= 623) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3678
      if ( res /= 3678) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1375
      if ( res /= 1375) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3157
      if ( res /= 3157) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_s, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",936
      if ( res /= 936) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1210
      if ( res /= 1210) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3788
      if ( res /= 3788) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3303
      if ( res /= 3303) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2085
      if ( res /= 2085) then
        stop
      end if
      call createParticleConfig(P_A, P_g, P_Z, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3827
      if ( res /= 3827) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",13
      if ( res /= 13) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WPlus, P_WMinus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",406
      if ( res /= 406) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1333
      if ( res /= 1333) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",640
      if ( res /= 640) then
        stop
      end if
      call createParticleConfig(P_Ha, P_uAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2161
      if ( res /= 2161) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_Hl, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",814
      if ( res /= 814) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2061
      if ( res /= 2061) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2105
      if ( res /= 2105) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2653
      if ( res /= 2653) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_t, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1669
      if ( res /= 1669) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1217
      if ( res /= 1217) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3078
      if ( res /= 3078) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3741
      if ( res /= 3741) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1586
      if ( res /= 1586) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1055
      if ( res /= 1055) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3200
      if ( res /= 3200) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2225
      if ( res /= 2225) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_ghZ, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2044
      if ( res /= 2044) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",220
      if ( res /= 220) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1675
      if ( res /= 1675) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",770
      if ( res /= 770) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",736
      if ( res /= 736) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",331
      if ( res /= 331) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3365
      if ( res /= 3365) then
        stop
      end if
      call createParticleConfig(P_t, P_tAnti, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2243
      if ( res /= 2243) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",532
      if ( res /= 532) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3603
      if ( res /= 3603) then
        stop
      end if
      call createParticleConfig(P_t, P_Ha, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2459
      if ( res /= 2459) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1420
      if ( res /= 1420) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghWp, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",271
      if ( res /= 271) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",470
      if ( res /= 470) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_ePlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",116
      if ( res /= 116) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3234
      if ( res /= 3234) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",272
      if ( res /= 272) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2518
      if ( res /= 2518) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",489
      if ( res /= 489) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2144
      if ( res /= 2144) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HPlus, P_HMinus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2392
      if ( res /= 2392) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2421
      if ( res /= 2421) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",961
      if ( res /= 961) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_WMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3487
      if ( res /= 3487) then
        stop
      end if
      call createParticleConfig(P_Hl, P_tauPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",16
      if ( res /= 16) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",201
      if ( res /= 201) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_u, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1260
      if ( res /= 1260) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",79
      if ( res /= 79) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",541
      if ( res /= 541) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",607
      if ( res /= 607) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",984
      if ( res /= 984) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",30
      if ( res /= 30) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",957
      if ( res /= 957) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghZAnti, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2154
      if ( res /= 2154) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3397
      if ( res /= 3397) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",126
      if ( res /= 126) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1457
      if ( res /= 1457) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghWpAnti, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1775
      if ( res /= 1775) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3203
      if ( res /= 3203) then
        stop
      end if
      call createParticleConfig(P_g, P_Hl, P_Hh, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3630
      if ( res /= 3630) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_Z, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",556
      if ( res /= 556) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1661
      if ( res /= 1661) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2880
      if ( res /= 2880) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3759
      if ( res /= 3759) then
        stop
      end if
      call createParticleConfig(P_Z, P_g, P_g, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3645
      if ( res /= 3645) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WMinus, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2354
      if ( res /= 2354) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1392
      if ( res /= 1392) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3541
      if ( res /= 3541) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WPlus, P_GMinus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3385
      if ( res /= 3385) then
        stop
      end if
      call createParticleConfig(P_G0, P_u, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2178
      if ( res /= 2178) then
        stop
      end if
      call createParticleConfig(P_u, P_WMinus, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",988
      if ( res /= 988) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2778
      if ( res /= 2778) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3293
      if ( res /= 3293) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",713
      if ( res /= 713) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",283
      if ( res /= 283) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",540
      if ( res /= 540) then
        stop
      end if
      call createParticleConfig(P_ghG, P_g, P_ghGAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1823
      if ( res /= 1823) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3107
      if ( res /= 3107) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",863
      if ( res /= 863) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1569
      if ( res /= 1569) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_ghZAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2663
      if ( res /= 2663) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3179
      if ( res /= 3179) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",120
      if ( res /= 120) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1853
      if ( res /= 1853) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_HMinus, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",243
      if ( res /= 243) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_Z, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",158
      if ( res /= 158) then
        stop
      end if
      call createParticleConfig(P_A, P_g, P_g, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3610
      if ( res /= 3610) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2819
      if ( res /= 2819) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_nu_mu, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2429
      if ( res /= 2429) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",330
      if ( res /= 330) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",502
      if ( res /= 502) then
        stop
      end if
      call createParticleConfig(P_A, P_bAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1215
      if ( res /= 1215) then
        stop
      end if
      call createParticleConfig(P_g, P_HMinus, P_HPlus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3814
      if ( res /= 3814) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghWm, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2489
      if ( res /= 2489) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",184
      if ( res /= 184) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3464
      if ( res /= 3464) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",269
      if ( res /= 269) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2790
      if ( res /= 2790) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3381
      if ( res /= 3381) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_nu_tauAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1680
      if ( res /= 1680) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_WMinus, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2138
      if ( res /= 2138) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2323
      if ( res /= 2323) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",745
      if ( res /= 745) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1809
      if ( res /= 1809) then
        stop
      end if
      call createParticleConfig(P_Hl, P_tauMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",797
      if ( res /= 797) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3359
      if ( res /= 3359) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghWpAnti, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3425
      if ( res /= 3425) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3142
      if ( res /= 3142) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HMinus, P_GPlus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2422
      if ( res /= 2422) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghZ, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",560
      if ( res /= 560) then
        stop
      end if
      call createParticleConfig(P_g, P_Ha, P_Ha, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3634
      if ( res /= 3634) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",924
      if ( res /= 924) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2319
      if ( res /= 2319) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",463
      if ( res /= 463) then
        stop
      end if
      call createParticleConfig(P_g, P_Z, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3702
      if ( res /= 3702) then
        stop
      end if
      call createParticleConfig(P_Z, P_tauMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1245
      if ( res /= 1245) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3525
      if ( res /= 3525) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HMinus, P_HPlus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",122
      if ( res /= 122) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HPlus, P_HMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",104
      if ( res /= 104) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghWpAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",565
      if ( res /= 565) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1367
      if ( res /= 1367) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2648
      if ( res /= 2648) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",546
      if ( res /= 546) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2709
      if ( res /= 2709) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1610
      if ( res /= 1610) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",129
      if ( res /= 129) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1431
      if ( res /= 1431) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1794
      if ( res /= 1794) then
        stop
      end if
      call createParticleConfig(P_Ha, P_eMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",360
      if ( res /= 360) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_GMinus, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2532
      if ( res /= 2532) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3329
      if ( res /= 3329) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2576
      if ( res /= 2576) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1554
      if ( res /= 1554) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3555
      if ( res /= 3555) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2239
      if ( res /= 2239) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_g, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1846
      if ( res /= 1846) then
        stop
      end if
      call createParticleConfig(P_G0, P_tauMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2409
      if ( res /= 2409) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3681
      if ( res /= 3681) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2669
      if ( res /= 2669) then
        stop
      end if
      call createParticleConfig(P_G0, P_s, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1906
      if ( res /= 1906) then
        stop
      end if
      call createParticleConfig(P_g, P_ghG, P_ghGAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1072
      if ( res /= 1072) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1566
      if ( res /= 1566) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3842
      if ( res /= 3842) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1933
      if ( res /= 1933) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_WPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",302
      if ( res /= 302) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1412
      if ( res /= 1412) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_b, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1871
      if ( res /= 1871) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1699
      if ( res /= 1699) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1739
      if ( res /= 1739) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3138
      if ( res /= 3138) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",867
      if ( res /= 867) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1639
      if ( res /= 1639) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3297
      if ( res /= 3297) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_muPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",786
      if ( res /= 786) then
        stop
      end if
      call createParticleConfig(P_ghAAnti, P_WPlus, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2495
      if ( res /= 2495) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3493
      if ( res /= 3493) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3003
      if ( res /= 3003) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_HMinus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",389
      if ( res /= 389) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1151
      if ( res /= 1151) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_nu_tau, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1176
      if ( res /= 1176) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GPlus, P_HMinus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",628
      if ( res /= 628) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",444
      if ( res /= 444) then
        stop
      end if
      call createParticleConfig(P_Z, P_g, P_A, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3774
      if ( res /= 3774) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_t, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2498
      if ( res /= 2498) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_nu_muAnti, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",139
      if ( res /= 139) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",665
      if ( res /= 665) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3587
      if ( res /= 3587) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",437
      if ( res /= 437) then
        stop
      end if
      call createParticleConfig(P_Hh, P_tauMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2127
      if ( res /= 2127) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1452
      if ( res /= 1452) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",317
      if ( res /= 317) then
        stop
      end if
      call createParticleConfig(P_b, P_bAnti, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",840
      if ( res /= 840) then
        stop
      end if
      call createParticleConfig(P_s, P_G0, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1703
      if ( res /= 1703) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1737
      if ( res /= 1737) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1363
      if ( res /= 1363) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3520
      if ( res /= 3520) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2547
      if ( res /= 2547) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_ghWp, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",716
      if ( res /= 716) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1796
      if ( res /= 1796) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1533
      if ( res /= 1533) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_Ha, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2918
      if ( res /= 2918) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1560
      if ( res /= 1560) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_WPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3369
      if ( res /= 3369) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",383
      if ( res /= 383) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_tauMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",805
      if ( res /= 805) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_nu_eAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3264
      if ( res /= 3264) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",933
      if ( res /= 933) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2870
      if ( res /= 2870) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",50
      if ( res /= 50) then
        stop
      end if
      call createParticleConfig(P_t, P_bAnti, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1281
      if ( res /= 1281) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2340
      if ( res /= 2340) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2047
      if ( res /= 2047) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",841
      if ( res /= 841) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3302
      if ( res /= 3302) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",596
      if ( res /= 596) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",41
      if ( res /= 41) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2170
      if ( res /= 2170) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1494
      if ( res /= 1494) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3013
      if ( res /= 3013) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3816
      if ( res /= 3816) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2468
      if ( res /= 2468) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3256
      if ( res /= 3256) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2794
      if ( res /= 2794) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3147
      if ( res /= 3147) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1183
      if ( res /= 1183) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2617
      if ( res /= 2617) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",939
      if ( res /= 939) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2969
      if ( res /= 2969) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",282
      if ( res /= 282) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3733
      if ( res /= 3733) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",23
      if ( res /= 23) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2664
      if ( res /= 2664) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3285
      if ( res /= 3285) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3730
      if ( res /= 3730) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_Hh, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1840
      if ( res /= 1840) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1444
      if ( res /= 1444) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3509
      if ( res /= 3509) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2048
      if ( res /= 2048) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2798
      if ( res /= 2798) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Ha, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2925
      if ( res /= 2925) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",982
      if ( res /= 982) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WPlus, P_WMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3277
      if ( res /= 3277) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",288
      if ( res /= 288) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3409
      if ( res /= 3409) then
        stop
      end if
      call createParticleConfig(P_Z, P_ghWp, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2552
      if ( res /= 2552) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1903
      if ( res /= 1903) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2868
      if ( res /= 2868) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1230
      if ( res /= 1230) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",515
      if ( res /= 515) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_A, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2145
      if ( res /= 2145) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2090
      if ( res /= 2090) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3257
      if ( res /= 3257) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",362
      if ( res /= 362) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2856
      if ( res /= 2856) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",834
      if ( res /= 834) then
        stop
      end if
      call createParticleConfig(P_c, P_WMinus, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1091
      if ( res /= 1091) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2193
      if ( res /= 2193) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2504
      if ( res /= 2504) then
        stop
      end if
      call createParticleConfig(P_g, P_GPlus, P_g, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3709
      if ( res /= 3709) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",323
      if ( res /= 323) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",163
      if ( res /= 163) then
        stop
      end if
      call createParticleConfig(P_s, P_sAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",407
      if ( res /= 407) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2229
      if ( res /= 2229) then
        stop
      end if
      call createParticleConfig(P_Ha, P_s, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2470
      if ( res /= 2470) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2619
      if ( res /= 2619) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2770
      if ( res /= 2770) then
        stop
      end if
      call createParticleConfig(P_t, P_tAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1590
      if ( res /= 1590) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2367
      if ( res /= 2367) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_ghA, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",322
      if ( res /= 322) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",387
      if ( res /= 387) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1221
      if ( res /= 1221) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3519
      if ( res /= 3519) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",411
      if ( res /= 411) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3014
      if ( res /= 3014) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3041
      if ( res /= 3041) then
        stop
      end if
      call createParticleConfig(P_Hl, P_g, P_Hh, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3834
      if ( res /= 3834) then
        stop
      end if
      call createParticleConfig(P_Hl, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3619
      if ( res /= 3619) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3389
      if ( res /= 3389) then
        stop
      end if
      call createParticleConfig(P_Z, P_bAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2074
      if ( res /= 2074) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1811
      if ( res /= 1811) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2387
      if ( res /= 2387) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2414
      if ( res /= 2414) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",700
      if ( res /= 700) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1593
      if ( res /= 1593) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2564
      if ( res /= 2564) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1470
      if ( res /= 1470) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1060
      if ( res /= 1060) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3066
      if ( res /= 3066) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2032
      if ( res /= 2032) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",71
      if ( res /= 71) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghWp, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",226
      if ( res /= 226) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",128
      if ( res /= 128) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",570
      if ( res /= 570) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_b, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2672
      if ( res /= 2672) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_Hh, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1359
      if ( res /= 1359) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3792
      if ( res /= 3792) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2808
      if ( res /= 2808) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",543
      if ( res /= 543) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2096
      if ( res /= 2096) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3440
      if ( res /= 3440) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",366
      if ( res /= 366) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3092
      if ( res /= 3092) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_t, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1219
      if ( res /= 1219) then
        stop
      end if
      call createParticleConfig(P_A, P_uAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2117
      if ( res /= 2117) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1777
      if ( res /= 1777) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",594
      if ( res /= 594) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",182
      if ( res /= 182) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2420
      if ( res /= 2420) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_HPlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2100
      if ( res /= 2100) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",827
      if ( res /= 827) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",934
      if ( res /= 934) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3165
      if ( res /= 3165) then
        stop
      end if
      call createParticleConfig(P_Z, P_g, P_Z, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3624
      if ( res /= 3624) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3396
      if ( res /= 3396) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",98
      if ( res /= 98) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1300
      if ( res /= 1300) then
        stop
      end if
      call createParticleConfig(P_b, P_A, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2675
      if ( res /= 2675) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_nu_eAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",915
      if ( res /= 915) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2106
      if ( res /= 2106) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3289
      if ( res /= 3289) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3435
      if ( res /= 3435) then
        stop
      end if
      call createParticleConfig(P_s, P_g, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2627
      if ( res /= 2627) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3174
      if ( res /= 3174) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2365
      if ( res /= 2365) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",862
      if ( res /= 862) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2128
      if ( res /= 2128) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",615
      if ( res /= 615) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",832
      if ( res /= 832) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3255
      if ( res /= 3255) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1172
      if ( res /= 1172) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2488
      if ( res /= 2488) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1344
      if ( res /= 1344) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2550
      if ( res /= 2550) then
        stop
      end if
      call createParticleConfig(P_A, P_g, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3690
      if ( res /= 3690) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2962
      if ( res /= 2962) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3242
      if ( res /= 3242) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_GMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1734
      if ( res /= 1734) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2965
      if ( res /= 2965) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",580
      if ( res /= 580) then
        stop
      end if
      call createParticleConfig(P_b, P_Hh, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1768
      if ( res /= 1768) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3848
      if ( res /= 3848) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1263
      if ( res /= 1263) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3552
      if ( res /= 3552) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2885
      if ( res /= 2885) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2717
      if ( res /= 2717) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3501
      if ( res /= 3501) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Ha, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",600
      if ( res /= 600) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2872
      if ( res /= 2872) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1503
      if ( res /= 1503) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_HMinus, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3305
      if ( res /= 3305) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",597
      if ( res /= 597) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1250
      if ( res /= 1250) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3407
      if ( res /= 3407) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3076
      if ( res /= 3076) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",836
      if ( res /= 836) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3544
      if ( res /= 3544) then
        stop
      end if
      call createParticleConfig(P_s, P_sAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",823
      if ( res /= 823) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3058
      if ( res /= 3058) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3077
      if ( res /= 3077) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1175
      if ( res /= 1175) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3559
      if ( res /= 3559) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2900
      if ( res /= 2900) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",944
      if ( res /= 944) then
        stop
      end if
      call createParticleConfig(P_Z, P_ghWm, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2281
      if ( res /= 2281) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2540
      if ( res /= 2540) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",264
      if ( res /= 264) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",224
      if ( res /= 224) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1009
      if ( res /= 1009) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",183
      if ( res /= 183) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1282
      if ( res /= 1282) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",213
      if ( res /= 213) then
        stop
      end if
      call createParticleConfig(P_g, P_d, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",373
      if ( res /= 373) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_ghWpAnti, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2837
      if ( res /= 2837) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1025
      if ( res /= 1025) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3761
      if ( res /= 3761) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1509
      if ( res /= 1509) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3468
      if ( res /= 3468) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_ghWm, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3063
      if ( res /= 3063) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_g, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",999
      if ( res /= 999) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2238
      if ( res /= 2238) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2915
      if ( res /= 2915) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2123
      if ( res /= 2123) then
        stop
      end if
      call createParticleConfig(P_A, P_cAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2220
      if ( res /= 2220) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",787
      if ( res /= 787) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GPlus, P_HMinus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",295
      if ( res /= 295) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",392
      if ( res /= 392) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",587
      if ( res /= 587) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",431
      if ( res /= 431) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3803
      if ( res /= 3803) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2577
      if ( res /= 2577) then
        stop
      end if
      call createParticleConfig(P_A, P_nu_muAnti, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3334
      if ( res /= 3334) then
        stop
      end if
      call createParticleConfig(P_g, P_tAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1926
      if ( res /= 1926) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_WPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3278
      if ( res /= 3278) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_g, P_g, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3860
      if ( res /= 3860) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2530
      if ( res /= 2530) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3754
      if ( res /= 3754) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2269
      if ( res /= 2269) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_Hl, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",844
      if ( res /= 844) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",847
      if ( res /= 847) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3866
      if ( res /= 3866) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2922
      if ( res /= 2922) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3589
      if ( res /= 3589) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghWmAnti, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2135
      if ( res /= 2135) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1404
      if ( res /= 1404) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3813
      if ( res /= 3813) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3667
      if ( res /= 3667) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3876
      if ( res /= 3876) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3657
      if ( res /= 3657) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_s, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",49
      if ( res /= 49) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1259
      if ( res /= 1259) then
        stop
      end if
      call createParticleConfig(P_t, P_g, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2139
      if ( res /= 2139) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3373
      if ( res /= 3373) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",921
      if ( res /= 921) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2378
      if ( res /= 2378) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3836
      if ( res /= 3836) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghA, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1041
      if ( res /= 1041) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3292
      if ( res /= 3292) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2116
      if ( res /= 2116) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3536
      if ( res /= 3536) then
        stop
      end if
      call createParticleConfig(P_ghG, P_ghGAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1218
      if ( res /= 1218) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",705
      if ( res /= 705) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1832
      if ( res /= 1832) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1789
      if ( res /= 1789) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3791
      if ( res /= 3791) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1538
      if ( res /= 1538) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2190
      if ( res /= 2190) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1666
      if ( res /= 1666) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2765
      if ( res /= 2765) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1758
      if ( res /= 1758) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1953
      if ( res /= 1953) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3527
      if ( res /= 3527) then
        stop
      end if
      call createParticleConfig(P_ghA, P_WPlus, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1750
      if ( res /= 1750) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",960
      if ( res /= 960) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3483
      if ( res /= 3483) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",228
      if ( res /= 228) then
        stop
      end if
      call createParticleConfig(P_Hl, P_d, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",608
      if ( res /= 608) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",751
      if ( res /= 751) then
        stop
      end if
      call createParticleConfig(P_Hh, P_eMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1864
      if ( res /= 1864) then
        stop
      end if
      call createParticleConfig(P_u, P_Hh, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2277
      if ( res /= 2277) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2824
      if ( res /= 2824) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",488
      if ( res /= 488) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1188
      if ( res /= 1188) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_WMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1772
      if ( res /= 1772) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",815
      if ( res /= 815) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2520
      if ( res /= 2520) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",377
      if ( res /= 377) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2377
      if ( res /= 2377) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_G0, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",666
      if ( res /= 666) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",967
      if ( res /= 967) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2400
      if ( res /= 2400) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2080
      if ( res /= 2080) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2011
      if ( res /= 2011) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1802
      if ( res /= 1802) then
        stop
      end if
      call createParticleConfig(P_A, P_ghWmAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1482
      if ( res /= 1482) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3864
      if ( res /= 3864) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1324
      if ( res /= 1324) then
        stop
      end if
      call createParticleConfig(P_Hh, P_dAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2587
      if ( res /= 2587) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2644
      if ( res /= 2644) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2612
      if ( res /= 2612) then
        stop
      end if
      call createParticleConfig(P_Hl, P_ghZAnti, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",718
      if ( res /= 718) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3824
      if ( res /= 3824) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_WMinus, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",166
      if ( res /= 166) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3812
      if ( res /= 3812) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2722
      if ( res /= 2722) then
        stop
      end if
      call createParticleConfig(P_d, P_Hl, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1391
      if ( res /= 1391) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3849
      if ( res /= 3849) then
        stop
      end if
      call createParticleConfig(P_Hl, P_u, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",365
      if ( res /= 365) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3815
      if ( res /= 3815) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2614
      if ( res /= 2614) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1842
      if ( res /= 1842) then
        stop
      end if
      call createParticleConfig(P_Hl, P_ghWp, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2051
      if ( res /= 2051) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3246
      if ( res /= 3246) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2175
      if ( res /= 2175) then
        stop
      end if
      call createParticleConfig(P_Z, P_b, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1698
      if ( res /= 1698) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1697
      if ( res /= 1697) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2721
      if ( res /= 2721) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1423
      if ( res /= 1423) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_Hl, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1279
      if ( res /= 1279) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1627
      if ( res /= 1627) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3144
      if ( res /= 3144) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2023
      if ( res /= 2023) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1384
      if ( res /= 1384) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WMinus, P_HPlus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",25
      if ( res /= 25) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",429
      if ( res /= 429) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",420
      if ( res /= 420) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_nu_e, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",305
      if ( res /= 305) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2974
      if ( res /= 2974) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1492
      if ( res /= 1492) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",822
      if ( res /= 822) then
        stop
      end if
      call createParticleConfig(P_g, P_u, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1798
      if ( res /= 1798) then
        stop
      end if
      call createParticleConfig(P_d, P_WPlus, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1469
      if ( res /= 1469) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3523
      if ( res /= 3523) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_A, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",631
      if ( res /= 631) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1855
      if ( res /= 1855) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",101
      if ( res /= 101) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2859
      if ( res /= 2859) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3079
      if ( res /= 3079) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",479
      if ( res /= 479) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2126
      if ( res /= 2126) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_Z, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2315
      if ( res /= 2315) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_GPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2295
      if ( res /= 2295) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1729
      if ( res /= 1729) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3386
      if ( res /= 3386) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_g, P_WMinus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3725
      if ( res /= 3725) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",769
      if ( res /= 769) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2110
      if ( res /= 2110) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",920
      if ( res /= 920) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2977
      if ( res /= 2977) then
        stop
      end if
      call createParticleConfig(P_g, P_Hl, P_g, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3658
      if ( res /= 3658) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2399
      if ( res /= 2399) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1100
      if ( res /= 1100) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1727
      if ( res /= 1727) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1332
      if ( res /= 1332) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",731
      if ( res /= 731) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_Ha, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3507
      if ( res /= 3507) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",500
      if ( res /= 500) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_Ha, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1063
      if ( res /= 1063) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3175
      if ( res /= 3175) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_s, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",191
      if ( res /= 191) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3060
      if ( res /= 3060) then
        stop
      end if
      call createParticleConfig(P_g, P_HMinus, P_g, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3605
      if ( res /= 3605) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_muPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",108
      if ( res /= 108) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",856
      if ( res /= 856) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2987
      if ( res /= 2987) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",199
      if ( res /= 199) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1925
      if ( res /= 1925) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2780
      if ( res /= 2780) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_ePlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2416
      if ( res /= 2416) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",244
      if ( res /= 244) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",304
      if ( res /= 304) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2523
      if ( res /= 2523) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",985
      if ( res /= 985) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GPlus, P_WMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1784
      if ( res /= 1784) then
        stop
      end if
      call createParticleConfig(P_s, P_sAnti, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",141
      if ( res /= 141) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",691
      if ( res /= 691) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2069
      if ( res /= 2069) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_ePlus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",624
      if ( res /= 624) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1113
      if ( res /= 1113) then
        stop
      end if
      call createParticleConfig(P_t, P_tAnti, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1883
      if ( res /= 1883) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1712
      if ( res /= 1712) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2707
      if ( res /= 2707) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3626
      if ( res /= 3626) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_ghWpAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",974
      if ( res /= 974) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",639
      if ( res /= 639) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",204
      if ( res /= 204) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_Ha, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",696
      if ( res /= 696) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",547
      if ( res /= 547) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2849
      if ( res /= 2849) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3128
      if ( res /= 3128) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghAAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",910
      if ( res /= 910) then
        stop
      end if
      call createParticleConfig(P_Ha, P_bAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",531
      if ( res /= 531) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1199
      if ( res /= 1199) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_c, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1571
      if ( res /= 1571) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_Ha, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2366
      if ( res /= 2366) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_nu_tau, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3130
      if ( res /= 3130) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_Hh, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2357
      if ( res /= 2357) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",688
      if ( res /= 688) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",490
      if ( res /= 490) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_GPlus, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2570
      if ( res /= 2570) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_ePlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",877
      if ( res /= 877) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2748
      if ( res /= 2748) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3858
      if ( res /= 3858) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1254
      if ( res /= 1254) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3535
      if ( res /= 3535) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2362
      if ( res /= 2362) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3337
      if ( res /= 3337) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3225
      if ( res /= 3225) then
        stop
      end if
      call createParticleConfig(P_A, P_g, P_A, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3594
      if ( res /= 3594) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3853
      if ( res /= 3853) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2018
      if ( res /= 2018) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2358
      if ( res /= 2358) then
        stop
      end if
      call createParticleConfig(P_A, P_sAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1961
      if ( res /= 1961) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2788
      if ( res /= 2788) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3412
      if ( res /= 3412) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1256
      if ( res /= 1256) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",817
      if ( res /= 817) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",446
      if ( res /= 446) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1769
      if ( res /= 1769) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1501
      if ( res /= 1501) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2972
      if ( res /= 2972) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_c, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1239
      if ( res /= 1239) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1477
      if ( res /= 1477) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3043
      if ( res /= 3043) then
        stop
      end if
      call createParticleConfig(P_d, P_dAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",923
      if ( res /= 923) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Ha, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2714
      if ( res /= 2714) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_Ha, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1405
      if ( res /= 1405) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2984
      if ( res /= 2984) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_tauPlus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",703
      if ( res /= 703) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",606
      if ( res /= 606) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2313
      if ( res /= 2313) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",574
      if ( res /= 574) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1353
      if ( res /= 1353) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3822
      if ( res /= 3822) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2403
      if ( res /= 2403) then
        stop
      end if
      call createParticleConfig(P_Hh, P_d, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1709
      if ( res /= 1709) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3473
      if ( res /= 3473) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3019
      if ( res /= 3019) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WPlus, P_WMinus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",450
      if ( res /= 450) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3153
      if ( res /= 3153) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1688
      if ( res /= 1688) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2370
      if ( res /= 2370) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_s, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",514
      if ( res /= 514) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1149
      if ( res /= 1149) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3604
      if ( res /= 3604) then
        stop
      end if
      call createParticleConfig(P_u, P_Hl, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",962
      if ( res /= 962) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3313
      if ( res /= 3313) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2191
      if ( res /= 2191) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2774
      if ( res /= 2774) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2706
      if ( res /= 2706) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_g, P_HMinus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3830
      if ( res /= 3830) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1857
      if ( res /= 1857) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_u, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",604
      if ( res /= 604) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",140
      if ( res /= 140) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",27
      if ( res /= 27) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2911
      if ( res /= 2911) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",773
      if ( res /= 773) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",914
      if ( res /= 914) then
        stop
      end if
      call createParticleConfig(P_Z, P_ghWpAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2694
      if ( res /= 2694) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2098
      if ( res /= 2098) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2927
      if ( res /= 2927) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2475
      if ( res /= 2475) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1029
      if ( res /= 1029) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1390
      if ( res /= 1390) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3273
      if ( res /= 3273) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3150
      if ( res /= 3150) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2795
      if ( res /= 2795) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1518
      if ( res /= 1518) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2827
      if ( res /= 2827) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3139
      if ( res /= 3139) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2231
      if ( res /= 2231) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3462
      if ( res /= 3462) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_G0, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",454
      if ( res /= 454) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",56
      if ( res /= 56) then
        stop
      end if
      call createParticleConfig(P_ghGAnti, P_ghG, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1821
      if ( res /= 1821) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_ghWpAnti, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3143
      if ( res /= 3143) then
        stop
      end if
      call createParticleConfig(P_Ha, P_tauMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",861
      if ( res /= 861) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2300
      if ( res /= 2300) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2130
      if ( res /= 2130) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_Z, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2306
      if ( res /= 2306) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2082
      if ( res /= 2082) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2143
      if ( res /= 2143) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WMinus, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2336
      if ( res /= 2336) then
        stop
      end if
      call createParticleConfig(P_Hl, P_g, P_Hl, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3769
      if ( res /= 3769) then
        stop
      end if
      call createParticleConfig(P_b, P_bAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",955
      if ( res /= 955) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1625
      if ( res /= 1625) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3374
      if ( res /= 3374) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3489
      if ( res /= 3489) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghWmAnti, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2668
      if ( res /= 2668) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3571
      if ( res /= 3571) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2003
      if ( res /= 2003) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2195
      if ( res /= 2195) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3547
      if ( res /= 3547) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2536
      if ( res /= 2536) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2200
      if ( res /= 2200) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WPlus, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2015
      if ( res /= 2015) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",40
      if ( res /= 40) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_g, P_GMinus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3638
      if ( res /= 3638) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",94
      if ( res /= 94) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2730
      if ( res /= 2730) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3825
      if ( res /= 3825) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_b, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2594
      if ( res /= 2594) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",194
      if ( res /= 194) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1724
      if ( res /= 1724) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1410
      if ( res /= 1410) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3411
      if ( res /= 3411) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",223
      if ( res /= 223) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_eMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2054
      if ( res /= 2054) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3420
      if ( res /= 3420) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_b, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2471
      if ( res /= 2471) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1148
      if ( res /= 1148) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1389
      if ( res /= 1389) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WPlus, P_HMinus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2280
      if ( res /= 2280) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1197
      if ( res /= 1197) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",338
      if ( res /= 338) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3276
      if ( res /= 3276) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",241
      if ( res /= 241) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_muPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",440
      if ( res /= 440) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2275
      if ( res /= 2275) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3760
      if ( res /= 3760) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_WMinus, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2241
      if ( res /= 2241) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3430
      if ( res /= 3430) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3490
      if ( res /= 3490) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3307
      if ( res /= 3307) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2097
      if ( res /= 2097) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3676
      if ( res /= 3676) then
        stop
      end if
      call createParticleConfig(P_t, P_WMinus, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1079
      if ( res /= 1079) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",251
      if ( res /= 251) then
        stop
      end if
      call createParticleConfig(P_Hl, P_c, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1253
      if ( res /= 1253) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1498
      if ( res /= 1498) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",747
      if ( res /= 747) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1995
      if ( res /= 1995) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3188
      if ( res /= 3188) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1137
      if ( res /= 1137) then
        stop
      end if
      call createParticleConfig(P_t, P_tAnti, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1543
      if ( res /= 1543) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2067
      if ( res /= 2067) then
        stop
      end if
      call createParticleConfig(P_c, P_HMinus, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1522
      if ( res /= 1522) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghWp, P_ghAAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2445
      if ( res /= 2445) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1996
      if ( res /= 1996) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1435
      if ( res /= 1435) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3471
      if ( res /= 3471) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3872
      if ( res /= 3872) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",352
      if ( res /= 352) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1598
      if ( res /= 1598) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2413
      if ( res /= 2413) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1133
      if ( res /= 1133) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2101
      if ( res /= 2101) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2375
      if ( res /= 2375) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_A, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",300
      if ( res /= 300) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2356
      if ( res /= 2356) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1653
      if ( res /= 1653) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_t, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1368
      if ( res /= 1368) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3687
      if ( res /= 3687) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",972
      if ( res /= 972) then
        stop
      end if
      call createParticleConfig(P_G0, P_t, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1804
      if ( res /= 1804) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2443
      if ( res /= 2443) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_c, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",765
      if ( res /= 765) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_Hl, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1766
      if ( res /= 1766) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_c, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2270
      if ( res /= 2270) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_g, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",294
      if ( res /= 294) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",493
      if ( res /= 493) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",926
      if ( res /= 926) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2131
      if ( res /= 2131) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2555
      if ( res /= 2555) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GMinus, P_HPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",829
      if ( res /= 829) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2402
      if ( res /= 2402) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3010
      if ( res /= 3010) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3539
      if ( res /= 3539) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2388
      if ( res /= 2388) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2424
      if ( res /= 2424) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1930
      if ( res /= 1930) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2593
      if ( res /= 2593) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3100
      if ( res /= 3100) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",124
      if ( res /= 124) then
        stop
      end if
      call createParticleConfig(P_Hh, P_ghWpAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",86
      if ( res /= 86) then
        stop
      end if
      call createParticleConfig(P_Z, P_c, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1373
      if ( res /= 1373) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3082
      if ( res /= 3082) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_WPlus, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1946
      if ( res /= 1946) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1123
      if ( res /= 1123) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",702
      if ( res /= 702) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_Hl, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",588
      if ( res /= 588) then
        stop
      end if
      call createParticleConfig(P_g, P_uAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",400
      if ( res /= 400) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3211
      if ( res /= 3211) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",236
      if ( res /= 236) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2828
      if ( res /= 2828) then
        stop
      end if
      call createParticleConfig(P_Ha, P_t, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1854
      if ( res /= 1854) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2978
      if ( res /= 2978) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2991
      if ( res /= 2991) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",561
      if ( res /= 561) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3560
      if ( res /= 3560) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3558
      if ( res /= 3558) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_G0, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1682
      if ( res /= 1682) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",380
      if ( res /= 380) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1613
      if ( res /= 1613) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2715
      if ( res /= 2715) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2599
      if ( res /= 2599) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_GMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1701
      if ( res /= 1701) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_g, P_g, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3685
      if ( res /= 3685) then
        stop
      end if
      call createParticleConfig(P_Hl, P_g, P_g, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3705
      if ( res /= 3705) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghAAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1931
      if ( res /= 1931) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",577
      if ( res /= 577) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2511
      if ( res /= 2511) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3704
      if ( res /= 3704) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_Hl, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",859
      if ( res /= 859) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1062
      if ( res /= 1062) then
        stop
      end if
      call createParticleConfig(P_Hh, P_bAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1400
      if ( res /= 1400) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_Z, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1022
      if ( res /= 1022) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_tauMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",979
      if ( res /= 979) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",83
      if ( res /= 83) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3505
      if ( res /= 3505) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",678
      if ( res /= 678) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2945
      if ( res /= 2945) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1372
      if ( res /= 1372) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_Z, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",31
      if ( res /= 31) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3288
      if ( res /= 3288) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1297
      if ( res /= 1297) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1006
      if ( res /= 1006) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_ghWpAnti, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2428
      if ( res /= 2428) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3740
      if ( res /= 3740) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2923
      if ( res /= 2923) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",899
      if ( res /= 899) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3620
      if ( res /= 3620) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1073
      if ( res /= 1073) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3677
      if ( res /= 3677) then
        stop
      end if
      call createParticleConfig(P_g, P_WMinus, P_WPlus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3717
      if ( res /= 3717) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2477
      if ( res /= 2477) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1307
      if ( res /= 1307) then
        stop
      end if
      call createParticleConfig(P_d, P_Hh, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",768
      if ( res /= 768) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",507
      if ( res /= 507) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghWp, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2218
      if ( res /= 2218) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3380
      if ( res /= 3380) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3863
      if ( res /= 3863) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",807
      if ( res /= 807) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3371
      if ( res /= 3371) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3659
      if ( res /= 3659) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",983
      if ( res /= 983) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1975
      if ( res /= 1975) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2107
      if ( res /= 2107) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_ghWmAnti, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3566
      if ( res /= 3566) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3149
      if ( res /= 3149) then
        stop
      end if
      call createParticleConfig(P_Z, P_cAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2615
      if ( res /= 2615) then
        stop
      end if
      call createParticleConfig(P_Hl, P_ghZ, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1313
      if ( res /= 1313) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_G0, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",529
      if ( res /= 529) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2301
      if ( res /= 2301) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_A, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2907
      if ( res /= 2907) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_WPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",430
      if ( res /= 430) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3826
      if ( res /= 3826) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HPlus, P_GMinus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2329
      if ( res /= 2329) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_tauPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2079
      if ( res /= 2079) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",740
      if ( res /= 740) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2613
      if ( res /= 2613) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",510
      if ( res /= 510) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3301
      if ( res /= 3301) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3591
      if ( res /= 3591) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2186
      if ( res /= 2186) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1489
      if ( res /= 1489) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1128
      if ( res /= 1128) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",795
      if ( res /= 795) then
        stop
      end if
      call createParticleConfig(P_g, P_A, P_g, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3764
      if ( res /= 3764) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",137
      if ( res /= 137) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2894
      if ( res /= 2894) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1491
      if ( res /= 1491) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3156
      if ( res /= 3156) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",585
      if ( res /= 585) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_b, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2156
      if ( res /= 2156) then
        stop
      end if
      call createParticleConfig(P_s, P_cAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",76
      if ( res /= 76) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",152
      if ( res /= 152) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_c, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1118
      if ( res /= 1118) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2321
      if ( res /= 2321) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1983
      if ( res /= 1983) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1700
      if ( res /= 1700) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2121
      if ( res /= 2121) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",943
      if ( res /= 943) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2797
      if ( res /= 2797) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_WPlus, P_ghAAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1872
      if ( res /= 1872) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1656
      if ( res /= 1656) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3868
      if ( res /= 3868) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2217
      if ( res /= 2217) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1851
      if ( res /= 1851) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2383
      if ( res /= 2383) then
        stop
      end if
      call createParticleConfig(P_u, P_uAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1537
      if ( res /= 1537) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2930
      if ( res /= 2930) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_G0, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2425
      if ( res /= 2425) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3317
      if ( res /= 3317) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",980
      if ( res /= 980) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",11
      if ( res /= 11) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",75
      if ( res /= 75) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1785
      if ( res /= 1785) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1882
      if ( res /= 1882) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3342
      if ( res /= 3342) then
        stop
      end if
      call createParticleConfig(P_G0, P_ghWpAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2093
      if ( res /= 2093) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_nu_e, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",9
      if ( res /= 9) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",33
      if ( res /= 33) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",930
      if ( res /= 930) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_nu_tauAnti, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2029
      if ( res /= 2029) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3065
      if ( res /= 3065) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3356
      if ( res /= 3356) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",66
      if ( res /= 66) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Ha, P_Ha, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2030
      if ( res /= 2030) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ePlus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",764
      if ( res /= 764) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1
      if ( res /= 1) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",156
      if ( res /= 156) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",439
      if ( res /= 439) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",118
      if ( res /= 118) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1511
      if ( res /= 1511) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3808
      if ( res /= 3808) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2852
      if ( res /= 2852) then
        stop
      end if
      call createParticleConfig(P_t, P_bAnti, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1617
      if ( res /= 1617) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3465
      if ( res /= 3465) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2946
      if ( res /= 2946) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2382
      if ( res /= 2382) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3062
      if ( res /= 3062) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",675
      if ( res /= 675) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3134
      if ( res /= 3134) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2906
      if ( res /= 2906) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",845
      if ( res /= 845) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1465
      if ( res /= 1465) then
        stop
      end if
      call createParticleConfig(P_g, P_GMinus, P_g, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3805
      if ( res /= 3805) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3573
      if ( res /= 3573) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3029
      if ( res /= 3029) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1642
      if ( res /= 1642) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3621
      if ( res /= 3621) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",208
      if ( res /= 208) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",54
      if ( res /= 54) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_u, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",848
      if ( res /= 848) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_G0, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1536
      if ( res /= 1536) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2783
      if ( res /= 2783) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_HPlus, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3023
      if ( res /= 3023) then
        stop
      end if
      call createParticleConfig(P_b, P_bAnti, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2250
      if ( res /= 2250) then
        stop
      end if
      call createParticleConfig(P_Hl, P_ghWmAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1928
      if ( res /= 1928) then
        stop
      end if
      call createParticleConfig(P_s, P_sAnti, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2112
      if ( res /= 2112) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1052
      if ( res /= 1052) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_nu_mu, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2386
      if ( res /= 2386) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",181
      if ( res /= 181) then
        stop
      end if
      call createParticleConfig(P_Z, P_nu_eAnti, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1662
      if ( res /= 1662) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2734
      if ( res /= 2734) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2287
      if ( res /= 2287) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2206
      if ( res /= 2206) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",881
      if ( res /= 881) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_Z, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1291
      if ( res /= 1291) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3461
      if ( res /= 3461) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_u, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",664
      if ( res /= 664) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1637
      if ( res /= 1637) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",413
      if ( res /= 413) then
        stop
      end if
      call createParticleConfig(P_Hh, P_muMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1502
      if ( res /= 1502) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1387
      if ( res /= 1387) then
        stop
      end if
      call createParticleConfig(P_g, P_G0, P_Ha, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3772
      if ( res /= 3772) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",195
      if ( res /= 195) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghWmAnti, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1787
      if ( res /= 1787) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1274
      if ( res /= 1274) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2521
      if ( res /= 2521) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3102
      if ( res /= 3102) then
        stop
      end if
      call createParticleConfig(P_c, P_cAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2398
      if ( res /= 2398) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3515
      if ( res /= 3515) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_tauPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1138
      if ( res /= 1138) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",850
      if ( res /= 850) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2182
      if ( res /= 2182) then
        stop
      end if
      call createParticleConfig(P_b, P_bAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",499
      if ( res /= 499) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2541
      if ( res /= 2541) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1032
      if ( res /= 1032) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_Ha, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2994
      if ( res /= 2994) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_WMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2580
      if ( res /= 2580) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2812
      if ( res /= 2812) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1397
      if ( res /= 1397) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_nu_tauAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",732
      if ( res /= 732) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",393
      if ( res /= 393) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1505
      if ( res /= 1505) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1232
      if ( res /= 1232) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2680
      if ( res /= 2680) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3097
      if ( res /= 3097) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3746
      if ( res /= 3746) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1193
      if ( res /= 1193) then
        stop
      end if
      call createParticleConfig(P_g, P_A, P_A, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3651
      if ( res /= 3651) then
        stop
      end if
      call createParticleConfig(P_Ha, P_g, P_g, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3623
      if ( res /= 3623) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3823
      if ( res /= 3823) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_Z, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2042
      if ( res /= 2042) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2020
      if ( res /= 2020) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1834
      if ( res /= 1834) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",699
      if ( res /= 699) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",711
      if ( res /= 711) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1580
      if ( res /= 1580) then
        stop
      end if
      call createParticleConfig(P_G0, P_g, P_g, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3688
      if ( res /= 3688) then
        stop
      end if
      call createParticleConfig(P_g, P_WPlus, P_WMinus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3856
      if ( res /= 3856) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",286
      if ( res /= 286) then
        stop
      end if
      call createParticleConfig(P_Z, P_muMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1456
      if ( res /= 1456) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2696
      if ( res /= 2696) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2104
      if ( res /= 2104) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",869
      if ( res /= 869) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1929
      if ( res /= 1929) then
        stop
      end if
      call createParticleConfig(P_b, P_tAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1302
      if ( res /= 1302) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HMinus, P_GPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1058
      if ( res /= 1058) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1082
      if ( res /= 1082) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3121
      if ( res /= 3121) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2712
      if ( res /= 2712) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_A, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",897
      if ( res /= 897) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3275
      if ( res /= 3275) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3498
      if ( res /= 3498) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1413
      if ( res /= 1413) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3286
      if ( res /= 3286) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WMinus, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1721
      if ( res /= 1721) then
        stop
      end if
      call createParticleConfig(P_Z, P_tAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1131
      if ( res /= 1131) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3694
      if ( res /= 3694) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_muMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2391
      if ( res /= 2391) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2760
      if ( res /= 2760) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_GPlus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1156
      if ( res /= 1156) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",328
      if ( res /= 328) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3665
      if ( res /= 3665) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3674
      if ( res /= 3674) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2385
      if ( res /= 2385) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2571
      if ( res /= 2571) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2198
      if ( res /= 2198) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2809
      if ( res /= 2809) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3105
      if ( res /= 3105) then
        stop
      end if
      call createParticleConfig(P_s, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3363
      if ( res /= 3363) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1166
      if ( res /= 1166) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1213
      if ( res /= 1213) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_d, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1905
      if ( res /= 1905) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",579
      if ( res /= 579) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2645
      if ( res /= 2645) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3467
      if ( res /= 3467) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1831
      if ( res /= 1831) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2476
      if ( res /= 2476) then
        stop
      end if
      call createParticleConfig(P_u, P_dAnti, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",99
      if ( res /= 99) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2637
      if ( res /= 2637) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1233
      if ( res /= 1233) then
        stop
      end if
      call createParticleConfig(P_Hl, P_g, P_g, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3728
      if ( res /= 3728) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1376
      if ( res /= 1376) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",952
      if ( res /= 952) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3336
      if ( res /= 3336) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",674
      if ( res /= 674) then
        stop
      end if
      call createParticleConfig(P_g, P_G0, P_g, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3654
      if ( res /= 3654) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HMinus, P_GPlus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3575
      if ( res /= 3575) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3344
      if ( res /= 3344) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",900
      if ( res /= 900) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3742
      if ( res /= 3742) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1584
      if ( res /= 1584) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2522
      if ( res /= 2522) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3655
      if ( res /= 3655) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_ghZAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3131
      if ( res /= 3131) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1859
      if ( res /= 1859) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1350
      if ( res /= 1350) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3568
      if ( res /= 3568) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2703
      if ( res /= 2703) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3556
      if ( res /= 3556) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3310
      if ( res /= 3310) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3327
      if ( res /= 3327) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1997
      if ( res /= 1997) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_c, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1711
      if ( res /= 1711) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2751
      if ( res /= 2751) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3155
      if ( res /= 3155) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_t, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2146
      if ( res /= 2146) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",435
      if ( res /= 435) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3517
      if ( res /= 3517) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3528
      if ( res /= 3528) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2899
      if ( res /= 2899) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3574
      if ( res /= 3574) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3703
      if ( res /= 3703) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",135
      if ( res /= 135) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",677
      if ( res /= 677) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",785
      if ( res /= 785) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2246
      if ( res /= 2246) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3326
      if ( res /= 3326) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2297
      if ( res /= 2297) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",161
      if ( res /= 161) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",759
      if ( res /= 759) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2162
      if ( res /= 2162) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_bAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",887
      if ( res /= 887) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_HMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2276
      if ( res /= 2276) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",958
      if ( res /= 958) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3084
      if ( res /= 3084) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2990
      if ( res /= 2990) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",217
      if ( res /= 217) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3765
      if ( res /= 3765) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1086
      if ( res /= 1086) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1341
      if ( res /= 1341) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",0
      if ( res /= 0) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",612
      if ( res /= 612) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1468
      if ( res /= 1468) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2531
      if ( res /= 2531) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1555
      if ( res /= 1555) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1718
      if ( res /= 1718) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1440
      if ( res /= 1440) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1989
      if ( res /= 1989) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1048
      if ( res /= 1048) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2240
      if ( res /= 2240) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2634
      if ( res /= 2634) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",511
      if ( res /= 511) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_GMinus, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2316
      if ( res /= 2316) then
        stop
      end if
      call createParticleConfig(P_Hl, P_sAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",468
      if ( res /= 468) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WMinus, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3226
      if ( res /= 3226) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_cAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",743
      if ( res /= 743) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1284
      if ( res /= 1284) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",117
      if ( res /= 117) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_Hh, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",123
      if ( res /= 123) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghZ, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1987
      if ( res /= 1987) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",864
      if ( res /= 864) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",533
      if ( res /= 533) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghWm, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2844
      if ( res /= 2844) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3387
      if ( res /= 3387) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2689
      if ( res /= 2689) then
        stop
      end if
      call createParticleConfig(P_Hh, P_sAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",355
      if ( res /= 355) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3135
      if ( res /= 3135) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3086
      if ( res /= 3086) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HPlus, P_HMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2695
      if ( res /= 2695) then
        stop
      end if
      call createParticleConfig(P_u, P_GMinus, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",333
      if ( res /= 333) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghA, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1978
      if ( res /= 1978) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_g, P_g, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3789
      if ( res /= 3789) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3332
      if ( res /= 3332) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_GPlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",84
      if ( res /= 84) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",721
      if ( res /= 721) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1904
      if ( res /= 1904) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1514
      if ( res /= 1514) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",554
      if ( res /= 554) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_ghWm, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1630
      if ( res /= 1630) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2573
      if ( res /= 2573) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1707
      if ( res /= 1707) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1681
      if ( res /= 1681) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",802
      if ( res /= 802) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",111
      if ( res /= 111) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_Hh, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1357
      if ( res /= 1357) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",762
      if ( res /= 762) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1246
      if ( res /= 1246) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3549
      if ( res /= 3549) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3809
      if ( res /= 3809) then
        stop
      end if
      call createParticleConfig(P_g, P_bAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2211
      if ( res /= 2211) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2960
      if ( res /= 2960) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",913
      if ( res /= 913) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1507
      if ( res /= 1507) then
        stop
      end if
      call createParticleConfig(P_ghA, P_WMinus, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1725
      if ( res /= 1725) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1795
      if ( res /= 1795) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1474
      if ( res /= 1474) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1481
      if ( res /= 1481) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3004
      if ( res /= 3004) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_muPlus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2361
      if ( res /= 2361) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",171
      if ( res /= 171) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1743
      if ( res /= 1743) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1142
      if ( res /= 1142) then
        stop
      end if
      call createParticleConfig(P_ghA, P_ghWmAnti, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1304
      if ( res /= 1304) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",146
      if ( res /= 146) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",277
      if ( res /= 277) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",564
      if ( res /= 564) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2724
      if ( res /= 2724) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3766
      if ( res /= 3766) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3859
      if ( res /= 3859) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2328
      if ( res /= 2328) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_sAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1958
      if ( res /= 1958) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1248
      if ( res /= 1248) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_ghWmAnti, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2189
      if ( res /= 2189) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2376
      if ( res /= 2376) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2964
      if ( res /= 2964) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2325
      if ( res /= 2325) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_b, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2068
      if ( res /= 2068) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1225
      if ( res /= 1225) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1347
      if ( res /= 1347) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2976
      if ( res /= 2976) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",425
      if ( res /= 425) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1875
      if ( res /= 1875) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Ha, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2150
      if ( res /= 2150) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Ha, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2968
      if ( res /= 2968) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_muPlus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",47
      if ( res /= 47) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2036
      if ( res /= 2036) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HMinus, P_WPlus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1328
      if ( res /= 1328) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",656
      if ( res /= 656) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2646
      if ( res /= 2646) then
        stop
      end if
      call createParticleConfig(P_G0, P_muPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",239
      if ( res /= 239) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",578
      if ( res /= 578) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",799
      if ( res /= 799) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1862
      if ( res /= 1862) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3095
      if ( res /= 3095) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3228
      if ( res /= 3228) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3583
      if ( res /= 3583) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2159
      if ( res /= 2159) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",576
      if ( res /= 576) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghZ, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",668
      if ( res /= 668) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_g, P_GPlus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3777
      if ( res /= 3777) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1934
      if ( res /= 1934) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",206
      if ( res /= 206) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",46
      if ( res /= 46) then
        stop
      end if
      call createParticleConfig(P_b, P_GPlus, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",519
      if ( res /= 519) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3268
      if ( res /= 3268) then
        stop
      end if
      call createParticleConfig(P_Ha, P_u, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2347
      if ( res /= 2347) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1968
      if ( res /= 1968) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",872
      if ( res /= 872) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1001
      if ( res /= 1001) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_muMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2444
      if ( res /= 2444) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3361
      if ( res /= 3361) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1173
      if ( res /= 1173) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3446
      if ( res /= 3446) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Ha, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3193
      if ( res /= 3193) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3542
      if ( res /= 3542) then
        stop
      end if
      call createParticleConfig(P_g, P_GPlus, P_HMinus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3846
      if ( res /= 3846) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2592
      if ( res /= 2592) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3036
      if ( res /= 3036) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1064
      if ( res /= 1064) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2948
      if ( res /= 2948) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1364
      if ( res /= 1364) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2513
      if ( res /= 2513) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1020
      if ( res /= 1020) then
        stop
      end if
      call createParticleConfig(P_c, P_Ha, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2017
      if ( res /= 2017) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2081
      if ( res /= 2081) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",497
      if ( res /= 497) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",36
      if ( res /= 36) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1485
      if ( res /= 1485) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1189
      if ( res /= 1189) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2853
      if ( res /= 2853) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2075
      if ( res /= 2075) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",60
      if ( res /= 60) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2485
      if ( res /= 2485) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",369
      if ( res /= 369) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1101
      if ( res /= 1101) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1108
      if ( res /= 1108) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3475
      if ( res /= 3475) then
        stop
      end if
      call createParticleConfig(P_g, P_HPlus, P_g, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3736
      if ( res /= 3736) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",567
      if ( res /= 567) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2761
      if ( res /= 2761) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1786
      if ( res /= 1786) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1962
      if ( res /= 1962) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_nu_tau, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",307
      if ( res /= 307) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",234
      if ( res /= 234) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",928
      if ( res /= 928) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2493
      if ( res /= 2493) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2909
      if ( res /= 2909) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1664
      if ( res /= 1664) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2914
      if ( res /= 2914) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghZ, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3453
      if ( res /= 3453) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3546
      if ( res /= 3546) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1403
      if ( res /= 1403) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2904
      if ( res /= 2904) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_A, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",69
      if ( res /= 69) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WMinus, P_WPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",219
      if ( res /= 219) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_Ha, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3561
      if ( res /= 3561) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1670
      if ( res /= 1670) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2932
      if ( res /= 2932) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2710
      if ( res /= 2710) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1763
      if ( res /= 1763) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghWpAnti, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1436
      if ( res /= 1436) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_Ha, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1005
      if ( res /= 1005) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",93
      if ( res /= 93) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3068
      if ( res /= 3068) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_g, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1228
      if ( res /= 1228) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3554
      if ( res /= 3554) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3786
      if ( res /= 3786) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1132
      if ( res /= 1132) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",376
      if ( res /= 376) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",145
      if ( res /= 145) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",242
      if ( res /= 242) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2843
      if ( res /= 2843) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2954
      if ( res /= 2954) then
        stop
      end if
      call createParticleConfig(P_Hl, P_uAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1365
      if ( res /= 1365) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_g, P_GPlus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3732
      if ( res /= 3732) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3612
      if ( res /= 3612) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_A, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1814
      if ( res /= 1814) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",603
      if ( res /= 603) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2045
      if ( res /= 2045) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3260
      if ( res /= 3260) then
        stop
      end if
      call createParticleConfig(P_g, P_GMinus, P_g, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3641
      if ( res /= 3641) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghWm, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1759
      if ( res /= 1759) then
        stop
      end if
      call createParticleConfig(P_Hh, P_tAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2639
      if ( res /= 2639) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_Hl, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2291
      if ( res /= 2291) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2575
      if ( res /= 2575) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2335
      if ( res /= 2335) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3714
      if ( res /= 3714) then
        stop
      end if
      call createParticleConfig(P_Z, P_muPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1273
      if ( res /= 1273) then
        stop
      end if
      call createParticleConfig(P_b, P_Ha, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1510
      if ( res /= 1510) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",293
      if ( res /= 293) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2260
      if ( res /= 2260) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1716
      if ( res /= 1716) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_nu_tauAnti, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2660
      if ( res /= 2660) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1583
      if ( res /= 1583) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3469
      if ( res /= 3469) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3034
      if ( res /= 3034) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1010
      if ( res /= 1010) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1066
      if ( res /= 1066) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2431
      if ( res /= 2431) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_cAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",318
      if ( res /= 318) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2410
      if ( res /= 2410) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_d, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1951
      if ( res /= 1951) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1742
      if ( res /= 1742) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_Hh, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2283
      if ( res /= 2283) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3239
      if ( res /= 3239) then
        stop
      end if
      call createParticleConfig(P_G0, P_cAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2285
      if ( res /= 2285) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2185
      if ( res /= 2185) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3637
      if ( res /= 3637) then
        stop
      end if
      call createParticleConfig(P_c, P_G0, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2262
      if ( res /= 2262) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2343
      if ( res /= 2343) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_muPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1370
      if ( res /= 1370) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3115
      if ( res /= 3115) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",635
      if ( res /= 635) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1913
      if ( res /= 1913) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2979
      if ( res /= 2979) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2353
      if ( res /= 2353) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",481
      if ( res /= 481) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3492
      if ( res /= 3492) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1944
      if ( res /= 1944) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1998
      if ( res /= 1998) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",51
      if ( res /= 51) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_muPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1442
      if ( res /= 1442) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",777
      if ( res /= 777) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",530
      if ( res /= 530) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",22
      if ( res /= 22) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_muMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",586
      if ( res /= 586) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3629
      if ( res /= 3629) then
        stop
      end if
      call createParticleConfig(P_c, P_cAnti, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",670
      if ( res /= 670) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",843
      if ( res /= 843) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3767
      if ( res /= 3767) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",261
      if ( res /= 261) then
        stop
      end if
      call createParticleConfig(P_Z, P_HPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3205
      if ( res /= 3205) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_Hh, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",997
      if ( res /= 997) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3006
      if ( res /= 3006) then
        stop
      end if
      call createParticleConfig(P_t, P_Hh, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2690
      if ( res /= 2690) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",487
      if ( res /= 487) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2980
      if ( res /= 2980) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_d, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1070
      if ( res /= 1070) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3622
      if ( res /= 3622) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1858
      if ( res /= 1858) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",173
      if ( res /= 173) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2892
      if ( res /= 2892) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1919
      if ( res /= 1919) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3198
      if ( res /= 3198) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3710
      if ( res /= 3710) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_WPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3443
      if ( res /= 3443) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2854
      if ( res /= 2854) then
        stop
      end if
      call createParticleConfig(P_Ha, P_g, P_Ha, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3693
      if ( res /= 3693) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",202
      if ( res /= 202) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1553
      if ( res /= 1553) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2677
      if ( res /= 2677) then
        stop
      end if
      call createParticleConfig(P_G0, P_g, P_g, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3615
      if ( res /= 3615) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",408
      if ( res /= 408) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",404
      if ( res /= 404) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",180
      if ( res /= 180) then
        stop
      end if
      call createParticleConfig(P_A, P_dAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1713
      if ( res /= 1713) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2887
      if ( res /= 2887) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1427
      if ( res /= 1427) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1426
      if ( res /= 1426) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1722
      if ( res /= 1722) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2463
      if ( res /= 2463) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3817
      if ( res /= 3817) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_ghA, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3300
      if ( res /= 3300) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1287
      if ( res /= 1287) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_ghZAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3423
      if ( res /= 3423) then
        stop
      end if
      call createParticleConfig(P_c, P_sAnti, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2187
      if ( res /= 2187) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",673
      if ( res /= 673) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",613
      if ( res /= 613) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_A, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1316
      if ( res /= 1316) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_ghZ, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",710
      if ( res /= 710) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",647
      if ( res /= 647) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GPlus, P_GMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",559
      if ( res /= 559) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2057
      if ( res /= 2057) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1292
      if ( res /= 1292) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2926
      if ( res /= 2926) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1923
      if ( res /= 1923) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3537
      if ( res /= 3537) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3484
      if ( res /= 3484) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3586
      if ( res /= 3586) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3424
      if ( res /= 3424) then
        stop
      end if
      call createParticleConfig(P_d, P_dAnti, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",614
      if ( res /= 614) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1691
      if ( res /= 1691) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1833
      if ( res /= 1833) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3248
      if ( res /= 3248) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2226
      if ( res /= 2226) then
        stop
      end if
      call createParticleConfig(P_Hh, P_ghZ, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2480
      if ( res /= 2480) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2732
      if ( res /= 2732) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",940
      if ( res /= 940) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",247
      if ( res /= 247) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_ghWm, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",894
      if ( res /= 894) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_HPlus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",767
      if ( res /= 767) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1402
      if ( res /= 1402) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",697
      if ( res /= 697) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3713
      if ( res /= 3713) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GPlus, P_GMinus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2318
      if ( res /= 2318) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",582
      if ( res /= 582) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2439
      if ( res /= 2439) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2805
      if ( res /= 2805) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_Hl, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2292
      if ( res /= 2292) then
        stop
      end if
      call createParticleConfig(P_t, P_G0, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2078
      if ( res /= 2078) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3486
      if ( res /= 3486) then
        stop
      end if
      call createParticleConfig(P_g, P_Hl, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3734
      if ( res /= 3734) then
        stop
      end if
      call createParticleConfig(P_d, P_Ha, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",63
      if ( res /= 63) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1847
      if ( res /= 1847) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2384
      if ( res /= 2384) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1541
      if ( res /= 1541) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",260
      if ( res /= 260) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2733
      if ( res /= 2733) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",77
      if ( res /= 77) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Ha, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2967
      if ( res /= 2967) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2171
      if ( res /= 2171) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1095
      if ( res /= 1095) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1276
      if ( res /= 1276) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2119
      if ( res /= 2119) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_tauMinus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",113
      if ( res /= 113) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2992
      if ( res /= 2992) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_g, P_g, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3672
      if ( res /= 3672) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3271
      if ( res /= 3271) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1974
      if ( res /= 1974) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3046
      if ( res /= 3046) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_WPlus, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2008
      if ( res /= 2008) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3585
      if ( res /= 3585) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2467
      if ( res /= 2467) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_HPlus, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1158
      if ( res /= 1158) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1388
      if ( res /= 1388) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",190
      if ( res /= 190) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1683
      if ( res /= 1683) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3506
      if ( res /= 3506) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1964
      if ( res /= 1964) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1044
      if ( res /= 1044) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3222
      if ( res /= 3222) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_HMinus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",695
      if ( res /= 695) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3494
      if ( res /= 3494) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3418
      if ( res /= 3418) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2776
      if ( res /= 2776) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",88
      if ( res /= 88) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1588
      if ( res /= 1588) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_Hl, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1696
      if ( res /= 1696) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3038
      if ( res /= 3038) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",32
      if ( res /= 32) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2951
      if ( res /= 2951) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1902
      if ( res /= 1902) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2158
      if ( res /= 2158) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2947
      if ( res /= 2947) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3437
      if ( res /= 3437) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2891
      if ( res /= 2891) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2840
      if ( res /= 2840) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",80
      if ( res /= 80) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1655
      if ( res /= 1655) then
        stop
      end if
      call createParticleConfig(P_t, P_GMinus, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",44
      if ( res /= 44) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2596
      if ( res /= 2596) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",774
      if ( res /= 774) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3392
      if ( res /= 3392) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3064
      if ( res /= 3064) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3354
      if ( res /= 3354) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_WMinus, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2478
      if ( res /= 2478) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GPlus, P_HMinus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3263
      if ( res /= 3263) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2671
      if ( res /= 2671) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2622
      if ( res /= 2622) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3032
      if ( res /= 3032) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",384
      if ( res /= 384) then
        stop
      end if
      call createParticleConfig(P_d, P_HPlus, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",501
      if ( res /= 501) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_WMinus, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",752
      if ( res /= 752) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2888
      if ( res /= 2888) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_g, P_g, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3844
      if ( res /= 3844) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghZAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",405
      if ( res /= 405) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2304
      if ( res /= 2304) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_GPlus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",839
      if ( res /= 839) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3247
      if ( res /= 3247) then
        stop
      end if
      call createParticleConfig(P_u, P_A, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1027
      if ( res /= 1027) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_ghWmAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1557
      if ( res /= 1557) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",919
      if ( res /= 919) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WMinus, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1165
      if ( res /= 1165) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3158
      if ( res /= 3158) then
        stop
      end if
      call createParticleConfig(P_ghA, P_HMinus, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2875
      if ( res /= 2875) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1018
      if ( res /= 1018) then
        stop
      end if
      call createParticleConfig(P_Hh, P_b, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1421
      if ( res /= 1421) then
        stop
      end if
      call createParticleConfig(P_A, P_u, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1034
      if ( res /= 1034) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1529
      if ( res /= 1529) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",308
      if ( res /= 308) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2757
      if ( res /= 2757) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3176
      if ( res /= 3176) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3511
      if ( res /= 3511) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghZ, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1985
      if ( res /= 1985) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",947
      if ( res /= 947) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2290
      if ( res /= 2290) then
        stop
      end if
      call createParticleConfig(P_s, P_sAnti, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2494
      if ( res /= 2494) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",367
      if ( res /= 367) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1325
      if ( res /= 1325) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1563
      if ( res /= 1563) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1876
      if ( res /= 1876) then
        stop
      end if
      call createParticleConfig(P_ghA, P_ghWpAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1247
      if ( res /= 1247) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2441
      if ( res /= 2441) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2609
      if ( res /= 2609) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",788
      if ( res /= 788) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3321
      if ( res /= 3321) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1674
      if ( res /= 1674) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2786
      if ( res /= 2786) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1918
      if ( res /= 1918) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2114
      if ( res /= 2114) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",521
      if ( res /= 521) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_GMinus, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",712
      if ( res /= 712) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_Hl, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1459
      if ( res /= 1459) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1014
      if ( res /= 1014) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2046
      if ( res /= 2046) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",625
      if ( res /= 625) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3379
      if ( res /= 3379) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghWpAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1942
      if ( res /= 1942) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",798
      if ( res /= 798) then
        stop
      end if
      call createParticleConfig(P_Ha, P_muMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",340
      if ( res /= 340) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",761
      if ( res /= 761) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",477
      if ( res /= 477) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",692
      if ( res /= 692) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3410
      if ( res /= 3410) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3340
      if ( res /= 3340) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_WPlus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2129
      if ( res /= 2129) then
        stop
      end if
      call createParticleConfig(P_g, P_Z, P_g, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3597
      if ( res /= 3597) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3049
      if ( res /= 3049) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GPlus, P_GMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",964
      if ( res /= 964) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2626
      if ( res /= 2626) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3308
      if ( res /= 3308) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1301
      if ( res /= 1301) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3182
      if ( res /= 3182) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1843
      if ( res /= 1843) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",301
      if ( res /= 301) then
        stop
      end if
      call createParticleConfig(P_G0, P_muMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1083
      if ( res /= 1083) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1836
      if ( res /= 1836) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1447
      if ( res /= 1447) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",442
      if ( res /= 442) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_nu_mu, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3298
      if ( res /= 3298) then
        stop
      end if
      call createParticleConfig(P_Hh, P_ePlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",103
      if ( res /= 103) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_muPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",998
      if ( res /= 998) then
        stop
      end if
      call createParticleConfig(P_Ha, P_cAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",29
      if ( res /= 29) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",268
      if ( res /= 268) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2893
      if ( res /= 2893) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3763
      if ( res /= 3763) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Ha, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",148
      if ( res /= 148) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2731
      if ( res /= 2731) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3699
      if ( res /= 3699) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_ghWm, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3563
      if ( res /= 3563) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",410
      if ( res /= 410) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1278
      if ( res /= 1278) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Ha, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3053
      if ( res /= 3053) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2483
      if ( res /= 2483) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GPlus, P_HMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1801
      if ( res /= 1801) then
        stop
      end if
      call createParticleConfig(P_G0, P_ghWm, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2507
      if ( res /= 2507) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2166
      if ( res /= 2166) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2417
      if ( res /= 2417) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2777
      if ( res /= 2777) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3807
      if ( res /= 3807) then
        stop
      end if
      call createParticleConfig(P_Hh, P_tauPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",956
      if ( res /= 956) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2944
      if ( res /= 2944) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_muMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",112
      if ( res /= 112) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",230
      if ( res /= 230) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2379
      if ( res /= 2379) then
        stop
      end if
      call createParticleConfig(P_g, P_WMinus, P_g, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3649
      if ( res /= 3649) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3715
      if ( res /= 3715) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2311
      if ( res /= 2311) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3304
      if ( res /= 3304) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3416
      if ( res /= 3416) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3168
      if ( res /= 3168) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1433
      if ( res /= 1433) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",562
      if ( res /= 562) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3438
      if ( res /= 3438) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3652
      if ( res /= 3652) then
        stop
      end if
      call createParticleConfig(P_g, P_Hh, P_g, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3796
      if ( res /= 3796) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2202
      if ( res /= 2202) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",447
      if ( res /= 447) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2160
      if ( res /= 2160) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",279
      if ( res /= 279) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1369
      if ( res /= 1369) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3378
      if ( res /= 3378) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_G0, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",626
      if ( res /= 626) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",155
      if ( res /= 155) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_muMinus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1251
      if ( res /= 1251) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_Z, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3598
      if ( res /= 3598) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_A, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",865
      if ( res /= 865) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_WMinus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",82
      if ( res /= 82) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2822
      if ( res /= 2822) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",438
      if ( res /= 438) then
        stop
      end if
      call createParticleConfig(P_Ha, P_tauPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1887
      if ( res /= 1887) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2814
      if ( res /= 2814) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_nu_mu, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1346
      if ( res /= 1346) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3553
      if ( res /= 3553) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3784
      if ( res /= 3784) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3481
      if ( res /= 3481) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3696
      if ( res /= 3696) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3103
      if ( res /= 3103) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",853
      if ( res /= 853) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_t, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1971
      if ( res /= 1971) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2040
      if ( res /= 2040) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",735
      if ( res /= 735) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",756
      if ( res /= 756) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3223
      if ( res /= 3223) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3320
      if ( res /= 3320) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HMinus, P_GPlus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1305
      if ( res /= 1305) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",426
      if ( res /= 426) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2274
      if ( res /= 2274) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",153
      if ( res /= 153) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_WMinus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1880
      if ( res /= 1880) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3269
      if ( res /= 3269) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_Hh, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2667
      if ( res /= 2667) then
        stop
      end if
      call createParticleConfig(P_g, P_HPlus, P_g, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3600
      if ( res /= 3600) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_Ha, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1351
      if ( res /= 1351) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3122
      if ( res /= 3122) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2233
      if ( res /= 2233) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_HPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",432
      if ( res /= 432) then
        stop
      end if
      call createParticleConfig(P_g, P_A, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3726
      if ( res /= 3726) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2194
      if ( res /= 2194) then
        stop
      end if
      call createParticleConfig(P_Ha, P_g, P_g, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3782
      if ( res /= 3782) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2251
      if ( res /= 2251) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1443
      if ( res /= 1443) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_muMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2298
      if ( res /= 2298) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",310
      if ( res /= 310) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1585
      if ( res /= 1585) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1234
      if ( res /= 1234) then
        stop
      end if
      call createParticleConfig(P_d, P_uAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1608
      if ( res /= 1608) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",246
      if ( res /= 246) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1046
      if ( res /= 1046) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",569
      if ( res /= 569) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WPlus, P_WMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",382
      if ( res /= 382) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1493
      if ( res /= 1493) then
        stop
      end if
      call createParticleConfig(P_g, P_A, P_Z, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3682
      if ( res /= 3682) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Ha, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1226
      if ( res /= 1226) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2679
      if ( res /= 2679) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_eMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2484
      if ( res /= 2484) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_Ha, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3291
      if ( res /= 3291) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghWm, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",237
      if ( res /= 237) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",314
      if ( res /= 314) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2355
      if ( res /= 2355) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_Hh, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1530
      if ( res /= 1530) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3414
      if ( res /= 3414) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",826
      if ( res /= 826) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2983
      if ( res /= 2983) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1735
      if ( res /= 1735) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3838
      if ( res /= 3838) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3362
      if ( res /= 3362) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1523
      if ( res /= 1523) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2320
      if ( res /= 2320) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2372
      if ( res /= 2372) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_Hl, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2558
      if ( res /= 2558) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3311
      if ( res /= 3311) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Ha, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3348
      if ( res /= 3348) then
        stop
      end if
      call createParticleConfig(P_c, P_g, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",270
      if ( res /= 270) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3735
      if ( res /= 3735) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WPlus, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",37
      if ( res /= 37) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1178
      if ( res /= 1178) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3750
      if ( res /= 3750) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",467
      if ( res /= 467) then
        stop
      end if
      call createParticleConfig(P_c, P_cAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",329
      if ( res /= 329) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2469
      if ( res /= 2469) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2512
      if ( res /= 2512) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3579
      if ( res /= 3579) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",424
      if ( res /= 424) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1649
      if ( res /= 1649) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2322
      if ( res /= 2322) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1677
      if ( res /= 1677) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1473
      if ( res /= 1473) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1157
      if ( res /= 1157) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3238
      if ( res /= 3238) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",682
      if ( res /= 682) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",662
      if ( res /= 662) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3187
      if ( res /= 3187) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2050
      if ( res /= 2050) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2303
      if ( res /= 2303) then
        stop
      end if
      call createParticleConfig(P_u, P_Ha, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1692
      if ( res /= 1692) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",685
      if ( res /= 685) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_Z, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2465
      if ( res /= 2465) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",753
      if ( res /= 753) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_HPlus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1419
      if ( res /= 1419) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3613
      if ( res /= 3613) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2952
      if ( res /= 2952) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2437
      if ( res /= 2437) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HPlus, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2155
      if ( res /= 2155) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2142
      if ( res /= 2142) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3171
      if ( res /= 3171) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",512
      if ( res /= 512) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3810
      if ( res /= 3810) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3513
      if ( res /= 3513) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",81
      if ( res /= 81) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",72
      if ( res /= 72) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_WMinus, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1829
      if ( res /= 1829) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_u, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",74
      if ( res /= 74) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_tAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2077
      if ( res /= 2077) then
        stop
      end if
      call createParticleConfig(P_s, P_HPlus, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1736
      if ( res /= 1736) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",891
      if ( res /= 891) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1869
      if ( res /= 1869) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2066
      if ( res /= 2066) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",385
      if ( res /= 385) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1040
      if ( res /= 1040) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_WPlus, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1966
      if ( res /= 1966) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HMinus, P_WPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2742
      if ( res /= 2742) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3232
      if ( res /= 3232) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2013
      if ( res /= 2013) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",4
      if ( res /= 4) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3478
      if ( res /= 3478) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2583
      if ( res /= 2583) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3640
      if ( res /= 3640) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",375
      if ( res /= 375) then
        stop
      end if
      call createParticleConfig(P_Hl, P_b, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1573
      if ( res /= 1573) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",106
      if ( res /= 106) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3328
      if ( res /= 3328) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2871
      if ( res /= 2871) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1754
      if ( res /= 1754) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_t, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1720
      if ( res /= 1720) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",222
      if ( res /= 222) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",973
      if ( res /= 973) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_A, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3099
      if ( res /= 3099) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3878
      if ( res /= 3878) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3020
      if ( res /= 3020) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",552
      if ( res /= 552) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2792
      if ( res /= 2792) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3833
      if ( res /= 3833) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",262
      if ( res /= 262) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",416
      if ( res /= 416) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3173
      if ( res /= 3173) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2813
      if ( res /= 2813) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3806
      if ( res /= 3806) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_tauMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2563
      if ( res /= 2563) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_HMinus, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3050
      if ( res /= 3050) then
        stop
      end if
      call createParticleConfig(P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3133
      if ( res /= 3133) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",144
      if ( res /= 144) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_HPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",313
      if ( res /= 313) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1355
      if ( res /= 1355) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1881
      if ( res /= 1881) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_nu_eAnti, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1466
      if ( res /= 1466) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3832
      if ( res /= 3832) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_g, P_g, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3837
      if ( res /= 3837) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2028
      if ( res /= 2028) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",341
      if ( res /= 341) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1967
      if ( res /= 1967) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_muPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1702
      if ( res /= 1702) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_Ha, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2750
      if ( res /= 2750) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1719
      if ( res /= 1719) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1874
      if ( res /= 1874) then
        stop
      end if
      call createParticleConfig(P_b, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3390
      if ( res /= 3390) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",259
      if ( res /= 259) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2848
      if ( res /= 2848) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GMinus, P_WPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",299
      if ( res /= 299) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HMinus, P_HPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",391
      if ( res /= 391) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",176
      if ( res /= 176) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghWpAnti, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1094
      if ( res /= 1094) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",686
      if ( res /= 686) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",321
      if ( res /= 321) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3843
      if ( res /= 3843) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",319
      if ( res /= 319) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1984
      if ( res /= 1984) then
        stop
      end if
      call createParticleConfig(P_s, P_Hl, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",763
      if ( res /= 763) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",177
      if ( res /= 177) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3768
      if ( res /= 3768) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1437
      if ( res /= 1437) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1418
      if ( res /= 1418) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2346
      if ( res /= 2346) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1614
      if ( res /= 1614) then
        stop
      end if
      call createParticleConfig(P_Hl, P_tAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1076
      if ( res /= 1076) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1547
      if ( res /= 1547) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2720
      if ( res /= 2720) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_Ha, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",951
      if ( res /= 951) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2024
      if ( res /= 2024) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1395
      if ( res /= 1395) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",189
      if ( res /= 189) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1303
      if ( res /= 1303) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2435
      if ( res /= 2435) then
        stop
      end if
      call createParticleConfig(P_ghA, P_ghWpAnti, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2773
      if ( res /= 2773) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2137
      if ( res /= 2137) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2524
      if ( res /= 2524) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",43
      if ( res /= 43) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1652
      if ( res /= 1652) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1600
      if ( res /= 1600) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1771
      if ( res /= 1771) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",478
      if ( res /= 478) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",17
      if ( res /= 17) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3421
      if ( res /= 3421) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghWpAnti, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1408
      if ( res /= 1408) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1776
      if ( res /= 1776) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_g, P_g, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3608
      if ( res /= 3608) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2223
      if ( res /= 2223) then
        stop
      end if
      call createParticleConfig(P_Z, P_sAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2222
      if ( res /= 2222) then
        stop
      end if
      call createParticleConfig(P_A, P_ghWp, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1371
      if ( res /= 1371) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_tauPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2457
      if ( res /= 2457) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3875
      if ( res /= 3875) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",97
      if ( res /= 97) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3716
      if ( res /= 3716) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1773
      if ( res /= 1773) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GMinus, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",654
      if ( res /= 654) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2800
      if ( res /= 2800) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1528
      if ( res /= 1528) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghAAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2404
      if ( res /= 2404) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",566
      if ( res /= 566) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1147
      if ( res /= 1147) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2548
      if ( res /= 2548) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",386
      if ( res /= 386) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1439
      if ( res /= 1439) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2288
      if ( res /= 2288) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_tauMinus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1067
      if ( res /= 1067) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghA, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2462
      if ( res /= 2462) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3350
      if ( res /= 3350) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3189
      if ( res /= 3189) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_Ha, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2272
      if ( res /= 2272) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2799
      if ( res /= 2799) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1164
      if ( res /= 1164) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",475
      if ( res /= 475) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1850
      if ( res /= 1850) then
        stop
      end if
      call createParticleConfig(P_Hl, P_eMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",633
      if ( res /= 633) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2585
      if ( res /= 2585) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1000
      if ( res /= 1000) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3309
      if ( res /= 3309) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_tAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",648
      if ( res /= 648) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2380
      if ( res /= 2380) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",904
      if ( res /= 904) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2115
      if ( res /= 2115) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2510
      if ( res /= 2510) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1381
      if ( res /= 1381) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",350
      if ( res /= 350) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2515
      if ( res /= 2515) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3671
      if ( res /= 3671) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2001
      if ( res /= 2001) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1361
      if ( res /= 1361) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2022
      if ( res /= 2022) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1319
      if ( res /= 1319) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1839
      if ( res /= 1839) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_nu_eAnti, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",379
      if ( res /= 379) then
        stop
      end if
      call createParticleConfig(P_Hh, P_t, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2688
      if ( res /= 2688) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3028
      if ( res /= 3028) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1077
      if ( res /= 1077) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2099
      if ( res /= 2099) then
        stop
      end if
      call createParticleConfig(P_A, P_Hh, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1377
      if ( res /= 1377) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2176
      if ( res /= 2176) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2670
      if ( res /= 2670) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_A, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3346
      if ( res /= 3346) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2936
      if ( res /= 2936) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",953
      if ( res /= 953) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghWmAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2560
      if ( res /= 2560) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",428
      if ( res /= 428) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1016
      if ( res /= 1016) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",908
      if ( res /= 908) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",954
      if ( res /= 954) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1208
      if ( res /= 1208) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_G0, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",336
      if ( res /= 336) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1863
      if ( res /= 1863) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1061
      if ( res /= 1061) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2938
      if ( res /= 2938) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3820
      if ( res /= 3820) then
        stop
      end if
      call createParticleConfig(P_G0, P_g, P_Ha, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3731
      if ( res /= 3731) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3162
      if ( res /= 3162) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3318
      if ( res /= 3318) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1524
      if ( res /= 1524) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_Hl, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2526
      if ( res /= 2526) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WPlus, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1414
      if ( res /= 1414) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",452
      if ( res /= 452) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",996
      if ( res /= 996) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3433
      if ( res /= 3433) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_s, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",568
      if ( res /= 568) then
        stop
      end if
      call createParticleConfig(P_Hl, P_A, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2745
      if ( res /= 2745) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3426
      if ( res /= 3426) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3261
      if ( res /= 3261) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1227
      if ( res /= 1227) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2793
      if ( res /= 2793) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3259
      if ( res /= 3259) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1890
      if ( res /= 1890) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2
      if ( res /= 2) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3159
      if ( res /= 3159) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",457
      if ( res /= 457) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",482
      if ( res /= 482) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_ghZ, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1045
      if ( res /= 1045) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",830
      if ( res /= 830) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1267
      if ( res /= 1267) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_uAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1733
      if ( res /= 1733) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WMinus, P_WPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3323
      if ( res /= 3323) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HPlus, P_GMinus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3192
      if ( res /= 3192) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1751
      if ( res /= 1751) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",198
      if ( res /= 198) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_Ha, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3855
      if ( res /= 3855) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_G0, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1994
      if ( res /= 1994) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3406
      if ( res /= 3406) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2031
      if ( res /= 2031) then
        stop
      end if
      call createParticleConfig(P_d, P_dAnti, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",273
      if ( res /= 273) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2278
      if ( res /= 2278) then
        stop
      end if
      call createParticleConfig(P_g, P_s, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1078
      if ( res /= 1078) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2491
      if ( res /= 2491) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_G0, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3562
      if ( res /= 3562) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1860
      if ( res /= 1860) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1647
      if ( res /= 1647) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_HPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1434
      if ( res /= 1434) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_G0, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",527
      if ( res /= 527) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",520
      if ( res /= 520) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1658
      if ( res /= 1658) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_WMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3524
      if ( res /= 3524) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",151
      if ( res /= 151) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1549
      if ( res /= 1549) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3069
      if ( res /= 3069) then
        stop
      end if
      call createParticleConfig(P_c, P_A, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2133
      if ( res /= 2133) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Ha, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1631
      if ( res /= 1631) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_A, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",679
      if ( res /= 679) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1069
      if ( res /= 1069) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_Hh, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2659
      if ( res /= 2659) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1977
      if ( res /= 1977) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1209
      if ( res /= 1209) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2931
      if ( res /= 2931) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghA, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2999
      if ( res /= 2999) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1145
      if ( res /= 1145) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WMinus, P_WPlus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2650
      if ( res /= 2650) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2759
      if ( res /= 2759) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2056
      if ( res /= 2056) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",589
      if ( res /= 589) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_Hl, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",671
      if ( res /= 671) then
        stop
      end if
      call createParticleConfig(P_c, P_Hh, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1895
      if ( res /= 1895) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1602
      if ( res /= 1602) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2221
      if ( res /= 2221) then
        stop
      end if
      call createParticleConfig(P_Hh, P_g, P_Hh, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3616
      if ( res /= 3616) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2883
      if ( res /= 2883) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1105
      if ( res /= 1105) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_ghWpAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",905
      if ( res /= 905) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2263
      if ( res /= 2263) then
        stop
      end if
      call createParticleConfig(P_ghA, P_ghWmAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",197
      if ( res /= 197) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3117
      if ( res /= 3117) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2394
      if ( res /= 2394) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_g, P_g, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3707
      if ( res /= 3707) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3024
      if ( res /= 3024) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2804
      if ( res /= 2804) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",402
      if ( res /= 402) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WMinus, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",583
      if ( res /= 583) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",659
      if ( res /= 659) then
        stop
      end if
      call createParticleConfig(P_Hh, P_s, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",403
      if ( res /= 403) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3306
      if ( res /= 3306) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3353
      if ( res /= 3353) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3207
      if ( res /= 3207) then
        stop
      end if
      call createParticleConfig(P_t, P_tAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2681
      if ( res /= 2681) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_uAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2339
      if ( res /= 2339) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_A, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3080
      if ( res /= 3080) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2643
      if ( res /= 2643) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Z, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3773
      if ( res /= 3773) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3686
      if ( res /= 3686) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3391
      if ( res /= 3391) then
        stop
      end if
      call createParticleConfig(P_Ha, P_ghWp, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2831
      if ( res /= 2831) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_Ha, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2473
      if ( res /= 2473) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_tauPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",581
      if ( res /= 581) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1200
      if ( res /= 1200) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",950
      if ( res /= 950) then
        stop
      end if
      call createParticleConfig(P_Ha, P_G0, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3648
      if ( res /= 3648) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1126
      if ( res /= 1126) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WPlus, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",396
      if ( res /= 396) then
        stop
      end if
      call createParticleConfig(P_Hl, P_G0, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2682
      if ( res /= 2682) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2149
      if ( res /= 2149) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1112
      if ( res /= 1112) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2996
      if ( res /= 2996) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_g, P_g, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3854
      if ( res /= 3854) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2350
      if ( res /= 2350) then
        stop
      end if
      call createParticleConfig(P_Z, P_nu_e, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2496
      if ( res /= 2496) then
        stop
      end if
      call createParticleConfig(P_b, P_bAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1513
      if ( res /= 1513) then
        stop
      end if
      call createParticleConfig(P_Hh, P_g, P_Hl, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3829
      if ( res /= 3829) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2314
      if ( res /= 2314) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_Hh, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",263
      if ( res /= 263) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1280
      if ( res /= 1280) then
        stop
      end if
      call createParticleConfig(P_A, P_muMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1290
      if ( res /= 1290) then
        stop
      end if
      call createParticleConfig(P_g, P_Ha, P_g, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3785
      if ( res /= 3785) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3163
      if ( res /= 3163) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hh, P_Hl, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3673
      if ( res /= 3673) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WMinus, P_GPlus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2460
      if ( res /= 2460) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3720
      if ( res /= 3720) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1865
      if ( res /= 1865) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3614
      if ( res /= 3614) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1599
      if ( res /= 1599) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3267
      if ( res /= 3267) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3794
      if ( res /= 3794) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3253
      if ( res /= 3253) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1601
      if ( res /= 1601) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3366
      if ( res /= 3366) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2726
      if ( res /= 2726) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_Hl, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2084
      if ( res /= 2084) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Ha, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",618
      if ( res /= 618) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_Z, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",539
      if ( res /= 539) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1957
      if ( res /= 1957) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",642
      if ( res /= 642) then
        stop
      end if
      call createParticleConfig(P_Z, P_ghWmAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2411
      if ( res /= 2411) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_Z, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",649
      if ( res /= 649) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1976
      if ( res /= 1976) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3181
      if ( res /= 3181) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2167
      if ( res /= 2167) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3120
      if ( res /= 3120) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",358
      if ( res /= 358) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3422
      if ( res /= 3422) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_ghZ, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1462
      if ( res /= 1462) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GMinus, P_GPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1744
      if ( res /= 1744) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2549
      if ( res /= 2549) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_Z, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1826
      if ( res /= 1826) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hl, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2331
      if ( res /= 2331) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",852
      if ( res /= 852) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_ghWmAnti, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2855
      if ( res /= 2855) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_u, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1812
      if ( res /= 1812) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3510
      if ( res /= 3510) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_d, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",948
      if ( res /= 948) then
        stop
      end if
      call createParticleConfig(P_s, P_sAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1087
      if ( res /= 1087) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",421
      if ( res /= 421) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3790
      if ( res /= 3790) then
        stop
      end if
      call createParticleConfig(P_u, P_uAnti, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",21
      if ( res /= 21) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",793
      if ( res /= 793) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1587
      if ( res /= 1587) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3873
      if ( res /= 3873) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",725
      if ( res /= 725) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",990
      if ( res /= 990) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_Hl, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1659
      if ( res /= 1659) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2267
      if ( res /= 2267) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_nu_eAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1327
      if ( res /= 1327) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WPlus, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3545
      if ( res /= 3545) then
        stop
      end if
      call createParticleConfig(P_Hh, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3577
      if ( res /= 3577) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_WPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2697
      if ( res /= 2697) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hh, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3419
      if ( res /= 3419) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2041
      if ( res /= 2041) then
        stop
      end if
      call createParticleConfig(P_Z, P_g, P_g, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3783
      if ( res /= 3783) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2174
      if ( res /= 2174) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1216
      if ( res /= 1216) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WMinus, P_WPlus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1618
      if ( res /= 1618) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2816
      if ( res /= 2816) then
        stop
      end if
      call createParticleConfig(P_Z, P_t, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",755
      if ( res /= 755) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_ePlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",629
      if ( res /= 629) then
        stop
      end if
      call createParticleConfig(P_d, P_G0, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1810
      if ( res /= 1810) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3450
      if ( res /= 3450) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_Ha, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3220
      if ( res /= 3220) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2527
      if ( res /= 2527) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_Ha, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1255
      if ( res /= 1255) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",298
      if ( res /= 298) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2818
      if ( res /= 2818) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3280
      if ( res /= 3280) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Ha, P_Ha, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1356
      if ( res /= 1356) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_c, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",278
      if ( res /= 278) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_b, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",492
      if ( res /= 492) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",620
      if ( res /= 620) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_Hl, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1908
      if ( res /= 1908) then
        stop
      end if
      call createParticleConfig(P_Hh, P_g, P_g, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3756
      if ( res /= 3756) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3
      if ( res /= 3) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3035
      if ( res /= 3035) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",598
      if ( res /= 598) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2533
      if ( res /= 2533) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1187
      if ( res /= 1187) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1179
      if ( res /= 1179) then
        stop
      end if
      call createParticleConfig(P_d, P_dAnti, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2636
      if ( res /= 2636) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_Ha, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",57
      if ( res /= 57) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2419
      if ( res /= 2419) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",24
      if ( res /= 24) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_nu_tau, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1334
      if ( res /= 1334) then
        stop
      end if
      call createParticleConfig(P_b, P_g, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1196
      if ( res /= 1196) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3164
      if ( res /= 3164) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",227
      if ( res /= 227) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_Hh, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",536
      if ( res /= 536) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1478
      if ( res /= 1478) then
        stop
      end if
      call createParticleConfig(P_A, P_HPlus, P_WMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2148
      if ( res /= 2148) then
        stop
      end if
      call createParticleConfig(P_ghA, P_GMinus, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",345
      if ( res /= 345) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_b, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",689
      if ( res /= 689) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_G0, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1837
      if ( res /= 1837) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_HPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2006
      if ( res /= 2006) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2874
      if ( res /= 2874) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1517
      if ( res /= 1517) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",284
      if ( res /= 284) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",723
      if ( res /= 723) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3209
      if ( res /= 3209) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",975
      if ( res /= 975) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3241
      if ( res /= 3241) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghWmAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",842
      if ( res /= 842) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_HMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3113
      if ( res /= 3113) then
        stop
      end if
      call createParticleConfig(P_g, P_Hh, P_Hl, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3670
      if ( res /= 3670) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Ha, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",866
      if ( res /= 866) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_HPlus, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1753
      if ( res /= 1753) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_tauPlus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2620
      if ( res /= 2620) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HPlus, P_HMinus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2309
      if ( res /= 2309) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_nu_tauAnti, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2700
      if ( res /= 2700) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1294
      if ( res /= 1294) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",255
      if ( res /= 255) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3083
      if ( res /= 3083) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_GMinus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2088
      if ( res /= 2088) then
        stop
      end if
      call createParticleConfig(P_Hh, P_HMinus, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2294
      if ( res /= 2294) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1345
      if ( res /= 1345) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",167
      if ( res /= 167) then
        stop
      end if
      call createParticleConfig(P_t, P_HMinus, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",754
      if ( res /= 754) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1991
      if ( res /= 1991) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_GMinus, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1191
      if ( res /= 1191) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1633
      if ( res /= 1633) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2986
      if ( res /= 2986) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1914
      if ( res /= 1914) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_GPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1467
      if ( res /= 1467) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1896
      if ( res /= 1896) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Hl, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2581
      if ( res /= 2581) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_Z, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2259
      if ( res /= 2259) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_HMinus, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2845
      if ( res /= 2845) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",193
      if ( res /= 193) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1626
      if ( res /= 1626) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Hh, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1535
      if ( res /= 1535) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2621
      if ( res /= 2621) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_g, P_g, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3852
      if ( res /= 3852) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2956
      if ( res /= 2956) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2010
      if ( res /= 2010) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",401
      if ( res /= 401) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_Z, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",494
      if ( res /= 494) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3548
      if ( res /= 3548) then
        stop
      end if
      call createParticleConfig(P_Hh, P_GMinus, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3146
      if ( res /= 3146) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3221
      if ( res /= 3221) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3631
      if ( res /= 3631) then
        stop
      end if
      call createParticleConfig(P_Ha, P_A, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3865
      if ( res /= 3865) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",215
      if ( res /= 215) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1788
      if ( res /= 1788) then
        stop
      end if
      call createParticleConfig(P_Hl, P_GPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1889
      if ( res /= 1889) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",892
      if ( res /= 892) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_WMinus, P_A, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1161
      if ( res /= 1161) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",563
      if ( res /= 563) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HMinus, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2264
      if ( res /= 2264) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_WPlus, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3051
      if ( res /= 3051) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_Ha, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",605
      if ( res /= 605) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_GPlus, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",348
      if ( res /= 348) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1616
      if ( res /= 1616) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_muMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",233
      if ( res /= 233) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_G0, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1671
      if ( res /= 1671) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",448
      if ( res /= 448) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3482
      if ( res /= 3482) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2214
      if ( res /= 2214) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3330
      if ( res /= 3330) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3567
      if ( res /= 3567) then
        stop
      end if
      call createParticleConfig(P_g, P_dAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1488
      if ( res /= 1488) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HPlus, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1454
      if ( res /= 1454) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_t, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1694
      if ( res /= 1694) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_GMinus, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1331
      if ( res /= 1331) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_Ha, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1299
      if ( res /= 1299) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3240
      if ( res /= 3240) then
        stop
      end if
      call createParticleConfig(P_d, P_Z, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",342
      if ( res /= 342) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_Hh, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1973
      if ( res /= 1973) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_GMinus, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",724
      if ( res /= 724) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2438
      if ( res /= 2438) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",174
      if ( res /= 174) then
        stop
      end if
      call createParticleConfig(P_G0, P_ghWp, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2224
      if ( res /= 2224) then
        stop
      end if
      call createParticleConfig(P_t, P_A, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",632
      if ( res /= 632) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",772
      if ( res /= 772) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3074
      if ( res /= 3074) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_Hh, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",257
      if ( res /= 257) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2766
      if ( res /= 2766) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Z, P_WPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2019
      if ( res /= 2019) then
        stop
      end if
      call createParticleConfig(P_A, P_Hl, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2995
      if ( res /= 2995) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",784
      if ( res /= 784) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WPlus, P_WMinus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3127
      if ( res /= 3127) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2860
      if ( res /= 2860) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_G0, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1770
      if ( res /= 1770) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_sAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2071
      if ( res /= 2071) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1004
      if ( res /= 1004) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2655
      if ( res /= 2655) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",127
      if ( res /= 127) then
        stop
      end if
      call createParticleConfig(P_Hl, P_ePlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",509
      if ( res /= 509) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_G0, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",52
      if ( res /= 52) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_WPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2876
      if ( res /= 2876) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hl, P_WMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1127
      if ( res /= 1127) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HMinus, P_Z, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2699
      if ( res /= 2699) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3151
      if ( res /= 3151) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",989
      if ( res /= 989) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3368
      if ( res /= 3368) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_GMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",855
      if ( res /= 855) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1591
      if ( res /= 1591) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Ha, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2451
      if ( res /= 2451) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3870
      if ( res /= 3870) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",235
      if ( res /= 235) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2140
      if ( res /= 2140) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3312
      if ( res /= 3312) then
        stop
      end if
      call createParticleConfig(P_d, P_dAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2608
      if ( res /= 2608) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_Z, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2344
      if ( res /= 2344) then
        stop
      end if
      call createParticleConfig(P_Ha, P_ghWpAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2869
      if ( res /= 2869) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_GMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1455
      if ( res /= 1455) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Ha, P_HMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1211
      if ( res /= 1211) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_WPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3227
      if ( res /= 3227) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_HMinus, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1704
      if ( res /= 1704) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hl, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2086
      if ( res /= 2086) then
        stop
      end if
      call createParticleConfig(P_Z, P_Hl, P_A, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3656
      if ( res /= 3656) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1450
      if ( res /= 1450) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hh, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2607
      if ( res /= 2607) then
        stop
      end if
      call createParticleConfig(P_Ha, P_WMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1520
      if ( res /= 1520) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",573
      if ( res /= 573) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1309
      if ( res /= 1309) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Hh, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",658
      if ( res /= 658) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_ghWp, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1475
      if ( res /= 1475) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1921
      if ( res /= 1921) then
        stop
      end if
      call createParticleConfig(P_g, P_WPlus, P_g, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3599
      if ( res /= 3599) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hh, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2718
      if ( res /= 2718) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hh, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2192
      if ( res /= 2192) then
        stop
      end if
      call createParticleConfig(P_A, P_HMinus, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2447
      if ( res /= 2447) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2739
      if ( res /= 2739) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2877
      if ( res /= 2877) then
        stop
      end if
      call createParticleConfig(P_Hl, P_Hl, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",28
      if ( res /= 28) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_G0, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2305
      if ( res /= 2305) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2157
      if ( res /= 2157) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",641
      if ( res /= 641) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_Ha, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1603
      if ( res /= 1603) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hh, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",185
      if ( res /= 185) then
        stop
      end if
      call createParticleConfig(P_A, P_Ha, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3839
      if ( res /= 3839) then
        stop
      end if
      call createParticleConfig(P_g, P_ghGAnti, P_ghG, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",706
      if ( res /= 706) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_G0, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1337
      if ( res /= 1337) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_muPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",178
      if ( res /= 178) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_Z, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1592
      if ( res /= 1592) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_GPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2642
      if ( res /= 2642) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_HMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1352
      if ( res /= 1352) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Z, P_Ha, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2273
      if ( res /= 2273) then
        stop
      end if
      call createParticleConfig(P_G0, P_Ha, P_Hh, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",760
      if ( res /= 760) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_cAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",932
      if ( res /= 932) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1779
      if ( res /= 1779) then
        stop
      end if
      call createParticleConfig(P_Z, P_HMinus, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3140
      if ( res /= 3140) then
        stop
      end if
      call createParticleConfig(P_Hh, P_WMinus, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1340
      if ( res /= 1340) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2673
      if ( res /= 2673) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_HMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3091
      if ( res /= 3091) then
        stop
      end if
      call createParticleConfig(P_Hh, P_G0, P_HPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2772
      if ( res /= 2772) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghAAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2542
      if ( res /= 2542) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3012
      if ( res /= 3012) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_g, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1572
      if ( res /= 1572) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1205
      if ( res /= 1205) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3141
      if ( res /= 3141) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2989
      if ( res /= 2989) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_A, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3447
      if ( res /= 3447) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3799
      if ( res /= 3799) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_HMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2326
      if ( res /= 2326) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_GPlus, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1650
      if ( res /= 1650) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1959
      if ( res /= 1959) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_muMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",395
      if ( res /= 395) then
        stop
      end if
      call createParticleConfig(P_G0, P_HPlus, P_Hh, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3262
      if ( res /= 3262) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_Ha, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3296
      if ( res /= 3296) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_t, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1382
      if ( res /= 1382) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_s, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",893
      if ( res /= 893) then
        stop
      end if
      call createParticleConfig(P_Z, P_Ha, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3628
      if ( res /= 3628) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_Ha, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3283
      if ( res /= 3283) then
        stop
      end if
      call createParticleConfig(P_Hl, P_HMinus, P_HPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2763
      if ( res /= 2763) then
        stop
      end if
      call createParticleConfig(P_G0, P_HMinus, P_Hh, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2934
      if ( res /= 2934) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_Hl, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1231
      if ( res /= 1231) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2415
      if ( res /= 2415) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_Ha, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2779
      if ( res /= 2779) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Hh, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1570
      if ( res /= 1570) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_Ha, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",737
      if ( res /= 737) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_HPlus, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1822
      if ( res /= 1822) then
        stop
      end if
      call createParticleConfig(P_Hl, P_s, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1135
      if ( res /= 1135) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3572
      if ( res /= 3572) then
        stop
      end if
      call createParticleConfig(P_Ha, P_Ha, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3108
      if ( res /= 3108) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Hl, P_GMinus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",791
      if ( res /= 791) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1893
      if ( res /= 1893) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hl, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2072
      if ( res /= 2072) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_WMinus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2227
      if ( res /= 2227) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_G0, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",503
      if ( res /= 503) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1315
      if ( res /= 1315) then
        stop
      end if
      call createParticleConfig(P_G0, P_Hl, P_GPlus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2586
      if ( res /= 2586) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Hh, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",415
      if ( res /= 415) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_A, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2756
      if ( res /= 2756) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_eMinus, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",254
      if ( res /= 254) then
        stop
      end if
      call createParticleConfig(P_Hl, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2337
      if ( res /= 2337) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1506
      if ( res /= 1506) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_Hh, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1146
      if ( res /= 1146) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Hl, P_Hl, P_HPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1167
      if ( res /= 1167) then
        stop
      end if
      call createParticleConfig(P_g, P_Hh, P_Hh, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3721
      if ( res /= 3721) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_WPlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2666
      if ( res /= 2666) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Hl, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1738
      if ( res /= 1738) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_GMinus, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1867
      if ( res /= 1867) then
        stop
      end if
      call createParticleConfig(P_g, P_HMinus, P_GPlus, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3684
      if ( res /= 3684) then
        stop
      end if
      call createParticleConfig(P_Ha, P_GMinus, P_HPlus, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",356
      if ( res /= 356) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Hl, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1606
      if ( res /= 1606) then
        stop
      end if
      call createParticleConfig(P_G0, P_ePlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2049
      if ( res /= 2049) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_Hh, P_HPlus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2597
      if ( res /= 2597) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Ha, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2791
      if ( res /= 2791) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_Hl, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2136
      if ( res /= 2136) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3700
      if ( res /= 3700) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_HPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2847
      if ( res /= 2847) then
        stop
      end if
      call createParticleConfig(P_HPlus, P_Ha, P_HMinus, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2838
      if ( res /= 2838) then
        stop
      end if
      call createParticleConfig(P_Ha, P_HPlus, P_HMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",715
      if ( res /= 715) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_HMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3432
      if ( res /= 3432) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_HPlus, P_G0, P_Hh, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1556
      if ( res /= 1556) then
        stop
      end if
      call createParticleConfig(P_HMinus, P_G0, P_HPlus, P_Ha, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1710
      if ( res /= 1710) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_HPlus, P_Hh, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1182
      if ( res /= 1182) then
        stop
      end if
      call createParticleConfig(P_Hl, P_muPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1612
      if ( res /= 1612) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Z, P_A, P_Hl, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3627
      if ( res /= 3627) then
        stop
      end if
      call createParticleConfig(P_Hh, P_Hh, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2497
      if ( res /= 2497) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Hl, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",810
      if ( res /= 810) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3828
      if ( res /= 3828) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_HPlus, P_WMinus, P_HMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1938
      if ( res /= 1938) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1360
      if ( res /= 1360) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1116
      if ( res /= 1116) then
        stop
      end if
    end subroutine check_vertices_mdl

    subroutine get_vertex_lorentz_rank_mdl(ty,cc,mr)
      integer, intent(in) :: ty
      logical, intent(in) :: cc(0:)
      integer, intent(out) :: mr
      select case(ty)
      case(4)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(5)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(9)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(17)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(18)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(19)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(20)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(22)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(23)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(24)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(25)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(27)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(28)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(44)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(45)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(46)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(47)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(48)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(49)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(50)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(52)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(53)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(54)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(55)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(59)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(68)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(72)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(75)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(76)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(78)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case default
        mr = 0
      end select 
    end subroutine get_vertex_lorentz_rank_mdl
end module class_vertices
